/*
 * jQuery Easing v1.3 - http://gsgd.co.uk/sandbox/jquery/easing/
 *
 * Uses the built in easing capabilities added In jQuery 1.1
 * to offer multiple easing options
 *
 * TERMS OF USE - jQuery Easing
 * 
 * Open source under the BSD License. 
 * 
 * Copyright © 2008 George McGinley Smith
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without modification, 
 * are permitted provided that the following conditions are met:
 * 
 * Redistributions of source code must retain the above copyright notice, this list of 
 * conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright notice, this list 
 * of conditions and the following disclaimer in the documentation and/or other materials 
 * provided with the distribution.
 * 
 * Neither the name of the author nor the names of contributors may be used to endorse 
 * or promote products derived from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY 
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 *  COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 *  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
 *  GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 *  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED 
 * OF THE POSSIBILITY OF SUCH DAMAGE. 
 *
*/

// t: current time, b: begInnIng value, c: change In value, d: duration
jQuery.easing['jswing'] = jQuery.easing['swing'];

jQuery.extend( jQuery.easing,
{
	def: 'easeOutQuad',
	swing: function (x, t, b, c, d) {
		//alert(jQuery.easing.default);
		return jQuery.easing[jQuery.easing.def](x, t, b, c, d);
	},
	easeInQuad: function (x, t, b, c, d) {
		return c*(t/=d)*t + b;
	},
	easeOutQuad: function (x, t, b, c, d) {
		return -c *(t/=d)*(t-2) + b;
	},
	easeInOutQuad: function (x, t, b, c, d) {
		if ((t/=d/2) < 1) return c/2*t*t + b;
		return -c/2 * ((--t)*(t-2) - 1) + b;
	},
	easeInCubic: function (x, t, b, c, d) {
		return c*(t/=d)*t*t + b;
	},
	easeOutCubic: function (x, t, b, c, d) {
		return c*((t=t/d-1)*t*t + 1) + b;
	},
	easeInOutCubic: function (x, t, b, c, d) {
		if ((t/=d/2) < 1) return c/2*t*t*t + b;
		return c/2*((t-=2)*t*t + 2) + b;
	},
	easeInQuart: function (x, t, b, c, d) {
		return c*(t/=d)*t*t*t + b;
	},
	easeOutQuart: function (x, t, b, c, d) {
		return -c * ((t=t/d-1)*t*t*t - 1) + b;
	},
	easeInOutQuart: function (x, t, b, c, d) {
		if ((t/=d/2) < 1) return c/2*t*t*t*t + b;
		return -c/2 * ((t-=2)*t*t*t - 2) + b;
	},
	easeInQuint: function (x, t, b, c, d) {
		return c*(t/=d)*t*t*t*t + b;
	},
	easeOutQuint: function (x, t, b, c, d) {
		return c*((t=t/d-1)*t*t*t*t + 1) + b;
	},
	easeInOutQuint: function (x, t, b, c, d) {
		if ((t/=d/2) < 1) return c/2*t*t*t*t*t + b;
		return c/2*((t-=2)*t*t*t*t + 2) + b;
	},
	easeInSine: function (x, t, b, c, d) {
		return -c * Math.cos(t/d * (Math.PI/2)) + c + b;
	},
	easeOutSine: function (x, t, b, c, d) {
		return c * Math.sin(t/d * (Math.PI/2)) + b;
	},
	easeInOutSine: function (x, t, b, c, d) {
		return -c/2 * (Math.cos(Math.PI*t/d) - 1) + b;
	},
	easeInExpo: function (x, t, b, c, d) {
		return (t==0) ? b : c * Math.pow(2, 10 * (t/d - 1)) + b;
	},
	easeOutExpo: function (x, t, b, c, d) {
		return (t==d) ? b+c : c * (-Math.pow(2, -10 * t/d) + 1) + b;
	},
	easeInOutExpo: function (x, t, b, c, d) {
		if (t==0) return b;
		if (t==d) return b+c;
		if ((t/=d/2) < 1) return c/2 * Math.pow(2, 10 * (t - 1)) + b;
		return c/2 * (-Math.pow(2, -10 * --t) + 2) + b;
	},
	easeInCirc: function (x, t, b, c, d) {
		return -c * (Math.sqrt(1 - (t/=d)*t) - 1) + b;
	},
	easeOutCirc: function (x, t, b, c, d) {
		return c * Math.sqrt(1 - (t=t/d-1)*t) + b;
	},
	easeInOutCirc: function (x, t, b, c, d) {
		if ((t/=d/2) < 1) return -c/2 * (Math.sqrt(1 - t*t) - 1) + b;
		return c/2 * (Math.sqrt(1 - (t-=2)*t) + 1) + b;
	},
	easeInElastic: function (x, t, b, c, d) {
		var s=1.70158;var p=0;var a=c;
		if (t==0) return b;  if ((t/=d)==1) return b+c;  if (!p) p=d*.3;
		if (a < Math.abs(c)) { a=c; var s=p/4; }
		else var s = p/(2*Math.PI) * Math.asin (c/a);
		return -(a*Math.pow(2,10*(t-=1)) * Math.sin( (t*d-s)*(2*Math.PI)/p )) + b;
	},
	easeOutElastic: function (x, t, b, c, d) {
		var s=1.70158;var p=0;var a=c;
		if (t==0) return b;  if ((t/=d)==1) return b+c;  if (!p) p=d*.3;
		if (a < Math.abs(c)) { a=c; var s=p/4; }
		else var s = p/(2*Math.PI) * Math.asin (c/a);
		return a*Math.pow(2,-10*t) * Math.sin( (t*d-s)*(2*Math.PI)/p ) + c + b;
	},
	easeInOutElastic: function (x, t, b, c, d) {
		var s=1.70158;var p=0;var a=c;
		if (t==0) return b;  if ((t/=d/2)==2) return b+c;  if (!p) p=d*(.3*1.5);
		if (a < Math.abs(c)) { a=c; var s=p/4; }
		else var s = p/(2*Math.PI) * Math.asin (c/a);
		if (t < 1) return -.5*(a*Math.pow(2,10*(t-=1)) * Math.sin( (t*d-s)*(2*Math.PI)/p )) + b;
		return a*Math.pow(2,-10*(t-=1)) * Math.sin( (t*d-s)*(2*Math.PI)/p )*.5 + c + b;
	},
	easeInBack: function (x, t, b, c, d, s) {
		if (s == undefined) s = 1.70158;
		return c*(t/=d)*t*((s+1)*t - s) + b;
	},
	easeOutBack: function (x, t, b, c, d, s) {
		if (s == undefined) s = 1.70158;
		return c*((t=t/d-1)*t*((s+1)*t + s) + 1) + b;
	},
	easeInOutBack: function (x, t, b, c, d, s) {
		if (s == undefined) s = 1.70158; 
		if ((t/=d/2) < 1) return c/2*(t*t*(((s*=(1.525))+1)*t - s)) + b;
		return c/2*((t-=2)*t*(((s*=(1.525))+1)*t + s) + 2) + b;
	},
	easeInBounce: function (x, t, b, c, d) {
		return c - jQuery.easing.easeOutBounce (x, d-t, 0, c, d) + b;
	},
	easeOutBounce: function (x, t, b, c, d) {
		if ((t/=d) < (1/2.75)) {
			return c*(7.5625*t*t) + b;
		} else if (t < (2/2.75)) {
			return c*(7.5625*(t-=(1.5/2.75))*t + .75) + b;
		} else if (t < (2.5/2.75)) {
			return c*(7.5625*(t-=(2.25/2.75))*t + .9375) + b;
		} else {
			return c*(7.5625*(t-=(2.625/2.75))*t + .984375) + b;
		}
	},
	easeInOutBounce: function (x, t, b, c, d) {
		if (t < d/2) return jQuery.easing.easeInBounce (x, t*2, 0, c, d) * .5 + b;
		return jQuery.easing.easeOutBounce (x, t*2-d, 0, c, d) * .5 + c*.5 + b;
	}
});

/*
 *
 * TERMS OF USE - EASING EQUATIONS
 * 
 * Open source under the BSD License. 
 * 
 * Copyright © 2001 Robert Penner
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without modification, 
 * are permitted provided that the following conditions are met:
 * 
 * Redistributions of source code must retain the above copyright notice, this list of 
 * conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright notice, this list 
 * of conditions and the following disclaimer in the documentation and/or other materials 
 * provided with the distribution.
 * 
 * Neither the name of the author nor the names of contributors may be used to endorse 
 * or promote products derived from this software without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY 
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 *  COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 *  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
 *  GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 *  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED 
 * OF THE POSSIBILITY OF SUCH DAMAGE. 
 *
 */
function onYouTubePlayerAPIReady(){mejs.YouTubeApi.iFrameReady()}function onYouTubePlayerReady(e){mejs.YouTubeApi.flashReady(e)}!function(e){var t=new Array,i=new Array,o=function(){},n=0,s={splashVPos:"35%",loaderVPos:"75%",splashID:"#jpreContent",showSplash:!0,showPercentage:!0,autoClose:!0,closeBtnText:"Start!",onetimeLoad:!1,debugMode:!1,splashFunction:function(){}},r=function(){if(s.onetimeLoad){for(var e,t=document.cookie.split("; "),i=0;e=t[i]&&t[i].split("=");i++)if("jpreLoader"===e.shift())return e.join("=");return!1}return!1},a=function(e){if(s.onetimeLoad){var t=new Date;t.setDate(t.getDate()+e);var i=null==e?"":"expires="+t.toUTCString();document.cookie="jpreLoader=loaded; "+i}},l=function(){if(jOverlay=e("<div></div>").attr("id","jpreOverlay").css({position:"fixed",top:0,left:0,width:"100%",height:"100%",zIndex:9999999}).appendTo("body"),s.showSplash){jContent=e("<div></div>").attr("id","jpreSlide").appendTo(jOverlay);var t=e(window).width()-e(jContent).width();e(jContent).css({position:"absolute",top:s.splashVPos,left:Math.round(50/e(window).width()*t)+"%"}),e(jContent).html(e(s.splashID).wrap("<div/>").parent().html()),e(s.splashID).remove(),s.splashFunction()}jLoader=e("<div></div>").attr("id","jpreLoader").appendTo(jOverlay);var i=e(window).width()-e(jLoader).width();e(jLoader).css({position:"absolute",top:s.loaderVPos,left:Math.round(50/e(window).width()*i)+"%"}),jBar=e("<div></div>").attr("id","jpreBar").css({width:"0%",height:"100%"}).appendTo(jLoader),s.showPercentage&&(jPer=e("<div></div>").attr("id","jprePercentage").css({position:"relative",height:"100%"}).appendTo(jLoader).html("Loading...")),s.autoclose||(jButton=e("<div></div>").attr("id","jpreButton").on("click",function(){m()}).css({position:"relative",height:"100%"}).appendTo(jLoader).text(s.closeBtnText).hide())},d=function(i){e(i).find("*:not(script)").each(function(){var i="";if(-1==e(this).css("background-image").indexOf("none")&&-1==e(this).css("background-image").indexOf("-gradient")){if(i=e(this).css("background-image"),-1!=i.indexOf("url")){var o=i.match(/url\((.*?)\)/);i=o[1].replace(/\"/g,"")}}else"img"==e(this).get(0).nodeName.toLowerCase()&&"undefined"!=typeof e(this).attr("src")&&(i=e(this).attr("src"));i.length>0&&t.push(i)})},c=function(){for(var e=0;e<t.length;e++)u(t[e])},u=function(t){var o=new Image;e(o).load(function(){h()}).error(function(){i.push(e(this).attr("src")),h()}).attr("src",t)},h=function(){n++;var i=Math.round(n/t.length*100);if(e(jBar).stop().animate({width:i+"%"},500,"linear"),s.showPercentage&&e(jPer).text(i+"%"),n>=t.length){if(n=t.length,a(),s.showPercentage&&e(jPer).text("100%"),s.debugMode){p()}e(jBar).stop().animate({width:"100%"},500,"linear",function(){s.autoClose?m():e(jButton).fadeIn(1e3)})}},m=function(){e(jOverlay).fadeOut(800,function(){e(jOverlay).remove(),o()})},p=function(){if(i.length>0){var e="ERROR - IMAGE FILES MISSING!!!\n\r";e+=i.length+" image files cound not be found. \n\r",e+="Please check your image paths and filenames:\n\r";for(var t=0;t<i.length;t++)e+="- "+i[t]+"\n\r";return!0}return!1};e.fn.jpreLoader=function(t,i){return t&&e.extend(s,t),"function"==typeof i&&(o=i),e("body").css({display:"block"}),this.each(function(){r()?(e(s.splashID).remove(),o()):(l(),d(this),c())})}}(jQuery),function(e){"use strict";function t(e,t){for(var i in t)t.hasOwnProperty(i)&&(e[i]=t[i]);return e}function i(e,i){this.button=e,this.options=t({},this.options),t(this.options,i),this._init()}Modernizr.addTest("csstransformspreserve3d",function(){var t,i=Modernizr.prefixed("transformStyle"),o="preserve-3d";return i?(i=i.replace(/([A-Z])/g,function(e,t){return"-"+t.toLowerCase()}).replace(/^ms-/,"-ms-"),Modernizr.testStyles("#modernizr{"+i+":"+o+";}",function(o){t=e.getComputedStyle?getComputedStyle(o,null).getPropertyValue(i):""}),t===o):!1});var o={transitions:Modernizr.csstransitions,transforms3d:Modernizr.csstransforms3d&&Modernizr.csstransformspreserve3d},n={WebkitTransition:"webkitTransitionEnd",MozTransition:"transitionend",OTransition:"oTransitionEnd",msTransition:"MSTransitionEnd",transition:"transitionend"},s=n[Modernizr.prefixed("transition")];i.prototype.options={statusTime:1500},i.prototype._init=function(){this._validate(),this._create(),this._initEvents()},i.prototype._validate=function(){null===this.button.getAttribute("data-style")&&this.button.setAttribute("data-style","fill"),null===this.button.getAttribute("data-vertical")&&null===this.button.getAttribute("data-horizontal")&&this.button.setAttribute("data-horizontal",""),o.transforms3d||null===this.button.getAttribute("data-perspective")||(this.button.removeAttribute("data-perspective"),this.button.setAttribute("data-style","fill"),this.button.removeAttribute("data-vertical"),this.button.setAttribute("data-horizontal",""))},i.prototype._create=function(){var e=document.createElement("span");e.className="content",e.innerHTML=this.button.innerHTML;var t=document.createElement("span");t.className="progress";var i=document.createElement("span");if(i.className="progress-inner",t.appendChild(i),this.button.innerHTML="",null!==this.button.getAttribute("data-perspective")){var o=document.createElement("span");o.className="progress-wrap",o.appendChild(e),o.appendChild(t),this.button.appendChild(o)}else this.button.appendChild(e),this.button.appendChild(t);this.progress=i,null!==this.button.getAttribute("data-horizontal")?this.progressProp="width":null!==this.button.getAttribute("data-vertical")&&(this.progressProp="height"),this._enable()},i.prototype._setProgress=function(e){this.progress.style[this.progressProp]=100*e+"%"},i.prototype._initEvents=function(){var e=this;this.button.addEventListener("click",function(){e.button.setAttribute("disabled",""),classie.remove(e.progress,"notransition"),classie.add(this,"state-loading"),setTimeout(function(){if("function"==typeof e.options.callback)e.options.callback(e);else{e._setProgress(1);var t=function(i){o.transitions&&i.propertyName!==e.progressProp||(this.removeEventListener(s,t),e._stop())};o.transitions?e.progress.addEventListener(s,t):t.call()}},"fill"===e.button.getAttribute("data-style")||"top-line"===e.button.getAttribute("data-style")||"lateral-lines"===e.button.getAttribute("data-style")?0:200)})},i.prototype._stop=function(e){var t=this;setTimeout(function(){t.progress.style.opacity=0;var i=function(e){o.transitions&&"opacity"!==e.propertyName||(this.removeEventListener(s,i),classie.add(t.progress,"notransition"),t.progress.style[t.progressProp]="0%",t.progress.style.opacity=1)};if(o.transitions?t.progress.addEventListener(s,i):i.call(),"number"==typeof e){var n=e>=0?"state-success":"state-error";classie.add(t.button,n),setTimeout(function(){classie.remove(t.button,n),t._enable()},t.options.statusTime)}else t._enable();classie.remove(t.button,"state-loading")},100)},i.prototype._enable=function(){this.button.removeAttribute("disabled")},e.ProgressButton=i}(window),function(e){var t,i,o,n,s,r,a,l="Close",d="BeforeClose",c="AfterClose",u="BeforeAppend",h="MarkupParse",m="Open",p="Change",f="mfp",g="."+f,v="mfp-ready",y="mfp-removing",w="mfp-prevent-close",b=function(){},x=!!window.jQuery,T=e(window),S=function(e,i){t.ev.on(f+e+g,i)},C=function(t,i,o,n){var s=document.createElement("div");return s.className="mfp-"+t,o&&(s.innerHTML=o),n?i&&i.appendChild(s):(s=e(s),i&&s.appendTo(i)),s},j=function(i,o){t.ev.triggerHandler(f+i,o),t.st.callbacks&&(i=i.charAt(0).toLowerCase()+i.slice(1),t.st.callbacks[i]&&t.st.callbacks[i].apply(t,e.isArray(o)?o:[o]))},k=function(i){return i===a&&t.currTemplate.closeBtn||(t.currTemplate.closeBtn=e(t.st.closeMarkup.replace("%title%",t.st.tClose)),a=i),t.currTemplate.closeBtn},M=function(){e.magnificPopup.instance||(t=new b,t.init(),e.magnificPopup.instance=t)},E=function(){var e=document.createElement("p").style,t=["ms","O","Moz","Webkit"];if(void 0!==e.transition)return!0;for(;t.length;)if(t.pop()+"Transition"in e)return!0;return!1};b.prototype={constructor:b,init:function(){var i=navigator.appVersion;t.isIE7=-1!==i.indexOf("MSIE 7."),t.isIE8=-1!==i.indexOf("MSIE 8."),t.isLowIE=t.isIE7||t.isIE8,t.isAndroid=/android/gi.test(i),t.isIOS=/iphone|ipad|ipod/gi.test(i),t.supportsTransition=E(),t.probablyMobile=t.isAndroid||t.isIOS||/(Opera Mini)|Kindle|webOS|BlackBerry|(Opera Mobi)|(Windows Phone)|IEMobile/i.test(navigator.userAgent),o=e(document.body),n=e(document),t.popupsCache={}},open:function(i){var o;if(i.isObj===!1){t.items=i.items.toArray(),t.index=0;var s,a=i.items;for(o=0;a.length>o;o++)if(s=a[o],s.parsed&&(s=s.el[0]),s===i.el[0]){t.index=o;break}}else t.items=e.isArray(i.items)?i.items:[i.items],t.index=i.index||0;if(t.isOpen)return void t.updateItemHTML();t.types=[],r="",t.ev=i.mainEl&&i.mainEl.length?i.mainEl.eq(0):n,i.key?(t.popupsCache[i.key]||(t.popupsCache[i.key]={}),t.currTemplate=t.popupsCache[i.key]):t.currTemplate={},t.st=e.extend(!0,{},e.magnificPopup.defaults,i),t.fixedContentPos="auto"===t.st.fixedContentPos?!t.probablyMobile:t.st.fixedContentPos,t.st.modal&&(t.st.closeOnContentClick=!1,t.st.closeOnBgClick=!1,t.st.showCloseBtn=!1,t.st.enableEscapeKey=!1),t.bgOverlay||(t.bgOverlay=C("bg").on("click"+g,function(){t.close()}),t.wrap=C("wrap").attr("tabindex",-1).on("click"+g,function(e){t._checkIfClose(e.target)&&t.close()}),t.container=C("container",t.wrap)),t.contentContainer=C("content"),t.st.preloader&&(t.preloader=C("preloader",t.container,t.st.tLoading));var l=e.magnificPopup.modules;for(o=0;l.length>o;o++){var d=l[o];d=d.charAt(0).toUpperCase()+d.slice(1),t["init"+d].call(t)}j("BeforeOpen"),t.st.showCloseBtn&&(t.st.closeBtnInside?(S(h,function(e,t,i,o){i.close_replaceWith=k(o.type)}),r+=" mfp-close-btn-in"):t.wrap.append(k())),t.st.alignTop&&(r+=" mfp-align-top"),t.wrap.css(t.fixedContentPos?{overflow:t.st.overflowY,overflowX:"hidden",overflowY:t.st.overflowY}:{top:T.scrollTop(),position:"absolute"}),(t.st.fixedBgPos===!1||"auto"===t.st.fixedBgPos&&!t.fixedContentPos)&&t.bgOverlay.css({height:n.height(),position:"absolute"}),t.st.enableEscapeKey&&n.on("keyup"+g,function(e){27===e.keyCode&&t.close()}),T.on("resize"+g,function(){t.updateSize()}),t.st.closeOnContentClick||(r+=" mfp-auto-cursor"),r&&t.wrap.addClass(r);var c=t.wH=T.height(),u={};if(t.fixedContentPos&&t._hasScrollBar(c)){var p=t._getScrollbarSize();p&&(u.marginRight=p)}t.fixedContentPos&&(t.isIE7?e("body, html").css("overflow","hidden"):u.overflow="hidden");var f=t.st.mainClass;return t.isIE7&&(f+=" mfp-ie7"),f&&t._addClassToMFP(f),t.updateItemHTML(),j("BuildControls"),e("html").css(u),t.bgOverlay.add(t.wrap).prependTo(document.body),t._lastFocusedEl=document.activeElement,setTimeout(function(){t.content?(t._addClassToMFP(v),t._setFocus()):t.bgOverlay.addClass(v),n.on("focusin"+g,t._onFocusIn)},16),t.isOpen=!0,t.updateSize(c),j(m),i},close:function(){t.isOpen&&(j(d),t.isOpen=!1,t.st.removalDelay&&!t.isLowIE&&t.supportsTransition?(t._addClassToMFP(y),setTimeout(function(){t._close()},t.st.removalDelay)):t._close())},_close:function(){j(l);var i=y+" "+v+" ";if(t.bgOverlay.detach(),t.wrap.detach(),t.container.empty(),t.st.mainClass&&(i+=t.st.mainClass+" "),t._removeClassFromMFP(i),t.fixedContentPos){var o={marginRight:""};t.isIE7?e("body, html").css("overflow",""):o.overflow="",e("html").css(o)}n.off("keyup"+g+" focusin"+g),t.ev.off(g),t.wrap.attr("class","mfp-wrap").removeAttr("style"),t.bgOverlay.attr("class","mfp-bg"),t.container.attr("class","mfp-container"),!t.st.showCloseBtn||t.st.closeBtnInside&&t.currTemplate[t.currItem.type]!==!0||t.currTemplate.closeBtn&&t.currTemplate.closeBtn.detach(),t._lastFocusedEl&&e(t._lastFocusedEl).focus(),t.currItem=null,t.content=null,t.currTemplate=null,t.prevHeight=0,j(c)},updateSize:function(e){if(t.isIOS){var i=document.documentElement.clientWidth/window.innerWidth,o=window.innerHeight*i;t.wrap.css("height",o),t.wH=o}else t.wH=e||T.height();t.fixedContentPos||t.wrap.css("height",t.wH),j("Resize")},updateItemHTML:function(){var i=t.items[t.index];t.contentContainer.detach(),t.content&&t.content.detach(),i.parsed||(i=t.parseEl(t.index));var o=i.type;if(j("BeforeChange",[t.currItem?t.currItem.type:"",o]),t.currItem=i,!t.currTemplate[o]){var n=t.st[o]?t.st[o].markup:!1;j("FirstMarkupParse",n),t.currTemplate[o]=n?e(n):!0}s&&s!==i.type&&t.container.removeClass("mfp-"+s+"-holder");var r=t["get"+o.charAt(0).toUpperCase()+o.slice(1)](i,t.currTemplate[o]);t.appendContent(r,o),i.preloaded=!0,j(p,i),s=i.type,t.container.prepend(t.contentContainer),j("AfterChange")},appendContent:function(e,i){t.content=e,e?t.st.showCloseBtn&&t.st.closeBtnInside&&t.currTemplate[i]===!0?t.content.find(".mfp-close").length||t.content.append(k()):t.content=e:t.content="",j(u),t.container.addClass("mfp-"+i+"-holder"),t.contentContainer.append(t.content)},parseEl:function(i){var o=t.items[i],n=o.type;if(o=o.tagName?{el:e(o)}:{data:o,src:o.src},o.el){for(var s=t.types,r=0;s.length>r;r++)if(o.el.hasClass("mfp-"+s[r])){n=s[r];break}o.src=o.el.attr("data-mfp-src"),o.src||(o.src=o.el.attr("href"))}return o.type=n||t.st.type||"inline",o.index=i,o.parsed=!0,t.items[i]=o,j("ElementParse",o),t.items[i]},addGroup:function(e,i){var o=function(o){o.mfpEl=this,t._openClick(o,e,i)};i||(i={});var n="click.magnificPopup";i.mainEl=e,i.items?(i.isObj=!0,e.off(n).on(n,o)):(i.isObj=!1,i.delegate?e.off(n).on(n,i.delegate,o):(i.items=e,e.off(n).on(n,o)))},_openClick:function(i,o,n){var s=void 0!==n.midClick?n.midClick:e.magnificPopup.defaults.midClick;if(s||2!==i.which&&!i.ctrlKey&&!i.metaKey){var r=void 0!==n.disableOn?n.disableOn:e.magnificPopup.defaults.disableOn;if(r)if(e.isFunction(r)){if(!r.call(t))return!0}else if(r>T.width())return!0;i.type&&(i.preventDefault(),t.isOpen&&i.stopPropagation()),n.el=e(i.mfpEl),n.delegate&&(n.items=o.find(n.delegate)),t.open(n)}},updateStatus:function(e,o){if(t.preloader){i!==e&&t.container.removeClass("mfp-s-"+i),o||"loading"!==e||(o=t.st.tLoading);var n={status:e,text:o};j("UpdateStatus",n),e=n.status,o=n.text,t.preloader.html(o),t.preloader.find("a").on("click",function(e){e.stopImmediatePropagation()}),t.container.addClass("mfp-s-"+e),i=e}},_checkIfClose:function(i){if(!e(i).hasClass(w)){var o=t.st.closeOnContentClick,n=t.st.closeOnBgClick;if(o&&n)return!0;if(!t.content||e(i).hasClass("mfp-close")||t.preloader&&i===t.preloader[0])return!0;if(i===t.content[0]||e.contains(t.content[0],i)){if(o)return!0}else if(n&&e.contains(document,i))return!0;return!1}},_addClassToMFP:function(e){t.bgOverlay.addClass(e),t.wrap.addClass(e)},_removeClassFromMFP:function(e){this.bgOverlay.removeClass(e),t.wrap.removeClass(e)},_hasScrollBar:function(e){return(t.isIE7?n.height():document.body.scrollHeight)>(e||T.height())},_setFocus:function(){(t.st.focus?t.content.find(t.st.focus).eq(0):t.wrap).focus()},_onFocusIn:function(i){return i.target===t.wrap[0]||e.contains(t.wrap[0],i.target)?void 0:(t._setFocus(),!1)},_parseMarkup:function(t,i,o){var n;o.data&&(i=e.extend(o.data,i)),j(h,[t,i,o]),e.each(i,function(e,i){if(void 0===i||i===!1)return!0;if(n=e.split("_"),n.length>1){var o=t.find(g+"-"+n[0]);if(o.length>0){var s=n[1];"replaceWith"===s?o[0]!==i[0]&&o.replaceWith(i):"img"===s?o.is("img")?o.attr("src",i):o.replaceWith('<img src="'+i+'" class="'+o.attr("class")+'" />'):o.attr(n[1],i)}}else t.find(g+"-"+e).html(i)})},_getScrollbarSize:function(){if(void 0===t.scrollbarSize){var e=document.createElement("div");e.id="mfp-sbm",e.style.cssText="width: 99px; height: 99px; overflow: scroll; position: absolute; top: -9999px;",document.body.appendChild(e),t.scrollbarSize=e.offsetWidth-e.clientWidth,document.body.removeChild(e)}return t.scrollbarSize}},e.magnificPopup={instance:null,proto:b.prototype,modules:[],open:function(t,i){return M(),t=t?e.extend(!0,{},t):{},t.isObj=!0,t.index=i||0,this.instance.open(t)},close:function(){return e.magnificPopup.instance&&e.magnificPopup.instance.close()},registerModule:function(t,i){i.options&&(e.magnificPopup.defaults[t]=i.options),e.extend(this.proto,i.proto),this.modules.push(t)},defaults:{disableOn:0,key:null,midClick:!1,mainClass:"",preloader:!0,focus:"",closeOnContentClick:!1,closeOnBgClick:!0,closeBtnInside:!0,showCloseBtn:!0,enableEscapeKey:!0,modal:!1,alignTop:!1,removalDelay:0,fixedContentPos:"auto",fixedBgPos:"auto",overflowY:"auto",closeMarkup:'<button title="%title%" type="button" class="mfp-close">&times;</button>',tClose:"Close (Esc)",tLoading:"Loading..."}},e.fn.magnificPopup=function(i){M();var o=e(this);if("string"==typeof i)if("open"===i){var n,s=x?o.data("magnificPopup"):o[0].magnificPopup,r=parseInt(arguments[1],10)||0;s.items?n=s.items[r]:(n=o,s.delegate&&(n=n.find(s.delegate)),n=n.eq(r)),t._openClick({mfpEl:n},o,s)}else t.isOpen&&t[i].apply(t,Array.prototype.slice.call(arguments,1));else i=e.extend(!0,{},i),x?o.data("magnificPopup",i):o[0].magnificPopup=i,t.addGroup(o,i);return o};var P,z,F,A="inline",I=function(){F&&(z.after(F.addClass(P)).detach(),F=null)};e.magnificPopup.registerModule(A,{options:{hiddenClass:"hide",markup:"",tNotFound:"Content not found"},proto:{initInline:function(){t.types.push(A),S(l+"."+A,function(){I()})},getInline:function(i,o){if(I(),i.src){var n=t.st.inline,s=e(i.src);if(s.length){var r=s[0].parentNode;r&&r.tagName&&(z||(P=n.hiddenClass,z=C(P),P="mfp-"+P),F=s.after(z).detach().removeClass(P)),t.updateStatus("ready")}else t.updateStatus("error",n.tNotFound),s=e("<div>");return i.inlineElement=s,s}return t.updateStatus("ready"),t._parseMarkup(o,{},i),o}}});var L,_="ajax",B=function(){L&&o.removeClass(L)},N=function(){B(),t.req&&t.req.abort()};e.magnificPopup.registerModule(_,{options:{settings:null,cursor:"mfp-ajax-cur",tError:'<a href="%url%">The content</a> could not be loaded.'},proto:{initAjax:function(){t.types.push(_),L=t.st.ajax.cursor,S(l+"."+_,N),S("BeforeChange."+_,N)},getAjax:function(i){L&&o.addClass(L),t.updateStatus("loading");var n=e.extend({url:i.src,success:function(o,n,s){var r={data:o,xhr:s};j("ParseAjax",r),t.appendContent(e(r.data),_),i.finished=!0,B(),t._setFocus(),setTimeout(function(){t.wrap.addClass(v)},16),t.updateStatus("ready"),j("AjaxContentAdded")},error:function(){B(),i.finished=i.loadError=!0,t.updateStatus("error",t.st.ajax.tError.replace("%url%",i.src))}},t.st.ajax.settings);return t.req=e.ajax(n),""}}});var H,$=function(i){if(i.data&&void 0!==i.data.title)return i.data.title;var o=t.st.image.titleSrc;if(o){if(e.isFunction(o))return o.call(t,i);if(i.el)return i.el.attr(o)||""}return""};e.magnificPopup.registerModule("image",{options:{markup:'<div class="mfp-figure"><div class="mfp-close"></div><figure><div class="mfp-img"></div><figcaption><div class="mfp-bottom-bar"><div class="mfp-title"></div><div class="mfp-counter"></div></div></figcaption></figure></div>',cursor:"mfp-zoom-out-cur",titleSrc:"title",verticalFit:!0,tError:'<a href="%url%">The image</a> could not be loaded.'},proto:{initImage:function(){var e=t.st.image,i=".image";t.types.push("image"),S(m+i,function(){"image"===t.currItem.type&&e.cursor&&o.addClass(e.cursor)}),S(l+i,function(){e.cursor&&o.removeClass(e.cursor),T.off("resize"+g)}),S("Resize"+i,t.resizeImage),t.isLowIE&&S("AfterChange",t.resizeImage)},resizeImage:function(){var e=t.currItem;if(e&&e.img&&t.st.image.verticalFit){var i=0;t.isLowIE&&(i=parseInt(e.img.css("padding-top"),10)+parseInt(e.img.css("padding-bottom"),10)),e.img.css("max-height",t.wH-i)}},_onImageHasSize:function(e){e.img&&(e.hasSize=!0,H&&clearInterval(H),e.isCheckingImgSize=!1,j("ImageHasSize",e),e.imgHidden&&(t.content&&t.content.removeClass("mfp-loading"),e.imgHidden=!1))},findImageSize:function(e){var i=0,o=e.img[0],n=function(s){H&&clearInterval(H),H=setInterval(function(){return o.naturalWidth>0?void t._onImageHasSize(e):(i>200&&clearInterval(H),i++,void(3===i?n(10):40===i?n(50):100===i&&n(500)))},s)};n(1)},getImage:function(i,o){var n=0,s=function(){i&&(i.img[0].complete?(i.img.off(".mfploader"),i===t.currItem&&(t._onImageHasSize(i),t.updateStatus("ready")),i.hasSize=!0,i.loaded=!0,j("ImageLoadComplete")):(n++,200>n?setTimeout(s,100):r()))},r=function(){i&&(i.img.off(".mfploader"),i===t.currItem&&(t._onImageHasSize(i),t.updateStatus("error",a.tError.replace("%url%",i.src))),i.hasSize=!0,i.loaded=!0,i.loadError=!0)},a=t.st.image,l=o.find(".mfp-img");if(l.length){var d=document.createElement("img");d.className="mfp-img",i.img=e(d).on("load.mfploader",s).on("error.mfploader",r),d.src=i.src,l.is("img")&&(i.img=i.img.clone()),i.img[0].naturalWidth>0&&(i.hasSize=!0)}return t._parseMarkup(o,{title:$(i),img_replaceWith:i.img},i),t.resizeImage(),i.hasSize?(H&&clearInterval(H),i.loadError?(o.addClass("mfp-loading"),t.updateStatus("error",a.tError.replace("%url%",i.src))):(o.removeClass("mfp-loading"),t.updateStatus("ready")),o):(t.updateStatus("loading"),i.loading=!0,i.hasSize||(i.imgHidden=!0,o.addClass("mfp-loading"),t.findImageSize(i)),o)}}});var O,R=function(){return void 0===O&&(O=void 0!==document.createElement("p").style.MozTransform),O};e.magnificPopup.registerModule("zoom",{options:{enabled:!1,easing:"ease-in-out",duration:300,opener:function(e){return e.is("img")?e:e.find("img")}},proto:{initZoom:function(){var e,i=t.st.zoom,o=".zoom";if(i.enabled&&t.supportsTransition){var n,s,r=i.duration,a=function(e){var t=e.clone().removeAttr("style").removeAttr("class").addClass("mfp-animated-image"),o="all "+i.duration/1e3+"s "+i.easing,n={position:"fixed",zIndex:9999,left:0,top:0,"-webkit-backface-visibility":"hidden"},s="transition";return n["-webkit-"+s]=n["-moz-"+s]=n["-o-"+s]=n[s]=o,t.css(n),t},c=function(){t.content.css("visibility","visible")};S("BuildControls"+o,function(){if(t._allowZoom()){if(clearTimeout(n),t.content.css("visibility","hidden"),e=t._getItemToZoom(),!e)return void c();s=a(e),s.css(t._getOffset()),t.wrap.append(s),n=setTimeout(function(){s.css(t._getOffset(!0)),n=setTimeout(function(){c(),setTimeout(function(){s.remove(),e=s=null,j("ZoomAnimationEnded")},16)},r)},16)}}),S(d+o,function(){if(t._allowZoom()){if(clearTimeout(n),t.st.removalDelay=r,!e){if(e=t._getItemToZoom(),!e)return;s=a(e)}s.css(t._getOffset(!0)),t.wrap.append(s),t.content.css("visibility","hidden"),setTimeout(function(){s.css(t._getOffset())},16)}}),S(l+o,function(){t._allowZoom()&&(c(),s&&s.remove(),e=null)})}},_allowZoom:function(){return"image"===t.currItem.type},_getItemToZoom:function(){return t.currItem.hasSize?t.currItem.img:!1},_getOffset:function(i){var o;o=i?t.currItem.img:t.st.zoom.opener(t.currItem.el||t.currItem);var n=o.offset(),s=parseInt(o.css("padding-top"),10),r=parseInt(o.css("padding-bottom"),10);n.top-=e(window).scrollTop()-s;var a={width:o.width(),height:(x?o.innerHeight():o[0].offsetHeight)-r-s};return R()?a["-moz-transform"]=a.transform="translate("+n.left+"px,"+n.top+"px)":(a.left=n.left,a.top=n.top),a}}});var D="iframe",W="//about:blank",V=function(e){if(t.currTemplate[D]){var i=t.currTemplate[D].find("iframe");i.length&&(e||(i[0].src=W),t.isIE8&&i.css("display",e?"block":"none"))}};e.magnificPopup.registerModule(D,{options:{markup:'<div class="mfp-iframe-scaler"><div class="mfp-close"></div><iframe class="mfp-iframe" src="//about:blank" frameborder="0" allowfullscreen></iframe></div>',srcAction:"iframe_src",patterns:{youtube:{index:"youtube.com",id:"v=",src:"//www.youtube.com/embed/%id%?autoplay=1"},vimeo:{index:"vimeo.com/",id:"/",src:"//player.vimeo.com/video/%id%?autoplay=1"},gmaps:{index:"//maps.google.",src:"%id%&output=embed"}}},proto:{initIframe:function(){t.types.push(D),S("BeforeChange",function(e,t,i){t!==i&&(t===D?V():i===D&&V(!0))}),S(l+"."+D,function(){V()})},getIframe:function(i,o){var n=i.src,s=t.st.iframe;e.each(s.patterns,function(){return n.indexOf(this.index)>-1?(this.id&&(n="string"==typeof this.id?n.substr(n.lastIndexOf(this.id)+this.id.length,n.length):this.id.call(this,n)),n=this.src.replace("%id%",n),!1):void 0});var r={};return s.srcAction&&(r[s.srcAction]=n),t._parseMarkup(o,r,i),t.updateStatus("ready"),o}}});var U=function(e){var i=t.items.length;return e>i-1?e-i:0>e?i+e:e},q=function(e,t,i){return e.replace(/%curr%/gi,t+1).replace(/%total%/gi,i)};e.magnificPopup.registerModule("gallery",{options:{enabled:!1,arrowMarkup:'<button title="%title%" type="button" class="mfp-arrow mfp-arrow-%dir%"></button>',preload:[0,2],navigateByImgClick:!0,arrows:!0,tPrev:"Previous (Left arrow key)",tNext:"Next (Right arrow key)",tCounter:"%curr% of %total%"},proto:{initGallery:function(){var i=t.st.gallery,o=".mfp-gallery",s=Boolean(e.fn.mfpFastClick);return t.direction=!0,i&&i.enabled?(r+=" mfp-gallery",S(m+o,function(){i.navigateByImgClick&&t.wrap.on("click"+o,".mfp-img",function(){return t.items.length>1?(t.next(),!1):void 0}),n.on("keydown"+o,function(e){37===e.keyCode?t.prev():39===e.keyCode&&t.next()})}),S("UpdateStatus"+o,function(e,i){i.text&&(i.text=q(i.text,t.currItem.index,t.items.length))}),S(h+o,function(e,o,n,s){var r=t.items.length;n.counter=r>1?q(i.tCounter,s.index,r):""}),S("BuildControls"+o,function(){if(t.items.length>1&&i.arrows&&!t.arrowLeft){var o=i.arrowMarkup,n=t.arrowLeft=e(o.replace(/%title%/gi,i.tPrev).replace(/%dir%/gi,"left")).addClass(w),r=t.arrowRight=e(o.replace(/%title%/gi,i.tNext).replace(/%dir%/gi,"right")).addClass(w),a=s?"mfpFastClick":"click";n[a](function(){t.prev()}),r[a](function(){t.next()}),t.isIE7&&(C("b",n[0],!1,!0),C("a",n[0],!1,!0),C("b",r[0],!1,!0),C("a",r[0],!1,!0)),t.container.append(n.add(r))}}),S(p+o,function(){t._preloadTimeout&&clearTimeout(t._preloadTimeout),t._preloadTimeout=setTimeout(function(){t.preloadNearbyImages(),t._preloadTimeout=null},16)}),void S(l+o,function(){n.off(o),t.wrap.off("click"+o),t.arrowLeft&&s&&t.arrowLeft.add(t.arrowRight).destroyMfpFastClick(),t.arrowRight=t.arrowLeft=null})):!1},next:function(){t.direction=!0,t.index=U(t.index+1),t.updateItemHTML()},prev:function(){t.direction=!1,t.index=U(t.index-1),t.updateItemHTML()},goTo:function(e){t.direction=e>=t.index,t.index=e,t.updateItemHTML()},preloadNearbyImages:function(){var e,i=t.st.gallery.preload,o=Math.min(i[0],t.items.length),n=Math.min(i[1],t.items.length);for(e=1;(t.direction?n:o)>=e;e++)t._preloadItem(t.index+e);for(e=1;(t.direction?o:n)>=e;e++)t._preloadItem(t.index-e)},_preloadItem:function(i){if(i=U(i),!t.items[i].preloaded){var o=t.items[i];o.parsed||(o=t.parseEl(i)),j("LazyLoad",o),"image"===o.type&&(o.img=e('<img class="mfp-img" />').on("load.mfploader",function(){o.hasSize=!0}).on("error.mfploader",function(){o.hasSize=!0,o.loadError=!0,j("LazyLoadError",o)}).attr("src",o.src)),o.preloaded=!0}}}});var Y="retina";e.magnificPopup.registerModule(Y,{options:{replaceSrc:function(e){return e.src.replace(/\.\w+$/,function(e){return"@2x"+e})},ratio:1},proto:{initRetina:function(){if(window.devicePixelRatio>1){var e=t.st.retina,i=e.ratio;i=isNaN(i)?i():i,i>1&&(S("ImageHasSize."+Y,function(e,t){t.img.css({"max-width":t.img[0].naturalWidth/i,width:"100%"})}),S("ElementParse."+Y,function(t,o){o.src=e.replaceSrc(o,i)}))}}}}),function(){var t=1e3,i="ontouchstart"in window,o=function(){T.off("touchmove"+s+" touchend"+s)},n="mfpFastClick",s="."+n;e.fn.mfpFastClick=function(n){return e(this).each(function(){var r,a=e(this);if(i){var l,d,c,u,h,m;a.on("touchstart"+s,function(e){u=!1,m=1,h=e.originalEvent?e.originalEvent.touches[0]:e.touches[0],d=h.clientX,c=h.clientY,T.on("touchmove"+s,function(e){h=e.originalEvent?e.originalEvent.touches:e.touches,m=h.length,h=h[0],(Math.abs(h.clientX-d)>10||Math.abs(h.clientY-c)>10)&&(u=!0,o())}).on("touchend"+s,function(e){o(),u||m>1||(r=!0,e.preventDefault(),clearTimeout(l),l=setTimeout(function(){r=!1},t),n())})})}a.on("click"+s,function(){r||n()})})},e.fn.destroyMfpFastClick=function(){e(this).off("touchstart"+s+" click"+s),i&&T.off("touchmove"+s+" touchend"+s)}}(),M()}(window.jQuery||window.Zepto),function(e,t){"use strict";var i,o=e.document,n=e.Modernizr,s=function(e){return e.charAt(0).toUpperCase()+e.slice(1)},r="Moz Webkit O Ms".split(" "),a=function(e){var t,i=o.documentElement.style;if("string"==typeof i[e])return e;e=s(e);for(var n=0,a=r.length;a>n;n++)if(t=r[n]+e,"string"==typeof i[t])return t},l=a("transform"),d=a("transitionProperty"),c={csstransforms:function(){return!!l},csstransforms3d:function(){var e=!!a("perspective");if(e){var i=" -o- -moz- -ms- -webkit- -khtml- ".split(" "),o="@media ("+i.join("transform-3d),(")+"modernizr)",n=t("<style>"+o+"{#modernizr{height:3px}}</style>").appendTo("head"),s=t('<div id="modernizr" />').appendTo("html");e=3===s.height(),s.remove(),n.remove()}return e},csstransitions:function(){return!!d}};if(n)for(i in c)n.hasOwnProperty(i)||n.addTest(i,c[i]);else{n=e.Modernizr={_version:"1.6ish: miniModernizr for Isotope"};var u,h=" ";for(i in c)u=c[i](),n[i]=u,h+=" "+(u?"":"no-")+i;t("html").addClass(h)}if(n.csstransforms){var m=n.csstransforms3d?{translate:function(e){return"translate3d("+e[0]+"px, "+e[1]+"px, 0) "},scale:function(e){return"scale3d("+e+", "+e+", 1) "}}:{translate:function(e){return"translate("+e[0]+"px, "+e[1]+"px) "},scale:function(e){return"scale("+e+") "}},p=function(e,i,o){var n,s,r=t.data(e,"isoTransform")||{},a={},d={};a[i]=o,t.extend(r,a);for(n in r)s=r[n],d[n]=m[n](s);var c=d.translate||"",u=d.scale||"",h=c+u;t.data(e,"isoTransform",r),e.style[l]=h};t.cssNumber.scale=!0,t.cssHooks.scale={set:function(e,t){p(e,"scale",t)},get:function(e){var i=t.data(e,"isoTransform");return i&&i.scale?i.scale:1}},t.fx.step.scale=function(e){t.cssHooks.scale.set(e.elem,e.now+e.unit)},t.cssNumber.translate=!0,t.cssHooks.translate={set:function(e,t){p(e,"translate",t)},get:function(e){var i=t.data(e,"isoTransform");return i&&i.translate?i.translate:[0,0]}}}var f,g;n.csstransitions&&(f={WebkitTransitionProperty:"webkitTransitionEnd",MozTransitionProperty:"transitionend",OTransitionProperty:"oTransitionEnd otransitionend",transitionProperty:"transitionend"}[d],g=a("transitionDuration"));var v,y=t.event,w=t.event.handle?"handle":"dispatch";y.special.smartresize={setup:function(){t(this).bind("resize",y.special.smartresize.handler)},teardown:function(){t(this).unbind("resize",y.special.smartresize.handler)},handler:function(e,t){var i=this,o=arguments;e.type="smartresize",v&&clearTimeout(v),v=setTimeout(function(){y[w].apply(i,o)},"execAsap"===t?0:100)}},t.fn.smartresize=function(e){return e?this.bind("smartresize",e):this.trigger("smartresize",["execAsap"])},t.Isotope=function(e,i,o){this.element=t(i),this._create(e),this._init(o)};var b=["width","height"],x=t(e);t.Isotope.settings={resizable:!0,layoutMode:"masonry",containerClass:"isotope",itemClass:"isotope-item",hiddenClass:"isotope-hidden",hiddenStyle:{opacity:0,scale:.001},visibleStyle:{opacity:1,scale:1},containerStyle:{position:"relative",overflow:"hidden"},animationEngine:"best-available",animationOptions:{queue:!1,duration:800},sortBy:"original-order",sortAscending:!0,resizesContainer:!0,transformsEnabled:!0,itemPositionDataEnabled:!1},t.Isotope.prototype={_create:function(e){this.options=t.extend({},t.Isotope.settings,e),this.styleQueue=[],this.elemCount=0;var i=this.element[0].style;this.originalStyle={};var o=b.slice(0);for(var n in this.options.containerStyle)o.push(n);for(var s=0,r=o.length;r>s;s++)n=o[s],this.originalStyle[n]=i[n]||"";this.element.css(this.options.containerStyle),this._updateAnimationEngine(),this._updateUsingTransforms();var a={"original-order":function(e,t){return t.elemCount++,t.elemCount},random:function(){return Math.random()}};this.options.getSortData=t.extend(this.options.getSortData,a),this.reloadItems(),this.offset={left:parseInt(this.element.css("padding-left")||0,10),top:parseInt(this.element.css("padding-top")||0,10)};var l=this;setTimeout(function(){l.element.addClass(l.options.containerClass)},0),this.options.resizable&&x.bind("smartresize.isotope",function(){l.resize()}),this.element.delegate("."+this.options.hiddenClass,"click",function(){return!1})},_getAtoms:function(e){var t=this.options.itemSelector,i=t?e.filter(t).add(e.find(t)):e,o={position:"absolute"};return i=i.filter(function(e,t){return 1===t.nodeType}),this.usingTransforms&&(o.left=0,o.top=0),i.css(o).addClass(this.options.itemClass),this.updateSortData(i,!0),i
},_init:function(e){this.$filteredAtoms=this._filter(this.$allAtoms),this._sort(),this.reLayout(e)},option:function(e){if(t.isPlainObject(e)){this.options=t.extend(!0,this.options,e);var i;for(var o in e)i="_update"+s(o),this[i]&&this[i]()}},_updateAnimationEngine:function(){var e,t=this.options.animationEngine.toLowerCase().replace(/[ _\-]/g,"");switch(t){case"css":case"none":e=!1;break;case"jquery":e=!0;break;default:e=!n.csstransitions}this.isUsingJQueryAnimation=e,this._updateUsingTransforms()},_updateTransformsEnabled:function(){this._updateUsingTransforms()},_updateUsingTransforms:function(){var e=this.usingTransforms=this.options.transformsEnabled&&n.csstransforms&&n.csstransitions&&!this.isUsingJQueryAnimation;e||(delete this.options.hiddenStyle.scale,delete this.options.visibleStyle.scale),this.getPositionStyles=e?this._translate:this._positionAbs},_filter:function(e){var t=""===this.options.filter?"*":this.options.filter;if(!t)return e;var i=this.options.hiddenClass,o="."+i,n=e.filter(o),s=n;if("*"!==t){s=n.filter(t);var r=e.not(o).not(t).addClass(i);this.styleQueue.push({$el:r,style:this.options.hiddenStyle})}return this.styleQueue.push({$el:s,style:this.options.visibleStyle}),s.removeClass(i),e.filter(t)},updateSortData:function(e,i){var o,n,s=this,r=this.options.getSortData;e.each(function(){o=t(this),n={};for(var e in r)n[e]=i||"original-order"!==e?r[e](o,s):t.data(this,"isotope-sort-data")[e];t.data(this,"isotope-sort-data",n)})},_sort:function(){var e=this.options.sortBy,t=this._getSorter,i=this.options.sortAscending?1:-1,o=function(o,n){var s=t(o,e),r=t(n,e);return s===r&&"original-order"!==e&&(s=t(o,"original-order"),r=t(n,"original-order")),(s>r?1:r>s?-1:0)*i};this.$filteredAtoms.sort(o)},_getSorter:function(e,i){return t.data(e,"isotope-sort-data")[i]},_translate:function(e,t){return{translate:[e,t]}},_positionAbs:function(e,t){return{left:e,top:t}},_pushPosition:function(e,t,i){t=Math.round(t+this.offset.left),i=Math.round(i+this.offset.top);var o=this.getPositionStyles(t,i);this.styleQueue.push({$el:e,style:o}),this.options.itemPositionDataEnabled&&e.data("isotope-item-position",{x:t,y:i})},layout:function(e,t){var i=this.options.layoutMode;if(this["_"+i+"Layout"](e),this.options.resizesContainer){var o=this["_"+i+"GetContainerSize"]();this.styleQueue.push({$el:this.element,style:o})}this._processStyleQueue(e,t),this.isLaidOut=!0},_processStyleQueue:function(e,i){var o,s,r,a,l=this.isLaidOut?this.isUsingJQueryAnimation?"animate":"css":"css",d=this.options.animationOptions,c=this.options.onLayout;if(s=function(e,t){t.$el[l](t.style,d)},this._isInserting&&this.isUsingJQueryAnimation)s=function(e,t){o=t.$el.hasClass("no-transition")?"css":l,t.$el[o](t.style,d)};else if(i||c||d.complete){var u=!1,h=[i,c,d.complete],m=this;if(r=!0,a=function(){if(!u){for(var t,i=0,o=h.length;o>i;i++)t=h[i],"function"==typeof t&&t.call(m.element,e,m);u=!0}},this.isUsingJQueryAnimation&&"animate"===l)d.complete=a,r=!1;else if(n.csstransitions){for(var p,v=0,y=this.styleQueue[0],w=y&&y.$el;!w||!w.length;){if(p=this.styleQueue[v++],!p)return;w=p.$el}var b=parseFloat(getComputedStyle(w[0])[g]);b>0&&(s=function(e,t){t.$el[l](t.style,d).one(f,a)},r=!1)}}t.each(this.styleQueue,s),r&&a(),this.styleQueue=[]},resize:function(){this["_"+this.options.layoutMode+"ResizeChanged"]()&&this.reLayout()},reLayout:function(e){this["_"+this.options.layoutMode+"Reset"](),this.layout(this.$filteredAtoms,e)},addItems:function(e,t){var i=this._getAtoms(e);this.$allAtoms=this.$allAtoms.add(i),t&&t(i)},insert:function(e,t){this.element.append(e);var i=this;this.addItems(e,function(e){var o=i._filter(e);i._addHideAppended(o),i._sort(),i.reLayout(),i._revealAppended(o,t)})},appended:function(e,t){var i=this;this.addItems(e,function(e){i._addHideAppended(e),i.layout(e),i._revealAppended(e,t)})},_addHideAppended:function(e){this.$filteredAtoms=this.$filteredAtoms.add(e),e.addClass("no-transition"),this._isInserting=!0,this.styleQueue.push({$el:e,style:this.options.hiddenStyle})},_revealAppended:function(e,t){var i=this;setTimeout(function(){e.removeClass("no-transition"),i.styleQueue.push({$el:e,style:i.options.visibleStyle}),i._isInserting=!1,i._processStyleQueue(e,t)},10)},reloadItems:function(){this.$allAtoms=this._getAtoms(this.element.children())},remove:function(e,t){this.$allAtoms=this.$allAtoms.not(e),this.$filteredAtoms=this.$filteredAtoms.not(e);var i=this,o=function(){e.remove(),t&&t.call(i.element)};e.filter(":not(."+this.options.hiddenClass+")").length?(this.styleQueue.push({$el:e,style:this.options.hiddenStyle}),this._sort(),this.reLayout(o)):o()},shuffle:function(e){this.updateSortData(this.$allAtoms),this.options.sortBy="random",this._sort(),this.reLayout(e)},destroy:function(){var e=this.usingTransforms,t=this.options;this.$allAtoms.removeClass(t.hiddenClass+" "+t.itemClass).each(function(){var t=this.style;t.position="",t.top="",t.left="",t.opacity="",e&&(t[l]="")});var i=this.element[0].style;for(var o in this.originalStyle)i[o]=this.originalStyle[o];this.element.unbind(".isotope").undelegate("."+t.hiddenClass,"click").removeClass(t.containerClass).removeData("isotope"),x.unbind(".isotope")},_getSegments:function(e){var t,i=this.options.layoutMode,o=e?"rowHeight":"columnWidth",n=e?"height":"width",r=e?"rows":"cols",a=this.element[n](),l=this.options[i]&&this.options[i][o]||this.$filteredAtoms["outer"+s(n)](!0)||a;t=Math.floor(a/l),t=Math.max(t,1),this[i][r]=t,this[i][o]=l},_checkIfSegmentsChanged:function(e){var t=this.options.layoutMode,i=e?"rows":"cols",o=this[t][i];return this._getSegments(e),this[t][i]!==o},_masonryReset:function(){this.masonry={},this._getSegments();var e=this.masonry.cols;for(this.masonry.colYs=[];e--;)this.masonry.colYs.push(0)},_masonryLayout:function(e){var i=this,o=i.masonry;e.each(function(){var e=t(this),n=Math.ceil(e.outerWidth(!0)/o.columnWidth);if(n=Math.min(n,o.cols),1===n)i._masonryPlaceBrick(e,o.colYs);else{var s,r,a=o.cols+1-n,l=[];for(r=0;a>r;r++)s=o.colYs.slice(r,r+n),l[r]=Math.max.apply(Math,s);i._masonryPlaceBrick(e,l)}})},_masonryPlaceBrick:function(e,t){for(var i=Math.min.apply(Math,t),o=0,n=0,s=t.length;s>n;n++)if(t[n]===i){o=n;break}var r=this.masonry.columnWidth*o,a=i;this._pushPosition(e,r,a);var l=i+e.outerHeight(!0),d=this.masonry.cols+1-s;for(n=0;d>n;n++)this.masonry.colYs[o+n]=l},_masonryGetContainerSize:function(){var e=Math.max.apply(Math,this.masonry.colYs);return{height:e}},_masonryResizeChanged:function(){return this._checkIfSegmentsChanged()},_fitRowsReset:function(){this.fitRows={x:0,y:0,height:0}},_fitRowsLayout:function(e){var i=this,o=this.element.width(),n=this.fitRows;e.each(function(){var e=t(this),s=e.outerWidth(!0),r=e.outerHeight(!0);0!==n.x&&s+n.x>o&&(n.x=0,n.y=n.height),i._pushPosition(e,n.x,n.y),n.height=Math.max(n.y+r,n.height),n.x+=s})},_fitRowsGetContainerSize:function(){return{height:this.fitRows.height}},_fitRowsResizeChanged:function(){return!0},_cellsByRowReset:function(){this.cellsByRow={index:0},this._getSegments(),this._getSegments(!0)},_cellsByRowLayout:function(e){var i=this,o=this.cellsByRow;e.each(function(){var e=t(this),n=o.index%o.cols,s=Math.floor(o.index/o.cols),r=(n+.5)*o.columnWidth-e.outerWidth(!0)/2,a=(s+.5)*o.rowHeight-e.outerHeight(!0)/2;i._pushPosition(e,r,a),o.index++})},_cellsByRowGetContainerSize:function(){return{height:Math.ceil(this.$filteredAtoms.length/this.cellsByRow.cols)*this.cellsByRow.rowHeight+this.offset.top}},_cellsByRowResizeChanged:function(){return this._checkIfSegmentsChanged()},_straightDownReset:function(){this.straightDown={y:0}},_straightDownLayout:function(e){var i=this;e.each(function(){var e=t(this);i._pushPosition(e,0,i.straightDown.y),i.straightDown.y+=e.outerHeight(!0)})},_straightDownGetContainerSize:function(){return{height:this.straightDown.y}},_straightDownResizeChanged:function(){return!0},_masonryHorizontalReset:function(){this.masonryHorizontal={},this._getSegments(!0);var e=this.masonryHorizontal.rows;for(this.masonryHorizontal.rowXs=[];e--;)this.masonryHorizontal.rowXs.push(0)},_masonryHorizontalLayout:function(e){var i=this,o=i.masonryHorizontal;e.each(function(){var e=t(this),n=Math.ceil(e.outerHeight(!0)/o.rowHeight);if(n=Math.min(n,o.rows),1===n)i._masonryHorizontalPlaceBrick(e,o.rowXs);else{var s,r,a=o.rows+1-n,l=[];for(r=0;a>r;r++)s=o.rowXs.slice(r,r+n),l[r]=Math.max.apply(Math,s);i._masonryHorizontalPlaceBrick(e,l)}})},_masonryHorizontalPlaceBrick:function(e,t){for(var i=Math.min.apply(Math,t),o=0,n=0,s=t.length;s>n;n++)if(t[n]===i){o=n;break}var r=i,a=this.masonryHorizontal.rowHeight*o;this._pushPosition(e,r,a);var l=i+e.outerWidth(!0),d=this.masonryHorizontal.rows+1-s;for(n=0;d>n;n++)this.masonryHorizontal.rowXs[o+n]=l},_masonryHorizontalGetContainerSize:function(){var e=Math.max.apply(Math,this.masonryHorizontal.rowXs);return{width:e}},_masonryHorizontalResizeChanged:function(){return this._checkIfSegmentsChanged(!0)},_fitColumnsReset:function(){this.fitColumns={x:0,y:0,width:0}},_fitColumnsLayout:function(e){var i=this,o=this.element.height(),n=this.fitColumns;e.each(function(){var e=t(this),s=e.outerWidth(!0),r=e.outerHeight(!0);0!==n.y&&r+n.y>o&&(n.x=n.width,n.y=0),i._pushPosition(e,n.x,n.y),n.width=Math.max(n.x+s,n.width),n.y+=r})},_fitColumnsGetContainerSize:function(){return{width:this.fitColumns.width}},_fitColumnsResizeChanged:function(){return!0},_cellsByColumnReset:function(){this.cellsByColumn={index:0},this._getSegments(),this._getSegments(!0)},_cellsByColumnLayout:function(e){var i=this,o=this.cellsByColumn;e.each(function(){var e=t(this),n=Math.floor(o.index/o.rows),s=o.index%o.rows,r=(n+.5)*o.columnWidth-e.outerWidth(!0)/2,a=(s+.5)*o.rowHeight-e.outerHeight(!0)/2;i._pushPosition(e,r,a),o.index++})},_cellsByColumnGetContainerSize:function(){return{width:Math.ceil(this.$filteredAtoms.length/this.cellsByColumn.rows)*this.cellsByColumn.columnWidth}},_cellsByColumnResizeChanged:function(){return this._checkIfSegmentsChanged(!0)},_straightAcrossReset:function(){this.straightAcross={x:0}},_straightAcrossLayout:function(e){var i=this;e.each(function(){var e=t(this);i._pushPosition(e,i.straightAcross.x,0),i.straightAcross.x+=e.outerWidth(!0)})},_straightAcrossGetContainerSize:function(){return{width:this.straightAcross.x}},_straightAcrossResizeChanged:function(){return!0}},t.fn.imagesLoaded=function(e){function i(){e.call(n,s)}function o(e){var n=e.target;n.src!==a&&-1===t.inArray(n,l)&&(l.push(n),--r<=0&&(setTimeout(i),s.unbind(".imagesLoaded",o)))}var n=this,s=n.find("img").add(n.filter("img")),r=s.length,a="data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///ywAAAAAAQABAAACAUwAOw==",l=[];return r||i(),s.bind("load.imagesLoaded error.imagesLoaded",o).each(function(){var e=this.src;this.src=a,this.src=e}),n};var T=function(t){e.console&&e.console.error(t)};t.fn.isotope=function(e,i){if("string"==typeof e){var o=Array.prototype.slice.call(arguments,1);this.each(function(){var i=t.data(this,"isotope");return i?t.isFunction(i[e])&&"_"!==e.charAt(0)?void i[e].apply(i,o):void T("no such method '"+e+"' for isotope instance"):void T("cannot call methods on isotope prior to initialization; attempted to call method '"+e+"'")})}else this.each(function(){var o=t.data(this,"isotope");o?(o.option(e),o._init(i)):t.data(this,"isotope",new t.Isotope(e,this,i))});return this}}(window,jQuery);var mejs=mejs||{};mejs.version="2.14.2",mejs.meIndex=0,mejs.plugins={silverlight:[{version:[3,0],types:["video/mp4","video/m4v","video/mov","video/wmv","audio/wma","audio/m4a","audio/mp3","audio/wav","audio/mpeg"]}],flash:[{version:[9,0,124],types:["video/mp4","video/m4v","video/mov","video/flv","video/rtmp","video/x-flv","audio/flv","audio/x-flv","audio/mp3","audio/m4a","audio/mpeg","video/youtube","video/x-youtube"]}],youtube:[{version:null,types:["video/youtube","video/x-youtube","audio/youtube","audio/x-youtube"]}],vimeo:[{version:null,types:["video/vimeo","video/x-vimeo"]}]},mejs.Utility={encodeUrl:function(e){return encodeURIComponent(e)},escapeHTML:function(e){return e.toString().split("&").join("&amp;").split("<").join("&lt;").split('"').join("&quot;")},absolutizeUrl:function(e){var t=document.createElement("div");return t.innerHTML='<a href="'+this.escapeHTML(e)+'">x</a>',t.firstChild.href},getScriptPath:function(e){for(var t,i,o,n=0,s="",r="",a=document.getElementsByTagName("script"),l=a.length,d=e.length;l>n;n++){for(i=a[n].src,t=i.lastIndexOf("/"),t>-1?(o=i.substring(t+1),i=i.substring(0,t+1)):(o=i,i=""),t=0;d>t;t++)if(r=e[t],r=o.indexOf(r),r>-1){s=i;break}if(""!==s)break}return s},secondsToTimeCode:function(e,t,i,o){"undefined"==typeof i?i=!1:"undefined"==typeof o&&(o=25);var n=Math.floor(e/3600)%24,s=Math.floor(e/60)%60,r=Math.floor(e%60);return e=Math.floor((e%1*o).toFixed(3)),(t||n>0?(10>n?"0"+n:n)+":":"")+(10>s?"0"+s:s)+":"+(10>r?"0"+r:r)+(i?":"+(10>e?"0"+e:e):"")},timeCodeToSeconds:function(e,t,i,o){"undefined"==typeof i?i=!1:"undefined"==typeof o&&(o=25),e=e.split(":"),t=parseInt(e[0],10);var n=parseInt(e[1],10),s=parseInt(e[2],10),r=0,a=0;return i&&(r=parseInt(e[3])/o),a=3600*t+60*n+s+r},convertSMPTEtoSeconds:function(e){if("string"!=typeof e)return!1;e=e.replace(",",".");var t=0,i=-1!=e.indexOf(".")?e.split(".")[1].length:0,o=1;e=e.split(":").reverse();for(var n=0;n<e.length;n++)o=1,n>0&&(o=Math.pow(60,n)),t+=Number(e[n])*o;return Number(t.toFixed(i))},removeSwf:function(e){var t=document.getElementById(e);t&&/object|embed/i.test(t.nodeName)&&(mejs.MediaFeatures.isIE?(t.style.display="none",function(){4==t.readyState?mejs.Utility.removeObjectInIE(e):setTimeout(arguments.callee,10)}()):t.parentNode.removeChild(t))},removeObjectInIE:function(e){if(e=document.getElementById(e)){for(var t in e)"function"==typeof e[t]&&(e[t]=null);e.parentNode.removeChild(e)}}},mejs.PluginDetector={hasPluginVersion:function(e,t){var i=this.plugins[e];return t[1]=t[1]||0,t[2]=t[2]||0,i[0]>t[0]||i[0]==t[0]&&i[1]>t[1]||i[0]==t[0]&&i[1]==t[1]&&i[2]>=t[2]?!0:!1},nav:window.navigator,ua:window.navigator.userAgent.toLowerCase(),plugins:[],addPlugin:function(e,t,i,o,n){this.plugins[e]=this.detectPlugin(t,i,o,n)},detectPlugin:function(e,t,i,o){var n,s=[0,0,0];if("undefined"!=typeof this.nav.plugins&&"object"==typeof this.nav.plugins[e]){if((i=this.nav.plugins[e].description)&&("undefined"==typeof this.nav.mimeTypes||!this.nav.mimeTypes[t]||this.nav.mimeTypes[t].enabledPlugin))for(s=i.replace(e,"").replace(/^\s+/,"").replace(/\sr/gi,".").split("."),e=0;e<s.length;e++)s[e]=parseInt(s[e].match(/\d+/),10)}else if("undefined"!=typeof window.ActiveXObject)try{(n=new ActiveXObject(i))&&(s=o(n))}catch(r){}return s}},mejs.PluginDetector.addPlugin("flash","Shockwave Flash","application/x-shockwave-flash","ShockwaveFlash.ShockwaveFlash",function(e){var t=[];return(e=e.GetVariable("$version"))&&(e=e.split(" ")[1].split(","),t=[parseInt(e[0],10),parseInt(e[1],10),parseInt(e[2],10)]),t}),mejs.PluginDetector.addPlugin("silverlight","Silverlight Plug-In","application/x-silverlight-2","AgControl.AgControl",function(e){var t=[0,0,0,0],i=function(e,t,i,o){for(;e.isVersionSupported(t[0]+"."+t[1]+"."+t[2]+"."+t[3]);)t[i]+=o;t[i]-=o};return i(e,t,0,1),i(e,t,1,1),i(e,t,2,1e4),i(e,t,2,1e3),i(e,t,2,100),i(e,t,2,10),i(e,t,2,1),i(e,t,3,1),t}),mejs.MediaFeatures={init:function(){var e,t=this,i=document,o=mejs.PluginDetector.nav,n=mejs.PluginDetector.ua.toLowerCase(),s=["source","track","audio","video"];t.isiPad=null!==n.match(/ipad/i),t.isiPhone=null!==n.match(/iphone/i),t.isiOS=t.isiPhone||t.isiPad,t.isAndroid=null!==n.match(/android/i),t.isBustedAndroid=null!==n.match(/android 2\.[12]/),t.isBustedNativeHTTPS="https:"===location.protocol&&(null!==n.match(/android [12]\./)||null!==n.match(/macintosh.* version.* safari/)),t.isIE=-1!=o.appName.toLowerCase().indexOf("microsoft")||null!==o.appName.toLowerCase().match(/trident/gi),t.isChrome=null!==n.match(/chrome/gi),t.isFirefox=null!==n.match(/firefox/gi),t.isWebkit=null!==n.match(/webkit/gi),t.isGecko=null!==n.match(/gecko/gi)&&!t.isWebkit&&!t.isIE,t.isOpera=null!==n.match(/opera/gi),t.hasTouch="ontouchstart"in window,t.svg=!!document.createElementNS&&!!document.createElementNS("http://www.w3.org/2000/svg","svg").createSVGRect;for(o=0;o<s.length;o++)e=document.createElement(s[o]);t.supportsMediaTag="undefined"!=typeof e.canPlayType||t.isBustedAndroid;try{e.canPlayType("video/mp4")}catch(r){t.supportsMediaTag=!1}t.hasSemiNativeFullScreen="undefined"!=typeof e.webkitEnterFullscreen,t.hasNativeFullscreen="undefined"!=typeof e.requestFullscreen,t.hasWebkitNativeFullScreen="undefined"!=typeof e.webkitRequestFullScreen,t.hasMozNativeFullScreen="undefined"!=typeof e.mozRequestFullScreen,t.hasMsNativeFullScreen="undefined"!=typeof e.msRequestFullscreen,t.hasTrueNativeFullScreen=t.hasWebkitNativeFullScreen||t.hasMozNativeFullScreen||t.hasMsNativeFullScreen,t.nativeFullScreenEnabled=t.hasTrueNativeFullScreen,t.hasMozNativeFullScreen?t.nativeFullScreenEnabled=document.mozFullScreenEnabled:t.hasMsNativeFullScreen&&(t.nativeFullScreenEnabled=document.msFullscreenEnabled),t.isChrome&&(t.hasSemiNativeFullScreen=!1),t.hasTrueNativeFullScreen&&(t.fullScreenEventName="",t.hasWebkitNativeFullScreen?t.fullScreenEventName="webkitfullscreenchange":t.hasMozNativeFullScreen?t.fullScreenEventName="mozfullscreenchange":t.hasMsNativeFullScreen&&(t.fullScreenEventName="MSFullscreenChange"),t.isFullScreen=function(){return e.mozRequestFullScreen?i.mozFullScreen:e.webkitRequestFullScreen?i.webkitIsFullScreen:e.hasMsNativeFullScreen?null!==i.msFullscreenElement:void 0},t.requestFullScreen=function(e){t.hasWebkitNativeFullScreen?e.webkitRequestFullScreen():t.hasMozNativeFullScreen?e.mozRequestFullScreen():t.hasMsNativeFullScreen&&e.msRequestFullscreen()},t.cancelFullScreen=function(){t.hasWebkitNativeFullScreen?document.webkitCancelFullScreen():t.hasMozNativeFullScreen?document.mozCancelFullScreen():t.hasMsNativeFullScreen&&document.msExitFullscreen()}),t.hasSemiNativeFullScreen&&n.match(/mac os x 10_5/i)&&(t.hasNativeFullScreen=!1,t.hasSemiNativeFullScreen=!1)}},mejs.MediaFeatures.init(),mejs.HtmlMediaElement={pluginType:"native",isFullScreen:!1,setCurrentTime:function(e){this.currentTime=e},setMuted:function(e){this.muted=e},setVolume:function(e){this.volume=e},stop:function(){this.pause()},setSrc:function(e){for(var t=this.getElementsByTagName("source");t.length>0;)this.removeChild(t[0]);if("string"==typeof e)this.src=e;else{var i;for(t=0;t<e.length;t++)if(i=e[t],this.canPlayType(i.type)){this.src=i.src;break}}},setVideoSize:function(e,t){this.width=e,this.height=t}},mejs.PluginMediaElement=function(e,t,i){this.id=e,this.pluginType=t,this.src=i,this.events={},this.attributes={}},mejs.PluginMediaElement.prototype={pluginElement:null,pluginType:"",isFullScreen:!1,playbackRate:-1,defaultPlaybackRate:-1,seekable:[],played:[],paused:!0,ended:!1,seeking:!1,duration:0,error:null,tagName:"",muted:!1,volume:1,currentTime:0,play:function(){null!=this.pluginApi&&("youtube"==this.pluginType||"vimeo"==this.pluginType?this.pluginApi.playVideo():this.pluginApi.playMedia(),this.paused=!1)},load:function(){null!=this.pluginApi&&("youtube"==this.pluginType||"vimeo"==this.pluginType||this.pluginApi.loadMedia(),this.paused=!1)},pause:function(){null!=this.pluginApi&&("youtube"==this.pluginType||"vimeo"==this.pluginType?this.pluginApi.pauseVideo():this.pluginApi.pauseMedia(),this.paused=!0)},stop:function(){null!=this.pluginApi&&("youtube"==this.pluginType||"vimeo"==this.pluginType?this.pluginApi.stopVideo():this.pluginApi.stopMedia(),this.paused=!0)},canPlayType:function(e){var t,i,o,n=mejs.plugins[this.pluginType];for(t=0;t<n.length;t++)if(o=n[t],mejs.PluginDetector.hasPluginVersion(this.pluginType,o.version))for(i=0;i<o.types.length;i++)if(e==o.types[i])return"probably";return""},positionFullscreenButton:function(e,t,i){null!=this.pluginApi&&this.pluginApi.positionFullscreenButton&&this.pluginApi.positionFullscreenButton(Math.floor(e),Math.floor(t),i)},hideFullscreenButton:function(){null!=this.pluginApi&&this.pluginApi.hideFullscreenButton&&this.pluginApi.hideFullscreenButton()},setSrc:function(e){if("string"==typeof e)this.pluginApi.setSrc(mejs.Utility.absolutizeUrl(e)),this.src=mejs.Utility.absolutizeUrl(e);else{var t,i;for(t=0;t<e.length;t++)if(i=e[t],this.canPlayType(i.type)){this.pluginApi.setSrc(mejs.Utility.absolutizeUrl(i.src)),this.src=mejs.Utility.absolutizeUrl(e);break}}},setCurrentTime:function(e){null!=this.pluginApi&&("youtube"==this.pluginType||"vimeo"==this.pluginType?this.pluginApi.seekTo(e):this.pluginApi.setCurrentTime(e),this.currentTime=e)},setVolume:function(e){null!=this.pluginApi&&(this.pluginApi.setVolume("youtube"==this.pluginType||"vimeo"==this.pluginType?100*e:e),this.volume=e)},setMuted:function(e){null!=this.pluginApi&&("youtube"==this.pluginType||"vimeo"==this.pluginType?(e?this.pluginApi.mute():this.pluginApi.unMute(),this.muted=e,this.dispatchEvent("volumechange")):this.pluginApi.setMuted(e),this.muted=e)},setVideoSize:function(e,t){this.pluginElement.style&&(this.pluginElement.style.width=e+"px",this.pluginElement.style.height=t+"px"),null!=this.pluginApi&&this.pluginApi.setVideoSize&&this.pluginApi.setVideoSize(e,t)},setFullscreen:function(e){null!=this.pluginApi&&this.pluginApi.setFullscreen&&this.pluginApi.setFullscreen(e)},enterFullScreen:function(){null!=this.pluginApi&&this.pluginApi.setFullscreen&&this.setFullscreen(!0)},exitFullScreen:function(){null!=this.pluginApi&&this.pluginApi.setFullscreen&&this.setFullscreen(!1)},addEventListener:function(e,t){this.events[e]=this.events[e]||[],this.events[e].push(t)},removeEventListener:function(e,t){if(!e)return this.events={},!0;var i=this.events[e];if(!i)return!0;if(!t)return this.events[e]=[],!0;for(var o=0;o<i.length;o++)if(i[o]===t)return this.events[e].splice(o,1),!0;return!1},dispatchEvent:function(e){var t,i,o=this.events[e];if(o)for(i=Array.prototype.slice.call(arguments,1),t=0;t<o.length;t++)o[t].apply(null,i)},hasAttribute:function(e){return e in this.attributes},removeAttribute:function(e){delete this.attributes[e]},getAttribute:function(e){return this.hasAttribute(e)?this.attributes[e]:""},setAttribute:function(e,t){this.attributes[e]=t},remove:function(){mejs.Utility.removeSwf(this.pluginElement.id),mejs.MediaPluginBridge.unregisterPluginElement(this.pluginElement.id)}},mejs.MediaPluginBridge={pluginMediaElements:{},htmlMediaElements:{},registerPluginElement:function(e,t,i){this.pluginMediaElements[e]=t,this.htmlMediaElements[e]=i},unregisterPluginElement:function(e){delete this.pluginMediaElements[e],delete this.htmlMediaElements[e]},initPlugin:function(e){var t=this.pluginMediaElements[e],i=this.htmlMediaElements[e];if(t){switch(t.pluginType){case"flash":t.pluginElement=t.pluginApi=document.getElementById(e);break;case"silverlight":t.pluginElement=document.getElementById(t.id),t.pluginApi=t.pluginElement.Content.MediaElementJS}null!=t.pluginApi&&t.success&&t.success(t,i)}},fireEvent:function(e,t,i){var o,n;if(e=this.pluginMediaElements[e]){t={type:t,target:e};for(o in i)e[o]=i[o],t[o]=i[o];n=i.bufferedTime||0,t.target.buffered=t.buffered={start:function(){return 0},end:function(){return n},length:1},e.dispatchEvent(t.type,t)}}},mejs.MediaElementDefaults={mode:"auto",plugins:["flash","silverlight","youtube","vimeo"],enablePluginDebug:!1,httpsBasicAuthSite:!1,type:"",pluginPath:mejs.Utility.getScriptPath(["mediaelement.js","mediaelement.min.js","mediaelement-and-player.js","mediaelement-and-player.min.js"]),flashName:"flashmediaelement.swf",flashStreamer:"",enablePluginSmoothing:!1,enablePseudoStreaming:!1,pseudoStreamingStartQueryParam:"start",silverlightName:"silverlightmediaelement.xap",defaultVideoWidth:480,defaultVideoHeight:270,pluginWidth:-1,pluginHeight:-1,pluginVars:[],timerRate:250,startVolume:.8,success:function(){},error:function(){}},mejs.MediaElement=function(e,t){return mejs.HtmlMediaElementShim.create(e,t)},mejs.HtmlMediaElementShim={create:function(e,t){var i=mejs.MediaElementDefaults,o="string"==typeof e?document.getElementById(e):e,n=o.tagName.toLowerCase(),s="audio"===n||"video"===n,r=o.getAttribute(s?"src":"href");n=o.getAttribute("poster");var a,l=o.getAttribute("autoplay"),d=o.getAttribute("preload"),c=o.getAttribute("controls");for(a in t)i[a]=t[a];return r="undefined"==typeof r||null===r||""==r?null:r,n="undefined"==typeof n||null===n?"":n,d="undefined"==typeof d||null===d||"false"===d?"none":d,l=!("undefined"==typeof l||null===l||"false"===l),c=!("undefined"==typeof c||null===c||"false"===c),a=this.determinePlayback(o,i,mejs.MediaFeatures.supportsMediaTag,s,r),a.url=null!==a.url?mejs.Utility.absolutizeUrl(a.url):"","native"==a.method?(mejs.MediaFeatures.isBustedAndroid&&(o.src=a.url,o.addEventListener("click",function(){o.play()},!1)),this.updateNative(a,i,l,d)):""!==a.method?this.createPlugin(a,i,n,l,d,c):(this.createErrorMessage(a,i,n),this)},determinePlayback:function(e,t,i,o,n){var s,r,a,l,d=[],c={method:"",url:"",htmlMediaElement:e,isVideo:"audio"!=e.tagName.toLowerCase()};if("undefined"!=typeof t.type&&""!==t.type)if("string"==typeof t.type)d.push({type:t.type,url:n});else for(s=0;s<t.type.length;s++)d.push({type:t.type[s],url:n});else if(null!==n)a=this.formatType(n,e.getAttribute("type")),d.push({type:a,url:n});else for(s=0;s<e.childNodes.length;s++)r=e.childNodes[s],1==r.nodeType&&"source"==r.tagName.toLowerCase()&&(n=r.getAttribute("src"),a=this.formatType(n,r.getAttribute("type")),r=r.getAttribute("media"),(!r||!window.matchMedia||window.matchMedia&&window.matchMedia(r).matches)&&d.push({type:a,url:n}));if(!o&&d.length>0&&null!==d[0].url&&this.getTypeFromFile(d[0].url).indexOf("audio")>-1&&(c.isVideo=!1),mejs.MediaFeatures.isBustedAndroid&&(e.canPlayType=function(e){return null!==e.match(/video\/(mp4|m4v)/gi)?"maybe":""}),!(!i||"auto"!==t.mode&&"auto_plugin"!==t.mode&&"native"!==t.mode||mejs.MediaFeatures.isBustedNativeHTTPS&&t.httpsBasicAuthSite===!0)){for(o||(s=document.createElement(c.isVideo?"video":"audio"),e.parentNode.insertBefore(s,e),e.style.display="none",c.htmlMediaElement=e=s),s=0;s<d.length;s++)if(""!==e.canPlayType(d[s].type).replace(/no/,"")||""!==e.canPlayType(d[s].type.replace(/mp3/,"mpeg")).replace(/no/,"")||""!==e.canPlayType(d[s].type.replace(/m4a/,"mp4")).replace(/no/,"")){c.method="native",c.url=d[s].url;break}if("native"===c.method&&(null!==c.url&&(e.src=c.url),"auto_plugin"!==t.mode))return c}if("auto"===t.mode||"auto_plugin"===t.mode||"shim"===t.mode)for(s=0;s<d.length;s++)for(a=d[s].type,e=0;e<t.plugins.length;e++)for(n=t.plugins[e],r=mejs.plugins[n],i=0;i<r.length;i++)if(l=r[i],null==l.version||mejs.PluginDetector.hasPluginVersion(n,l.version))for(o=0;o<l.types.length;o++)if(a==l.types[o])return c.method=n,c.url=d[s].url,c;return"auto_plugin"===t.mode&&"native"===c.method?c:(""===c.method&&d.length>0&&(c.url=d[0].url),c)},formatType:function(e,t){return e&&!t?this.getTypeFromFile(e):t&&~t.indexOf(";")?t.substr(0,t.indexOf(";")):t},getTypeFromFile:function(e){return e=e.split("?")[0],e=e.substring(e.lastIndexOf(".")+1).toLowerCase(),(/(mp4|m4v|ogg|ogv|webm|webmv|flv|wmv|mpeg|mov)/gi.test(e)?"video":"audio")+"/"+this.getTypeFromExtension(e)},getTypeFromExtension:function(e){switch(e){case"mp4":case"m4v":case"m4a":return"mp4";case"webm":case"webma":case"webmv":return"webm";case"ogg":case"oga":case"ogv":return"ogg";default:return e}},createErrorMessage:function(e,t,i){var o=e.htmlMediaElement,n=document.createElement("div");n.className="me-cannotplay";try{n.style.width=o.width+"px",n.style.height=o.height+"px"}catch(s){}n.innerHTML=t.customError?t.customError:""!==i?'<a href="'+e.url+'"><img src="'+i+'" width="100%" height="100%" /></a>':'<a href="'+e.url+'"><span>'+mejs.i18n.t("Download File")+"</span></a>",o.parentNode.insertBefore(n,o),o.style.display="none",t.error(o)},createPlugin:function(e,t,i,o,n,s){i=e.htmlMediaElement;var r,a=1,l=1,d="me_"+e.method+"_"+mejs.meIndex++,c=new mejs.PluginMediaElement(d,e.method,e.url),u=document.createElement("div");for(c.tagName=i.tagName,r=0;r<i.attributes.length;r++){var h=i.attributes[r];1==h.specified&&c.setAttribute(h.name,h.value)}for(r=i.parentNode;null!==r&&"body"!==r.tagName.toLowerCase()&&null!=r.parentNode;){if("p"===r.parentNode.tagName.toLowerCase()){r.parentNode.parentNode.insertBefore(r,r.parentNode);break}r=r.parentNode}switch(e.isVideo?(a=t.pluginWidth>0?t.pluginWidth:t.videoWidth>0?t.videoWidth:null!==i.getAttribute("width")?i.getAttribute("width"):t.defaultVideoWidth,l=t.pluginHeight>0?t.pluginHeight:t.videoHeight>0?t.videoHeight:null!==i.getAttribute("height")?i.getAttribute("height"):t.defaultVideoHeight,a=mejs.Utility.encodeUrl(a),l=mejs.Utility.encodeUrl(l)):t.enablePluginDebug&&(a=320,l=240),c.success=t.success,mejs.MediaPluginBridge.registerPluginElement(d,c,i),u.className="me-plugin",u.id=d+"_container",e.isVideo?i.parentNode.insertBefore(u,i):document.body.insertBefore(u,document.body.childNodes[0]),o=["id="+d,"isvideo="+(e.isVideo?"true":"false"),"autoplay="+(o?"true":"false"),"preload="+n,"width="+a,"startvolume="+t.startVolume,"timerrate="+t.timerRate,"flashstreamer="+t.flashStreamer,"height="+l,"pseudostreamstart="+t.pseudoStreamingStartQueryParam],null!==e.url&&o.push("flash"==e.method?"file="+mejs.Utility.encodeUrl(e.url):"file="+e.url),t.enablePluginDebug&&o.push("debug=true"),t.enablePluginSmoothing&&o.push("smoothing=true"),t.enablePseudoStreaming&&o.push("pseudostreaming=true"),s&&o.push("controls=true"),t.pluginVars&&(o=o.concat(t.pluginVars)),e.method){case"silverlight":u.innerHTML='<object data="data:application/x-silverlight-2," type="application/x-silverlight-2" id="'+d+'" name="'+d+'" width="'+a+'" height="'+l+'" class="mejs-shim"><param name="initParams" value="'+o.join(",")+'" /><param name="windowless" value="true" /><param name="background" value="black" /><param name="minRuntimeVersion" value="3.0.0.0" /><param name="autoUpgrade" value="true" /><param name="source" value="'+t.pluginPath+t.silverlightName+'" /></object>';break;case"flash":mejs.MediaFeatures.isIE?(e=document.createElement("div"),u.appendChild(e),e.outerHTML='<object classid="clsid:D27CDB6E-AE6D-11cf-96B8-444553540000" codebase="//download.macromedia.com/pub/shockwave/cabs/flash/swflash.cab" id="'+d+'" width="'+a+'" height="'+l+'" class="mejs-shim"><param name="movie" value="'+t.pluginPath+t.flashName+"?x="+new Date+'" /><param name="flashvars" value="'+o.join("&amp;")+'" /><param name="quality" value="high" /><param name="bgcolor" value="#000000" /><param name="wmode" value="transparent" /><param name="allowScriptAccess" value="always" /><param name="allowFullScreen" value="true" /><param name="scale" value="default" /></object>'):u.innerHTML='<embed id="'+d+'" name="'+d+'" play="true" loop="false" quality="high" bgcolor="#000000" wmode="transparent" allowScriptAccess="always" allowFullScreen="true" type="application/x-shockwave-flash" pluginspage="//www.macromedia.com/go/getflashplayer" src="'+t.pluginPath+t.flashName+'" flashvars="'+o.join("&")+'" width="'+a+'" height="'+l+'" scale="default"class="mejs-shim"></embed>';break;case"youtube":-1!=e.url.lastIndexOf("youtu.be")?(e=e.url.substr(e.url.lastIndexOf("/")+1),-1!=e.indexOf("?")&&(e=e.substr(0,e.indexOf("?")))):e=e.url.substr(e.url.lastIndexOf("=")+1),youtubeSettings={container:u,containerId:u.id,pluginMediaElement:c,pluginId:d,videoId:e,height:l,width:a},mejs.PluginDetector.hasPluginVersion("flash",[10,0,0])?mejs.YouTubeApi.createFlash(youtubeSettings):mejs.YouTubeApi.enqueueIframe(youtubeSettings);break;case"vimeo":if(t=d+"_player",c.vimeoid=e.url.substr(e.url.lastIndexOf("/")+1),u.innerHTML='<iframe src="//player.vimeo.com/video/'+c.vimeoid+"?api=1&portrait=0&byline=0&title=0&player_id="+t+'" width="'+a+'" height="'+l+'" frameborder="0" class="mejs-shim" id="'+t+'"></iframe>',"function"==typeof $f){var m=$f(u.childNodes[0]);m.addEvent("ready",function(){function e(e,t,i,o){e={type:i,target:t},"timeupdate"==i&&(t.currentTime=e.currentTime=o.seconds,t.duration=e.duration=o.duration),t.dispatchEvent(e.type,e)}m.playVideo=function(){m.api("play")},m.pauseVideo=function(){m.api("pause")
},m.seekTo=function(e){m.api("seekTo",e)},m.addEvent("play",function(){e(m,c,"play"),e(m,c,"playing")}),m.addEvent("pause",function(){e(m,c,"pause")}),m.addEvent("finish",function(){e(m,c,"ended")}),m.addEvent("playProgress",function(t){e(m,c,"timeupdate",t)}),c.pluginApi=m,mejs.MediaPluginBridge.initPlugin(d)})}else console.warn("You need to include froogaloop for vimeo to work")}return i.style.display="none",i.removeAttribute("autoplay"),c},updateNative:function(e,t){var i,o=e.htmlMediaElement;for(i in mejs.HtmlMediaElement)o[i]=mejs.HtmlMediaElement[i];return t.success(o,o),o}},mejs.YouTubeApi={isIframeStarted:!1,isIframeLoaded:!1,loadIframeApi:function(){if(!this.isIframeStarted){var e=document.createElement("script");e.src="//www.youtube.com/player_api";var t=document.getElementsByTagName("script")[0];t.parentNode.insertBefore(e,t),this.isIframeStarted=!0}},iframeQueue:[],enqueueIframe:function(e){this.isLoaded?this.createIframe(e):(this.loadIframeApi(),this.iframeQueue.push(e))},createIframe:function(e){var t=e.pluginMediaElement,i=new YT.Player(e.containerId,{height:e.height,width:e.width,videoId:e.videoId,playerVars:{controls:0},events:{onReady:function(){e.pluginMediaElement.pluginApi=i,mejs.MediaPluginBridge.initPlugin(e.pluginId),setInterval(function(){mejs.YouTubeApi.createEvent(i,t,"timeupdate")},250)},onStateChange:function(e){mejs.YouTubeApi.handleStateChange(e.data,i,t)}}})},createEvent:function(e,t,i){if(i={type:i,target:t},e&&e.getDuration){t.currentTime=i.currentTime=e.getCurrentTime(),t.duration=i.duration=e.getDuration(),i.paused=t.paused,i.ended=t.ended,i.muted=e.isMuted(),i.volume=e.getVolume()/100,i.bytesTotal=e.getVideoBytesTotal(),i.bufferedBytes=e.getVideoBytesLoaded();var o=i.bufferedBytes/i.bytesTotal*i.duration;i.target.buffered=i.buffered={start:function(){return 0},end:function(){return o},length:1}}t.dispatchEvent(i.type,i)},iFrameReady:function(){for(this.isIframeLoaded=this.isLoaded=!0;this.iframeQueue.length>0;)this.createIframe(this.iframeQueue.pop())},flashPlayers:{},createFlash:function(e){this.flashPlayers[e.pluginId]=e;var t,i="//www.youtube.com/apiplayer?enablejsapi=1&amp;playerapiid="+e.pluginId+"&amp;version=3&amp;autoplay=0&amp;controls=0&amp;modestbranding=1&loop=0";mejs.MediaFeatures.isIE?(t=document.createElement("div"),e.container.appendChild(t),t.outerHTML='<object classid="clsid:D27CDB6E-AE6D-11cf-96B8-444553540000" codebase="//download.macromedia.com/pub/shockwave/cabs/flash/swflash.cab" id="'+e.pluginId+'" width="'+e.width+'" height="'+e.height+'" class="mejs-shim"><param name="movie" value="'+i+'" /><param name="wmode" value="transparent" /><param name="allowScriptAccess" value="always" /><param name="allowFullScreen" value="true" /></object>'):e.container.innerHTML='<object type="application/x-shockwave-flash" id="'+e.pluginId+'" data="'+i+'" width="'+e.width+'" height="'+e.height+'" style="visibility: visible; " class="mejs-shim"><param name="allowScriptAccess" value="always"><param name="wmode" value="transparent"></object>'},flashReady:function(e){var t=this.flashPlayers[e],i=document.getElementById(e),o=t.pluginMediaElement;o.pluginApi=o.pluginElement=i,mejs.MediaPluginBridge.initPlugin(e),i.cueVideoById(t.videoId),e=t.containerId+"_callback",window[e]=function(e){mejs.YouTubeApi.handleStateChange(e,i,o)},i.addEventListener("onStateChange",e),setInterval(function(){mejs.YouTubeApi.createEvent(i,o,"timeupdate")},250)},handleStateChange:function(e,t,i){switch(e){case-1:i.paused=!0,i.ended=!0,mejs.YouTubeApi.createEvent(t,i,"loadedmetadata");break;case 0:i.paused=!1,i.ended=!0,mejs.YouTubeApi.createEvent(t,i,"ended");break;case 1:i.paused=!1,i.ended=!1,mejs.YouTubeApi.createEvent(t,i,"play"),mejs.YouTubeApi.createEvent(t,i,"playing");break;case 2:i.paused=!0,i.ended=!1,mejs.YouTubeApi.createEvent(t,i,"pause");break;case 3:mejs.YouTubeApi.createEvent(t,i,"progress")}}},window.mejs=mejs,window.MediaElement=mejs.MediaElement,function(e,t){var i={locale:{language:"",strings:{}},methods:{}};i.getLanguage=function(){return(i.locale.language||window.navigator.userLanguage||window.navigator.language).substr(0,2).toLowerCase()},"undefined"!=typeof mejsL10n&&(i.locale.language=mejsL10n.language),i.methods.checkPlain=function(e){var t,i,o={"&":"&amp;",'"':"&quot;","<":"&lt;",">":"&gt;"};e=String(e);for(t in o)o.hasOwnProperty(t)&&(i=RegExp(t,"g"),e=e.replace(i,o[t]));return e},i.methods.t=function(e,t){return i.locale.strings&&i.locale.strings[t.context]&&i.locale.strings[t.context][e]&&(e=i.locale.strings[t.context][e]),i.methods.checkPlain(e)},i.t=function(e,t){if("string"==typeof e&&e.length>0){var o=i.getLanguage();return t=t||{context:o},i.methods.t(e,t)}throw{name:"InvalidArgumentException",message:"First argument is either not a string or empty."}},t.i18n=i}(document,mejs),function(e){"undefined"!=typeof mejsL10n&&(e[mejsL10n.language]=mejsL10n.strings)}(mejs.i18n.locale.strings),function(e){"undefined"==typeof e.de&&(e.de={Fullscreen:"Vollbild","Go Fullscreen":"Vollbild an","Turn off Fullscreen":"Vollbild aus",Close:"Schließen"})}(mejs.i18n.locale.strings),function(e){"undefined"==typeof e.zh&&(e.zh={Fullscreen:"全螢幕","Go Fullscreen":"全屏模式","Turn off Fullscreen":"退出全屏模式",Close:"關閉"})}(mejs.i18n.locale.strings),"undefined"!=typeof jQuery?mejs.$=jQuery:"undefined"!=typeof ender&&(mejs.$=ender),function(e){mejs.MepDefaults={poster:"",showPosterWhenEnded:!1,defaultVideoWidth:480,defaultVideoHeight:270,videoWidth:-1,videoHeight:-1,defaultAudioWidth:400,defaultAudioHeight:30,defaultSeekBackwardInterval:function(e){return.05*e.duration},defaultSeekForwardInterval:function(e){return.05*e.duration},audioWidth:-1,audioHeight:-1,startVolume:.8,loop:!1,autoRewind:!0,enableAutosize:!0,alwaysShowHours:!1,showTimecodeFrameCount:!1,framesPerSecond:25,autosizeProgress:!0,alwaysShowControls:!1,hideVideoControlsOnLoad:!1,clickToPlayPause:!0,iPadUseNativeControls:!1,iPhoneUseNativeControls:!1,AndroidUseNativeControls:!1,features:["playpause","current","progress","duration","tracks","volume","fullscreen"],isVideo:!0,enableKeyboard:!0,pauseOtherPlayers:!0,keyActions:[{keys:[32,179],action:function(e,t){t.paused||t.ended?e.play():e.pause()}},{keys:[38],action:function(e,t){t.setVolume(Math.min(t.volume+.1,1))}},{keys:[40],action:function(e,t){t.setVolume(Math.max(t.volume-.1,0))}},{keys:[37,227],action:function(e,t){if(!isNaN(t.duration)&&t.duration>0){e.isVideo&&(e.showControls(),e.startControlsTimer());var i=Math.max(t.currentTime-e.options.defaultSeekBackwardInterval(t),0);t.setCurrentTime(i)}}},{keys:[39,228],action:function(e,t){if(!isNaN(t.duration)&&t.duration>0){e.isVideo&&(e.showControls(),e.startControlsTimer());var i=Math.min(t.currentTime+e.options.defaultSeekForwardInterval(t),t.duration);t.setCurrentTime(i)}}},{keys:[70],action:function(e){"undefined"!=typeof e.enterFullScreen&&(e.isFullScreen?e.exitFullScreen():e.enterFullScreen())}}]},mejs.mepIndex=0,mejs.players={},mejs.MediaElementPlayer=function(t,i){return this instanceof mejs.MediaElementPlayer?(this.$media=this.$node=e(t),this.node=this.media=this.$media[0],"undefined"!=typeof this.node.player?this.node.player:(this.node.player=this,"undefined"==typeof i&&(i=this.$node.data("mejsoptions")),this.options=e.extend({},mejs.MepDefaults,i),this.id="mep_"+mejs.mepIndex++,mejs.players[this.id]=this,this.init(),this)):new mejs.MediaElementPlayer(t,i)},mejs.MediaElementPlayer.prototype={hasFocus:!1,controlsAreVisible:!0,init:function(){var t=this,i=mejs.MediaFeatures,o=e.extend(!0,{},t.options,{success:function(e,i){t.meReady(e,i)},error:function(e){t.handleError(e)}}),n=t.media.tagName.toLowerCase();t.isDynamic="audio"!==n&&"video"!==n,t.isVideo=t.isDynamic?t.options.isVideo:"audio"!==n&&t.options.isVideo,i.isiPad&&t.options.iPadUseNativeControls||i.isiPhone&&t.options.iPhoneUseNativeControls?(t.$media.attr("controls","controls"),i.isiPad&&null!==t.media.getAttribute("autoplay")&&t.play()):i.isAndroid&&t.options.AndroidUseNativeControls||(t.$media.removeAttr("controls"),t.container=e('<div id="'+t.id+'" class="mejs-container '+(mejs.MediaFeatures.svg?"svg":"no-svg")+'"><div class="mejs-inner"><div class="mejs-mediaelement"></div><div class="mejs-layers"></div><div class="mejs-controls"></div><div class="mejs-clear"></div></div></div>').addClass(t.$media[0].className).insertBefore(t.$media),t.container.addClass((i.isAndroid?"mejs-android ":"")+(i.isiOS?"mejs-ios ":"")+(i.isiPad?"mejs-ipad ":"")+(i.isiPhone?"mejs-iphone ":"")+(t.isVideo?"mejs-video ":"mejs-audio ")),i.isiOS?(i=t.$media.clone(),t.container.find(".mejs-mediaelement").append(i),t.$media.remove(),t.$node=t.$media=i,t.node=t.media=i[0]):t.container.find(".mejs-mediaelement").append(t.$media),t.controls=t.container.find(".mejs-controls"),t.layers=t.container.find(".mejs-layers"),i=t.isVideo?"video":"audio",n=i.substring(0,1).toUpperCase()+i.substring(1),t.width=t.options[i+"Width"]>0||t.options[i+"Width"].toString().indexOf("%")>-1?t.options[i+"Width"]:""!==t.media.style.width&&null!==t.media.style.width?t.media.style.width:null!==t.media.getAttribute("width")?t.$media.attr("width"):t.options["default"+n+"Width"],t.height=t.options[i+"Height"]>0||t.options[i+"Height"].toString().indexOf("%")>-1?t.options[i+"Height"]:""!==t.media.style.height&&null!==t.media.style.height?t.media.style.height:null!==t.$media[0].getAttribute("height")?t.$media.attr("height"):t.options["default"+n+"Height"],t.setPlayerSize(t.width,t.height),o.pluginWidth=t.width,o.pluginHeight=t.height),mejs.MediaElement(t.$media[0],o),"undefined"!=typeof t.container&&t.controlsAreVisible&&t.container.trigger("controlsshown")},showControls:function(e){var t=this;e="undefined"==typeof e||e,t.controlsAreVisible||(e?(t.controls.css("visibility","visible").stop(!0,!0).fadeIn(200,function(){t.controlsAreVisible=!0,t.container.trigger("controlsshown")}),t.container.find(".mejs-control").css("visibility","visible").stop(!0,!0).fadeIn(200,function(){t.controlsAreVisible=!0})):(t.controls.css("visibility","visible").css("display","block"),t.container.find(".mejs-control").css("visibility","visible").css("display","block"),t.controlsAreVisible=!0,t.container.trigger("controlsshown")),t.setControlsSize())},hideControls:function(t){var i=this;t="undefined"==typeof t||t,i.controlsAreVisible&&!i.options.alwaysShowControls&&(t?(i.controls.stop(!0,!0).fadeOut(200,function(){e(this).css("visibility","hidden").css("display","block"),i.controlsAreVisible=!1,i.container.trigger("controlshidden")}),i.container.find(".mejs-control").stop(!0,!0).fadeOut(200,function(){e(this).css("visibility","hidden").css("display","block")})):(i.controls.css("visibility","hidden").css("display","block"),i.container.find(".mejs-control").css("visibility","hidden").css("display","block"),i.controlsAreVisible=!1,i.container.trigger("controlshidden")))},controlsTimer:null,startControlsTimer:function(e){var t=this;e="undefined"!=typeof e?e:1500,t.killControlsTimer("start"),t.controlsTimer=setTimeout(function(){t.hideControls(),t.killControlsTimer("hide")},e)},killControlsTimer:function(){null!==this.controlsTimer&&(clearTimeout(this.controlsTimer),delete this.controlsTimer,this.controlsTimer=null)},controlsEnabled:!0,disableControls:function(){this.killControlsTimer(),this.hideControls(!1),this.controlsEnabled=!1},enableControls:function(){this.showControls(!1),this.controlsEnabled=!0},meReady:function(e,t){var i=this,o=mejs.MediaFeatures,n=t.getAttribute("autoplay");n=!("undefined"==typeof n||null===n||"false"===n);var s;if(!i.created){if(i.created=!0,i.media=e,i.domNode=t,!(o.isAndroid&&i.options.AndroidUseNativeControls||o.isiPad&&i.options.iPadUseNativeControls||o.isiPhone&&i.options.iPhoneUseNativeControls)){i.buildposter(i,i.controls,i.layers,i.media),i.buildkeyboard(i,i.controls,i.layers,i.media),i.buildoverlays(i,i.controls,i.layers,i.media),i.findTracks();for(s in i.options.features)if(o=i.options.features[s],i["build"+o])try{i["build"+o](i,i.controls,i.layers,i.media)}catch(r){}i.container.trigger("controlsready"),i.setPlayerSize(i.width,i.height),i.setControlsSize(),i.isVideo&&(mejs.MediaFeatures.hasTouch?i.$media.bind("touchstart",function(){i.controlsAreVisible?i.hideControls(!1):i.controlsEnabled&&i.showControls(!1)}):(i.clickToPlayPauseCallback=function(){i.options.clickToPlayPause&&(i.media.paused?i.play():i.pause())},i.media.addEventListener("click",i.clickToPlayPauseCallback,!1),i.container.bind("mouseenter mouseover",function(){i.controlsEnabled&&(i.options.alwaysShowControls||(i.killControlsTimer("enter"),i.showControls(),i.startControlsTimer(2500)))}).bind("mousemove",function(){i.controlsEnabled&&(i.controlsAreVisible||i.showControls(),i.options.alwaysShowControls||i.startControlsTimer(2500))}).bind("mouseleave",function(){i.controlsEnabled&&!i.media.paused&&!i.options.alwaysShowControls&&i.startControlsTimer(1e3)})),i.options.hideVideoControlsOnLoad&&i.hideControls(!1),n&&!i.options.alwaysShowControls&&i.hideControls(),i.options.enableAutosize&&i.media.addEventListener("loadedmetadata",function(e){i.options.videoHeight<=0&&null===i.domNode.getAttribute("height")&&!isNaN(e.target.videoHeight)&&(i.setPlayerSize(e.target.videoWidth,e.target.videoHeight),i.setControlsSize(),i.media.setVideoSize(e.target.videoWidth,e.target.videoHeight))},!1)),e.addEventListener("play",function(){for(var e in mejs.players){var t=mejs.players[e];t.id!=i.id&&i.options.pauseOtherPlayers&&!t.paused&&!t.ended&&t.pause(),t.hasFocus=!1}i.hasFocus=!0},!1),i.media.addEventListener("ended",function(){if(i.options.autoRewind)try{i.media.setCurrentTime(0)}catch(e){}i.media.pause(),i.setProgressRail&&i.setProgressRail(),i.setCurrentRail&&i.setCurrentRail(),i.options.loop?i.play():!i.options.alwaysShowControls&&i.controlsEnabled&&i.showControls()},!1),i.media.addEventListener("loadedmetadata",function(){i.updateDuration&&i.updateDuration(),i.updateCurrent&&i.updateCurrent(),i.isFullScreen||(i.setPlayerSize(i.width,i.height),i.setControlsSize())},!1),setTimeout(function(){i.setPlayerSize(i.width,i.height),i.setControlsSize()},50),i.globalBind("resize",function(){i.isFullScreen||mejs.MediaFeatures.hasTrueNativeFullScreen&&document.webkitIsFullScreen||i.setPlayerSize(i.width,i.height),i.setControlsSize()}),"youtube"==i.media.pluginType&&i.container.find(".mejs-overlay-play").hide()}n&&"native"==e.pluginType&&i.play(),i.options.success&&("string"==typeof i.options.success?window[i.options.success](i.media,i.domNode,i):i.options.success(i.media,i.domNode,i))}},handleError:function(e){this.controls.hide(),this.options.error&&this.options.error(e)},setPlayerSize:function(t,i){if("undefined"!=typeof t&&(this.width=t),"undefined"!=typeof i&&(this.height=i),this.height.toString().indexOf("%")>0||"100%"===this.$node.css("max-width")||parseInt(this.$node.css("max-width").replace(/px/,""),10)/this.$node.offsetParent().width()===1||this.$node[0].currentStyle&&"100%"===this.$node[0].currentStyle.maxWidth){var o=this.isVideo?this.media.videoWidth&&this.media.videoWidth>0?this.media.videoWidth:this.options.defaultVideoWidth:this.options.defaultAudioWidth,n=this.isVideo?this.media.videoHeight&&this.media.videoHeight>0?this.media.videoHeight:this.options.defaultVideoHeight:this.options.defaultAudioHeight,s=this.container.parent().closest(":visible").width();o=this.isVideo||!this.options.autosizeProgress?parseInt(s*n/o,10):n,isNaN(o)&&(o=this.container.parent().closest(":visible").height()),"body"===this.container.parent()[0].tagName.toLowerCase()&&(s=e(window).width(),o=e(window).height()),0!=o&&0!=s&&(this.container.width(s).height(o),this.$media.add(this.container.find(".mejs-shim")).width("100%").height("100%"),this.isVideo&&this.media.setVideoSize&&this.media.setVideoSize(s,o),this.layers.children(".mejs-layer").width("100%").height("100%"))}else this.container.width(this.width).height(this.height),this.layers.children(".mejs-layer").width(this.width).height(this.height);s=this.layers.find(".mejs-overlay-play"),o=s.find(".mejs-overlay-button"),s.height(this.container.height()-this.controls.height()),o.css("margin-top","-"+(o.height()/2-this.controls.height()/2).toString()+"px")},setControlsSize:function(){var t=0,i=0,o=this.controls.find(".mejs-time-rail"),n=this.controls.find(".mejs-time-total");this.controls.find(".mejs-time-current"),this.controls.find(".mejs-time-loaded");var s=o.siblings(),r=s.last(),a=null;if(this.container.is(":visible")&&o.length&&o.is(":visible")){this.options&&!this.options.autosizeProgress&&(i=parseInt(o.css("width"))),0!==i&&i||(s.each(function(){var i=e(this);"absolute"!=i.css("position")&&i.is(":visible")&&(t+=e(this).outerWidth(!0))}),i=this.controls.width()-t-(o.outerWidth(!0)-o.width()));do o.width(i),n.width(i-(n.outerWidth(!0)-n.width())),"absolute"!=r.css("position")&&(a=r.position(),i--);while(null!=a&&a.top>0&&i>0);this.setProgressRail&&this.setProgressRail(),this.setCurrentRail&&this.setCurrentRail()}},buildposter:function(t,i,o,n){var s=e('<div class="mejs-poster mejs-layer"></div>').appendTo(o);i=t.$media.attr("poster"),""!==t.options.poster&&(i=t.options.poster),""!==i&&null!=i?this.setPoster(i):s.hide(),n.addEventListener("play",function(){s.hide()},!1),t.options.showPosterWhenEnded&&t.options.autoRewind&&n.addEventListener("ended",function(){s.show()},!1)},setPoster:function(t){var i=this.container.find(".mejs-poster"),o=i.find("img");0==o.length&&(o=e('<img width="100%" height="100%" />').appendTo(i)),o.attr("src",t),i.css({"background-image":"url("+t+")"})},buildoverlays:function(t,i,o,n){var s=this;if(t.isVideo){var r=e('<div class="mejs-overlay mejs-layer"><div class="mejs-overlay-loading"><span></span></div></div>').hide().appendTo(o),a=e('<div class="mejs-overlay mejs-layer"><div class="mejs-overlay-error"></div></div>').hide().appendTo(o),l=e('<div class="mejs-overlay mejs-layer mejs-overlay-play"><div class="mejs-overlay-button"></div></div>').appendTo(o).bind("click touchstart",function(){s.options.clickToPlayPause&&n.paused&&n.play()});n.addEventListener("play",function(){l.hide(),r.hide(),i.find(".mejs-time-buffering").hide(),a.hide()},!1),n.addEventListener("playing",function(){l.hide(),r.hide(),i.find(".mejs-time-buffering").hide(),a.hide()},!1),n.addEventListener("seeking",function(){r.show(),i.find(".mejs-time-buffering").show()},!1),n.addEventListener("seeked",function(){r.hide(),i.find(".mejs-time-buffering").hide()},!1),n.addEventListener("pause",function(){mejs.MediaFeatures.isiPhone||l.show()},!1),n.addEventListener("waiting",function(){r.show(),i.find(".mejs-time-buffering").show()},!1),n.addEventListener("loadeddata",function(){r.show(),i.find(".mejs-time-buffering").show()},!1),n.addEventListener("canplay",function(){r.hide(),i.find(".mejs-time-buffering").hide()},!1),n.addEventListener("error",function(){r.hide(),i.find(".mejs-time-buffering").hide(),a.show(),a.find("mejs-overlay-error").html("Error loading this resource")},!1)}},buildkeyboard:function(t,i,o,n){this.globalBind("keydown",function(e){if(t.hasFocus&&t.options.enableKeyboard)for(var i=0,o=t.options.keyActions.length;o>i;i++)for(var s=t.options.keyActions[i],r=0,a=s.keys.length;a>r;r++)if(e.keyCode==s.keys[r])return e.preventDefault(),s.action(t,n,e.keyCode),!1;return!0}),this.globalBind("click",function(i){t.hasFocus=0!=e(i.target).closest(".mejs-container").length})},findTracks:function(){var t=this,i=t.$media.find("track");t.tracks=[],i.each(function(i,o){o=e(o),t.tracks.push({srclang:o.attr("srclang")?o.attr("srclang").toLowerCase():"",src:o.attr("src"),kind:o.attr("kind"),label:o.attr("label")||"",entries:[],isLoaded:!1})})},changeSkin:function(e){this.container[0].className="mejs-container "+e,this.setPlayerSize(this.width,this.height),this.setControlsSize()},play:function(){this.load(),this.media.play()},pause:function(){try{this.media.pause()}catch(e){}},load:function(){this.isLoaded||this.media.load(),this.isLoaded=!0},setMuted:function(e){this.media.setMuted(e)},setCurrentTime:function(e){this.media.setCurrentTime(e)},getCurrentTime:function(){return this.media.currentTime},setVolume:function(e){this.media.setVolume(e)},getVolume:function(){return this.media.volume},setSrc:function(e){this.media.setSrc(e)},remove:function(){var e,t;for(e in this.options.features)if(t=this.options.features[e],this["clean"+t])try{this["clean"+t](this)}catch(i){}this.isDynamic?this.$node.insertBefore(this.container):(this.$media.prop("controls",!0),this.$node.clone().show().insertBefore(this.container),this.$node.remove()),"native"!==this.media.pluginType&&this.media.remove(),delete mejs.players[this.id],"object"==typeof this.container&&this.container.remove(),this.globalUnbind(),delete this.node.player}},function(){function t(t,o){var n={d:[],w:[]};return e.each((t||"").split(" "),function(e,t){var s=t+"."+o;0===s.indexOf(".")?(n.d.push(s),n.w.push(s)):n[i.test(t)?"w":"d"].push(s)}),n.d=n.d.join(" "),n.w=n.w.join(" "),n}var i=/^((after|before)print|(before)?unload|hashchange|message|o(ff|n)line|page(hide|show)|popstate|resize|storage)\b/;mejs.MediaElementPlayer.prototype.globalBind=function(i,o,n){i=t(i,this.id),i.d&&e(document).bind(i.d,o,n),i.w&&e(window).bind(i.w,o,n)},mejs.MediaElementPlayer.prototype.globalUnbind=function(i,o){i=t(i,this.id),i.d&&e(document).unbind(i.d,o),i.w&&e(window).unbind(i.w,o)}}(),"undefined"!=typeof jQuery&&(jQuery.fn.mediaelementplayer=function(e){return this.each(e===!1?function(){var e=jQuery(this).data("mediaelementplayer");e&&e.remove(),jQuery(this).removeData("mediaelementplayer")}:function(){jQuery(this).data("mediaelementplayer",new mejs.MediaElementPlayer(this,e))}),this}),e(document).ready(function(){e(".mejs-player").mediaelementplayer()}),window.MediaElementPlayer=mejs.MediaElementPlayer}(mejs.$),function(e){e.extend(mejs.MepDefaults,{playpauseText:mejs.i18n.t("Play/Pause")}),e.extend(MediaElementPlayer.prototype,{buildplaypause:function(t,i,o,n){var s=e('<div class="mejs-button mejs-playpause-button mejs-play" ><button type="button" aria-controls="'+this.id+'" title="'+this.options.playpauseText+'" aria-label="'+this.options.playpauseText+'"></button></div>').appendTo(i).click(function(e){return e.preventDefault(),n.paused?n.play():n.pause(),!1});n.addEventListener("play",function(){s.removeClass("mejs-play").addClass("mejs-pause")},!1),n.addEventListener("playing",function(){s.removeClass("mejs-play").addClass("mejs-pause")},!1),n.addEventListener("pause",function(){s.removeClass("mejs-pause").addClass("mejs-play")},!1),n.addEventListener("paused",function(){s.removeClass("mejs-pause").addClass("mejs-play")},!1)}})}(mejs.$),function(e){e.extend(mejs.MepDefaults,{stopText:"Stop"}),e.extend(MediaElementPlayer.prototype,{buildstop:function(t,i,o,n){e('<div class="mejs-button mejs-stop-button mejs-stop"><button type="button" aria-controls="'+this.id+'" title="'+this.options.stopText+'" aria-label="'+this.options.stopText+'"></button></div>').appendTo(i).click(function(){n.paused||n.pause(),n.currentTime>0&&(n.setCurrentTime(0),n.pause(),i.find(".mejs-time-current").width("0px"),i.find(".mejs-time-handle").css("left","0px"),i.find(".mejs-time-float-current").html(mejs.Utility.secondsToTimeCode(0)),i.find(".mejs-currenttime").html(mejs.Utility.secondsToTimeCode(0)),o.find(".mejs-poster").show())})}})}(mejs.$),function(e){e.extend(MediaElementPlayer.prototype,{buildprogress:function(t,i,o,n){e('<div class="mejs-time-rail"><span class="mejs-time-total"><span class="mejs-time-buffering"></span><span class="mejs-time-loaded"></span><span class="mejs-time-current"></span><span class="mejs-time-handle"></span><span class="mejs-time-float"><span class="mejs-time-float-current">00:00</span><span class="mejs-time-float-corner"></span></span></span></div>').appendTo(i),i.find(".mejs-time-buffering").hide();var s=this,r=i.find(".mejs-time-total");o=i.find(".mejs-time-loaded");var a=i.find(".mejs-time-current"),l=i.find(".mejs-time-handle"),d=i.find(".mejs-time-float"),c=i.find(".mejs-time-float-current"),u=function(e){e=e.originalEvent.changedTouches?e.originalEvent.changedTouches[0].pageX:e.pageX;var t=r.offset(),i=r.outerWidth(!0),o=0,s=o=0;n.duration&&(e<t.left?e=t.left:e>i+t.left&&(e=i+t.left),s=e-t.left,o=s/i,o=.02>=o?0:o*n.duration,h&&o!==n.currentTime&&n.setCurrentTime(o),mejs.MediaFeatures.hasTouch||(d.css("left",s),c.html(mejs.Utility.secondsToTimeCode(o)),d.show()))},h=!1;r.bind("mousedown touchstart",function(e){return 1===e.which||0===e.which?(h=!0,u(e),s.globalBind("mousemove.dur touchmove.dur",function(e){u(e)}),s.globalBind("mouseup.dur touchend.dur",function(){h=!1,d.hide(),s.globalUnbind(".dur")}),!1):void 0}).bind("mouseenter",function(){s.globalBind("mousemove.dur",function(e){u(e)}),mejs.MediaFeatures.hasTouch||d.show()}).bind("mouseleave",function(){h||(s.globalUnbind(".dur"),d.hide())}),n.addEventListener("progress",function(e){t.setProgressRail(e),t.setCurrentRail(e)},!1),n.addEventListener("timeupdate",function(e){t.setProgressRail(e),t.setCurrentRail(e)},!1),s.loaded=o,s.total=r,s.current=a,s.handle=l},setProgressRail:function(e){var t=void 0!=e?e.target:this.media,i=null;t&&t.buffered&&t.buffered.length>0&&t.buffered.end&&t.duration?i=t.buffered.end(0)/t.duration:t&&void 0!=t.bytesTotal&&t.bytesTotal>0&&void 0!=t.bufferedBytes?i=t.bufferedBytes/t.bytesTotal:e&&e.lengthComputable&&0!=e.total&&(i=e.loaded/e.total),null!==i&&(i=Math.min(1,Math.max(0,i)),this.loaded&&this.total&&this.loaded.width(this.total.width()*i))},setCurrentRail:function(){if(void 0!=this.media.currentTime&&this.media.duration&&this.total&&this.handle){var e=Math.round(this.total.width()*this.media.currentTime/this.media.duration),t=e-Math.round(this.handle.outerWidth(!0)/2);this.current.width(e),this.handle.css("left",t)}}})}(mejs.$),function(e){e.extend(mejs.MepDefaults,{duration:-1,timeAndDurationSeparator:"<span> | </span>"}),e.extend(MediaElementPlayer.prototype,{buildcurrent:function(t,i,o,n){e('<div class="mejs-time"><span class="mejs-currenttime">'+(t.options.alwaysShowHours?"00:":"")+(t.options.showTimecodeFrameCount?"00:00:00":"00:00")+"</span></div>").appendTo(i),this.currenttime=this.controls.find(".mejs-currenttime"),n.addEventListener("timeupdate",function(){t.updateCurrent()},!1)},buildduration:function(t,i,o,n){i.children().last().find(".mejs-currenttime").length>0?e(this.options.timeAndDurationSeparator+'<span class="mejs-duration">'+(this.options.duration>0?mejs.Utility.secondsToTimeCode(this.options.duration,this.options.alwaysShowHours||this.media.duration>3600,this.options.showTimecodeFrameCount,this.options.framesPerSecond||25):(t.options.alwaysShowHours?"00:":"")+(t.options.showTimecodeFrameCount?"00:00:00":"00:00"))+"</span>").appendTo(i.find(".mejs-time")):(i.find(".mejs-currenttime").parent().addClass("mejs-currenttime-container"),e('<div class="mejs-time mejs-duration-container"><span class="mejs-duration">'+(this.options.duration>0?mejs.Utility.secondsToTimeCode(this.options.duration,this.options.alwaysShowHours||this.media.duration>3600,this.options.showTimecodeFrameCount,this.options.framesPerSecond||25):(t.options.alwaysShowHours?"00:":"")+(t.options.showTimecodeFrameCount?"00:00:00":"00:00"))+"</span></div>").appendTo(i)),this.durationD=this.controls.find(".mejs-duration"),n.addEventListener("timeupdate",function(){t.updateDuration()},!1)},updateCurrent:function(){this.currenttime&&this.currenttime.html(mejs.Utility.secondsToTimeCode(this.media.currentTime,this.options.alwaysShowHours||this.media.duration>3600,this.options.showTimecodeFrameCount,this.options.framesPerSecond||25))},updateDuration:function(){this.container.toggleClass("mejs-long-video",this.media.duration>3600),this.durationD&&(this.options.duration>0||this.media.duration)&&this.durationD.html(mejs.Utility.secondsToTimeCode(this.options.duration>0?this.options.duration:this.media.duration,this.options.alwaysShowHours,this.options.showTimecodeFrameCount,this.options.framesPerSecond||25))}})}(mejs.$),function(e){e.extend(mejs.MepDefaults,{muteText:mejs.i18n.t("Mute Toggle"),hideVolumeOnTouchDevices:!0,audioVolume:"horizontal",videoVolume:"vertical"}),e.extend(MediaElementPlayer.prototype,{buildvolume:function(t,i,o,n){if(!mejs.MediaFeatures.isAndroid&&!mejs.MediaFeatures.isiOS||!this.options.hideVolumeOnTouchDevices){var s=this,r=s.isVideo?s.options.videoVolume:s.options.audioVolume,a="horizontal"==r?e('<div class="mejs-button mejs-volume-button mejs-mute"><button type="button" aria-controls="'+s.id+'" title="'+s.options.muteText+'" aria-label="'+s.options.muteText+'"></button></div><div class="mejs-horizontal-volume-slider"><div class="mejs-horizontal-volume-total"></div><div class="mejs-horizontal-volume-current"></div><div class="mejs-horizontal-volume-handle"></div></div>').appendTo(i):e('<div class="mejs-button mejs-volume-button mejs-mute"><button type="button" aria-controls="'+s.id+'" title="'+s.options.muteText+'" aria-label="'+s.options.muteText+'"></button><div class="mejs-volume-slider"><div class="mejs-volume-total"></div><div class="mejs-volume-current"></div><div class="mejs-volume-handle"></div></div></div>').appendTo(i),l=s.container.find(".mejs-volume-slider, .mejs-horizontal-volume-slider"),d=s.container.find(".mejs-volume-total, .mejs-horizontal-volume-total"),c=s.container.find(".mejs-volume-current, .mejs-horizontal-volume-current"),u=s.container.find(".mejs-volume-handle, .mejs-horizontal-volume-handle"),h=function(e,t){if(l.is(":visible")||"undefined"!=typeof t)if(e=Math.max(0,e),e=Math.min(e,1),0==e?a.removeClass("mejs-mute").addClass("mejs-unmute"):a.removeClass("mejs-unmute").addClass("mejs-mute"),"vertical"==r){var i=d.height(),o=d.position(),n=i-i*e;u.css("top",Math.round(o.top+n-u.height()/2)),c.height(i-n),c.css("top",o.top+n)}else i=d.width(),o=d.position(),i*=e,u.css("left",Math.round(o.left+i-u.width()/2)),c.width(Math.round(i));else l.show(),h(e,!0),l.hide()},m=function(e){var t=null,i=d.offset();if("vertical"==r){if(t=d.height(),parseInt(d.css("top").replace(/px/,""),10),t=(t-(e.pageY-i.top))/t,0==i.top||0==i.left)return}else t=d.width(),t=(e.pageX-i.left)/t;t=Math.max(0,t),t=Math.min(t,1),h(t),n.setMuted(0==t?!0:!1),n.setVolume(t)},p=!1,f=!1;a.hover(function(){l.show(),f=!0},function(){f=!1,!p&&"vertical"==r&&l.hide()}),l.bind("mouseover",function(){f=!0}).bind("mousedown",function(e){return m(e),s.globalBind("mousemove.vol",function(e){m(e)}),s.globalBind("mouseup.vol",function(){p=!1,s.globalUnbind(".vol"),!f&&"vertical"==r&&l.hide()}),p=!0,!1}),a.find("button").click(function(){n.setMuted(!n.muted)}),n.addEventListener("volumechange",function(){p||(n.muted?(h(0),a.removeClass("mejs-mute").addClass("mejs-unmute")):(h(n.volume),a.removeClass("mejs-unmute").addClass("mejs-mute")))},!1),s.container.is(":visible")&&(h(t.options.startVolume),0===t.options.startVolume&&n.setMuted(!0),"native"===n.pluginType&&n.setVolume(t.options.startVolume))}}})}(mejs.$),function(e){e.extend(mejs.MepDefaults,{usePluginFullScreen:!0,newWindowCallback:function(){return""},fullscreenText:mejs.i18n.t("Fullscreen")}),e.extend(MediaElementPlayer.prototype,{isFullScreen:!1,isNativeFullScreen:!1,isInIframe:!1,buildfullscreen:function(t,i,o,n){if(t.isVideo){t.isInIframe=window.location!=window.parent.location,mejs.MediaFeatures.hasTrueNativeFullScreen&&(o=function(){t.isFullScreen&&(mejs.MediaFeatures.isFullScreen()?(t.isNativeFullScreen=!0,t.setControlsSize()):(t.isNativeFullScreen=!1,t.exitFullScreen()))},mejs.MediaFeatures.hasMozNativeFullScreen?t.globalBind(mejs.MediaFeatures.fullScreenEventName,o):t.container.bind(mejs.MediaFeatures.fullScreenEventName,o));var s=this,r=e('<div class="mejs-button mejs-fullscreen-button"><button type="button" aria-controls="'+s.id+'" title="'+s.options.fullscreenText+'" aria-label="'+s.options.fullscreenText+'"></button></div>').appendTo(i);if("native"===s.media.pluginType||!s.options.usePluginFullScreen&&!mejs.MediaFeatures.isFirefox)r.click(function(){mejs.MediaFeatures.hasTrueNativeFullScreen&&mejs.MediaFeatures.isFullScreen()||t.isFullScreen?t.exitFullScreen():t.enterFullScreen()
});else{var a=null;if(function(){var e=document.createElement("x"),t=document.documentElement,i=window.getComputedStyle;return"pointerEvents"in e.style?(e.style.pointerEvents="auto",e.style.pointerEvents="x",t.appendChild(e),i=i&&"auto"===i(e,"").pointerEvents,t.removeChild(e),!!i):!1}()&&!mejs.MediaFeatures.isOpera){var l=!1,d=function(){if(l){for(var e in c)c[e].hide();r.css("pointer-events",""),s.controls.css("pointer-events",""),s.media.removeEventListener("click",s.clickToPlayPauseCallback),l=!1}},c={};i=["top","left","right","bottom"];var u,h=function(){var e=r.offset().left-s.container.offset().left,t=r.offset().top-s.container.offset().top,i=r.outerWidth(!0),o=r.outerHeight(!0),n=s.container.width(),a=s.container.height();for(u in c)c[u].css({position:"absolute",top:0,left:0});c.top.width(n).height(t),c.left.width(e).height(o).css({top:t}),c.right.width(n-e-i).height(o).css({top:t,left:e+i}),c.bottom.width(n).height(a-o-t).css({top:t+o})};for(s.globalBind("resize",function(){h()}),u=0,o=i.length;o>u;u++)c[i[u]]=e('<div class="mejs-fullscreen-hover" />').appendTo(s.container).mouseover(d).hide();r.on("mouseover",function(){if(!s.isFullScreen){var e=r.offset(),i=t.container.offset();n.positionFullscreenButton(e.left-i.left,e.top-i.top,!1),r.css("pointer-events","none"),s.controls.css("pointer-events","none"),s.media.addEventListener("click",s.clickToPlayPauseCallback);for(u in c)c[u].show();h(),l=!0}}),n.addEventListener("fullscreenchange",function(){s.isFullScreen=!s.isFullScreen,s.isFullScreen?s.media.removeEventListener("click",s.clickToPlayPauseCallback):s.media.addEventListener("click",s.clickToPlayPauseCallback),d()}),s.globalBind("mousemove",function(e){if(l){var t=r.offset();(e.pageY<t.top||e.pageY>t.top+r.outerHeight(!0)||e.pageX<t.left||e.pageX>t.left+r.outerWidth(!0))&&(r.css("pointer-events",""),s.controls.css("pointer-events",""),l=!1)}})}else r.on("mouseover",function(){null!==a&&(clearTimeout(a),delete a);var e=r.offset(),i=t.container.offset();n.positionFullscreenButton(e.left-i.left,e.top-i.top,!0)}).on("mouseout",function(){null!==a&&(clearTimeout(a),delete a),a=setTimeout(function(){n.hideFullscreenButton()},1500)})}t.fullscreenBtn=r,s.globalBind("keydown",function(e){(mejs.MediaFeatures.hasTrueNativeFullScreen&&mejs.MediaFeatures.isFullScreen()||s.isFullScreen)&&27==e.keyCode&&t.exitFullScreen()})}},cleanfullscreen:function(e){e.exitFullScreen()},containerSizeTimeout:null,enterFullScreen:function(){var t=this;if("native"===t.media.pluginType||!mejs.MediaFeatures.isFirefox&&!t.options.usePluginFullScreen){if(e(document.documentElement).addClass("mejs-fullscreen"),normalHeight=t.container.height(),normalWidth=t.container.width(),"native"===t.media.pluginType)if(mejs.MediaFeatures.hasTrueNativeFullScreen)mejs.MediaFeatures.requestFullScreen(t.container[0]),t.isInIframe&&setTimeout(function o(){if(t.isNativeFullScreen){var i=(window.devicePixelRatio||1)*e(window).width(),n=screen.width;Math.abs(n-i)>.002*n?t.exitFullScreen():setTimeout(o,500)}},500);else if(mejs.MediaFeatures.hasSemiNativeFullScreen)return void t.media.webkitEnterFullscreen();if(t.isInIframe){var i=t.options.newWindowCallback(this);if(""!==i){if(!mejs.MediaFeatures.hasTrueNativeFullScreen)return t.pause(),void window.open(i,t.id,"top=0,left=0,width="+screen.availWidth+",height="+screen.availHeight+",resizable=yes,scrollbars=no,status=no,toolbar=no");setTimeout(function(){t.isNativeFullScreen||(t.pause(),window.open(i,t.id,"top=0,left=0,width="+screen.availWidth+",height="+screen.availHeight+",resizable=yes,scrollbars=no,status=no,toolbar=no"))},250)}}t.container.addClass("mejs-container-fullscreen").width("100%").height("100%"),t.containerSizeTimeout=setTimeout(function(){t.container.css({width:"100%",height:"100%"}),t.setControlsSize()},500),"native"===t.media.pluginType?t.$media.width("100%").height("100%"):(t.container.find(".mejs-shim").width("100%").height("100%"),t.media.setVideoSize(e(window).width(),e(window).height())),t.layers.children("div").width("100%").height("100%"),t.fullscreenBtn&&t.fullscreenBtn.removeClass("mejs-fullscreen").addClass("mejs-unfullscreen"),t.setControlsSize(),t.isFullScreen=!0}},exitFullScreen:function(){clearTimeout(this.containerSizeTimeout),"native"!==this.media.pluginType&&mejs.MediaFeatures.isFirefox?this.media.setFullscreen(!1):(mejs.MediaFeatures.hasTrueNativeFullScreen&&(mejs.MediaFeatures.isFullScreen()||this.isFullScreen)&&mejs.MediaFeatures.cancelFullScreen(),e(document.documentElement).removeClass("mejs-fullscreen"),this.container.removeClass("mejs-container-fullscreen").width(normalWidth).height(normalHeight),"native"===this.media.pluginType?this.$media.width(normalWidth).height(normalHeight):(this.container.find(".mejs-shim").width(normalWidth).height(normalHeight),this.media.setVideoSize(normalWidth,normalHeight)),this.layers.children("div").width(normalWidth).height(normalHeight),this.fullscreenBtn.removeClass("mejs-unfullscreen").addClass("mejs-fullscreen"),this.setControlsSize(),this.isFullScreen=!1)}})}(mejs.$),function(e){e.extend(mejs.MepDefaults,{startLanguage:"",tracksText:mejs.i18n.t("Captions/Subtitles"),hideCaptionsButtonWhenEmpty:!0,toggleCaptionsButtonWhenOnlyOne:!1,slidesSelector:""}),e.extend(MediaElementPlayer.prototype,{hasChapters:!1,buildtracks:function(t,i,o,n){if(0!=t.tracks.length){var s;if(this.domNode.textTracks)for(s=this.domNode.textTracks.length-1;s>=0;s--)this.domNode.textTracks[s].mode="hidden";for(t.chapters=e('<div class="mejs-chapters mejs-layer"></div>').prependTo(o).hide(),t.captions=e('<div class="mejs-captions-layer mejs-layer"><div class="mejs-captions-position mejs-captions-position-hover"><span class="mejs-captions-text"></span></div></div>').prependTo(o).hide(),t.captionsText=t.captions.find(".mejs-captions-text"),t.captionsButton=e('<div class="mejs-button mejs-captions-button"><button type="button" aria-controls="'+this.id+'" title="'+this.options.tracksText+'" aria-label="'+this.options.tracksText+'"></button><div class="mejs-captions-selector"><ul><li><input type="radio" name="'+t.id+'_captions" id="'+t.id+'_captions_none" value="none" checked="checked" /><label for="'+t.id+'_captions_none">'+mejs.i18n.t("None")+"</label></li></ul></div></div>").appendTo(i),s=i=0;s<t.tracks.length;s++)"subtitles"==t.tracks[s].kind&&i++;for(this.options.toggleCaptionsButtonWhenOnlyOne&&1==i?t.captionsButton.on("click",function(){t.setTrack(null==t.selectedTrack?t.tracks[0].srclang:"none")}):t.captionsButton.hover(function(){e(this).find(".mejs-captions-selector").css("visibility","visible")},function(){e(this).find(".mejs-captions-selector").css("visibility","hidden")}).on("click","input[type=radio]",function(){lang=this.value,t.setTrack(lang)}),t.options.alwaysShowControls?t.container.find(".mejs-captions-position").addClass("mejs-captions-position-hover"):t.container.bind("controlsshown",function(){t.container.find(".mejs-captions-position").addClass("mejs-captions-position-hover")}).bind("controlshidden",function(){n.paused||t.container.find(".mejs-captions-position").removeClass("mejs-captions-position-hover")}),t.trackToLoad=-1,t.selectedTrack=null,t.isLoadingTrack=!1,s=0;s<t.tracks.length;s++)"subtitles"==t.tracks[s].kind&&t.addTrackButton(t.tracks[s].srclang,t.tracks[s].label);t.loadNextTrack(),n.addEventListener("timeupdate",function(){t.displayCaptions()},!1),""!=t.options.slidesSelector&&(t.slidesContainer=e(t.options.slidesSelector),n.addEventListener("timeupdate",function(){t.displaySlides()},!1)),n.addEventListener("loadedmetadata",function(){t.displayChapters()},!1),t.container.hover(function(){t.hasChapters&&(t.chapters.css("visibility","visible"),t.chapters.fadeIn(200).height(t.chapters.find(".mejs-chapter").outerHeight()))},function(){t.hasChapters&&!n.paused&&t.chapters.fadeOut(200,function(){e(this).css("visibility","hidden"),e(this).css("display","block")})}),null!==t.node.getAttribute("autoplay")&&t.chapters.css("visibility","hidden")}},setTrack:function(e){var t;if("none"==e)this.selectedTrack=null,this.captionsButton.removeClass("mejs-captions-enabled");else for(t=0;t<this.tracks.length;t++)if(this.tracks[t].srclang==e){null==this.selectedTrack&&this.captionsButton.addClass("mejs-captions-enabled"),this.selectedTrack=this.tracks[t],this.captions.attr("lang",this.selectedTrack.srclang),this.displayCaptions();break}},loadNextTrack:function(){this.trackToLoad++,this.trackToLoad<this.tracks.length?(this.isLoadingTrack=!0,this.loadTrack(this.trackToLoad)):(this.isLoadingTrack=!1,this.checkForTracks())},loadTrack:function(t){var i=this,o=i.tracks[t];e.ajax({url:o.src,dataType:"text",success:function(e){o.entries="string"==typeof e&&/<tt\s+xml/gi.exec(e)?mejs.TrackFormatParser.dfxp.parse(e):mejs.TrackFormatParser.webvvt.parse(e),o.isLoaded=!0,i.enableTrackButton(o.srclang,o.label),i.loadNextTrack(),"chapters"==o.kind&&i.media.addEventListener("play",function(){i.media.duration>0&&i.displayChapters(o)},!1),"slides"==o.kind&&i.setupSlides(o)},error:function(){i.loadNextTrack()}})},enableTrackButton:function(t,i){""===i&&(i=mejs.language.codes[t]||t),this.captionsButton.find("input[value="+t+"]").prop("disabled",!1).siblings("label").html(i),this.options.startLanguage==t&&e("#"+this.id+"_captions_"+t).click(),this.adjustLanguageBox()},addTrackButton:function(t,i){""===i&&(i=mejs.language.codes[t]||t),this.captionsButton.find("ul").append(e('<li><input type="radio" name="'+this.id+'_captions" id="'+this.id+"_captions_"+t+'" value="'+t+'" disabled="disabled" /><label for="'+this.id+"_captions_"+t+'">'+i+" (loading)</label></li>")),this.adjustLanguageBox(),this.container.find(".mejs-captions-translations option[value="+t+"]").remove()},adjustLanguageBox:function(){this.captionsButton.find(".mejs-captions-selector").height(this.captionsButton.find(".mejs-captions-selector ul").outerHeight(!0)+this.captionsButton.find(".mejs-captions-translations").outerHeight(!0))},checkForTracks:function(){var e=!1;if(this.options.hideCaptionsButtonWhenEmpty){for(i=0;i<this.tracks.length;i++)if("subtitles"==this.tracks[i].kind){e=!0;break}e||(this.captionsButton.hide(),this.setControlsSize())}},displayCaptions:function(){if("undefined"!=typeof this.tracks){var e,t=this.selectedTrack;if(null!=t&&t.isLoaded)for(e=0;e<t.entries.times.length;e++)if(this.media.currentTime>=t.entries.times[e].start&&this.media.currentTime<=t.entries.times[e].stop)return this.captionsText.html(t.entries.text[e]),void this.captions.show().height(0);this.captions.hide()}},setupSlides:function(e){this.slides=e,this.slides.entries.imgs=[this.slides.entries.text.length],this.showSlide(0)},showSlide:function(t){if("undefined"!=typeof this.tracks&&"undefined"!=typeof this.slidesContainer){var i=this,o=i.slides.entries.text[t],n=i.slides.entries.imgs[t];"undefined"==typeof n||"undefined"==typeof n.fadeIn?i.slides.entries.imgs[t]=n=e('<img src="'+o+'">').on("load",function(){n.appendTo(i.slidesContainer).hide().fadeIn().siblings(":visible").fadeOut()}):!n.is(":visible")&&!n.is(":animated")&&n.fadeIn().siblings(":visible").fadeOut()}},displaySlides:function(){if("undefined"!=typeof this.slides){var e,t=this.slides;for(e=0;e<t.entries.times.length;e++)if(this.media.currentTime>=t.entries.times[e].start&&this.media.currentTime<=t.entries.times[e].stop){this.showSlide(e);break}}},displayChapters:function(){var e;for(e=0;e<this.tracks.length;e++)if("chapters"==this.tracks[e].kind&&this.tracks[e].isLoaded){this.drawChapters(this.tracks[e]),this.hasChapters=!0;break}},drawChapters:function(t){var i,o,n=this,s=o=0;for(n.chapters.empty(),i=0;i<t.entries.times.length;i++)o=t.entries.times[i].stop-t.entries.times[i].start,o=Math.floor(o/n.media.duration*100),(o+s>100||i==t.entries.times.length-1&&100>o+s)&&(o=100-s),n.chapters.append(e('<div class="mejs-chapter" rel="'+t.entries.times[i].start+'" style="left: '+s.toString()+"%;width: "+o.toString()+'%;"><div class="mejs-chapter-block'+(i==t.entries.times.length-1?" mejs-chapter-block-last":"")+'"><span class="ch-title">'+t.entries.text[i]+'</span><span class="ch-time">'+mejs.Utility.secondsToTimeCode(t.entries.times[i].start)+"&ndash;"+mejs.Utility.secondsToTimeCode(t.entries.times[i].stop)+"</span></div></div>")),s+=o;n.chapters.find("div.mejs-chapter").click(function(){n.media.setCurrentTime(parseFloat(e(this).attr("rel"))),n.media.paused&&n.media.play()}),n.chapters.show()}}),mejs.language={codes:{af:"Afrikaans",sq:"Albanian",ar:"Arabic",be:"Belarusian",bg:"Bulgarian",ca:"Catalan",zh:"Chinese","zh-cn":"Chinese Simplified","zh-tw":"Chinese Traditional",hr:"Croatian",cs:"Czech",da:"Danish",nl:"Dutch",en:"English",et:"Estonian",tl:"Filipino",fi:"Finnish",fr:"French",gl:"Galician",de:"German",el:"Greek",ht:"Haitian Creole",iw:"Hebrew",hi:"Hindi",hu:"Hungarian",is:"Icelandic",id:"Indonesian",ga:"Irish",it:"Italian",ja:"Japanese",ko:"Korean",lv:"Latvian",lt:"Lithuanian",mk:"Macedonian",ms:"Malay",mt:"Maltese",no:"Norwegian",fa:"Persian",pl:"Polish",pt:"Portuguese",ro:"Romanian",ru:"Russian",sr:"Serbian",sk:"Slovak",sl:"Slovenian",es:"Spanish",sw:"Swahili",sv:"Swedish",tl:"Tagalog",th:"Thai",tr:"Turkish",uk:"Ukrainian",vi:"Vietnamese",cy:"Welsh",yi:"Yiddish"}},mejs.TrackFormatParser={webvvt:{pattern_identifier:/^([a-zA-z]+-)?[0-9]+$/,pattern_timecode:/^([0-9]{2}:[0-9]{2}:[0-9]{2}([,.][0-9]{1,3})?) --\> ([0-9]{2}:[0-9]{2}:[0-9]{2}([,.][0-9]{3})?)(.*)$/,parse:function(t){var i=0;t=mejs.TrackFormatParser.split2(t,/\r?\n/);for(var o,n,s={text:[],times:[]};i<t.length;i++)if(this.pattern_identifier.exec(t[i])&&(i++,(o=this.pattern_timecode.exec(t[i]))&&i<t.length)){for(i++,n=t[i],i++;""!==t[i]&&i<t.length;)n=n+"\n"+t[i],i++;n=e.trim(n).replace(/(\b(https?|ftp|file):\/\/[-A-Z0-9+&@#\/%?=~_|!:,.;]*[-A-Z0-9+&@#\/%=~_|])/gi,"<a href='$1' target='_blank'>$1</a>"),s.text.push(n),s.times.push({start:0==mejs.Utility.convertSMPTEtoSeconds(o[1])?.2:mejs.Utility.convertSMPTEtoSeconds(o[1]),stop:mejs.Utility.convertSMPTEtoSeconds(o[3]),settings:o[5]})}return s}},dfxp:{parse:function(t){t=e(t).filter("tt");var i=0;i=t.children("div").eq(0);var o=i.find("p");i=t.find("#"+i.attr("style"));var n,s;if(t={text:[],times:[]},i.length&&(s=i.removeAttr("id").get(0).attributes,s.length))for(n={},i=0;i<s.length;i++)n[s[i].name.split(":")[1]]=s[i].value;for(i=0;i<o.length;i++){var r;if(s={start:null,stop:null,style:null},o.eq(i).attr("begin")&&(s.start=mejs.Utility.convertSMPTEtoSeconds(o.eq(i).attr("begin"))),!s.start&&o.eq(i-1).attr("end")&&(s.start=mejs.Utility.convertSMPTEtoSeconds(o.eq(i-1).attr("end"))),o.eq(i).attr("end")&&(s.stop=mejs.Utility.convertSMPTEtoSeconds(o.eq(i).attr("end"))),!s.stop&&o.eq(i+1).attr("begin")&&(s.stop=mejs.Utility.convertSMPTEtoSeconds(o.eq(i+1).attr("begin"))),n){r="";for(var a in n)r+=a+":"+n[a]+";"}r&&(s.style=r),0==s.start&&(s.start=.2),t.times.push(s),s=e.trim(o.eq(i).html()).replace(/(\b(https?|ftp|file):\/\/[-A-Z0-9+&@#\/%?=~_|!:,.;]*[-A-Z0-9+&@#\/%=~_|])/gi,"<a href='$1' target='_blank'>$1</a>"),t.text.push(s),0==t.times.start&&(t.times.start=2)}return t}},split2:function(e,t){return e.split(t)}},3!="x\n\ny".split(/\n/gi).length&&(mejs.TrackFormatParser.split2=function(e,t){var i,o=[],n="";for(i=0;i<e.length;i++)n+=e.substring(i,i+1),t.test(n)&&(o.push(n.replace(t,"")),n="");return o.push(n),o})}(mejs.$),function(e){e.extend(mejs.MepDefaults,{contextMenuItems:[{render:function(e){return"undefined"==typeof e.enterFullScreen?null:mejs.i18n.t(e.isFullScreen?"Turn off Fullscreen":"Go Fullscreen")},click:function(e){e.isFullScreen?e.exitFullScreen():e.enterFullScreen()}},{render:function(e){return mejs.i18n.t(e.media.muted?"Unmute":"Mute")},click:function(e){e.setMuted(e.media.muted?!1:!0)}},{isSeparator:!0},{render:function(){return mejs.i18n.t("Download Video")},click:function(e){window.location.href=e.media.currentSrc}}]}),e.extend(MediaElementPlayer.prototype,{buildcontextmenu:function(t){t.contextMenu=e('<div class="mejs-contextmenu"></div>').appendTo(e("body")).hide(),t.container.bind("contextmenu",function(e){return t.isContextMenuEnabled?(e.preventDefault(),t.renderContextMenu(e.clientX-1,e.clientY-1),!1):void 0}),t.container.bind("click",function(){t.contextMenu.hide()}),t.contextMenu.bind("mouseleave",function(){t.startContextMenuTimer()})},cleancontextmenu:function(e){e.contextMenu.remove()},isContextMenuEnabled:!0,enableContextMenu:function(){this.isContextMenuEnabled=!0},disableContextMenu:function(){this.isContextMenuEnabled=!1},contextMenuTimeout:null,startContextMenuTimer:function(){var e=this;e.killContextMenuTimer(),e.contextMenuTimer=setTimeout(function(){e.hideContextMenu(),e.killContextMenuTimer()},750)},killContextMenuTimer:function(){var e=this.contextMenuTimer;null!=e&&(clearTimeout(e),delete e)},hideContextMenu:function(){this.contextMenu.hide()},renderContextMenu:function(t,i){for(var o=this,n="",s=o.options.contextMenuItems,r=0,a=s.length;a>r;r++)if(s[r].isSeparator)n+='<div class="mejs-contextmenu-separator"></div>';else{var l=s[r].render(o);null!=l&&(n+='<div class="mejs-contextmenu-item" data-itemindex="'+r+'" id="element-'+1e6*Math.random()+'">'+l+"</div>")}o.contextMenu.empty().append(e(n)).css({top:i,left:t}).show(),o.contextMenu.find(".mejs-contextmenu-item").each(function(){var t=e(this),i=parseInt(t.data("itemindex"),10),n=o.options.contextMenuItems[i];"undefined"!=typeof n.show&&n.show(t,o),t.click(function(){"undefined"!=typeof n.click&&n.click(o),o.contextMenu.hide()})}),setTimeout(function(){o.killControlsTimer("rev3")},100)}})}(mejs.$),function(e){e.extend(mejs.MepDefaults,{postrollCloseText:mejs.i18n.t("Close")}),e.extend(MediaElementPlayer.prototype,{buildpostroll:function(t,i,o){var n=this.container.find('link[rel="postroll"]').attr("href");"undefined"!=typeof n&&(t.postroll=e('<div class="mejs-postroll-layer mejs-layer"><a class="mejs-postroll-close" onclick="$(this).parent().hide();return false;">'+this.options.postrollCloseText+'</a><div class="mejs-postroll-layer-content"></div></div>').prependTo(o).hide(),this.media.addEventListener("ended",function(){e.ajax({dataType:"html",url:n,success:function(e){o.find(".mejs-postroll-layer-content").html(e)}}),t.postroll.show()},!1))}})}(mejs.$),"undefined"!=typeof jQuery?mejs.$=jQuery:"undefined"!=typeof ender&&(mejs.$=ender),function(e){mejs.MepDefaults={poster:"",showPosterWhenEnded:!1,defaultVideoWidth:480,defaultVideoHeight:270,videoWidth:-1,videoHeight:-1,defaultAudioWidth:400,defaultAudioHeight:30,defaultSeekBackwardInterval:function(e){return.05*e.duration},defaultSeekForwardInterval:function(e){return.05*e.duration},audioWidth:-1,audioHeight:-1,startVolume:.8,loop:!1,autoRewind:!0,enableAutosize:!0,alwaysShowHours:!1,showTimecodeFrameCount:!1,framesPerSecond:25,autosizeProgress:!0,alwaysShowControls:!1,hideVideoControlsOnLoad:!1,clickToPlayPause:!0,iPadUseNativeControls:!1,iPhoneUseNativeControls:!1,AndroidUseNativeControls:!1,features:["playpause","current","progress","duration","tracks","volume","fullscreen"],isVideo:!0,enableKeyboard:!0,pauseOtherPlayers:!0,keyActions:[{keys:[32,179],action:function(e,t){t.paused||t.ended?e.play():e.pause()}},{keys:[38],action:function(e,t){t.setVolume(Math.min(t.volume+.1,1))}},{keys:[40],action:function(e,t){t.setVolume(Math.max(t.volume-.1,0))}},{keys:[37,227],action:function(e,t){if(!isNaN(t.duration)&&t.duration>0){e.isVideo&&(e.showControls(),e.startControlsTimer());var i=Math.max(t.currentTime-e.options.defaultSeekBackwardInterval(t),0);t.setCurrentTime(i)}}},{keys:[39,228],action:function(e,t){if(!isNaN(t.duration)&&t.duration>0){e.isVideo&&(e.showControls(),e.startControlsTimer());var i=Math.min(t.currentTime+e.options.defaultSeekForwardInterval(t),t.duration);t.setCurrentTime(i)}}},{keys:[70],action:function(e){"undefined"!=typeof e.enterFullScreen&&(e.isFullScreen?e.exitFullScreen():e.enterFullScreen())}}]},mejs.mepIndex=0,mejs.players={},mejs.MediaElementPlayer=function(t,i){return this instanceof mejs.MediaElementPlayer?(this.$media=this.$node=e(t),this.node=this.media=this.$media[0],"undefined"!=typeof this.node.player?this.node.player:(this.node.player=this,"undefined"==typeof i&&(i=this.$node.data("mejsoptions")),this.options=e.extend({},mejs.MepDefaults,i),this.id="mep_"+mejs.mepIndex++,mejs.players[this.id]=this,this.init(),this)):new mejs.MediaElementPlayer(t,i)},mejs.MediaElementPlayer.prototype={hasFocus:!1,controlsAreVisible:!0,init:function(){var t=this,i=mejs.MediaFeatures,o=e.extend(!0,{},t.options,{success:function(e,i){t.meReady(e,i)},error:function(e){t.handleError(e)}}),n=t.media.tagName.toLowerCase();t.isDynamic="audio"!==n&&"video"!==n,t.isVideo=t.isDynamic?t.options.isVideo:"audio"!==n&&t.options.isVideo,i.isiPad&&t.options.iPadUseNativeControls||i.isiPhone&&t.options.iPhoneUseNativeControls?(t.$media.attr("controls","controls"),i.isiPad&&null!==t.media.getAttribute("autoplay")&&t.play()):i.isAndroid&&t.options.AndroidUseNativeControls||(t.$media.removeAttr("controls"),t.container=e('<div id="'+t.id+'" class="mejs-container '+(mejs.MediaFeatures.svg?"svg":"no-svg")+'"><div class="mejs-inner"><div class="mejs-mediaelement"></div><div class="mejs-layers"></div><div class="mejs-controls"></div><div class="mejs-clear"></div></div></div>').addClass(t.$media[0].className).insertBefore(t.$media),t.container.addClass((i.isAndroid?"mejs-android ":"")+(i.isiOS?"mejs-ios ":"")+(i.isiPad?"mejs-ipad ":"")+(i.isiPhone?"mejs-iphone ":"")+(t.isVideo?"mejs-video ":"mejs-audio ")),i.isiOS?(i=t.$media.clone(),t.container.find(".mejs-mediaelement").append(i),t.$media.remove(),t.$node=t.$media=i,t.node=t.media=i[0]):t.container.find(".mejs-mediaelement").append(t.$media),t.controls=t.container.find(".mejs-controls"),t.layers=t.container.find(".mejs-layers"),i=t.isVideo?"video":"audio",n=i.substring(0,1).toUpperCase()+i.substring(1),t.width=t.options[i+"Width"]>0||t.options[i+"Width"].toString().indexOf("%")>-1?t.options[i+"Width"]:""!==t.media.style.width&&null!==t.media.style.width?t.media.style.width:null!==t.media.getAttribute("width")?t.$media.attr("width"):t.options["default"+n+"Width"],t.height=t.options[i+"Height"]>0||t.options[i+"Height"].toString().indexOf("%")>-1?t.options[i+"Height"]:""!==t.media.style.height&&null!==t.media.style.height?t.media.style.height:null!==t.$media[0].getAttribute("height")?t.$media.attr("height"):t.options["default"+n+"Height"],t.setPlayerSize(t.width,t.height),o.pluginWidth=t.width,o.pluginHeight=t.height),mejs.MediaElement(t.$media[0],o),"undefined"!=typeof t.container&&t.controlsAreVisible&&t.container.trigger("controlsshown")},showControls:function(e){var t=this;e="undefined"==typeof e||e,t.controlsAreVisible||(e?(t.controls.css("visibility","visible").stop(!0,!0).fadeIn(200,function(){t.controlsAreVisible=!0,t.container.trigger("controlsshown")}),t.container.find(".mejs-control").css("visibility","visible").stop(!0,!0).fadeIn(200,function(){t.controlsAreVisible=!0})):(t.controls.css("visibility","visible").css("display","block"),t.container.find(".mejs-control").css("visibility","visible").css("display","block"),t.controlsAreVisible=!0,t.container.trigger("controlsshown")),t.setControlsSize())},hideControls:function(t){var i=this;t="undefined"==typeof t||t,i.controlsAreVisible&&!i.options.alwaysShowControls&&(t?(i.controls.stop(!0,!0).fadeOut(200,function(){e(this).css("visibility","hidden").css("display","block"),i.controlsAreVisible=!1,i.container.trigger("controlshidden")}),i.container.find(".mejs-control").stop(!0,!0).fadeOut(200,function(){e(this).css("visibility","hidden").css("display","block")})):(i.controls.css("visibility","hidden").css("display","block"),i.container.find(".mejs-control").css("visibility","hidden").css("display","block"),i.controlsAreVisible=!1,i.container.trigger("controlshidden")))},controlsTimer:null,startControlsTimer:function(e){var t=this;e="undefined"!=typeof e?e:1500,t.killControlsTimer("start"),t.controlsTimer=setTimeout(function(){t.hideControls(),t.killControlsTimer("hide")},e)},killControlsTimer:function(){null!==this.controlsTimer&&(clearTimeout(this.controlsTimer),delete this.controlsTimer,this.controlsTimer=null)},controlsEnabled:!0,disableControls:function(){this.killControlsTimer(),this.hideControls(!1),this.controlsEnabled=!1},enableControls:function(){this.showControls(!1),this.controlsEnabled=!0},meReady:function(e,t){var i=this,o=mejs.MediaFeatures,n=t.getAttribute("autoplay");n=!("undefined"==typeof n||null===n||"false"===n);var s;if(!i.created){if(i.created=!0,i.media=e,i.domNode=t,!(o.isAndroid&&i.options.AndroidUseNativeControls||o.isiPad&&i.options.iPadUseNativeControls||o.isiPhone&&i.options.iPhoneUseNativeControls)){i.buildposter(i,i.controls,i.layers,i.media),i.buildkeyboard(i,i.controls,i.layers,i.media),i.buildoverlays(i,i.controls,i.layers,i.media),i.findTracks();for(s in i.options.features)if(o=i.options.features[s],i["build"+o])try{i["build"+o](i,i.controls,i.layers,i.media)}catch(r){}i.container.trigger("controlsready"),i.setPlayerSize(i.width,i.height),i.setControlsSize(),i.isVideo&&(mejs.MediaFeatures.hasTouch?i.$media.bind("touchstart",function(){i.controlsAreVisible?i.hideControls(!1):i.controlsEnabled&&i.showControls(!1)}):(i.clickToPlayPauseCallback=function(){i.options.clickToPlayPause&&(i.media.paused?i.play():i.pause())},i.media.addEventListener("click",i.clickToPlayPauseCallback,!1),i.container.bind("mouseenter mouseover",function(){i.controlsEnabled&&(i.options.alwaysShowControls||(i.killControlsTimer("enter"),i.showControls(),i.startControlsTimer(2500)))}).bind("mousemove",function(){i.controlsEnabled&&(i.controlsAreVisible||i.showControls(),i.options.alwaysShowControls||i.startControlsTimer(2500))}).bind("mouseleave",function(){i.controlsEnabled&&!i.media.paused&&!i.options.alwaysShowControls&&i.startControlsTimer(1e3)})),i.options.hideVideoControlsOnLoad&&i.hideControls(!1),n&&!i.options.alwaysShowControls&&i.hideControls(),i.options.enableAutosize&&i.media.addEventListener("loadedmetadata",function(e){i.options.videoHeight<=0&&null===i.domNode.getAttribute("height")&&!isNaN(e.target.videoHeight)&&(i.setPlayerSize(e.target.videoWidth,e.target.videoHeight),i.setControlsSize(),i.media.setVideoSize(e.target.videoWidth,e.target.videoHeight))},!1)),e.addEventListener("play",function(){for(var e in mejs.players){var t=mejs.players[e];t.id!=i.id&&i.options.pauseOtherPlayers&&!t.paused&&!t.ended&&t.pause(),t.hasFocus=!1}i.hasFocus=!0},!1),i.media.addEventListener("ended",function(){if(i.options.autoRewind)try{i.media.setCurrentTime(0)}catch(e){}i.media.pause(),i.setProgressRail&&i.setProgressRail(),i.setCurrentRail&&i.setCurrentRail(),i.options.loop?i.play():!i.options.alwaysShowControls&&i.controlsEnabled&&i.showControls()},!1),i.media.addEventListener("loadedmetadata",function(){i.updateDuration&&i.updateDuration(),i.updateCurrent&&i.updateCurrent(),i.isFullScreen||(i.setPlayerSize(i.width,i.height),i.setControlsSize())},!1),setTimeout(function(){i.setPlayerSize(i.width,i.height),i.setControlsSize()},50),i.globalBind("resize",function(){i.isFullScreen||mejs.MediaFeatures.hasTrueNativeFullScreen&&document.webkitIsFullScreen||i.setPlayerSize(i.width,i.height),i.setControlsSize()}),"youtube"==i.media.pluginType&&i.container.find(".mejs-overlay-play").hide()}n&&"native"==e.pluginType&&i.play(),i.options.success&&("string"==typeof i.options.success?window[i.options.success](i.media,i.domNode,i):i.options.success(i.media,i.domNode,i))}},handleError:function(e){this.controls.hide(),this.options.error&&this.options.error(e)},setPlayerSize:function(t,i){if("undefined"!=typeof t&&(this.width=t),"undefined"!=typeof i&&(this.height=i),this.height.toString().indexOf("%")>0||"100%"===this.$node.css("max-width")||parseInt(this.$node.css("max-width").replace(/px/,""),10)/this.$node.offsetParent().width()===1||this.$node[0].currentStyle&&"100%"===this.$node[0].currentStyle.maxWidth){var o=this.isVideo?this.media.videoWidth&&this.media.videoWidth>0?this.media.videoWidth:this.options.defaultVideoWidth:this.options.defaultAudioWidth,n=this.isVideo?this.media.videoHeight&&this.media.videoHeight>0?this.media.videoHeight:this.options.defaultVideoHeight:this.options.defaultAudioHeight,s=this.container.parent().closest(":visible").width();o=this.isVideo||!this.options.autosizeProgress?parseInt(s*n/o,10):n,isNaN(o)&&(o=this.container.parent().closest(":visible").height()),"body"===this.container.parent()[0].tagName.toLowerCase()&&(s=e(window).width(),o=e(window).height()),0!=o&&0!=s&&(this.container.width(s).height(o),this.$media.add(this.container.find(".mejs-shim")).width("100%").height("100%"),this.isVideo&&this.media.setVideoSize&&this.media.setVideoSize(s,o),this.layers.children(".mejs-layer").width("100%").height("100%"))}else this.container.width(this.width).height(this.height),this.layers.children(".mejs-layer").width(this.width).height(this.height);s=this.layers.find(".mejs-overlay-play"),o=s.find(".mejs-overlay-button"),s.height(this.container.height()-this.controls.height()),o.css("margin-top","-"+(o.height()/2-this.controls.height()/2).toString()+"px")},setControlsSize:function(){var t=0,i=0,o=this.controls.find(".mejs-time-rail"),n=this.controls.find(".mejs-time-total");this.controls.find(".mejs-time-current"),this.controls.find(".mejs-time-loaded");var s=o.siblings(),r=s.last(),a=null;if(this.container.is(":visible")&&o.length&&o.is(":visible")){this.options&&!this.options.autosizeProgress&&(i=parseInt(o.css("width"))),0!==i&&i||(s.each(function(){var i=e(this);"absolute"!=i.css("position")&&i.is(":visible")&&(t+=e(this).outerWidth(!0))}),i=this.controls.width()-t-(o.outerWidth(!0)-o.width()));do o.width(i),n.width(i-(n.outerWidth(!0)-n.width())),"absolute"!=r.css("position")&&(a=r.position(),i--);while(null!=a&&a.top>0&&i>0);this.setProgressRail&&this.setProgressRail(),this.setCurrentRail&&this.setCurrentRail()}},buildposter:function(t,i,o,n){var s=e('<div class="mejs-poster mejs-layer"></div>').appendTo(o);i=t.$media.attr("poster"),""!==t.options.poster&&(i=t.options.poster),""!==i&&null!=i?this.setPoster(i):s.hide(),n.addEventListener("play",function(){s.hide()},!1),t.options.showPosterWhenEnded&&t.options.autoRewind&&n.addEventListener("ended",function(){s.show()},!1)},setPoster:function(t){var i=this.container.find(".mejs-poster"),o=i.find("img");0==o.length&&(o=e('<img width="100%" height="100%" />').appendTo(i)),o.attr("src",t),i.css({"background-image":"url("+t+")"})},buildoverlays:function(t,i,o,n){var s=this;if(t.isVideo){var r=e('<div class="mejs-overlay mejs-layer"><div class="mejs-overlay-loading"><span></span></div></div>').hide().appendTo(o),a=e('<div class="mejs-overlay mejs-layer"><div class="mejs-overlay-error"></div></div>').hide().appendTo(o),l=e('<div class="mejs-overlay mejs-layer mejs-overlay-play"><div class="mejs-overlay-button"></div></div>').appendTo(o).bind("click touchstart",function(){s.options.clickToPlayPause&&n.paused&&n.play()});n.addEventListener("play",function(){l.hide(),r.hide(),i.find(".mejs-time-buffering").hide(),a.hide()},!1),n.addEventListener("playing",function(){l.hide(),r.hide(),i.find(".mejs-time-buffering").hide(),a.hide()},!1),n.addEventListener("seeking",function(){r.show(),i.find(".mejs-time-buffering").show()},!1),n.addEventListener("seeked",function(){r.hide(),i.find(".mejs-time-buffering").hide()},!1),n.addEventListener("pause",function(){mejs.MediaFeatures.isiPhone||l.show()},!1),n.addEventListener("waiting",function(){r.show(),i.find(".mejs-time-buffering").show()},!1),n.addEventListener("loadeddata",function(){r.show(),i.find(".mejs-time-buffering").show()},!1),n.addEventListener("canplay",function(){r.hide(),i.find(".mejs-time-buffering").hide()},!1),n.addEventListener("error",function(){r.hide(),i.find(".mejs-time-buffering").hide(),a.show(),a.find("mejs-overlay-error").html("Error loading this resource")},!1)}},buildkeyboard:function(t,i,o,n){this.globalBind("keydown",function(e){if(t.hasFocus&&t.options.enableKeyboard)for(var i=0,o=t.options.keyActions.length;o>i;i++)for(var s=t.options.keyActions[i],r=0,a=s.keys.length;a>r;r++)if(e.keyCode==s.keys[r])return e.preventDefault(),s.action(t,n,e.keyCode),!1;
return!0}),this.globalBind("click",function(i){t.hasFocus=0!=e(i.target).closest(".mejs-container").length})},findTracks:function(){var t=this,i=t.$media.find("track");t.tracks=[],i.each(function(i,o){o=e(o),t.tracks.push({srclang:o.attr("srclang")?o.attr("srclang").toLowerCase():"",src:o.attr("src"),kind:o.attr("kind"),label:o.attr("label")||"",entries:[],isLoaded:!1})})},changeSkin:function(e){this.container[0].className="mejs-container "+e,this.setPlayerSize(this.width,this.height),this.setControlsSize()},play:function(){this.load(),this.media.play()},pause:function(){try{this.media.pause()}catch(e){}},load:function(){this.isLoaded||this.media.load(),this.isLoaded=!0},setMuted:function(e){this.media.setMuted(e)},setCurrentTime:function(e){this.media.setCurrentTime(e)},getCurrentTime:function(){return this.media.currentTime},setVolume:function(e){this.media.setVolume(e)},getVolume:function(){return this.media.volume},setSrc:function(e){this.media.setSrc(e)},remove:function(){var e,t;for(e in this.options.features)if(t=this.options.features[e],this["clean"+t])try{this["clean"+t](this)}catch(i){}this.isDynamic?this.$node.insertBefore(this.container):(this.$media.prop("controls",!0),this.$node.clone().show().insertBefore(this.container),this.$node.remove()),"native"!==this.media.pluginType&&this.media.remove(),delete mejs.players[this.id],"object"==typeof this.container&&this.container.remove(),this.globalUnbind(),delete this.node.player}},function(){function t(t,o){var n={d:[],w:[]};return e.each((t||"").split(" "),function(e,t){var s=t+"."+o;0===s.indexOf(".")?(n.d.push(s),n.w.push(s)):n[i.test(t)?"w":"d"].push(s)}),n.d=n.d.join(" "),n.w=n.w.join(" "),n}var i=/^((after|before)print|(before)?unload|hashchange|message|o(ff|n)line|page(hide|show)|popstate|resize|storage)\b/;mejs.MediaElementPlayer.prototype.globalBind=function(i,o,n){i=t(i,this.id),i.d&&e(document).bind(i.d,o,n),i.w&&e(window).bind(i.w,o,n)},mejs.MediaElementPlayer.prototype.globalUnbind=function(i,o){i=t(i,this.id),i.d&&e(document).unbind(i.d,o),i.w&&e(window).unbind(i.w,o)}}(),"undefined"!=typeof jQuery&&(jQuery.fn.mediaelementplayer=function(e){return this.each(e===!1?function(){var e=jQuery(this).data("mediaelementplayer");e&&e.remove(),jQuery(this).removeData("mediaelementplayer")}:function(){jQuery(this).data("mediaelementplayer",new mejs.MediaElementPlayer(this,e))}),this}),e(document).ready(function(){e(".mejs-player").mediaelementplayer()}),window.MediaElementPlayer=mejs.MediaElementPlayer}(mejs.$),function(e){e.extend(mejs.MepDefaults,{playpauseText:mejs.i18n.t("Play/Pause")}),e.extend(MediaElementPlayer.prototype,{buildplaypause:function(t,i,o,n){var s=e('<div class="mejs-button mejs-playpause-button mejs-play" ><button type="button" aria-controls="'+this.id+'" title="'+this.options.playpauseText+'" aria-label="'+this.options.playpauseText+'"></button></div>').appendTo(i).click(function(e){return e.preventDefault(),n.paused?n.play():n.pause(),!1});n.addEventListener("play",function(){s.removeClass("mejs-play").addClass("mejs-pause")},!1),n.addEventListener("playing",function(){s.removeClass("mejs-play").addClass("mejs-pause")},!1),n.addEventListener("pause",function(){s.removeClass("mejs-pause").addClass("mejs-play")},!1),n.addEventListener("paused",function(){s.removeClass("mejs-pause").addClass("mejs-play")},!1)}})}(mejs.$),function(e){e.extend(mejs.MepDefaults,{stopText:"Stop"}),e.extend(MediaElementPlayer.prototype,{buildstop:function(t,i,o,n){e('<div class="mejs-button mejs-stop-button mejs-stop"><button type="button" aria-controls="'+this.id+'" title="'+this.options.stopText+'" aria-label="'+this.options.stopText+'"></button></div>').appendTo(i).click(function(){n.paused||n.pause(),n.currentTime>0&&(n.setCurrentTime(0),n.pause(),i.find(".mejs-time-current").width("0px"),i.find(".mejs-time-handle").css("left","0px"),i.find(".mejs-time-float-current").html(mejs.Utility.secondsToTimeCode(0)),i.find(".mejs-currenttime").html(mejs.Utility.secondsToTimeCode(0)),o.find(".mejs-poster").show())})}})}(mejs.$),function(e){e.extend(MediaElementPlayer.prototype,{buildprogress:function(t,i,o,n){e('<div class="mejs-time-rail"><span class="mejs-time-total"><span class="mejs-time-buffering"></span><span class="mejs-time-loaded"></span><span class="mejs-time-current"></span><span class="mejs-time-handle"></span><span class="mejs-time-float"><span class="mejs-time-float-current">00:00</span><span class="mejs-time-float-corner"></span></span></span></div>').appendTo(i),i.find(".mejs-time-buffering").hide();var s=this,r=i.find(".mejs-time-total");o=i.find(".mejs-time-loaded");var a=i.find(".mejs-time-current"),l=i.find(".mejs-time-handle"),d=i.find(".mejs-time-float"),c=i.find(".mejs-time-float-current"),u=function(e){e=e.originalEvent.changedTouches?e.originalEvent.changedTouches[0].pageX:e.pageX;var t=r.offset(),i=r.outerWidth(!0),o=0,s=o=0;n.duration&&(e<t.left?e=t.left:e>i+t.left&&(e=i+t.left),s=e-t.left,o=s/i,o=.02>=o?0:o*n.duration,h&&o!==n.currentTime&&n.setCurrentTime(o),mejs.MediaFeatures.hasTouch||(d.css("left",s),c.html(mejs.Utility.secondsToTimeCode(o)),d.show()))},h=!1;r.bind("mousedown touchstart",function(e){return 1===e.which||0===e.which?(h=!0,u(e),s.globalBind("mousemove.dur touchmove.dur",function(e){u(e)}),s.globalBind("mouseup.dur touchend.dur",function(){h=!1,d.hide(),s.globalUnbind(".dur")}),!1):void 0}).bind("mouseenter",function(){s.globalBind("mousemove.dur",function(e){u(e)}),mejs.MediaFeatures.hasTouch||d.show()}).bind("mouseleave",function(){h||(s.globalUnbind(".dur"),d.hide())}),n.addEventListener("progress",function(e){t.setProgressRail(e),t.setCurrentRail(e)},!1),n.addEventListener("timeupdate",function(e){t.setProgressRail(e),t.setCurrentRail(e)},!1),s.loaded=o,s.total=r,s.current=a,s.handle=l},setProgressRail:function(e){var t=void 0!=e?e.target:this.media,i=null;t&&t.buffered&&t.buffered.length>0&&t.buffered.end&&t.duration?i=t.buffered.end(0)/t.duration:t&&void 0!=t.bytesTotal&&t.bytesTotal>0&&void 0!=t.bufferedBytes?i=t.bufferedBytes/t.bytesTotal:e&&e.lengthComputable&&0!=e.total&&(i=e.loaded/e.total),null!==i&&(i=Math.min(1,Math.max(0,i)),this.loaded&&this.total&&this.loaded.width(this.total.width()*i))},setCurrentRail:function(){if(void 0!=this.media.currentTime&&this.media.duration&&this.total&&this.handle){var e=Math.round(this.total.width()*this.media.currentTime/this.media.duration),t=e-Math.round(this.handle.outerWidth(!0)/2);this.current.width(e),this.handle.css("left",t)}}})}(mejs.$),function(e){e.extend(mejs.MepDefaults,{duration:-1,timeAndDurationSeparator:"<span> | </span>"}),e.extend(MediaElementPlayer.prototype,{buildcurrent:function(t,i,o,n){e('<div class="mejs-time"><span class="mejs-currenttime">'+(t.options.alwaysShowHours?"00:":"")+(t.options.showTimecodeFrameCount?"00:00:00":"00:00")+"</span></div>").appendTo(i),this.currenttime=this.controls.find(".mejs-currenttime"),n.addEventListener("timeupdate",function(){t.updateCurrent()},!1)},buildduration:function(t,i,o,n){i.children().last().find(".mejs-currenttime").length>0?e(this.options.timeAndDurationSeparator+'<span class="mejs-duration">'+(this.options.duration>0?mejs.Utility.secondsToTimeCode(this.options.duration,this.options.alwaysShowHours||this.media.duration>3600,this.options.showTimecodeFrameCount,this.options.framesPerSecond||25):(t.options.alwaysShowHours?"00:":"")+(t.options.showTimecodeFrameCount?"00:00:00":"00:00"))+"</span>").appendTo(i.find(".mejs-time")):(i.find(".mejs-currenttime").parent().addClass("mejs-currenttime-container"),e('<div class="mejs-time mejs-duration-container"><span class="mejs-duration">'+(this.options.duration>0?mejs.Utility.secondsToTimeCode(this.options.duration,this.options.alwaysShowHours||this.media.duration>3600,this.options.showTimecodeFrameCount,this.options.framesPerSecond||25):(t.options.alwaysShowHours?"00:":"")+(t.options.showTimecodeFrameCount?"00:00:00":"00:00"))+"</span></div>").appendTo(i)),this.durationD=this.controls.find(".mejs-duration"),n.addEventListener("timeupdate",function(){t.updateDuration()},!1)},updateCurrent:function(){this.currenttime&&this.currenttime.html(mejs.Utility.secondsToTimeCode(this.media.currentTime,this.options.alwaysShowHours||this.media.duration>3600,this.options.showTimecodeFrameCount,this.options.framesPerSecond||25))},updateDuration:function(){this.container.toggleClass("mejs-long-video",this.media.duration>3600),this.durationD&&(this.options.duration>0||this.media.duration)&&this.durationD.html(mejs.Utility.secondsToTimeCode(this.options.duration>0?this.options.duration:this.media.duration,this.options.alwaysShowHours,this.options.showTimecodeFrameCount,this.options.framesPerSecond||25))}})}(mejs.$),function(e){e.extend(mejs.MepDefaults,{muteText:mejs.i18n.t("Mute Toggle"),hideVolumeOnTouchDevices:!0,audioVolume:"horizontal",videoVolume:"vertical"}),e.extend(MediaElementPlayer.prototype,{buildvolume:function(t,i,o,n){if(!mejs.MediaFeatures.isAndroid&&!mejs.MediaFeatures.isiOS||!this.options.hideVolumeOnTouchDevices){var s=this,r=s.isVideo?s.options.videoVolume:s.options.audioVolume,a="horizontal"==r?e('<div class="mejs-button mejs-volume-button mejs-mute"><button type="button" aria-controls="'+s.id+'" title="'+s.options.muteText+'" aria-label="'+s.options.muteText+'"></button></div><div class="mejs-horizontal-volume-slider"><div class="mejs-horizontal-volume-total"></div><div class="mejs-horizontal-volume-current"></div><div class="mejs-horizontal-volume-handle"></div></div>').appendTo(i):e('<div class="mejs-button mejs-volume-button mejs-mute"><button type="button" aria-controls="'+s.id+'" title="'+s.options.muteText+'" aria-label="'+s.options.muteText+'"></button><div class="mejs-volume-slider"><div class="mejs-volume-total"></div><div class="mejs-volume-current"></div><div class="mejs-volume-handle"></div></div></div>').appendTo(i),l=s.container.find(".mejs-volume-slider, .mejs-horizontal-volume-slider"),d=s.container.find(".mejs-volume-total, .mejs-horizontal-volume-total"),c=s.container.find(".mejs-volume-current, .mejs-horizontal-volume-current"),u=s.container.find(".mejs-volume-handle, .mejs-horizontal-volume-handle"),h=function(e,t){if(l.is(":visible")||"undefined"!=typeof t)if(e=Math.max(0,e),e=Math.min(e,1),0==e?a.removeClass("mejs-mute").addClass("mejs-unmute"):a.removeClass("mejs-unmute").addClass("mejs-mute"),"vertical"==r){var i=d.height(),o=d.position(),n=i-i*e;u.css("top",Math.round(o.top+n-u.height()/2)),c.height(i-n),c.css("top",o.top+n)}else i=d.width(),o=d.position(),i*=e,u.css("left",Math.round(o.left+i-u.width()/2)),c.width(Math.round(i));else l.show(),h(e,!0),l.hide()},m=function(e){var t=null,i=d.offset();if("vertical"==r){if(t=d.height(),parseInt(d.css("top").replace(/px/,""),10),t=(t-(e.pageY-i.top))/t,0==i.top||0==i.left)return}else t=d.width(),t=(e.pageX-i.left)/t;t=Math.max(0,t),t=Math.min(t,1),h(t),n.setMuted(0==t?!0:!1),n.setVolume(t)},p=!1,f=!1;a.hover(function(){l.show(),f=!0},function(){f=!1,!p&&"vertical"==r&&l.hide()}),l.bind("mouseover",function(){f=!0}).bind("mousedown",function(e){return m(e),s.globalBind("mousemove.vol",function(e){m(e)}),s.globalBind("mouseup.vol",function(){p=!1,s.globalUnbind(".vol"),!f&&"vertical"==r&&l.hide()}),p=!0,!1}),a.find("button").click(function(){n.setMuted(!n.muted)}),n.addEventListener("volumechange",function(){p||(n.muted?(h(0),a.removeClass("mejs-mute").addClass("mejs-unmute")):(h(n.volume),a.removeClass("mejs-unmute").addClass("mejs-mute")))},!1),s.container.is(":visible")&&(h(t.options.startVolume),0===t.options.startVolume&&n.setMuted(!0),"native"===n.pluginType&&n.setVolume(t.options.startVolume))}}})}(mejs.$),function(e){e.extend(mejs.MepDefaults,{usePluginFullScreen:!0,newWindowCallback:function(){return""},fullscreenText:mejs.i18n.t("Fullscreen")}),e.extend(MediaElementPlayer.prototype,{isFullScreen:!1,isNativeFullScreen:!1,isInIframe:!1,buildfullscreen:function(t,i,o,n){if(t.isVideo){t.isInIframe=window.location!=window.parent.location,mejs.MediaFeatures.hasTrueNativeFullScreen&&(o=function(){t.isFullScreen&&(mejs.MediaFeatures.isFullScreen()?(t.isNativeFullScreen=!0,t.setControlsSize()):(t.isNativeFullScreen=!1,t.exitFullScreen()))},mejs.MediaFeatures.hasMozNativeFullScreen?t.globalBind(mejs.MediaFeatures.fullScreenEventName,o):t.container.bind(mejs.MediaFeatures.fullScreenEventName,o));var s=this,r=e('<div class="mejs-button mejs-fullscreen-button"><button type="button" aria-controls="'+s.id+'" title="'+s.options.fullscreenText+'" aria-label="'+s.options.fullscreenText+'"></button></div>').appendTo(i);if("native"===s.media.pluginType||!s.options.usePluginFullScreen&&!mejs.MediaFeatures.isFirefox)r.click(function(){mejs.MediaFeatures.hasTrueNativeFullScreen&&mejs.MediaFeatures.isFullScreen()||t.isFullScreen?t.exitFullScreen():t.enterFullScreen()});else{var a=null;if(function(){var e=document.createElement("x"),t=document.documentElement,i=window.getComputedStyle;return"pointerEvents"in e.style?(e.style.pointerEvents="auto",e.style.pointerEvents="x",t.appendChild(e),i=i&&"auto"===i(e,"").pointerEvents,t.removeChild(e),!!i):!1}()&&!mejs.MediaFeatures.isOpera){var l=!1,d=function(){if(l){for(var e in c)c[e].hide();r.css("pointer-events",""),s.controls.css("pointer-events",""),s.media.removeEventListener("click",s.clickToPlayPauseCallback),l=!1}},c={};i=["top","left","right","bottom"];var u,h=function(){var e=r.offset().left-s.container.offset().left,t=r.offset().top-s.container.offset().top,i=r.outerWidth(!0),o=r.outerHeight(!0),n=s.container.width(),a=s.container.height();for(u in c)c[u].css({position:"absolute",top:0,left:0});c.top.width(n).height(t),c.left.width(e).height(o).css({top:t}),c.right.width(n-e-i).height(o).css({top:t,left:e+i}),c.bottom.width(n).height(a-o-t).css({top:t+o})};for(s.globalBind("resize",function(){h()}),u=0,o=i.length;o>u;u++)c[i[u]]=e('<div class="mejs-fullscreen-hover" />').appendTo(s.container).mouseover(d).hide();r.on("mouseover",function(){if(!s.isFullScreen){var e=r.offset(),i=t.container.offset();n.positionFullscreenButton(e.left-i.left,e.top-i.top,!1),r.css("pointer-events","none"),s.controls.css("pointer-events","none"),s.media.addEventListener("click",s.clickToPlayPauseCallback);for(u in c)c[u].show();h(),l=!0}}),n.addEventListener("fullscreenchange",function(){s.isFullScreen=!s.isFullScreen,s.isFullScreen?s.media.removeEventListener("click",s.clickToPlayPauseCallback):s.media.addEventListener("click",s.clickToPlayPauseCallback),d()}),s.globalBind("mousemove",function(e){if(l){var t=r.offset();(e.pageY<t.top||e.pageY>t.top+r.outerHeight(!0)||e.pageX<t.left||e.pageX>t.left+r.outerWidth(!0))&&(r.css("pointer-events",""),s.controls.css("pointer-events",""),l=!1)}})}else r.on("mouseover",function(){null!==a&&(clearTimeout(a),delete a);var e=r.offset(),i=t.container.offset();n.positionFullscreenButton(e.left-i.left,e.top-i.top,!0)}).on("mouseout",function(){null!==a&&(clearTimeout(a),delete a),a=setTimeout(function(){n.hideFullscreenButton()},1500)})}t.fullscreenBtn=r,s.globalBind("keydown",function(e){(mejs.MediaFeatures.hasTrueNativeFullScreen&&mejs.MediaFeatures.isFullScreen()||s.isFullScreen)&&27==e.keyCode&&t.exitFullScreen()})}},cleanfullscreen:function(e){e.exitFullScreen()},containerSizeTimeout:null,enterFullScreen:function(){var t=this;if("native"===t.media.pluginType||!mejs.MediaFeatures.isFirefox&&!t.options.usePluginFullScreen){if(e(document.documentElement).addClass("mejs-fullscreen"),normalHeight=t.container.height(),normalWidth=t.container.width(),"native"===t.media.pluginType)if(mejs.MediaFeatures.hasTrueNativeFullScreen)mejs.MediaFeatures.requestFullScreen(t.container[0]),t.isInIframe&&setTimeout(function o(){if(t.isNativeFullScreen){var i=(window.devicePixelRatio||1)*e(window).width(),n=screen.width;Math.abs(n-i)>.002*n?t.exitFullScreen():setTimeout(o,500)}},500);else if(mejs.MediaFeatures.hasSemiNativeFullScreen)return void t.media.webkitEnterFullscreen();if(t.isInIframe){var i=t.options.newWindowCallback(this);if(""!==i){if(!mejs.MediaFeatures.hasTrueNativeFullScreen)return t.pause(),void window.open(i,t.id,"top=0,left=0,width="+screen.availWidth+",height="+screen.availHeight+",resizable=yes,scrollbars=no,status=no,toolbar=no");setTimeout(function(){t.isNativeFullScreen||(t.pause(),window.open(i,t.id,"top=0,left=0,width="+screen.availWidth+",height="+screen.availHeight+",resizable=yes,scrollbars=no,status=no,toolbar=no"))},250)}}t.container.addClass("mejs-container-fullscreen").width("100%").height("100%"),t.containerSizeTimeout=setTimeout(function(){t.container.css({width:"100%",height:"100%"}),t.setControlsSize()},500),"native"===t.media.pluginType?t.$media.width("100%").height("100%"):(t.container.find(".mejs-shim").width("100%").height("100%"),t.media.setVideoSize(e(window).width(),e(window).height())),t.layers.children("div").width("100%").height("100%"),t.fullscreenBtn&&t.fullscreenBtn.removeClass("mejs-fullscreen").addClass("mejs-unfullscreen"),t.setControlsSize(),t.isFullScreen=!0}},exitFullScreen:function(){clearTimeout(this.containerSizeTimeout),"native"!==this.media.pluginType&&mejs.MediaFeatures.isFirefox?this.media.setFullscreen(!1):(mejs.MediaFeatures.hasTrueNativeFullScreen&&(mejs.MediaFeatures.isFullScreen()||this.isFullScreen)&&mejs.MediaFeatures.cancelFullScreen(),e(document.documentElement).removeClass("mejs-fullscreen"),this.container.removeClass("mejs-container-fullscreen").width(normalWidth).height(normalHeight),"native"===this.media.pluginType?this.$media.width(normalWidth).height(normalHeight):(this.container.find(".mejs-shim").width(normalWidth).height(normalHeight),this.media.setVideoSize(normalWidth,normalHeight)),this.layers.children("div").width(normalWidth).height(normalHeight),this.fullscreenBtn.removeClass("mejs-unfullscreen").addClass("mejs-fullscreen"),this.setControlsSize(),this.isFullScreen=!1)}})}(mejs.$),function(e){e.extend(mejs.MepDefaults,{startLanguage:"",tracksText:mejs.i18n.t("Captions/Subtitles"),hideCaptionsButtonWhenEmpty:!0,toggleCaptionsButtonWhenOnlyOne:!1,slidesSelector:""}),e.extend(MediaElementPlayer.prototype,{hasChapters:!1,buildtracks:function(t,i,o,n){if(0!=t.tracks.length){var s;if(this.domNode.textTracks)for(s=this.domNode.textTracks.length-1;s>=0;s--)this.domNode.textTracks[s].mode="hidden";for(t.chapters=e('<div class="mejs-chapters mejs-layer"></div>').prependTo(o).hide(),t.captions=e('<div class="mejs-captions-layer mejs-layer"><div class="mejs-captions-position mejs-captions-position-hover"><span class="mejs-captions-text"></span></div></div>').prependTo(o).hide(),t.captionsText=t.captions.find(".mejs-captions-text"),t.captionsButton=e('<div class="mejs-button mejs-captions-button"><button type="button" aria-controls="'+this.id+'" title="'+this.options.tracksText+'" aria-label="'+this.options.tracksText+'"></button><div class="mejs-captions-selector"><ul><li><input type="radio" name="'+t.id+'_captions" id="'+t.id+'_captions_none" value="none" checked="checked" /><label for="'+t.id+'_captions_none">'+mejs.i18n.t("None")+"</label></li></ul></div></div>").appendTo(i),s=i=0;s<t.tracks.length;s++)"subtitles"==t.tracks[s].kind&&i++;for(this.options.toggleCaptionsButtonWhenOnlyOne&&1==i?t.captionsButton.on("click",function(){t.setTrack(null==t.selectedTrack?t.tracks[0].srclang:"none")}):t.captionsButton.hover(function(){e(this).find(".mejs-captions-selector").css("visibility","visible")},function(){e(this).find(".mejs-captions-selector").css("visibility","hidden")}).on("click","input[type=radio]",function(){lang=this.value,t.setTrack(lang)}),t.options.alwaysShowControls?t.container.find(".mejs-captions-position").addClass("mejs-captions-position-hover"):t.container.bind("controlsshown",function(){t.container.find(".mejs-captions-position").addClass("mejs-captions-position-hover")}).bind("controlshidden",function(){n.paused||t.container.find(".mejs-captions-position").removeClass("mejs-captions-position-hover")}),t.trackToLoad=-1,t.selectedTrack=null,t.isLoadingTrack=!1,s=0;s<t.tracks.length;s++)"subtitles"==t.tracks[s].kind&&t.addTrackButton(t.tracks[s].srclang,t.tracks[s].label);t.loadNextTrack(),n.addEventListener("timeupdate",function(){t.displayCaptions()},!1),""!=t.options.slidesSelector&&(t.slidesContainer=e(t.options.slidesSelector),n.addEventListener("timeupdate",function(){t.displaySlides()},!1)),n.addEventListener("loadedmetadata",function(){t.displayChapters()},!1),t.container.hover(function(){t.hasChapters&&(t.chapters.css("visibility","visible"),t.chapters.fadeIn(200).height(t.chapters.find(".mejs-chapter").outerHeight()))},function(){t.hasChapters&&!n.paused&&t.chapters.fadeOut(200,function(){e(this).css("visibility","hidden"),e(this).css("display","block")})}),null!==t.node.getAttribute("autoplay")&&t.chapters.css("visibility","hidden")}},setTrack:function(e){var t;if("none"==e)this.selectedTrack=null,this.captionsButton.removeClass("mejs-captions-enabled");else for(t=0;t<this.tracks.length;t++)if(this.tracks[t].srclang==e){null==this.selectedTrack&&this.captionsButton.addClass("mejs-captions-enabled"),this.selectedTrack=this.tracks[t],this.captions.attr("lang",this.selectedTrack.srclang),this.displayCaptions();break}},loadNextTrack:function(){this.trackToLoad++,this.trackToLoad<this.tracks.length?(this.isLoadingTrack=!0,this.loadTrack(this.trackToLoad)):(this.isLoadingTrack=!1,this.checkForTracks())},loadTrack:function(t){var i=this,o=i.tracks[t];e.ajax({url:o.src,dataType:"text",success:function(e){o.entries="string"==typeof e&&/<tt\s+xml/gi.exec(e)?mejs.TrackFormatParser.dfxp.parse(e):mejs.TrackFormatParser.webvvt.parse(e),o.isLoaded=!0,i.enableTrackButton(o.srclang,o.label),i.loadNextTrack(),"chapters"==o.kind&&i.media.addEventListener("play",function(){i.media.duration>0&&i.displayChapters(o)},!1),"slides"==o.kind&&i.setupSlides(o)},error:function(){i.loadNextTrack()}})},enableTrackButton:function(t,i){""===i&&(i=mejs.language.codes[t]||t),this.captionsButton.find("input[value="+t+"]").prop("disabled",!1).siblings("label").html(i),this.options.startLanguage==t&&e("#"+this.id+"_captions_"+t).click(),this.adjustLanguageBox()},addTrackButton:function(t,i){""===i&&(i=mejs.language.codes[t]||t),this.captionsButton.find("ul").append(e('<li><input type="radio" name="'+this.id+'_captions" id="'+this.id+"_captions_"+t+'" value="'+t+'" disabled="disabled" /><label for="'+this.id+"_captions_"+t+'">'+i+" (loading)</label></li>")),this.adjustLanguageBox(),this.container.find(".mejs-captions-translations option[value="+t+"]").remove()},adjustLanguageBox:function(){this.captionsButton.find(".mejs-captions-selector").height(this.captionsButton.find(".mejs-captions-selector ul").outerHeight(!0)+this.captionsButton.find(".mejs-captions-translations").outerHeight(!0))},checkForTracks:function(){var e=!1;if(this.options.hideCaptionsButtonWhenEmpty){for(i=0;i<this.tracks.length;i++)if("subtitles"==this.tracks[i].kind){e=!0;break}e||(this.captionsButton.hide(),this.setControlsSize())}},displayCaptions:function(){if("undefined"!=typeof this.tracks){var e,t=this.selectedTrack;if(null!=t&&t.isLoaded)for(e=0;e<t.entries.times.length;e++)if(this.media.currentTime>=t.entries.times[e].start&&this.media.currentTime<=t.entries.times[e].stop)return this.captionsText.html(t.entries.text[e]),void this.captions.show().height(0);this.captions.hide()}},setupSlides:function(e){this.slides=e,this.slides.entries.imgs=[this.slides.entries.text.length],this.showSlide(0)},showSlide:function(t){if("undefined"!=typeof this.tracks&&"undefined"!=typeof this.slidesContainer){var i=this,o=i.slides.entries.text[t],n=i.slides.entries.imgs[t];"undefined"==typeof n||"undefined"==typeof n.fadeIn?i.slides.entries.imgs[t]=n=e('<img src="'+o+'">').on("load",function(){n.appendTo(i.slidesContainer).hide().fadeIn().siblings(":visible").fadeOut()}):!n.is(":visible")&&!n.is(":animated")&&n.fadeIn().siblings(":visible").fadeOut()}},displaySlides:function(){if("undefined"!=typeof this.slides){var e,t=this.slides;for(e=0;e<t.entries.times.length;e++)if(this.media.currentTime>=t.entries.times[e].start&&this.media.currentTime<=t.entries.times[e].stop){this.showSlide(e);break}}},displayChapters:function(){var e;for(e=0;e<this.tracks.length;e++)if("chapters"==this.tracks[e].kind&&this.tracks[e].isLoaded){this.drawChapters(this.tracks[e]),this.hasChapters=!0;break}},drawChapters:function(t){var i,o,n=this,s=o=0;for(n.chapters.empty(),i=0;i<t.entries.times.length;i++)o=t.entries.times[i].stop-t.entries.times[i].start,o=Math.floor(o/n.media.duration*100),(o+s>100||i==t.entries.times.length-1&&100>o+s)&&(o=100-s),n.chapters.append(e('<div class="mejs-chapter" rel="'+t.entries.times[i].start+'" style="left: '+s.toString()+"%;width: "+o.toString()+'%;"><div class="mejs-chapter-block'+(i==t.entries.times.length-1?" mejs-chapter-block-last":"")+'"><span class="ch-title">'+t.entries.text[i]+'</span><span class="ch-time">'+mejs.Utility.secondsToTimeCode(t.entries.times[i].start)+"&ndash;"+mejs.Utility.secondsToTimeCode(t.entries.times[i].stop)+"</span></div></div>")),s+=o;n.chapters.find("div.mejs-chapter").click(function(){n.media.setCurrentTime(parseFloat(e(this).attr("rel"))),n.media.paused&&n.media.play()}),n.chapters.show()}}),mejs.language={codes:{af:"Afrikaans",sq:"Albanian",ar:"Arabic",be:"Belarusian",bg:"Bulgarian",ca:"Catalan",zh:"Chinese","zh-cn":"Chinese Simplified","zh-tw":"Chinese Traditional",hr:"Croatian",cs:"Czech",da:"Danish",nl:"Dutch",en:"English",et:"Estonian",tl:"Filipino",fi:"Finnish",fr:"French",gl:"Galician",de:"German",el:"Greek",ht:"Haitian Creole",iw:"Hebrew",hi:"Hindi",hu:"Hungarian",is:"Icelandic",id:"Indonesian",ga:"Irish",it:"Italian",ja:"Japanese",ko:"Korean",lv:"Latvian",lt:"Lithuanian",mk:"Macedonian",ms:"Malay",mt:"Maltese",no:"Norwegian",fa:"Persian",pl:"Polish",pt:"Portuguese",ro:"Romanian",ru:"Russian",sr:"Serbian",sk:"Slovak",sl:"Slovenian",es:"Spanish",sw:"Swahili",sv:"Swedish",tl:"Tagalog",th:"Thai",tr:"Turkish",uk:"Ukrainian",vi:"Vietnamese",cy:"Welsh",yi:"Yiddish"}},mejs.TrackFormatParser={webvvt:{pattern_identifier:/^([a-zA-z]+-)?[0-9]+$/,pattern_timecode:/^([0-9]{2}:[0-9]{2}:[0-9]{2}([,.][0-9]{1,3})?) --\> ([0-9]{2}:[0-9]{2}:[0-9]{2}([,.][0-9]{3})?)(.*)$/,parse:function(t){var i=0;t=mejs.TrackFormatParser.split2(t,/\r?\n/);for(var o,n,s={text:[],times:[]};i<t.length;i++)if(this.pattern_identifier.exec(t[i])&&(i++,(o=this.pattern_timecode.exec(t[i]))&&i<t.length)){for(i++,n=t[i],i++;""!==t[i]&&i<t.length;)n=n+"\n"+t[i],i++;n=e.trim(n).replace(/(\b(https?|ftp|file):\/\/[-A-Z0-9+&@#\/%?=~_|!:,.;]*[-A-Z0-9+&@#\/%=~_|])/gi,"<a href='$1' target='_blank'>$1</a>"),s.text.push(n),s.times.push({start:0==mejs.Utility.convertSMPTEtoSeconds(o[1])?.2:mejs.Utility.convertSMPTEtoSeconds(o[1]),stop:mejs.Utility.convertSMPTEtoSeconds(o[3]),settings:o[5]})}return s}},dfxp:{parse:function(t){t=e(t).filter("tt");var i=0;i=t.children("div").eq(0);var o=i.find("p");i=t.find("#"+i.attr("style"));var n,s;if(t={text:[],times:[]},i.length&&(s=i.removeAttr("id").get(0).attributes,s.length))for(n={},i=0;i<s.length;i++)n[s[i].name.split(":")[1]]=s[i].value;for(i=0;i<o.length;i++){var r;if(s={start:null,stop:null,style:null},o.eq(i).attr("begin")&&(s.start=mejs.Utility.convertSMPTEtoSeconds(o.eq(i).attr("begin"))),!s.start&&o.eq(i-1).attr("end")&&(s.start=mejs.Utility.convertSMPTEtoSeconds(o.eq(i-1).attr("end"))),o.eq(i).attr("end")&&(s.stop=mejs.Utility.convertSMPTEtoSeconds(o.eq(i).attr("end"))),!s.stop&&o.eq(i+1).attr("begin")&&(s.stop=mejs.Utility.convertSMPTEtoSeconds(o.eq(i+1).attr("begin"))),n){r="";for(var a in n)r+=a+":"+n[a]+";"}r&&(s.style=r),0==s.start&&(s.start=.2),t.times.push(s),s=e.trim(o.eq(i).html()).replace(/(\b(https?|ftp|file):\/\/[-A-Z0-9+&@#\/%?=~_|!:,.;]*[-A-Z0-9+&@#\/%=~_|])/gi,"<a href='$1' target='_blank'>$1</a>"),t.text.push(s),0==t.times.start&&(t.times.start=2)}return t}},split2:function(e,t){return e.split(t)}},3!="x\n\ny".split(/\n/gi).length&&(mejs.TrackFormatParser.split2=function(e,t){var i,o=[],n="";for(i=0;i<e.length;i++)n+=e.substring(i,i+1),t.test(n)&&(o.push(n.replace(t,"")),n="");return o.push(n),o})}(mejs.$),function(e){e.extend(mejs.MepDefaults,{contextMenuItems:[{render:function(e){return"undefined"==typeof e.enterFullScreen?null:mejs.i18n.t(e.isFullScreen?"Turn off Fullscreen":"Go Fullscreen")},click:function(e){e.isFullScreen?e.exitFullScreen():e.enterFullScreen()}},{render:function(e){return mejs.i18n.t(e.media.muted?"Unmute":"Mute")},click:function(e){e.setMuted(e.media.muted?!1:!0)}},{isSeparator:!0},{render:function(){return mejs.i18n.t("Download Video")},click:function(e){window.location.href=e.media.currentSrc}}]}),e.extend(MediaElementPlayer.prototype,{buildcontextmenu:function(t){t.contextMenu=e('<div class="mejs-contextmenu"></div>').appendTo(e("body")).hide(),t.container.bind("contextmenu",function(e){return t.isContextMenuEnabled?(e.preventDefault(),t.renderContextMenu(e.clientX-1,e.clientY-1),!1):void 0}),t.container.bind("click",function(){t.contextMenu.hide()}),t.contextMenu.bind("mouseleave",function(){t.startContextMenuTimer()})},cleancontextmenu:function(e){e.contextMenu.remove()},isContextMenuEnabled:!0,enableContextMenu:function(){this.isContextMenuEnabled=!0},disableContextMenu:function(){this.isContextMenuEnabled=!1},contextMenuTimeout:null,startContextMenuTimer:function(){var e=this;e.killContextMenuTimer(),e.contextMenuTimer=setTimeout(function(){e.hideContextMenu(),e.killContextMenuTimer()},750)},killContextMenuTimer:function(){var e=this.contextMenuTimer;null!=e&&(clearTimeout(e),delete e)},hideContextMenu:function(){this.contextMenu.hide()},renderContextMenu:function(t,i){for(var o=this,n="",s=o.options.contextMenuItems,r=0,a=s.length;a>r;r++)if(s[r].isSeparator)n+='<div class="mejs-contextmenu-separator"></div>';else{var l=s[r].render(o);null!=l&&(n+='<div class="mejs-contextmenu-item" data-itemindex="'+r+'" id="element-'+1e6*Math.random()+'">'+l+"</div>")}o.contextMenu.empty().append(e(n)).css({top:i,left:t}).show(),o.contextMenu.find(".mejs-contextmenu-item").each(function(){var t=e(this),i=parseInt(t.data("itemindex"),10),n=o.options.contextMenuItems[i];"undefined"!=typeof n.show&&n.show(t,o),t.click(function(){"undefined"!=typeof n.click&&n.click(o),o.contextMenu.hide()})}),setTimeout(function(){o.killControlsTimer("rev3")},100)}})}(mejs.$),function(e){e.extend(mejs.MepDefaults,{postrollCloseText:mejs.i18n.t("Close")}),e.extend(MediaElementPlayer.prototype,{buildpostroll:function(t,i,o){var n=this.container.find('link[rel="postroll"]').attr("href");"undefined"!=typeof n&&(t.postroll=e('<div class="mejs-postroll-layer mejs-layer"><a class="mejs-postroll-close" onclick="$(this).parent().hide();return false;">'+this.options.postrollCloseText+'</a><div class="mejs-postroll-layer-content"></div></div>').prependTo(o).hide(),this.media.addEventListener("ended",function(){e.ajax({dataType:"html",url:n,success:function(e){o.find(".mejs-postroll-layer-content").html(e)}}),t.postroll.show()},!1))}})}(mejs.$),function(e){var t=!1,i=!1,o=5e3,n=2e3,s=0,r=function(){var e=document.getElementsByTagName("script"),e=e[e.length-1].src.split("?")[0];return 0<e.split("/").length?e.split("/").slice(0,-1).join("/")+"/":""}();Array.prototype.forEach||(Array.prototype.forEach=function(e,t){for(var i=0,o=this.length;o>i;++i)e.call(t,this[i],i,this)});var l=window.requestAnimationFrame||!1,d=window.cancelAnimationFrame||!1;["ms","moz","webkit","o"].forEach(function(e){l||(l=window[e+"RequestAnimationFrame"]),d||(d=window[e+"CancelAnimationFrame"]||window[e+"CancelRequestAnimationFrame"])});var c=window.MutationObserver||window.WebKitMutationObserver||!1,u={zindex:"auto",cursoropacitymin:0,cursoropacitymax:1,cursorcolor:"#424242",cursorwidth:"5px",cursorborder:"1px solid #fff",cursorborderradius:"5px",scrollspeed:60,mousescrollstep:24,touchbehavior:!1,hwacceleration:!0,usetransition:!0,boxzoom:!1,dblclickzoom:!0,gesturezoom:!0,grabcursorenabled:!0,autohidemode:!0,background:"",iframeautoresize:!0,cursorminheight:32,preservenativescrolling:!0,railoffset:!1,bouncescroll:!0,spacebarenabled:!0,railpadding:{top:0,right:0,left:0,bottom:0},disableoutline:!0,horizrailenabled:!0,railalign:"right",railvalign:"bottom",enabletranslate3d:!0,enablemousewheel:!0,enablekeyboard:!0,smoothscroll:!0,sensitiverail:!0,enablemouselockapi:!0,cursorfixedheight:!1,directionlockdeadzone:6,hidecursordelay:400,nativeparentscrolling:!0,enablescrollonselection:!0,overflowx:!0,overflowy:!0,cursordragspeed:.3,rtlmode:!1,cursordragontouch:!1},h=!1,m=function(){if(h)return h;
var e=document.createElement("DIV"),t={haspointerlock:"pointerLockElement"in document||"mozPointerLockElement"in document||"webkitPointerLockElement"in document};t.isopera="opera"in window,t.isopera12=t.isopera&&"getUserMedia"in navigator,t.isie="all"in document&&"attachEvent"in e&&!t.isopera,t.isieold=t.isie&&!("msInterpolationMode"in e.style),t.isie7=!(!t.isie||t.isieold||"documentMode"in document&&7!=document.documentMode),t.isie8=t.isie&&"documentMode"in document&&8==document.documentMode,t.isie9=t.isie&&"performance"in window&&9<=document.documentMode,t.isie10=t.isie&&"performance"in window&&10<=document.documentMode,t.isie9mobile=/iemobile.9/i.test(navigator.userAgent),t.isie9mobile&&(t.isie9=!1),t.isie7mobile=!t.isie9mobile&&t.isie7&&/iemobile/i.test(navigator.userAgent),t.ismozilla="MozAppearance"in e.style,t.iswebkit="WebkitAppearance"in e.style,t.ischrome="chrome"in window,t.ischrome22=t.ischrome&&t.haspointerlock,t.ischrome26=t.ischrome&&"transition"in e.style,t.cantouch="ontouchstart"in document.documentElement||"ontouchstart"in window,t.hasmstouch=window.navigator.msPointerEnabled||!1,t.ismac=/^mac$/i.test(navigator.platform),t.isios=t.cantouch&&/iphone|ipad|ipod/i.test(navigator.platform),t.isios4=t.isios&&!("seal"in Object),t.isandroid=/android/i.test(navigator.userAgent),t.trstyle=!1,t.hastransform=!1,t.hastranslate3d=!1,t.transitionstyle=!1,t.hastransition=!1,t.transitionend=!1;for(var i=["transform","msTransform","webkitTransform","MozTransform","OTransform"],o=0;o<i.length;o++)if("undefined"!=typeof e.style[i[o]]){t.trstyle=i[o];break}t.hastransform=0!=t.trstyle,t.hastransform&&(e.style[t.trstyle]="translate3d(1px,2px,3px)",t.hastranslate3d=/translate3d/.test(e.style[t.trstyle])),t.transitionstyle=!1,t.prefixstyle="",t.transitionend=!1;for(var i="transition webkitTransition MozTransition OTransition OTransition msTransition KhtmlTransition".split(" "),n=" -webkit- -moz- -o- -o -ms- -khtml-".split(" "),s="transitionend webkitTransitionEnd transitionend otransitionend oTransitionEnd msTransitionEnd KhtmlTransitionEnd".split(" "),o=0;o<i.length;o++)if(i[o]in e.style){t.transitionstyle=i[o],t.prefixstyle=n[o],t.transitionend=s[o];break}t.ischrome26&&(t.prefixstyle=n[1]),t.hastransition=t.transitionstyle;e:{for(i=["-moz-grab","-webkit-grab","grab"],(t.ischrome&&!t.ischrome22||t.isie)&&(i=[]),o=0;o<i.length;o++)if(n=i[o],e.style.cursor=n,e.style.cursor==n){i=n;break e}i="url(http://www.google.com/intl/en_ALL/mapfiles/openhand.cur),n-resize"}return t.cursorgrabvalue=i,t.hasmousecapture="setCapture"in e,t.hasMutationObserver=!1!==c,h=t},p=function(a,h){function p(){var e=w.win;if("zIndex"in e)return e.zIndex();for(;0<e.length&&9!=e[0].nodeType;){var t=e.css("zIndex");if(!isNaN(t)&&0!=t)return parseInt(t);e=e.parent()}return!1}function g(e,t,i){return t=e.css(t),e=parseFloat(t),isNaN(e)?(e=S[t]||0,i=3==e?i?w.win.outerHeight()-w.win.innerHeight():w.win.outerWidth()-w.win.innerWidth():1,w.isie8&&e&&(e+=1),i?e:0):e}function v(e,t,i,o){w._bind(e,t,function(o){o=o?o:window.event;var n={original:o,target:o.target||o.srcElement,type:"wheel",deltaMode:"MozMousePixelScroll"==o.type?0:1,deltaX:0,deltaZ:0,preventDefault:function(){return o.preventDefault?o.preventDefault():o.returnValue=!1,!1},stopImmediatePropagation:function(){o.stopImmediatePropagation?o.stopImmediatePropagation():o.cancelBubble=!0}};return"mousewheel"==t?(n.deltaY=-.025*o.wheelDelta,o.wheelDeltaX&&(n.deltaX=-.025*o.wheelDeltaX)):n.deltaY=o.detail,i.call(e,n)},o)}function y(e,t,i){var o,n;if(0==e.deltaMode?(o=-Math.floor(e.deltaX*(w.opt.mousescrollstep/54)),n=-Math.floor(e.deltaY*(w.opt.mousescrollstep/54))):1==e.deltaMode&&(o=-Math.floor(e.deltaX*w.opt.mousescrollstep),n=-Math.floor(e.deltaY*w.opt.mousescrollstep)),t&&0==o&&n&&(o=n,n=0),o&&(w.scrollmom&&w.scrollmom.stop(),w.lastdeltax+=o,w.debounced("mousewheelx",function(){var e=w.lastdeltax;w.lastdeltax=0,w.rail.drag||w.doScrollLeftBy(e)},120)),n){if(w.opt.nativeparentscrolling&&i&&!w.ispage&&!w.zoomactive)if(0>n){if(w.getScrollTop()>=w.page.maxh)return!0}else if(0>=w.getScrollTop())return!0;w.scrollmom&&w.scrollmom.stop(),w.lastdeltay+=n,w.debounced("mousewheely",function(){var e=w.lastdeltay;w.lastdeltay=0,w.rail.drag||w.doScrollBy(e)},120)}return e.stopImmediatePropagation(),e.preventDefault()}var w=this;if(this.version="3.4.0",this.name="nicescroll",this.me=h,this.opt={doc:e("body"),win:!1},e.extend(this.opt,u),this.opt.snapbackspeed=80,a)for(var b in w.opt)"undefined"!=typeof a[b]&&(w.opt[b]=a[b]);this.iddoc=(this.doc=w.opt.doc)&&this.doc[0]?this.doc[0].id||"":"",this.ispage=/BODY|HTML/.test(w.opt.win?w.opt.win[0].nodeName:this.doc[0].nodeName),this.haswrapper=!1!==w.opt.win,this.win=w.opt.win||(this.ispage?e(window):this.doc),this.docscroll=this.ispage&&!this.haswrapper?e(window):this.win,this.body=e("body"),this.iframe=this.isfixed=this.viewport=!1,this.isiframe="IFRAME"==this.doc[0].nodeName&&"IFRAME"==this.win[0].nodeName,this.istextarea="TEXTAREA"==this.win[0].nodeName,this.forcescreen=!1,this.canshowonmouseevent="scroll"!=w.opt.autohidemode,this.page=this.view=this.onzoomout=this.onzoomin=this.onscrollcancel=this.onscrollend=this.onscrollstart=this.onclick=this.ongesturezoom=this.onkeypress=this.onmousewheel=this.onmousemove=this.onmouseup=this.onmousedown=!1,this.scroll={x:0,y:0},this.scrollratio={x:0,y:0},this.cursorheight=20,this.scrollvaluemax=0,this.observerremover=this.observer=this.scrollmom=this.scrollrunning=this.checkrtlmode=!1;do this.id="ascrail"+n++;while(document.getElementById(this.id));this.hasmousefocus=this.hasfocus=this.zoomactive=this.zoom=this.selectiondrag=this.cursorfreezed=this.cursor=this.rail=!1,this.visibility=!0,this.hidden=this.locked=!1,this.cursoractive=!0,this.overflowx=w.opt.overflowx,this.overflowy=w.opt.overflowy,this.nativescrollingarea=!1,this.checkarea=0,this.events=[],this.saved={},this.delaylist={},this.synclist={},this.lastdeltay=this.lastdeltax=0,this.detected=m();var x=e.extend({},this.detected);if(this.ishwscroll=(this.canhwscroll=x.hastransform&&w.opt.hwacceleration)&&w.haswrapper,this.istouchcapable=!1,x.cantouch&&x.ischrome&&!x.isios&&!x.isandroid&&(this.istouchcapable=!0,x.cantouch=!1),x.cantouch&&x.ismozilla&&!x.isios&&(this.istouchcapable=!0,x.cantouch=!1),w.opt.enablemouselockapi||(x.hasmousecapture=!1,x.haspointerlock=!1),this.delayed=function(e,t,i,o){var n=w.delaylist[e],s=(new Date).getTime();return!o&&n&&n.tt?!1:(n&&n.tt&&clearTimeout(n.tt),void(n&&n.last+i>s&&!n.tt?w.delaylist[e]={last:s+i,tt:setTimeout(function(){w.delaylist[e].tt=0,t.call()},i)}:n&&n.tt||(w.delaylist[e]={last:s,tt:0},setTimeout(function(){t.call()},0))))},this.debounced=function(e,t,i){var o=w.delaylist[e];(new Date).getTime(),w.delaylist[e]=t,o||setTimeout(function(){var t=w.delaylist[e];w.delaylist[e]=!1,t.call()},i)},this.synched=function(e,t){return w.synclist[e]=t,function(){w.onsync||(l(function(){w.onsync=!1;for(e in w.synclist){var t=w.synclist[e];t&&t.call(w),w.synclist[e]=!1}}),w.onsync=!0)}(),e},this.unsynched=function(e){w.synclist[e]&&(w.synclist[e]=!1)},this.css=function(e,t){for(var i in t)w.saved.css.push([e,i,e.css(i)]),e.css(i,t[i])},this.scrollTop=function(e){return"undefined"==typeof e?w.getScrollTop():w.setScrollTop(e)},this.scrollLeft=function(e){return"undefined"==typeof e?w.getScrollLeft():w.setScrollLeft(e)},BezierClass=function(e,t,i,o,n,s,r){this.st=e,this.ed=t,this.spd=i,this.p1=o||0,this.p2=n||1,this.p3=s||0,this.p4=r||1,this.ts=(new Date).getTime(),this.df=this.ed-this.st},BezierClass.prototype={B2:function(e){return 3*e*e*(1-e)},B3:function(e){return 3*e*(1-e)*(1-e)},B4:function(e){return(1-e)*(1-e)*(1-e)},getNow:function(){var e=1-((new Date).getTime()-this.ts)/this.spd,t=this.B2(e)+this.B3(e)+this.B4(e);return 0>e?this.ed:this.st+Math.round(this.df*t)},update:function(e,t){return this.st=this.getNow(),this.ed=e,this.spd=t,this.ts=(new Date).getTime(),this.df=this.ed-this.st,this}},this.ishwscroll){this.doc.translate={x:0,y:0,tx:"0px",ty:"0px"},x.hastranslate3d&&x.isios&&this.doc.css("-webkit-backface-visibility","hidden");var T=function(){var e=w.doc.css(x.trstyle);return e&&"matrix"==e.substr(0,6)?e.replace(/^.*\((.*)\)$/g,"$1").replace(/px/g,"").split(/, +/):!1};this.getScrollTop=function(e){if(!e){if(e=T())return 16==e.length?-e[13]:-e[5];if(w.timerscroll&&w.timerscroll.bz)return w.timerscroll.bz.getNow()}return w.doc.translate.y},this.getScrollLeft=function(e){if(!e){if(e=T())return 16==e.length?-e[12]:-e[4];if(w.timerscroll&&w.timerscroll.bh)return w.timerscroll.bh.getNow()}return w.doc.translate.x},this.notifyScrollEvent=document.createEvent?function(e){var t=document.createEvent("UIEvents");t.initUIEvent("scroll",!1,!0,window,1),e.dispatchEvent(t)}:document.fireEvent?function(e){var t=document.createEventObject();e.fireEvent("onscroll"),t.cancelBubble=!0}:function(){},x.hastranslate3d&&w.opt.enabletranslate3d?(this.setScrollTop=function(e,t){w.doc.translate.y=e,w.doc.translate.ty=-1*e+"px",w.doc.css(x.trstyle,"translate3d("+w.doc.translate.tx+","+w.doc.translate.ty+",0px)"),t||w.notifyScrollEvent(w.win[0])},this.setScrollLeft=function(e,t){w.doc.translate.x=e,w.doc.translate.tx=-1*e+"px",w.doc.css(x.trstyle,"translate3d("+w.doc.translate.tx+","+w.doc.translate.ty+",0px)"),t||w.notifyScrollEvent(w.win[0])}):(this.setScrollTop=function(e,t){w.doc.translate.y=e,w.doc.translate.ty=-1*e+"px",w.doc.css(x.trstyle,"translate("+w.doc.translate.tx+","+w.doc.translate.ty+")"),t||w.notifyScrollEvent(w.win[0])},this.setScrollLeft=function(e,t){w.doc.translate.x=e,w.doc.translate.tx=-1*e+"px",w.doc.css(x.trstyle,"translate("+w.doc.translate.tx+","+w.doc.translate.ty+")"),t||w.notifyScrollEvent(w.win[0])})}else this.getScrollTop=function(){return w.docscroll.scrollTop()},this.setScrollTop=function(e){return w.docscroll.scrollTop(e)},this.getScrollLeft=function(){return w.docscroll.scrollLeft()},this.setScrollLeft=function(e){return w.docscroll.scrollLeft(e)};this.getTarget=function(e){return e?e.target?e.target:e.srcElement?e.srcElement:!1:!1},this.hasParent=function(e,t){if(!e)return!1;for(var i=e.target||e.srcElement||e||!1;i&&i.id!=t;)i=i.parentNode||!1;return!1!==i};var S={thin:1,medium:3,thick:5};this.getOffset=function(){if(w.isfixed)return{top:parseFloat(w.win.css("top")),left:parseFloat(w.win.css("left"))};if(!w.viewport)return w.win.offset();var e=w.win.offset(),t=w.viewport.offset();return{top:e.top-t.top+w.viewport.scrollTop(),left:e.left-t.left+w.viewport.scrollLeft()}},this.updateScrollBar=function(e){if(w.ishwscroll)w.rail.css({height:w.win.innerHeight()}),w.railh&&w.railh.css({width:w.win.innerWidth()});else{var t=w.getOffset(),i=t.top,o=t.left,i=i+g(w.win,"border-top-width",!0);w.win.outerWidth(),w.win.innerWidth();var o=o+(w.rail.align?w.win.outerWidth()-g(w.win,"border-right-width")-w.rail.width:g(w.win,"border-left-width")),n=w.opt.railoffset;n&&(n.top&&(i+=n.top),w.rail.align&&n.left&&(o+=n.left)),w.locked||w.rail.css({top:i,left:o,height:e?e.h:w.win.innerHeight()}),w.zoom&&w.zoom.css({top:i+1,left:1==w.rail.align?o-20:o+w.rail.width+4}),w.railh&&!w.locked&&(i=t.top,o=t.left,e=w.railh.align?i+g(w.win,"border-top-width",!0)+w.win.innerHeight()-w.railh.height:i+g(w.win,"border-top-width",!0),o+=g(w.win,"border-left-width"),w.railh.css({top:e,left:o,width:w.railh.width}))}},this.doRailClick=function(e,t,i){var o;w.locked||(w.cancelEvent(e),t?(t=i?w.doScrollLeft:w.doScrollTop,o=i?(e.pageX-w.railh.offset().left-w.cursorwidth/2)*w.scrollratio.x:(e.pageY-w.rail.offset().top-w.cursorheight/2)*w.scrollratio.y,t(o)):(t=i?w.doScrollLeftBy:w.doScrollBy,o=i?w.scroll.x:w.scroll.y,e=i?e.pageX-w.railh.offset().left:e.pageY-w.rail.offset().top,i=i?w.view.w:w.view.h,t(o>=e?i:-i)))},w.hasanimationframe=l,w.hascancelanimationframe=d,w.hasanimationframe?w.hascancelanimationframe||(d=function(){w.cancelAnimationFrame=!0}):(l=function(e){return setTimeout(e,15-Math.floor(+new Date/1e3)%16)},d=clearInterval),this.init=function(){if(w.saved.css=[],x.isie7mobile)return!0;if(x.hasmstouch&&w.css(w.ispage?e("html"):w.win,{"-ms-touch-action":"none"}),w.zindex="auto",w.zindex=w.ispage||"auto"!=w.opt.zindex?w.opt.zindex:p()||"auto",!w.ispage&&"auto"!=w.zindex&&w.zindex>s&&(s=w.zindex),w.isie&&0==w.zindex&&"auto"==w.opt.zindex&&(w.zindex="auto"),!w.ispage||!x.cantouch&&!x.isieold&&!x.isie9mobile){var n=w.docscroll;w.ispage&&(n=w.haswrapper?w.win:w.doc),x.isie9mobile||w.css(n,{"overflow-y":"hidden"}),w.ispage&&x.isie7&&("BODY"==w.doc[0].nodeName?w.css(e("html"),{"overflow-y":"hidden"}):"HTML"==w.doc[0].nodeName&&w.css(e("body"),{"overflow-y":"hidden"})),x.isios&&!w.ispage&&!w.haswrapper&&w.css(e("body"),{"-webkit-overflow-scrolling":"touch"});var a=e(document.createElement("div"));a.css({position:"relative",top:0,"float":"right",width:w.opt.cursorwidth,height:"0px","background-color":w.opt.cursorcolor,border:w.opt.cursorborder,"background-clip":"padding-box","-webkit-border-radius":w.opt.cursorborderradius,"-moz-border-radius":w.opt.cursorborderradius,"border-radius":w.opt.cursorborderradius}),a.hborder=parseFloat(a.outerHeight()-a.innerHeight()),w.cursor=a;var l=e(document.createElement("div"));l.attr("id",w.id),l.addClass("nicescroll-rails");var d,u,h,m=["left","right"];for(h in m)u=m[h],(d=w.opt.railpadding[u])?l.css("padding-"+u,d+"px"):w.opt.railpadding[u]=0;if(l.append(a),l.width=Math.max(parseFloat(w.opt.cursorwidth),a.outerWidth())+w.opt.railpadding.left+w.opt.railpadding.right,l.css({width:l.width+"px",zIndex:w.zindex,background:w.opt.background,cursor:"default"}),l.visibility=!0,l.scrollable=!0,l.align="left"==w.opt.railalign?0:1,w.rail=l,a=w.rail.drag=!1,w.opt.boxzoom&&!w.ispage&&!x.isieold&&(a=document.createElement("div"),w.bind(a,"click",w.doZoom),w.zoom=e(a),w.zoom.css({cursor:"pointer","z-index":w.zindex,backgroundImage:"url("+r+"zoomico.png)",height:18,width:18,backgroundPosition:"0px 0px"}),w.opt.dblclickzoom&&w.bind(w.win,"dblclick",w.doZoom),x.cantouch&&w.opt.gesturezoom&&(w.ongesturezoom=function(e){return 1.5<e.scale&&w.doZoomIn(e),.8>e.scale&&w.doZoomOut(e),w.cancelEvent(e)},w.bind(w.win,"gestureend",w.ongesturezoom))),w.railh=!1,w.opt.horizrailenabled){w.css(n,{"overflow-x":"hidden"}),a=e(document.createElement("div")),a.css({position:"relative",top:0,height:w.opt.cursorwidth,width:"0px","background-color":w.opt.cursorcolor,border:w.opt.cursorborder,"background-clip":"padding-box","-webkit-border-radius":w.opt.cursorborderradius,"-moz-border-radius":w.opt.cursorborderradius,"border-radius":w.opt.cursorborderradius}),a.wborder=parseFloat(a.outerWidth()-a.innerWidth()),w.cursorh=a;var g=e(document.createElement("div"));g.attr("id",w.id+"-hr"),g.addClass("nicescroll-rails"),g.height=Math.max(parseFloat(w.opt.cursorwidth),a.outerHeight()),g.css({height:g.height+"px",zIndex:w.zindex,background:w.opt.background}),g.append(a),g.visibility=!0,g.scrollable=!0,g.align="top"==w.opt.railvalign?0:1,w.railh=g,w.railh.drag=!1}if(w.ispage?(l.css({position:"fixed",top:"0px",height:"100%"}),l.css(l.align?{right:"0px"}:{left:"0px"}),w.body.append(l),w.railh&&(g.css({position:"fixed",left:"0px",width:"100%"}),g.css(g.align?{bottom:"0px"}:{top:"0px"}),w.body.append(g))):(w.ishwscroll?("static"==w.win.css("position")&&w.css(w.win,{position:"relative"}),n="HTML"==w.win[0].nodeName?w.body:w.win,w.zoom&&(w.zoom.css({position:"absolute",top:1,right:0,"margin-right":l.width+4}),n.append(w.zoom)),l.css({position:"absolute",top:0}),l.css(l.align?{right:0}:{left:0}),n.append(l),g&&(g.css({position:"absolute",left:0,bottom:0}),g.css(g.align?{bottom:0}:{top:0}),n.append(g))):(w.isfixed="fixed"==w.win.css("position"),n=w.isfixed?"fixed":"absolute",w.isfixed||(w.viewport=w.getViewport(w.win[0])),w.viewport&&(w.body=w.viewport,0==/relative|absolute/.test(w.viewport.css("position"))&&w.css(w.viewport,{position:"relative"})),l.css({position:n}),w.zoom&&w.zoom.css({position:n}),w.updateScrollBar(),w.body.append(l),w.zoom&&w.body.append(w.zoom),w.railh&&(g.css({position:n}),w.body.append(g))),x.isios&&w.css(w.win,{"-webkit-tap-highlight-color":"rgba(0,0,0,0)","-webkit-touch-callout":"none"}),x.isie&&w.opt.disableoutline&&w.win.attr("hideFocus","true"),x.iswebkit&&w.opt.disableoutline&&w.win.css({outline:"none"})),!1===w.opt.autohidemode?(w.autohidedom=!1,w.rail.css({opacity:w.opt.cursoropacitymax}),w.railh&&w.railh.css({opacity:w.opt.cursoropacitymax})):!0===w.opt.autohidemode?(w.autohidedom=e().add(w.rail),x.isie8&&(w.autohidedom=w.autohidedom.add(w.cursor)),w.railh&&(w.autohidedom=w.autohidedom.add(w.railh)),w.railh&&x.isie8&&(w.autohidedom=w.autohidedom.add(w.cursorh))):"scroll"==w.opt.autohidemode?(w.autohidedom=e().add(w.rail),w.railh&&(w.autohidedom=w.autohidedom.add(w.railh))):"cursor"==w.opt.autohidemode?(w.autohidedom=e().add(w.cursor),w.railh&&(w.autohidedom=w.autohidedom.add(w.cursorh))):"hidden"==w.opt.autohidemode&&(w.autohidedom=!1,w.hide(),w.locked=!1),x.isie9mobile)w.scrollmom=new f(w),w.onmangotouch=function(e){e=w.getScrollTop();var t=w.getScrollLeft();if(e==w.scrollmom.lastscrolly&&t==w.scrollmom.lastscrollx)return!0;var i=e-w.mangotouch.sy,o=t-w.mangotouch.sx;if(0!=Math.round(Math.sqrt(Math.pow(o,2)+Math.pow(i,2)))){var n=0>i?-1:1,s=0>o?-1:1,r=+new Date;w.mangotouch.lazy&&clearTimeout(w.mangotouch.lazy),80<r-w.mangotouch.tm||w.mangotouch.dry!=n||w.mangotouch.drx!=s?(w.scrollmom.stop(),w.scrollmom.reset(t,e),w.mangotouch.sy=e,w.mangotouch.ly=e,w.mangotouch.sx=t,w.mangotouch.lx=t,w.mangotouch.dry=n,w.mangotouch.drx=s,w.mangotouch.tm=r):(w.scrollmom.stop(),w.scrollmom.update(w.mangotouch.sx-o,w.mangotouch.sy-i),w.mangotouch.tm=r,i=Math.max(Math.abs(w.mangotouch.ly-e),Math.abs(w.mangotouch.lx-t)),w.mangotouch.ly=e,w.mangotouch.lx=t,i>2&&(w.mangotouch.lazy=setTimeout(function(){w.mangotouch.lazy=!1,w.mangotouch.dry=0,w.mangotouch.drx=0,w.mangotouch.tm=0,w.scrollmom.doMomentum(30)},100)))}},l=w.getScrollTop(),g=w.getScrollLeft(),w.mangotouch={sy:l,ly:l,dry:0,sx:g,lx:g,drx:0,lazy:!1,tm:0},w.bind(w.docscroll,"scroll",w.onmangotouch);else{if(x.cantouch||w.istouchcapable||w.opt.touchbehavior||x.hasmstouch){w.scrollmom=new f(w),w.ontouchstart=function(t){if(t.pointerType&&2!=t.pointerType)return!1;if(!w.locked){if(x.hasmstouch)for(var i=t.target?t.target:!1;i;){var o=e(i).getNiceScroll();if(0<o.length&&o[0].me==w.me)break;if(0<o.length)return!1;if("DIV"==i.nodeName&&i.id==w.id)break;i=i.parentNode?i.parentNode:!1}if(w.cancelScroll(),(i=w.getTarget(t))&&/INPUT/i.test(i.nodeName)&&/range/i.test(i.type))return w.stopPropagation(t);if(!("clientX"in t)&&"changedTouches"in t&&(t.clientX=t.changedTouches[0].clientX,t.clientY=t.changedTouches[0].clientY),w.forcescreen&&(o=t,t={original:t.original?t.original:t},t.clientX=o.screenX,t.clientY=o.screenY),w.rail.drag={x:t.clientX,y:t.clientY,sx:w.scroll.x,sy:w.scroll.y,st:w.getScrollTop(),sl:w.getScrollLeft(),pt:2,dl:!1},w.ispage||!w.opt.directionlockdeadzone)w.rail.drag.dl="f";else{var o=e(window).width(),n=e(window).height(),s=Math.max(document.body.scrollWidth,document.documentElement.scrollWidth),r=Math.max(document.body.scrollHeight,document.documentElement.scrollHeight),n=Math.max(0,r-n),o=Math.max(0,s-o);w.rail.drag.ck=!w.rail.scrollable&&w.railh.scrollable?n>0?"v":!1:w.rail.scrollable&&!w.railh.scrollable?o>0?"h":!1:!1,w.rail.drag.ck||(w.rail.drag.dl="f")}if(w.opt.touchbehavior&&w.isiframe&&x.isie&&(o=w.win.position(),w.rail.drag.x+=o.left,w.rail.drag.y+=o.top),w.hasmoving=!1,w.lastmouseup=!1,w.scrollmom.reset(t.clientX,t.clientY),!x.cantouch&&!this.istouchcapable&&!x.hasmstouch){if(!i||!/INPUT|SELECT|TEXTAREA/i.test(i.nodeName))return!w.ispage&&x.hasmousecapture&&i.setCapture(),w.cancelEvent(t);/SUBMIT|CANCEL|BUTTON/i.test(e(i).attr("type"))&&(pc={tg:i,click:!1},w.preventclick=pc)}}},w.ontouchend=function(e){return e.pointerType&&2!=e.pointerType?!1:w.rail.drag&&2==w.rail.drag.pt&&(w.scrollmom.doMomentum(),w.rail.drag=!1,w.hasmoving&&(w.hasmoving=!1,w.lastmouseup=!0,w.hideCursor(),x.hasmousecapture&&document.releaseCapture(),!x.cantouch))?w.cancelEvent(e):void 0};var v=w.opt.touchbehavior&&w.isiframe&&!x.hasmousecapture;w.ontouchmove=function(t,i){if(t.pointerType&&2!=t.pointerType)return!1;if(w.rail.drag&&2==w.rail.drag.pt){if(x.cantouch&&"undefined"==typeof t.original)return!0;if(w.hasmoving=!0,w.preventclick&&!w.preventclick.click&&(w.preventclick.click=w.preventclick.tg.onclick||!1,w.preventclick.tg.onclick=w.onpreventclick),t=e.extend({original:t},t),"changedTouches"in t&&(t.clientX=t.changedTouches[0].clientX,t.clientY=t.changedTouches[0].clientY),w.forcescreen){var o=t;t={original:t.original?t.original:t},t.clientX=o.screenX,t.clientY=o.screenY}if(o=ofy=0,v&&!i){var n=w.win.position(),o=-n.left;ofy=-n.top}var s=t.clientY+ofy,n=s-w.rail.drag.y,r=t.clientX+o,a=r-w.rail.drag.x,l=w.rail.drag.st-n;if(w.ishwscroll&&w.opt.bouncescroll?0>l?l=Math.round(l/2):l>w.page.maxh&&(l=w.page.maxh+Math.round((l-w.page.maxh)/2)):(0>l&&(s=l=0),l>w.page.maxh&&(l=w.page.maxh,s=0)),w.railh&&w.railh.scrollable){var d=w.rail.drag.sl-a;w.ishwscroll&&w.opt.bouncescroll?0>d?d=Math.round(d/2):d>w.page.maxw&&(d=w.page.maxw+Math.round((d-w.page.maxw)/2)):(0>d&&(r=d=0),d>w.page.maxw&&(d=w.page.maxw,r=0))}if(o=!1,w.rail.drag.dl)o=!0,"v"==w.rail.drag.dl?d=w.rail.drag.sl:"h"==w.rail.drag.dl&&(l=w.rail.drag.st);else{var n=Math.abs(n),a=Math.abs(a),c=w.opt.directionlockdeadzone;if("v"==w.rail.drag.ck){if(n>c&&.3*n>=a)return w.rail.drag=!1,!0;a>c&&(w.rail.drag.dl="f",e("body").scrollTop(e("body").scrollTop()))}else if("h"==w.rail.drag.ck){if(a>c&&.3*az>=n)return w.rail.drag=!1,!0;n>c&&(w.rail.drag.dl="f",e("body").scrollLeft(e("body").scrollLeft()))}}if(w.synched("touchmove",function(){w.rail.drag&&2==w.rail.drag.pt&&(w.prepareTransition&&w.prepareTransition(0),w.rail.scrollable&&w.setScrollTop(l),w.scrollmom.update(r,s),w.railh&&w.railh.scrollable?(w.setScrollLeft(d),w.showCursor(l,d)):w.showCursor(l),x.isie10&&document.selection.clear())}),x.ischrome&&w.istouchcapable&&(o=!1),o)return w.cancelEvent(t)}}}if(w.onmousedown=function(e,t){if(!w.rail.drag||1==w.rail.drag.pt){if(w.locked)return w.cancelEvent(e);w.cancelScroll(),w.rail.drag={x:e.clientX,y:e.clientY,sx:w.scroll.x,sy:w.scroll.y,pt:1,hr:!!t};var i=w.getTarget(e);return!w.ispage&&x.hasmousecapture&&i.setCapture(),w.isiframe&&!x.hasmousecapture&&(w.saved.csspointerevents=w.doc.css("pointer-events"),w.css(w.doc,{"pointer-events":"none"})),w.cancelEvent(e)}},w.onmouseup=function(e){return w.rail.drag&&(x.hasmousecapture&&document.releaseCapture(),w.isiframe&&!x.hasmousecapture&&w.doc.css("pointer-events",w.saved.csspointerevents),1==w.rail.drag.pt)?(w.rail.drag=!1,w.cancelEvent(e)):void 0},w.onmousemove=function(e){if(w.rail.drag&&1==w.rail.drag.pt){if(x.ischrome&&0==e.which)return w.onmouseup(e);if(w.cursorfreezed=!0,w.rail.drag.hr){w.scroll.x=w.rail.drag.sx+(e.clientX-w.rail.drag.x),0>w.scroll.x&&(w.scroll.x=0);var t=w.scrollvaluemaxw;w.scroll.x>t&&(w.scroll.x=t)}else w.scroll.y=w.rail.drag.sy+(e.clientY-w.rail.drag.y),0>w.scroll.y&&(w.scroll.y=0),t=w.scrollvaluemax,w.scroll.y>t&&(w.scroll.y=t);return w.synched("mousemove",function(){w.rail.drag&&1==w.rail.drag.pt&&(w.showCursor(),w.rail.drag.hr?w.doScrollLeft(Math.round(w.scroll.x*w.scrollratio.x),w.opt.cursordragspeed):w.doScrollTop(Math.round(w.scroll.y*w.scrollratio.y),w.opt.cursordragspeed))}),w.cancelEvent(e)}},x.cantouch||w.opt.touchbehavior)w.onpreventclick=function(e){return w.preventclick?(w.preventclick.tg.onclick=w.preventclick.click,w.preventclick=!1,w.cancelEvent(e)):void 0},w.bind(w.win,"mousedown",w.ontouchstart),w.onclick=x.isios?!1:function(e){return w.lastmouseup?(w.lastmouseup=!1,w.cancelEvent(e)):!0},w.opt.grabcursorenabled&&x.cursorgrabvalue&&(w.css(w.ispage?w.doc:w.win,{cursor:x.cursorgrabvalue}),w.css(w.rail,{cursor:x.cursorgrabvalue}));else{var y=function(e){if(w.selectiondrag){if(e){var t=w.win.outerHeight();e=e.pageY-w.selectiondrag.top,e>0&&t>e&&(e=0),e>=t&&(e-=t),w.selectiondrag.df=e}0!=w.selectiondrag.df&&(w.doScrollBy(2*-Math.floor(w.selectiondrag.df/6)),w.debounced("doselectionscroll",function(){y()},50))}};w.hasTextSelected="getSelection"in document?function(){return 0<document.getSelection().rangeCount}:"selection"in document?function(){return"None"!=document.selection.type}:function(){return!1},w.onselectionstart=function(){w.ispage||(w.selectiondrag=w.win.offset())},w.onselectionend=function(){w.selectiondrag=!1},w.onselectiondrag=function(e){w.selectiondrag&&w.hasTextSelected()&&w.debounced("selectionscroll",function(){y(e)},250)}}x.hasmstouch&&(w.css(w.rail,{"-ms-touch-action":"none"}),w.css(w.cursor,{"-ms-touch-action":"none"}),w.bind(w.win,"MSPointerDown",w.ontouchstart),w.bind(document,"MSPointerUp",w.ontouchend),w.bind(document,"MSPointerMove",w.ontouchmove),w.bind(w.cursor,"MSGestureHold",function(e){e.preventDefault()}),w.bind(w.cursor,"contextmenu",function(e){e.preventDefault()})),this.istouchcapable&&(w.bind(w.win,"touchstart",w.ontouchstart),w.bind(document,"touchend",w.ontouchend),w.bind(document,"touchcancel",w.ontouchend),w.bind(document,"touchmove",w.ontouchmove)),w.bind(w.cursor,"mousedown",w.onmousedown),w.bind(w.cursor,"mouseup",w.onmouseup),w.railh&&(w.bind(w.cursorh,"mousedown",function(e){w.onmousedown(e,!0)}),w.bind(w.cursorh,"mouseup",function(e){return w.rail.drag&&2==w.rail.drag.pt?void 0:(w.rail.drag=!1,w.hasmoving=!1,w.hideCursor(),x.hasmousecapture&&document.releaseCapture(),w.cancelEvent(e))})),(w.opt.cursordragontouch||!x.cantouch&&!w.opt.touchbehavior)&&(w.rail.css({cursor:"default"}),w.railh&&w.railh.css({cursor:"default"}),w.jqbind(w.rail,"mouseenter",function(){w.canshowonmouseevent&&w.showCursor(),w.rail.active=!0}),w.jqbind(w.rail,"mouseleave",function(){w.rail.active=!1,w.rail.drag||w.hideCursor()}),w.opt.sensitiverail&&(w.bind(w.rail,"click",function(e){w.doRailClick(e,!1,!1)}),w.bind(w.rail,"dblclick",function(e){w.doRailClick(e,!0,!1)}),w.bind(w.cursor,"click",function(e){w.cancelEvent(e)}),w.bind(w.cursor,"dblclick",function(e){w.cancelEvent(e)})),w.railh&&(w.jqbind(w.railh,"mouseenter",function(){w.canshowonmouseevent&&w.showCursor(),w.rail.active=!0}),w.jqbind(w.railh,"mouseleave",function(){w.rail.active=!1,w.rail.drag||w.hideCursor()}),w.opt.sensitiverail&&(w.bind(w.railh,"click",function(e){w.doRailClick(e,!1,!0)}),w.bind(w.railh,"dblclick",function(e){w.doRailClick(e,!0,!0)}),w.bind(w.cursorh,"click",function(e){w.cancelEvent(e)}),w.bind(w.cursorh,"dblclick",function(e){w.cancelEvent(e)})))),x.cantouch||w.opt.touchbehavior?(w.bind(x.hasmousecapture?w.win:document,"mouseup",w.ontouchend),w.bind(document,"mousemove",w.ontouchmove),w.onclick&&w.bind(document,"click",w.onclick),w.opt.cursordragontouch&&(w.bind(w.cursor,"mousedown",w.onmousedown),w.bind(w.cursor,"mousemove",w.onmousemove),w.cursorh&&w.bind(w.cursorh,"mousedown",w.onmousedown),w.cursorh&&w.bind(w.cursorh,"mousemove",w.onmousemove))):(w.bind(x.hasmousecapture?w.win:document,"mouseup",w.onmouseup),w.bind(document,"mousemove",w.onmousemove),w.onclick&&w.bind(document,"click",w.onclick),!w.ispage&&w.opt.enablescrollonselection&&(w.bind(w.win[0],"mousedown",w.onselectionstart),w.bind(document,"mouseup",w.onselectionend),w.bind(w.cursor,"mouseup",w.onselectionend),w.cursorh&&w.bind(w.cursorh,"mouseup",w.onselectionend),w.bind(document,"mousemove",w.onselectiondrag)),w.zoom&&(w.jqbind(w.zoom,"mouseenter",function(){w.canshowonmouseevent&&w.showCursor(),w.rail.active=!0}),w.jqbind(w.zoom,"mouseleave",function(){w.rail.active=!1,w.rail.drag||w.hideCursor()}))),w.opt.enablemousewheel&&(w.isiframe||w.bind(x.isie&&w.ispage?document:w.docscroll,"mousewheel",w.onmousewheel),w.bind(w.rail,"mousewheel",w.onmousewheel),w.railh&&w.bind(w.railh,"mousewheel",w.onmousewheelhr)),!w.ispage&&!x.cantouch&&!/HTML|BODY/.test(w.win[0].nodeName)&&(w.win.attr("tabindex")||w.win.attr({tabindex:o++}),w.jqbind(w.win,"focus",function(e){t=w.getTarget(e).id||!0,w.hasfocus=!0,w.canshowonmouseevent&&w.noticeCursor()}),w.jqbind(w.win,"blur",function(){t=!1,w.hasfocus=!1}),w.jqbind(w.win,"mouseenter",function(e){i=w.getTarget(e).id||!0,w.hasmousefocus=!0,w.canshowonmouseevent&&w.noticeCursor()}),w.jqbind(w.win,"mouseleave",function(){i=!1,w.hasmousefocus=!1}))}if(w.onkeypress=function(e){if(w.locked&&0==w.page.maxh)return!0;e=e?e:window.e;var o=w.getTarget(e);if(o&&/INPUT|TEXTAREA|SELECT|OPTION/.test(o.nodeName)&&(!o.getAttribute("type")&&!o.type||!/submit|button|cancel/i.tp))return!0;if(w.hasfocus||w.hasmousefocus&&!t||w.ispage&&!t&&!i){if(o=e.keyCode,w.locked&&27!=o)return w.cancelEvent(e);var n=e.ctrlKey||!1,s=e.shiftKey||!1,r=!1;switch(o){case 38:case 63233:w.doScrollBy(72),r=!0;break;case 40:case 63235:w.doScrollBy(-72),r=!0;break;case 37:case 63232:w.railh&&(n?w.doScrollLeft(0):w.doScrollLeftBy(72),r=!0);break;case 39:case 63234:w.railh&&(n?w.doScrollLeft(w.page.maxw):w.doScrollLeftBy(-72),r=!0);break;case 33:case 63276:w.doScrollBy(w.view.h),r=!0;break;case 34:case 63277:w.doScrollBy(-w.view.h),r=!0;break;case 36:case 63273:w.railh&&n?w.doScrollPos(0,0):w.doScrollTo(0),r=!0;break;case 35:case 63275:w.railh&&n?w.doScrollPos(w.page.maxw,w.page.maxh):w.doScrollTo(w.page.maxh),r=!0;break;case 32:w.opt.spacebarenabled&&(w.doScrollBy(s?w.view.h:-w.view.h),r=!0);break;case 27:w.zoomactive&&(w.doZoom(),r=!0)}if(r)return w.cancelEvent(e)}},w.opt.enablekeyboard&&w.bind(document,x.isopera&&!x.isopera12?"keypress":"keydown",w.onkeypress),w.bind(window,"resize",w.lazyResize),w.bind(window,"orientationchange",w.lazyResize),w.bind(window,"load",w.lazyResize),x.ischrome&&!w.ispage&&!w.haswrapper){var b=w.win.attr("style"),l=parseFloat(w.win.css("width"))+1;w.win.css("width",l),w.synched("chromefix",function(){w.win.attr("style",b)})}w.onAttributeChange=function(){w.lazyResize(250)},!w.ispage&&!w.haswrapper&&(!1!==c?(w.observer=new c(function(e){e.forEach(w.onAttributeChange)}),w.observer.observe(w.win[0],{childList:!0,characterData:!1,attributes:!0,subtree:!1}),w.observerremover=new c(function(e){e.forEach(function(e){if(0<e.removedNodes.length)for(var t in e.removedNodes)if(e.removedNodes[t]==w.win[0])return w.remove()})}),w.observerremover.observe(w.win[0].parentNode,{childList:!0,characterData:!1,attributes:!1,subtree:!1})):(w.bind(w.win,x.isie&&!x.isie9?"propertychange":"DOMAttrModified",w.onAttributeChange),x.isie9&&w.win[0].attachEvent("onpropertychange",w.onAttributeChange),w.bind(w.win,"DOMNodeRemoved",function(e){e.target==w.win[0]&&w.remove()}))),!w.ispage&&w.opt.boxzoom&&w.bind(window,"resize",w.resizeZoom),w.istextarea&&w.bind(w.win,"mouseup",w.lazyResize),w.checkrtlmode=!0,w.lazyResize(30)}if("IFRAME"==this.doc[0].nodeName){var T=function(t){w.iframexd=!1;try{var i="contentDocument"in this?this.contentDocument:this.contentWindow.document}catch(o){w.iframexd=!0,i=!1}return w.iframexd?("console"in window&&console.log("NiceScroll error: policy restriced iframe"),!0):(w.forcescreen=!0,w.isiframe&&(w.iframe={doc:e(i),html:w.doc.contents().find("html")[0],body:w.doc.contents().find("body")[0]},w.getContentSize=function(){return{w:Math.max(w.iframe.html.scrollWidth,w.iframe.body.scrollWidth),h:Math.max(w.iframe.html.scrollHeight,w.iframe.body.scrollHeight)}},w.docscroll=e(w.iframe.body)),!x.isios&&w.opt.iframeautoresize&&!w.isiframe&&(w.win.scrollTop(0),w.doc.height(""),t=Math.max(i.getElementsByTagName("html")[0].scrollHeight,i.body.scrollHeight),w.doc.height(t)),w.lazyResize(30),x.isie7&&w.css(e(w.iframe.html),{"overflow-y":"hidden"}),w.css(e(w.iframe.body),{"overflow-y":"hidden"}),"contentWindow"in this?w.bind(this.contentWindow,"scroll",w.onscroll):w.bind(i,"scroll",w.onscroll),w.opt.enablemousewheel&&w.bind(i,"mousewheel",w.onmousewheel),w.opt.enablekeyboard&&w.bind(i,x.isopera?"keypress":"keydown",w.onkeypress),(x.cantouch||w.opt.touchbehavior)&&(w.bind(i,"mousedown",w.onmousedown),w.bind(i,"mousemove",function(e){w.onmousemove(e,!0)}),w.opt.grabcursorenabled&&x.cursorgrabvalue&&w.css(e(i.body),{cursor:x.cursorgrabvalue})),w.bind(i,"mouseup",w.onmouseup),void(w.zoom&&(w.opt.dblclickzoom&&w.bind(i,"dblclick",w.doZoom),w.ongesturezoom&&w.bind(i,"gestureend",w.ongesturezoom))))};this.doc[0].readyState&&"complete"==this.doc[0].readyState&&setTimeout(function(){T.call(w.doc[0],!1)
},500),w.bind(this.doc,"load",T)}},this.showCursor=function(e,t){w.cursortimeout&&(clearTimeout(w.cursortimeout),w.cursortimeout=0),w.rail&&(w.autohidedom&&(w.autohidedom.stop().css({opacity:w.opt.cursoropacitymax}),w.cursoractive=!0),w.rail.drag&&1==w.rail.drag.pt||("undefined"!=typeof e&&!1!==e&&(w.scroll.y=Math.round(1*e/w.scrollratio.y)),"undefined"!=typeof t&&(w.scroll.x=Math.round(1*t/w.scrollratio.x))),w.cursor.css({height:w.cursorheight,top:w.scroll.y}),w.cursorh&&(w.cursorh.css(!w.rail.align&&w.rail.visibility?{width:w.cursorwidth,left:w.scroll.x+w.rail.width}:{width:w.cursorwidth,left:w.scroll.x}),w.cursoractive=!0),w.zoom&&w.zoom.stop().css({opacity:w.opt.cursoropacitymax}))},this.hideCursor=function(e){!w.cursortimeout&&w.rail&&w.autohidedom&&(w.cursortimeout=setTimeout(function(){w.rail.active&&w.showonmouseevent||(w.autohidedom.stop().animate({opacity:w.opt.cursoropacitymin}),w.zoom&&w.zoom.stop().animate({opacity:w.opt.cursoropacitymin}),w.cursoractive=!1),w.cursortimeout=0},e||w.opt.hidecursordelay))},this.noticeCursor=function(e,t,i){w.showCursor(t,i),w.rail.active||w.hideCursor(e)},this.getContentSize=w.ispage?function(){return{w:Math.max(document.body.scrollWidth,document.documentElement.scrollWidth),h:Math.max(document.body.scrollHeight,document.documentElement.scrollHeight)}}:w.haswrapper?function(){return{w:w.doc.outerWidth()+parseInt(w.win.css("paddingLeft"))+parseInt(w.win.css("paddingRight")),h:w.doc.outerHeight()+parseInt(w.win.css("paddingTop"))+parseInt(w.win.css("paddingBottom"))}}:function(){return{w:w.docscroll[0].scrollWidth,h:w.docscroll[0].scrollHeight}},this.onResize=function(e,t){if(!w.win)return!1;if(!w.haswrapper&&!w.ispage){if("none"==w.win.css("display"))return w.visibility&&w.hideRail().hideRailHr(),!1;!w.hidden&&!w.visibility&&w.showRail().showRailHr()}var i=w.page.maxh,o=w.page.maxw,n=w.view.w;if(w.view={w:w.ispage?w.win.width():parseInt(w.win[0].clientWidth),h:w.ispage?w.win.height():parseInt(w.win[0].clientHeight)},w.page=t?t:w.getContentSize(),w.page.maxh=Math.max(0,w.page.h-w.view.h),w.page.maxw=Math.max(0,w.page.w-w.view.w),w.page.maxh==i&&w.page.maxw==o&&w.view.w==n){if(w.ispage)return w;if(i=w.win.offset(),w.lastposition&&(o=w.lastposition,o.top==i.top&&o.left==i.left))return w;w.lastposition=i}return 0==w.page.maxh?(w.hideRail(),w.scrollvaluemax=0,w.scroll.y=0,w.scrollratio.y=0,w.cursorheight=0,w.setScrollTop(0),w.rail.scrollable=!1):w.rail.scrollable=!0,0==w.page.maxw?(w.hideRailHr(),w.scrollvaluemaxw=0,w.scroll.x=0,w.scrollratio.x=0,w.cursorwidth=0,w.setScrollLeft(0),w.railh.scrollable=!1):w.railh.scrollable=!0,w.locked=0==w.page.maxh&&0==w.page.maxw,w.locked?(w.ispage||w.updateScrollBar(w.view),!1):(w.hidden||w.visibility?!w.hidden&&!w.railh.visibility&&w.showRailHr():w.showRail().showRailHr(),w.istextarea&&w.win.css("resize")&&"none"!=w.win.css("resize")&&(w.view.h-=20),w.cursorheight=Math.min(w.view.h,Math.round(w.view.h*(w.view.h/w.page.h))),w.cursorheight=w.opt.cursorfixedheight?w.opt.cursorfixedheight:Math.max(w.opt.cursorminheight,w.cursorheight),w.cursorwidth=Math.min(w.view.w,Math.round(w.view.w*(w.view.w/w.page.w))),w.cursorwidth=w.opt.cursorfixedheight?w.opt.cursorfixedheight:Math.max(w.opt.cursorminheight,w.cursorwidth),w.scrollvaluemax=w.view.h-w.cursorheight-w.cursor.hborder,w.railh&&(w.railh.width=0<w.page.maxh?w.view.w-w.rail.width:w.view.w,w.scrollvaluemaxw=w.railh.width-w.cursorwidth-w.cursorh.wborder),w.checkrtlmode&&w.railh&&(w.checkrtlmode=!1,w.opt.rtlmode&&0==w.scroll.x&&w.setScrollLeft(w.page.maxw)),w.ispage||w.updateScrollBar(w.view),w.scrollratio={x:w.page.maxw/w.scrollvaluemaxw,y:w.page.maxh/w.scrollvaluemax},w.getScrollTop()>w.page.maxh?w.doScrollTop(w.page.maxh):(w.scroll.y=Math.round(w.getScrollTop()*(1/w.scrollratio.y)),w.scroll.x=Math.round(w.getScrollLeft()*(1/w.scrollratio.x)),w.cursoractive&&w.noticeCursor()),w.scroll.y&&0==w.getScrollTop()&&w.doScrollTo(Math.floor(w.scroll.y*w.scrollratio.y)),w)},this.resize=w.onResize,this.lazyResize=function(e){return e=isNaN(e)?30:e,w.delayed("resize",w.resize,e),w},this._bind=function(e,t,i,o){w.events.push({e:e,n:t,f:i,b:o,q:!1}),e.addEventListener?e.addEventListener(t,i,o||!1):e.attachEvent?e.attachEvent("on"+t,i):e["on"+t]=i},this.jqbind=function(t,i,o){w.events.push({e:t,n:i,f:o,q:!0}),e(t).bind(i,o)},this.bind=function(e,t,i,o){var n="jquery"in e?e[0]:e;"mousewheel"==t?"onwheel"in w.win?w._bind(n,"wheel",i,o||!1):(e="undefined"!=typeof document.onmousewheel?"mousewheel":"DOMMouseScroll",v(n,e,i,o||!1),"DOMMouseScroll"==e&&v(n,"MozMousePixelScroll",i,o||!1)):n.addEventListener?(x.cantouch&&/mouseup|mousedown|mousemove/.test(t)&&w._bind(n,"mousedown"==t?"touchstart":"mouseup"==t?"touchend":"touchmove",function(e){if(e.touches){if(2>e.touches.length){var t=e.touches.length?e.touches[0]:e;t.original=e,i.call(this,t)}}else e.changedTouches&&(t=e.changedTouches[0],t.original=e,i.call(this,t))},o||!1),w._bind(n,t,i,o||!1),x.cantouch&&"mouseup"==t&&w._bind(n,"touchcancel",i,o||!1)):w._bind(n,t,function(e){return(e=e||window.event||!1)&&e.srcElement&&(e.target=e.srcElement),"pageY"in e||(e.pageX=e.clientX+document.documentElement.scrollLeft,e.pageY=e.clientY+document.documentElement.scrollTop),!1===i.call(n,e)||!1===o?w.cancelEvent(e):!0})},this._unbind=function(e,t,i,o){e.removeEventListener?e.removeEventListener(t,i,o):e.detachEvent?e.detachEvent("on"+t,i):e["on"+t]=!1},this.unbindAll=function(){for(var e=0;e<w.events.length;e++){var t=w.events[e];t.q?t.e.unbind(t.n,t.f):w._unbind(t.e,t.n,t.f,t.b)}},this.cancelEvent=function(e){return(e=e.original?e.original:e?e:window.event||!1)?(e.preventDefault&&e.preventDefault(),e.stopPropagation&&e.stopPropagation(),e.preventManipulation&&e.preventManipulation(),e.cancelBubble=!0,e.cancel=!0,e.returnValue=!1):!1},this.stopPropagation=function(e){return(e=e.original?e.original:e?e:window.event||!1)?e.stopPropagation?e.stopPropagation():(e.cancelBubble&&(e.cancelBubble=!0),!1):!1},this.showRail=function(){return 0==w.page.maxh||!w.ispage&&"none"==w.win.css("display")||(w.visibility=!0,w.rail.visibility=!0,w.rail.css("display","block")),w},this.showRailHr=function(){return w.railh?(0==w.page.maxw||!w.ispage&&"none"==w.win.css("display")||(w.railh.visibility=!0,w.railh.css("display","block")),w):w},this.hideRail=function(){return w.visibility=!1,w.rail.visibility=!1,w.rail.css("display","none"),w},this.hideRailHr=function(){return w.railh?(w.railh.visibility=!1,w.railh.css("display","none"),w):w},this.show=function(){return w.hidden=!1,w.locked=!1,w.showRail().showRailHr()},this.hide=function(){return w.hidden=!0,w.locked=!0,w.hideRail().hideRailHr()},this.toggle=function(){return w.hidden?w.show():w.hide()},this.remove=function(){w.stop(),w.cursortimeout&&clearTimeout(w.cursortimeout),w.doZoomOut(),w.unbindAll(),!1!==w.observer&&w.observer.disconnect(),!1!==w.observerremover&&w.observerremover.disconnect(),w.events=[],w.cursor&&(w.cursor.remove(),w.cursor=null),w.cursorh&&(w.cursorh.remove(),w.cursorh=null),w.rail&&(w.rail.remove(),w.rail=null),w.railh&&(w.railh.remove(),w.railh=null),w.zoom&&(w.zoom.remove(),w.zoom=null);for(var e=0;e<w.saved.css.length;e++){var t=w.saved.css[e];t[0].css(t[1],"undefined"==typeof t[2]?"":t[2])}return w.saved=!1,w.me.data("__nicescroll",""),w.me=null,w.doc=null,w.docscroll=null,w.win=null,w},this.scrollstart=function(e){return this.onscrollstart=e,w},this.scrollend=function(e){return this.onscrollend=e,w},this.scrollcancel=function(e){return this.onscrollcancel=e,w},this.zoomin=function(e){return this.onzoomin=e,w},this.zoomout=function(e){return this.onzoomout=e,w},this.isScrollable=function(t){if(t=t.target?t.target:t,"OPTION"==t.nodeName)return!0;for(;t&&1==t.nodeType&&!/BODY|HTML/.test(t.nodeName);){var i=e(t),i=i.css("overflowY")||i.css("overflowX")||i.css("overflow")||"";if(/scroll|auto/.test(i))return t.clientHeight!=t.scrollHeight;t=t.parentNode?t.parentNode:!1}return!1},this.getViewport=function(t){for(t=t&&t.parentNode?t.parentNode:!1;t&&1==t.nodeType&&!/BODY|HTML/.test(t.nodeName);){var i=e(t),o=i.css("overflowY")||i.css("overflowX")||i.css("overflow")||"";if(/scroll|auto/.test(o)&&t.clientHeight!=t.scrollHeight||0<i.getNiceScroll().length)return i;t=t.parentNode?t.parentNode:!1}return!1},this.onmousewheel=function(e){if(w.locked)return!0;if(w.rail.drag)return w.cancelEvent(e);if(!w.rail.scrollable)return w.railh&&w.railh.scrollable?w.onmousewheelhr(e):!0;var t=+new Date,i=!1;return w.opt.preservenativescrolling&&w.checkarea+600<t&&(w.nativescrollingarea=w.isScrollable(e),i=!0),w.checkarea=t,w.nativescrollingarea?!0:((e=y(e,!1,i))&&(w.checkarea=0),e)},this.onmousewheelhr=function(e){if(w.locked||!w.railh.scrollable)return!0;if(w.rail.drag)return w.cancelEvent(e);var t=+new Date,i=!1;return w.opt.preservenativescrolling&&w.checkarea+600<t&&(w.nativescrollingarea=w.isScrollable(e),i=!0),w.checkarea=t,w.nativescrollingarea?!0:w.locked?w.cancelEvent(e):y(e,!0,i)},this.stop=function(){return w.cancelScroll(),w.scrollmon&&w.scrollmon.stop(),w.cursorfreezed=!1,w.scroll.y=Math.round(w.getScrollTop()*(1/w.scrollratio.y)),w.noticeCursor(),w},this.getTransitionSpeed=function(e){var t=Math.round(10*w.opt.scrollspeed);return e=Math.min(t,Math.round(e/20*w.opt.scrollspeed)),e>20?e:0},w.opt.smoothscroll?w.ishwscroll&&x.hastransition&&w.opt.usetransition?(this.prepareTransition=function(e,t){var i=t?e>20?e:0:w.getTransitionSpeed(e),o=i?x.prefixstyle+"transform "+i+"ms ease-out":"";return w.lasttransitionstyle&&w.lasttransitionstyle==o||(w.lasttransitionstyle=o,w.doc.css(x.transitionstyle,o)),i},this.doScrollLeft=function(e,t){var i=w.scrollrunning?w.newscrolly:w.getScrollTop();w.doScrollPos(e,i,t)},this.doScrollTop=function(e,t){var i=w.scrollrunning?w.newscrollx:w.getScrollLeft();w.doScrollPos(i,e,t)},this.doScrollPos=function(e,t,i){var o=w.getScrollTop(),n=w.getScrollLeft();return(0>(w.newscrolly-o)*(t-o)||0>(w.newscrollx-n)*(e-n))&&w.cancelScroll(),0==w.opt.bouncescroll&&(0>t?t=0:t>w.page.maxh&&(t=w.page.maxh),0>e?e=0:e>w.page.maxw&&(e=w.page.maxw)),w.scrollrunning&&e==w.newscrollx&&t==w.newscrolly?!1:(w.newscrolly=t,w.newscrollx=e,w.newscrollspeed=i||!1,w.timer?!1:void(w.timer=setTimeout(function(){var i,o,n=w.getScrollTop(),s=w.getScrollLeft();i=e-s,o=t-n,i=Math.round(Math.sqrt(Math.pow(i,2)+Math.pow(o,2))),i=w.newscrollspeed&&1<w.newscrollspeed?w.newscrollspeed:w.getTransitionSpeed(i),w.newscrollspeed&&1>=w.newscrollspeed&&(i*=w.newscrollspeed),w.prepareTransition(i,!0),w.timerscroll&&w.timerscroll.tm&&clearInterval(w.timerscroll.tm),i>0&&(!w.scrollrunning&&w.onscrollstart&&w.onscrollstart.call(w,{type:"scrollstart",current:{x:s,y:n},request:{x:e,y:t},end:{x:w.newscrollx,y:w.newscrolly},speed:i}),x.transitionend?w.scrollendtrapped||(w.scrollendtrapped=!0,w.bind(w.doc,x.transitionend,w.onScrollEnd,!1)):(w.scrollendtrapped&&clearTimeout(w.scrollendtrapped),w.scrollendtrapped=setTimeout(w.onScrollEnd,i)),w.timerscroll={bz:new BezierClass(n,w.newscrolly,i,0,0,.58,1),bh:new BezierClass(s,w.newscrollx,i,0,0,.58,1)},w.cursorfreezed||(w.timerscroll.tm=setInterval(function(){w.showCursor(w.getScrollTop(),w.getScrollLeft())},60))),w.synched("doScroll-set",function(){w.timer=0,w.scrollendtrapped&&(w.scrollrunning=!0),w.setScrollTop(w.newscrolly),w.setScrollLeft(w.newscrollx),w.scrollendtrapped||w.onScrollEnd()})},50)))},this.cancelScroll=function(){if(!w.scrollendtrapped)return!0;var e=w.getScrollTop(),t=w.getScrollLeft();return w.scrollrunning=!1,x.transitionend||clearTimeout(x.transitionend),w.scrollendtrapped=!1,w._unbind(w.doc,x.transitionend,w.onScrollEnd),w.prepareTransition(0),w.setScrollTop(e),w.railh&&w.setScrollLeft(t),w.timerscroll&&w.timerscroll.tm&&clearInterval(w.timerscroll.tm),w.timerscroll=!1,w.cursorfreezed=!1,w.showCursor(e,t),w},this.onScrollEnd=function(){w.scrollendtrapped&&w._unbind(w.doc,x.transitionend,w.onScrollEnd),w.scrollendtrapped=!1,w.prepareTransition(0),w.timerscroll&&w.timerscroll.tm&&clearInterval(w.timerscroll.tm),w.timerscroll=!1;var e=w.getScrollTop(),t=w.getScrollLeft();return w.setScrollTop(e),w.railh&&w.setScrollLeft(t),w.noticeCursor(!1,e,t),w.cursorfreezed=!1,0>e?e=0:e>w.page.maxh&&(e=w.page.maxh),0>t?t=0:t>w.page.maxw&&(t=w.page.maxw),e!=w.newscrolly||t!=w.newscrollx?w.doScrollPos(t,e,w.opt.snapbackspeed):(w.onscrollend&&w.scrollrunning&&w.onscrollend.call(w,{type:"scrollend",current:{x:t,y:e},end:{x:w.newscrollx,y:w.newscrolly}}),void(w.scrollrunning=!1))}):(this.doScrollLeft=function(e,t){var i=w.scrollrunning?w.newscrolly:w.getScrollTop();w.doScrollPos(e,i,t)},this.doScrollTop=function(e,t){var i=w.scrollrunning?w.newscrollx:w.getScrollLeft();w.doScrollPos(i,e,t)},this.doScrollPos=function(e,t,i){function o(){if(w.cancelAnimationFrame)return!0;if(w.scrollrunning=!0,u=1-u)return w.timer=l(o)||1;var e=0,t=sy=w.getScrollTop();if(w.dst.ay){var t=w.bzscroll?w.dst.py+w.bzscroll.getNow()*w.dst.ay:w.newscrolly,i=t-sy;(0>i&&t<w.newscrolly||i>0&&t>w.newscrolly)&&(t=w.newscrolly),w.setScrollTop(t),t==w.newscrolly&&(e=1)}else e=1;var n=sx=w.getScrollLeft();w.dst.ax?(n=w.bzscroll?w.dst.px+w.bzscroll.getNow()*w.dst.ax:w.newscrollx,i=n-sx,(0>i&&n<w.newscrollx||i>0&&n>w.newscrollx)&&(n=w.newscrollx),w.setScrollLeft(n),n==w.newscrollx&&(e+=1)):e+=1,2==e?(w.timer=0,w.cursorfreezed=!1,w.bzscroll=!1,w.scrollrunning=!1,0>t?t=0:t>w.page.maxh&&(t=w.page.maxh),0>n?n=0:n>w.page.maxw&&(n=w.page.maxw),n!=w.newscrollx||t!=w.newscrolly?w.doScrollPos(n,t):w.onscrollend&&w.onscrollend.call(w,{type:"scrollend",current:{x:sx,y:sy},end:{x:w.newscrollx,y:w.newscrolly}})):w.timer=l(o)||1}if(t="undefined"==typeof t||!1===t?w.getScrollTop(!0):t,w.timer&&w.newscrolly==t&&w.newscrollx==e)return!0;w.timer&&d(w.timer),w.timer=0;var n=w.getScrollTop(),s=w.getScrollLeft();(0>(w.newscrolly-n)*(t-n)||0>(w.newscrollx-s)*(e-s))&&w.cancelScroll(),w.newscrolly=t,w.newscrollx=e,w.bouncescroll&&w.rail.visibility||(0>w.newscrolly?w.newscrolly=0:w.newscrolly>w.page.maxh&&(w.newscrolly=w.page.maxh)),w.bouncescroll&&w.railh.visibility||(0>w.newscrollx?w.newscrollx=0:w.newscrollx>w.page.maxw&&(w.newscrollx=w.page.maxw)),w.dst={},w.dst.x=e-s,w.dst.y=t-n,w.dst.px=s,w.dst.py=n;var r=Math.round(Math.sqrt(Math.pow(w.dst.x,2)+Math.pow(w.dst.y,2)));w.dst.ax=w.dst.x/r,w.dst.ay=w.dst.y/r;var a=0,c=r;if(0==w.dst.x?(a=n,c=t,w.dst.ay=1,w.dst.py=0):0==w.dst.y&&(a=s,c=e,w.dst.ax=1,w.dst.px=0),r=w.getTransitionSpeed(r),i&&1>=i&&(r*=i),w.bzscroll=r>0?w.bzscroll?w.bzscroll.update(c,r):new BezierClass(a,c,r,0,1,0,1):!1,!w.timer){(n==w.page.maxh&&t>=w.page.maxh||s==w.page.maxw&&e>=w.page.maxw)&&w.checkContentSize();var u=1;w.cancelAnimationFrame=!1,w.timer=1,w.onscrollstart&&!w.scrollrunning&&w.onscrollstart.call(w,{type:"scrollstart",current:{x:s,y:n},request:{x:e,y:t},end:{x:w.newscrollx,y:w.newscrolly},speed:r}),o(),(n==w.page.maxh&&t>=n||s==w.page.maxw&&e>=s)&&w.checkContentSize(),w.noticeCursor()}},this.cancelScroll=function(){return w.timer&&d(w.timer),w.timer=0,w.bzscroll=!1,w.scrollrunning=!1,w}):(this.doScrollLeft=function(e,t){var i=w.getScrollTop();w.doScrollPos(e,i,t)},this.doScrollTop=function(e,t){var i=w.getScrollLeft();w.doScrollPos(i,e,t)},this.doScrollPos=function(e,t){var i=e>w.page.maxw?w.page.maxw:e;0>i&&(i=0);var o=t>w.page.maxh?w.page.maxh:t;0>o&&(o=0),w.synched("scroll",function(){w.setScrollTop(o),w.setScrollLeft(i)})},this.cancelScroll=function(){}),this.doScrollBy=function(e,t){var i=0,i=t?Math.floor((w.scroll.y-e)*w.scrollratio.y):(w.timer?w.newscrolly:w.getScrollTop(!0))-e;if(w.bouncescroll){var o=Math.round(w.view.h/2);-o>i?i=-o:i>w.page.maxh+o&&(i=w.page.maxh+o)}return w.cursorfreezed=!1,py=w.getScrollTop(!0),0>i&&0>=py?w.noticeCursor():i>w.page.maxh&&py>=w.page.maxh?(w.checkContentSize(),w.noticeCursor()):void w.doScrollTop(i)},this.doScrollLeftBy=function(e,t){var i=0,i=t?Math.floor((w.scroll.x-e)*w.scrollratio.x):(w.timer?w.newscrollx:w.getScrollLeft(!0))-e;if(w.bouncescroll){var o=Math.round(w.view.w/2);-o>i?i=-o:i>w.page.maxw+o&&(i=w.page.maxw+o)}return w.cursorfreezed=!1,px=w.getScrollLeft(!0),0>i&&0>=px||i>w.page.maxw&&px>=w.page.maxw?w.noticeCursor():void w.doScrollLeft(i)},this.doScrollTo=function(e,t){t&&Math.round(e*w.scrollratio.y),w.cursorfreezed=!1,w.doScrollTop(e)},this.checkContentSize=function(){var e=w.getContentSize();(e.h!=w.page.h||e.w!=w.page.w)&&w.resize(!1,e)},w.onscroll=function(){w.rail.drag||w.cursorfreezed||w.synched("scroll",function(){w.scroll.y=Math.round(w.getScrollTop()*(1/w.scrollratio.y)),w.railh&&(w.scroll.x=Math.round(w.getScrollLeft()*(1/w.scrollratio.x))),w.noticeCursor()})},w.bind(w.docscroll,"scroll",w.onscroll),this.doZoomIn=function(t){if(!w.zoomactive){w.zoomactive=!0,w.zoomrestore={style:{}};var i,o="position top left zIndex backgroundColor marginTop marginBottom marginLeft marginRight".split(" "),n=w.win[0].style;for(i in o){var r=o[i];w.zoomrestore.style[r]="undefined"!=typeof n[r]?n[r]:""}return w.zoomrestore.style.width=w.win.css("width"),w.zoomrestore.style.height=w.win.css("height"),w.zoomrestore.padding={w:w.win.outerWidth()-w.win.width(),h:w.win.outerHeight()-w.win.height()},x.isios4&&(w.zoomrestore.scrollTop=e(window).scrollTop(),e(window).scrollTop(0)),w.win.css({position:x.isios4?"absolute":"fixed",top:0,left:0,"z-index":s+100,margin:"0px"}),o=w.win.css("backgroundColor"),(""==o||/transparent|rgba\(0, 0, 0, 0\)|rgba\(0,0,0,0\)/.test(o))&&w.win.css("backgroundColor","#fff"),w.rail.css({"z-index":s+101}),w.zoom.css({"z-index":s+102}),w.zoom.css("backgroundPosition","0px -18px"),w.resizeZoom(),w.onzoomin&&w.onzoomin.call(w),w.cancelEvent(t)}},this.doZoomOut=function(t){return w.zoomactive?(w.zoomactive=!1,w.win.css("margin",""),w.win.css(w.zoomrestore.style),x.isios4&&e(window).scrollTop(w.zoomrestore.scrollTop),w.rail.css({"z-index":w.zindex}),w.zoom.css({"z-index":w.zindex}),w.zoomrestore=!1,w.zoom.css("backgroundPosition","0px 0px"),w.onResize(),w.onzoomout&&w.onzoomout.call(w),w.cancelEvent(t)):void 0},this.doZoom=function(e){return w.zoomactive?w.doZoomOut(e):w.doZoomIn(e)},this.resizeZoom=function(){if(w.zoomactive){var t=w.getScrollTop();w.win.css({width:e(window).width()-w.zoomrestore.padding.w+"px",height:e(window).height()-w.zoomrestore.padding.h+"px"}),w.onResize(),w.setScrollTop(Math.min(w.page.maxh,t))}},this.init(),e.nicescroll.push(this)},f=function(e){var t=this;this.nc=e,this.steptime=this.lasttime=this.speedy=this.speedx=this.lasty=this.lastx=0,this.snapy=this.snapx=!1,this.demuly=this.demulx=0,this.lastscrolly=this.lastscrollx=-1,this.timer=this.chky=this.chkx=0,this.time=function(){return+new Date},this.reset=function(e,i){t.stop();var o=t.time();t.steptime=0,t.lasttime=o,t.speedx=0,t.speedy=0,t.lastx=e,t.lasty=i,t.lastscrollx=-1,t.lastscrolly=-1},this.update=function(e,i){var o=t.time();t.steptime=o-t.lasttime,t.lasttime=o;var o=i-t.lasty,n=e-t.lastx,s=t.nc.getScrollTop(),r=t.nc.getScrollLeft(),s=s+o,r=r+n;t.snapx=0>r||r>t.nc.page.maxw,t.snapy=0>s||s>t.nc.page.maxh,t.speedx=n,t.speedy=o,t.lastx=e,t.lasty=i},this.stop=function(){t.nc.unsynched("domomentum2d"),t.timer&&clearTimeout(t.timer),t.timer=0,t.lastscrollx=-1,t.lastscrolly=-1},this.doSnapy=function(e,i){var o=!1;0>i?(i=0,o=!0):i>t.nc.page.maxh&&(i=t.nc.page.maxh,o=!0),0>e?(e=0,o=!0):e>t.nc.page.maxw&&(e=t.nc.page.maxw,o=!0),o&&t.nc.doScrollPos(e,i,t.nc.opt.snapbackspeed)},this.doMomentum=function(e){var i=t.time(),o=e?i+e:t.lasttime;e=t.nc.getScrollLeft();var n=t.nc.getScrollTop(),s=t.nc.page.maxh,r=t.nc.page.maxw;if(t.speedx=r>0?Math.min(60,t.speedx):0,t.speedy=s>0?Math.min(60,t.speedy):0,o=o&&50>=i-o,(0>n||n>s||0>e||e>r)&&(o=!1),e=t.speedx&&o?t.speedx:!1,t.speedy&&o&&t.speedy||e){var a=Math.max(16,t.steptime);a>50&&(e=a/50,t.speedx*=e,t.speedy*=e,a=50),t.demulxy=0,t.lastscrollx=t.nc.getScrollLeft(),t.chkx=t.lastscrollx,t.lastscrolly=t.nc.getScrollTop(),t.chky=t.lastscrolly;var l=t.lastscrollx,d=t.lastscrolly,c=function(){var e=600<t.time()-i?.04:.02;t.speedx&&(l=Math.floor(t.lastscrollx-t.speedx*(1-t.demulxy)),t.lastscrollx=l,0>l||l>r)&&(e=.1),t.speedy&&(d=Math.floor(t.lastscrolly-t.speedy*(1-t.demulxy)),t.lastscrolly=d,0>d||d>s)&&(e=.1),t.demulxy=Math.min(1,t.demulxy+e),t.nc.synched("domomentum2d",function(){t.speedx&&(t.nc.getScrollLeft()!=t.chkx&&t.stop(),t.chkx=l,t.nc.setScrollLeft(l)),t.speedy&&(t.nc.getScrollTop()!=t.chky&&t.stop(),t.chky=d,t.nc.setScrollTop(d)),t.timer||(t.nc.hideCursor(),t.doSnapy(l,d))}),1>t.demulxy?t.timer=setTimeout(c,a):(t.stop(),t.nc.hideCursor(),t.doSnapy(l,d))};c()}else t.doSnapy(t.nc.getScrollLeft(),t.nc.getScrollTop())}},g=e.fn.scrollTop;e.cssHooks.pageYOffset={get:function(t,i){return(i=e.data(t,"__nicescroll")||!1)&&i.ishwscroll?i.getScrollTop():g.call(t)},set:function(t,i){var o=e.data(t,"__nicescroll")||!1;return o&&o.ishwscroll?o.setScrollTop(parseInt(i)):g.call(t,i),this}},e.fn.scrollTop=function(t){if("undefined"==typeof t){var i=this[0]?e.data(this[0],"__nicescroll")||!1:!1;return i&&i.ishwscroll?i.getScrollTop():g.call(this)}return this.each(function(){var i=e.data(this,"__nicescroll")||!1;i&&i.ishwscroll?i.setScrollTop(parseInt(t)):g.call(e(this),t)})};var v=e.fn.scrollLeft;e.cssHooks.pageXOffset={get:function(t,i){return(i=e.data(t,"__nicescroll")||!1)&&i.ishwscroll?i.getScrollLeft():v.call(t)},set:function(t,i){var o=e.data(t,"__nicescroll")||!1;return o&&o.ishwscroll?o.setScrollLeft(parseInt(i)):v.call(t,i),this}},e.fn.scrollLeft=function(t){if("undefined"==typeof t){var i=this[0]?e.data(this[0],"__nicescroll")||!1:!1;return i&&i.ishwscroll?i.getScrollLeft():v.call(this)}return this.each(function(){var i=e.data(this,"__nicescroll")||!1;i&&i.ishwscroll?i.setScrollLeft(parseInt(t)):v.call(e(this),t)})};var y=function(t){var i=this;if(this.length=0,this.name="nicescrollarray",this.each=function(e){for(var t=0;t<i.length;t++)e.call(i[t]);return i},this.push=function(e){i[i.length]=e,i.length++},this.eq=function(e){return i[e]},t)for(a=0;a<t.length;a++){var o=e.data(t[a],"__nicescroll")||!1;o&&(this[this.length]=o,this.length++)}return this};!function(e,t,i){for(var o=0;o<t.length;o++)i(e,t[o])}(y.prototype,"show hide toggle onResize resize remove stop doScrollPos".split(" "),function(e,t){e[t]=function(){var e=arguments;return this.each(function(){this[t].apply(this,e)})}}),e.fn.getNiceScroll=function(t){return"undefined"==typeof t?new y(this):e.data(this[t],"__nicescroll")||!1},e.extend(e.expr[":"],{nicescroll:function(t){return e.data(t,"__nicescroll")?!0:!1}}),e.fn.niceScroll=function(t,i){"undefined"==typeof i&&"object"==typeof t&&!("jquery"in t)&&(i=t,t=!1);var o=new y;"undefined"==typeof i&&(i={}),t&&(i.doc=e(t),i.win=e(this));var n=!("doc"in i);return!n&&!("win"in i)&&(i.win=e(this)),this.each(function(){var t=e(this).data("__nicescroll")||!1;t||(i.doc=n?e(this):i.doc,t=new p(i,e(this)),e(this).data("__nicescroll",t)),o.push(t)}),1==o.length?o[0]:o},window.NiceScroll={getjQuery:function(){return e}},e.nicescroll||(e.nicescroll=new y,e.nicescroll.options=u)}(jQuery),!function(){var e=function(e){"use strict";function t(e){if(e.paused||e.ended||f)return!1;try{d.clearRect(0,0,a,r),d.drawImage(e,0,0,a,r)}catch(i){}setTimeout(t,E.duration,e),M.setIcon(l)}function i(e){var t=/^#?([a-f\d])([a-f\d])([a-f\d])$/i;e=e.replace(t,function(e,t,i,o){return t+t+i+i+o+o});var i=/^#?([a-f\d]{2})([a-f\d]{2})([a-f\d]{2})$/i.exec(e);return i?{r:parseInt(i[1],16),g:parseInt(i[2],16),b:parseInt(i[3],16)}:!1}function o(e,t){var i,o={};for(i in e)o[i]=e[i];for(i in t)o[i]=t[i];return o}e=e?e:{};var n,s,r,a,l,d,c,u,h,m,p,f,g,v={bgColor:"#d00",textColor:"#fff",fontFamily:"sans-serif",fontStyle:"bold",type:"circle",position:"down",animation:"slide",elementId:!1},y=[];p=function(){},u=f=!1;var w=function(){if(n=o(v,e),n.bgColor=i(n.bgColor),n.textColor=i(n.textColor),n.position=n.position.toLowerCase(),n.animation=E.types[""+n.animation]?n.animation:v.animation,"up"===n.position)for(var t=0;t<E.types[""+n.animation].length;t++){var u=E.types[""+n.animation][t];u.y=u.y<.6?u.y-.4:u.y-2*u.y+(1-u.w),E.types[""+n.animation][t]=u}n.type=x[""+n.type]?n.type:v.type;try{s=M.getIcon(),l=document.createElement("canvas"),c=document.createElement("img"),c.setAttribute("src",s.getAttribute("href")),c.onload=function(){r=c.height>0?c.height:32,a=c.width>0?c.width:32,l.height=r,l.width=a,d=l.getContext("2d"),b.ready()},g={},g.ff=/firefox/i.test(navigator.userAgent.toLowerCase()),g.chrome=/chrome/i.test(navigator.userAgent.toLowerCase()),g.opera=/opera/i.test(navigator.userAgent.toLowerCase()),g.ie=/msie/i.test(navigator.userAgent.toLowerCase())||/trident/i.test(navigator.userAgent.toLowerCase()),g.supported=g.chrome||g.ff||g.opera}catch(h){throw"Error initializing favico..."}},b={};b.ready=function(){u=!0,b.reset(),p()},b.reset=function(){y=[],h=!1,d.clearRect(0,0,a,r),d.drawImage(c,0,0,a,r),M.setIcon(l)},b.start=function(){if(u&&!m){var e=function(){h=y[0],m=!1,y.length>0&&(y.shift(),b.start())};y.length>0&&(m=!0,h?E.run(h.options,function(){E.run(y[0].options,function(){e()},!1)},!0):E.run(y[0].options,function(){e()},!1))}};var x={},T=function(e){return e.n=Math.abs(e.n),e.x=a*e.x,e.y=r*e.y,e.w=a*e.w,e.h=r*e.h,e};x.circle=function(e){e=T(e);var t=e.n>9&&e.n<100;t&&(e.x=e.x-.4*e.w,e.w=1.4*e.w),d.clearRect(0,0,a,r),d.drawImage(c,0,0,a,r),d.beginPath(),d.font=n.fontStyle+" "+Math.floor(e.h)+"px "+n.fontFamily,d.textAlign="center",t?(d.moveTo(e.x+e.w/2,e.y),d.lineTo(e.x+e.w-e.h/2,e.y),d.quadraticCurveTo(e.x+e.w,e.y,e.x+e.w,e.y+e.h/2),d.lineTo(e.x+e.w,e.y+e.h-e.h/2),d.quadraticCurveTo(e.x+e.w,e.y+e.h,e.x+e.w-e.h/2,e.y+e.h),d.lineTo(e.x+e.h/2,e.y+e.h),d.quadraticCurveTo(e.x,e.y+e.h,e.x,e.y+e.h-e.h/2),d.lineTo(e.x,e.y+e.h/2),d.quadraticCurveTo(e.x,e.y,e.x+e.h/2,e.y)):d.arc(e.x+e.w/2,e.y+e.h/2,e.h/2,0,2*Math.PI),d.fillStyle="rgba("+n.bgColor.r+","+n.bgColor.g+","+n.bgColor.b+","+e.o+")",d.fill(),d.closePath(),d.beginPath(),d.stroke(),d.fillStyle="rgba("+n.textColor.r+","+n.textColor.g+","+n.textColor.b+","+e.o+")",e.n>99?d.fillText("∞",Math.floor(e.x+e.w/2),Math.floor(e.y+e.h-.15*e.h)):d.fillText(e.n,Math.floor(e.x+e.w/2),Math.floor(e.y+e.h-.15*e.h)),d.closePath()},x.rectangle=function(e){e=T(e);var t=e.n>9&&e.n<100;t&&(e.x=Math.floor(e.x-.4*e.w),e.w=Math.floor(1.4*e.w)),d.clearRect(0,0,a,r),d.drawImage(c,0,0,a,r),d.beginPath(),d.font="bold "+Math.floor(e.h)+"px sans-serif",d.textAlign="center",d.fillStyle="rgba("+n.bgColor.r+","+n.bgColor.g+","+n.bgColor.b+","+e.o+")",d.fillRect(e.x,e.y,e.w,e.h),d.fillStyle="rgba("+n.textColor.r+","+n.textColor.g+","+n.textColor.b+","+e.o+")",e.n>99?d.fillText("∞",Math.floor(e.x+e.w/2),Math.floor(e.y+e.h-.15*e.h)):d.fillText(e.n,Math.floor(e.x+e.w/2),Math.floor(e.y+e.h-.15*e.h)),d.closePath()};var S=function(e,t){p=function(){try{if(e>0){if(E.types[""+t]&&(n.animation=t),y.push({type:"badge",options:{n:e}}),y.length>100)throw"Too many badges requests in queue...";b.start()}else b.reset()}catch(i){throw"Error setting badge..."}},u&&p()},C=function(e){p=function(){try{var t=e.width,i=e.height,o=document.createElement("img"),n=i/r>t/a?t/a:i/r;o.setAttribute("src",e.getAttribute("src")),o.height=i/n,o.width=t/n,d.clearRect(0,0,a,r),d.drawImage(o,0,0,a,r),M.setIcon(l)}catch(s){throw"Error setting image..."}},u&&p()},j=function(e){p=function(){try{if("stop"===e)return f=!0,b.reset(),void(f=!1);e.addEventListener("play",function(){t(this)},!1)}catch(i){throw"Error setting video..."}},u&&p()},k=function(e){if(window.URL&&window.URL.createObjectURL||(window.URL=window.URL||{},window.URL.createObjectURL=function(e){return e}),g.supported){var i=!1;navigator.getUserMedia=navigator.getUserMedia||navigator.oGetUserMedia||navigator.msGetUserMedia||navigator.mozGetUserMedia||navigator.webkitGetUserMedia,p=function(){try{if("stop"===e)return f=!0,b.reset(),void(f=!1);i=document.createElement("video"),i.width=a,i.height=r,navigator.getUserMedia({video:!0,audio:!1},function(e){i.src=URL.createObjectURL(e),i.play(),t(i)},function(){})}catch(o){throw"Error setting webcam..."}},u&&p()}},M={};M.getIcon=function(){var e=!1,t=function(){for(var e=document.getElementsByTagName("head")[0].getElementsByTagName("link"),t=e.length,i=t-1;i>=0;i--)if(/icon/i.test(e[i].getAttribute("rel")))return e[i];return!1};return n.elementId?(e=document.getElementById(n.elementId),e.setAttribute("href",e.getAttribute("src"))):(e=t(),e===!1&&(e=document.createElement("link"),e.setAttribute("rel","icon"),document.getElementsByTagName("head")[0].appendChild(e))),e.setAttribute("type","image/png"),e},M.setIcon=function(e){var t=e.toDataURL("image/png");if(n.elementId)document.getElementById(n.elementId).setAttribute("src",t);else if(g.ff||g.opera){var i=s;s=document.createElement("link"),g.opera&&s.setAttribute("rel","icon"),s.setAttribute("rel","icon"),s.setAttribute("type","image/png"),document.getElementsByTagName("head")[0].appendChild(s),s.setAttribute("href",t),i.parentNode&&i.parentNode.removeChild(i)}else s.setAttribute("href",t)};var E={};return E.duration=40,E.types={},E.types.fade=[{x:.4,y:.4,w:.6,h:.6,o:0},{x:.4,y:.4,w:.6,h:.6,o:.1},{x:.4,y:.4,w:.6,h:.6,o:.2},{x:.4,y:.4,w:.6,h:.6,o:.3},{x:.4,y:.4,w:.6,h:.6,o:.4},{x:.4,y:.4,w:.6,h:.6,o:.5},{x:.4,y:.4,w:.6,h:.6,o:.6},{x:.4,y:.4,w:.6,h:.6,o:.7},{x:.4,y:.4,w:.6,h:.6,o:.8},{x:.4,y:.4,w:.6,h:.6,o:.9},{x:.4,y:.4,w:.6,h:.6,o:1}],E.types.none=[{x:.4,y:.4,w:.6,h:.6,o:1}],E.types.pop=[{x:1,y:1,w:0,h:0,o:1},{x:.9,y:.9,w:.1,h:.1,o:1},{x:.8,y:.8,w:.2,h:.2,o:1},{x:.7,y:.7,w:.3,h:.3,o:1},{x:.6,y:.6,w:.4,h:.4,o:1},{x:.5,y:.5,w:.5,h:.5,o:1},{x:.4,y:.4,w:.6,h:.6,o:1}],E.types.popFade=[{x:.75,y:.75,w:0,h:0,o:0},{x:.65,y:.65,w:.1,h:.1,o:.2},{x:.6,y:.6,w:.2,h:.2,o:.4},{x:.55,y:.55,w:.3,h:.3,o:.6},{x:.5,y:.5,w:.4,h:.4,o:.8},{x:.45,y:.45,w:.5,h:.5,o:.9},{x:.4,y:.4,w:.6,h:.6,o:1}],E.types.slide=[{x:.4,y:1,w:.6,h:.6,o:1},{x:.4,y:.9,w:.6,h:.6,o:1},{x:.4,y:.9,w:.6,h:.6,o:1},{x:.4,y:.8,w:.6,h:.6,o:1},{x:.4,y:.7,w:.6,h:.6,o:1},{x:.4,y:.6,w:.6,h:.6,o:1},{x:.4,y:.5,w:.6,h:.6,o:1},{x:.4,y:.4,w:.6,h:.6,o:1}],E.run=function(e,t,i,s){var r=E.types[n.animation];return s=i===!0?"undefined"!=typeof s?s:r.length-1:"undefined"!=typeof s?s:0,t=t?t:function(){},s<r.length&&s>=0?(x[n.type](o(e,r[s])),setTimeout(function(){i?s-=1:s+=1,E.run(e,t,i,s)},E.duration),void M.setIcon(l)):void t()},w(),{badge:S,video:j,image:C,webcam:k,reset:b.reset}};"undefined"!=typeof define&&define.amd?define([],function(){return e}):"undefined"!=typeof module&&module.exports?module.exports=e:this.Favico=e}(),!function(e,t){"use strict";var i=t.Modernizr,o={},n={_init:function(t){return n.$el=e(this),n.options=e.extend(!0,{custom:!1,modalIdAttribute:"modal-id",hiddeBtnID:"hideemodal"},t),n._config(),n.$el.click(function(){}),this},_config:function(){var t=n.$el.data(n.options.modalIdAttribute);return o.modal=e("#"+t),this},showModal:function(){return n.baseHtml(),n.startLoading(),o.overlay.addClass("shown"),o.html.addClass("shown"),this},hideModal:function(){return o.overlay.removeClass("shown"),o.html.removeClass("shown"),setTimeout(function(){n.destroy()},300),this},setHideEvent:function(){o.overlay.click(function(){n.hideModal()}),o.closeBtnHtml.click(function(){n.hideModal()});var t=e("#"+n.options.hiddeBtnID);t.click(function(){n.hideModal()})},setHTML:function(e){return o.html.html(e),this},setTitle:function(e){return o.modalTitle.text(e),this},addText:function(e){return o.modalText.append(e),this},addError:function(e){return o.modalText.append('<p class="error-msg">'+e+"</p>"),o.modalTitle.text("ERROR"),this},addImage:function(e){return o.html.addClass("with-image"),o.modalImage=jQuery('<img src="'+e+'" />').appendTo(o.html),this},addBtn:function(t){return t=e.extend(!0,{href:"",cssClass:"",onclick:"",id:"",title:"",hideOnClick:!1},t),o.modalBtn=jQuery('<a href="'+t.href+'" id="'+t.id+'" class="'+t.cssClass+'" onclick="'+t.onclick+'"><span>'+t.title+"</span></a>").appendTo(o.modalText),t.hideOnClick&&o.modalBtn.click(function(){n.hideModal()}),this},startLoading:function(){return o.html.addClass("eloading"),this},endLoading:function(){return o.html.removeClass("eloading"),this},baseHtml:function(){return o.overlay=jQuery('<div class="emodal-overlay"></div>'),o.html=jQuery('<div class="emodal" id="base-modal"><div class="emodal-border"></div></div>'),o.modalText=jQuery('<div class="emodal-text"></div>').prependTo(o.html),o.modalTitle=jQuery('<h5 class="emodal-title"></h5>').prependTo(o.modalText),o.closeBtnHtml=jQuery('<div class="close-modal"><i class="icon-remove"></i></div>').prependTo(o.html),i.csstransforms&&(o.overlay.addClass("with-transforms"),o.html.addClass("with-transforms")),i.csstransitions&&(o.overlay.addClass("with-transitions"),o.html.addClass("with-transitions")),e("body").prepend(o.overlay),e("body").prepend(o.html),n.setHideEvent(),this
},destroy:function(){return o.overlay.remove(),o.html.remove(),this}};e.fn.eModal=function(t){return n[t]?n[t].apply(this,Array.prototype.slice.call(arguments,1)):"object"!=typeof t&&t?void e.error("invalid method call!"):n._init.apply(this,arguments)}}(jQuery,window),function(e){function t(t){var i=t||window.event,o=[].slice.call(arguments,1),n=0,s=0,r=0;return t=e.event.fix(i),t.type="mousewheel",i.wheelDelta&&(n=i.wheelDelta/120),i.detail&&(n=-i.detail/3),r=n,void 0!==i.axis&&i.axis===i.HORIZONTAL_AXIS&&(r=0,s=-1*n),void 0!==i.wheelDeltaY&&(r=i.wheelDeltaY/120),void 0!==i.wheelDeltaX&&(s=-1*i.wheelDeltaX/120),o.unshift(t,n,s,r),(e.event.dispatch||e.event.handle).apply(this,o)}var i=["DOMMouseScroll","mousewheel"];if(e.event.fixHooks)for(var o=i.length;o;)e.event.fixHooks[i[--o]]=e.event.mouseHooks;e.event.special.mousewheel={setup:function(){if(this.addEventListener)for(var e=i.length;e;)this.addEventListener(i[--e],t,!1);else this.onmousewheel=t},teardown:function(){if(this.removeEventListener)for(var e=i.length;e;)this.removeEventListener(i[--e],t,!1);else this.onmousewheel=null}},e.fn.extend({mousewheel:function(e){return e?this.bind("mousewheel",e):this.trigger("mousewheel")},unmousewheel:function(e){return this.unbind("mousewheel",e)}})}(jQuery),function(e,t,i){function o(t,i){this.bodyOverflowX,this.callbacks={hide:[],show:[]},this.checkInterval=null,this.Content,this.$el=e(t),this.$elProxy,this.elProxyPosition,this.enabled=!0,this.options=e.extend({},l,i),this.mouseIsOverProxy=!1,this.namespace="tooltipster-"+Math.round(1e5*Math.random()),this.Status="hidden",this.timerHide=null,this.timerShow=null,this.$tooltip,this.options.iconTheme=this.options.iconTheme.replace(".",""),this.options.theme=this.options.theme.replace(".",""),this._init()}function n(t,i){var o=!0;return e.each(t,function(e){return"undefined"==typeof i[e]||t[e]!==i[e]?(o=!1,!1):void 0}),o}function s(){return!c&&d}function r(){var e=i.body||i.documentElement,t=e.style,o="transition";if("string"==typeof t[o])return!0;v=["Moz","Webkit","Khtml","O","ms"],o=o.charAt(0).toUpperCase()+o.substr(1);for(var n=0;n<v.length;n++)if("string"==typeof t[v[n]+o])return!0;return!1}var a="tooltipster",l={animation:"fade",arrow:!0,arrowColor:"",autoClose:!0,content:null,contentAsHTML:!1,contentCloning:!0,delay:200,minWidth:0,maxWidth:null,functionInit:function(){},functionBefore:function(e,t){t()},functionReady:function(){},functionAfter:function(){},icon:"(?)",iconCloning:!0,iconDesktop:!1,iconTouch:!1,iconTheme:"tooltipster-icon",interactive:!1,interactiveTolerance:350,multiple:!1,offsetX:0,offsetY:0,onlyOne:!1,position:"top",positionTracker:!1,speed:350,timer:0,theme:"tooltipster-default",touchDevices:!0,trigger:"hover",updateAnimation:!0};o.prototype={_init:function(){var t=this;if(i.querySelector){if(null!==t.options.content)t._content_set(t.options.content);else{var o=t.$el.attr("title");"undefined"==typeof o&&(o=null),t._content_set(o)}var n=t.options.functionInit.call(t.$el,t.$el,t.Content);"undefined"!=typeof n&&t._content_set(n),t.$el.removeAttr("title").addClass("tooltipstered"),!d&&t.options.iconDesktop||d&&t.options.iconTouch?("string"==typeof t.options.icon?(t.$elProxy=e('<span class="'+t.options.iconTheme+'"></span>'),t.$elProxy.text(t.options.icon)):t.$elProxy=t.options.iconCloning?t.options.icon.clone(!0):t.options.icon,t.$elProxy.insertAfter(t.$el)):t.$elProxy=t.$el,"hover"==t.options.trigger?(t.$elProxy.on("mouseenter."+t.namespace,function(){(!s()||t.options.touchDevices)&&(t.mouseIsOverProxy=!0,t._show())}).on("mouseleave."+t.namespace,function(){(!s()||t.options.touchDevices)&&(t.mouseIsOverProxy=!1)}),d&&t.options.touchDevices&&t.$elProxy.on("touchstart."+t.namespace,function(){t._showNow()})):"click"==t.options.trigger&&t.$elProxy.on("click."+t.namespace,function(){(!s()||t.options.touchDevices)&&t._show()})}},_show:function(){var e=this;"shown"!=e.Status&&"appearing"!=e.Status&&(e.options.delay?e.timerShow=setTimeout(function(){("click"==e.options.trigger||"hover"==e.options.trigger&&e.mouseIsOverProxy)&&e._showNow()},e.options.delay):e._showNow())},_showNow:function(i){var o=this;o.options.functionBefore.call(o.$el,o.$el,function(){if(o.enabled&&null!==o.Content){i&&o.callbacks.show.push(i),o.callbacks.hide=[],clearTimeout(o.timerShow),o.timerShow=null,clearTimeout(o.timerHide),o.timerHide=null,o.options.onlyOne&&e(".tooltipstered").not(o.$el).each(function(t,i){var o=e(i),n=o.data("tooltipster-ns");e.each(n,function(e,t){var i=o.data(t),n=i.status(),s=i.option("autoClose");"hidden"!==n&&"disappearing"!==n&&s&&i.hide()})});var n=function(){o.Status="shown",e.each(o.callbacks.show,function(e,t){t.call(o.$el)}),o.callbacks.show=[]};if("hidden"!==o.Status){var s=0;"disappearing"===o.Status?(o.Status="appearing",r()?(o.$tooltip.clearQueue().removeClass("tooltipster-dying").addClass("tooltipster-"+o.options.animation+"-show"),o.options.speed>0&&o.$tooltip.delay(o.options.speed),o.$tooltip.queue(n)):o.$tooltip.stop().fadeIn(n)):"shown"===o.Status&&n()}else{o.Status="appearing";var s=o.options.speed;o.bodyOverflowX=e("body").css("overflow-x"),e("body").css("overflow-x","hidden");var a="tooltipster-"+o.options.animation,l="-webkit-transition-duration: "+o.options.speed+"ms; -webkit-animation-duration: "+o.options.speed+"ms; -moz-transition-duration: "+o.options.speed+"ms; -moz-animation-duration: "+o.options.speed+"ms; -o-transition-duration: "+o.options.speed+"ms; -o-animation-duration: "+o.options.speed+"ms; -ms-transition-duration: "+o.options.speed+"ms; -ms-animation-duration: "+o.options.speed+"ms; transition-duration: "+o.options.speed+"ms; animation-duration: "+o.options.speed+"ms;",c=o.options.minWidth?"min-width:"+Math.round(o.options.minWidth)+"px;":"",u=o.options.maxWidth?"max-width:"+Math.round(o.options.maxWidth)+"px;":"",h=o.options.interactive?"pointer-events: auto;":"";if(o.$tooltip=e('<div class="tooltipster-base '+o.options.theme+'" style="'+c+" "+u+" "+h+" "+l+'"><div class="tooltipster-content"></div></div>'),r()&&o.$tooltip.addClass(a),o._content_insert(),o.$tooltip.appendTo("body"),o.reposition(),o.options.functionReady.call(o.$el,o.$el,o.$tooltip),r()?(o.$tooltip.addClass(a+"-show"),o.options.speed>0&&o.$tooltip.delay(o.options.speed),o.$tooltip.queue(n)):o.$tooltip.css("display","none").fadeIn(o.options.speed,n),o._interval_set(),e(t).on("scroll."+o.namespace+" resize."+o.namespace,function(){o.reposition()}),o.options.autoClose)if(e("body").off("."+o.namespace),"hover"==o.options.trigger)if(d&&setTimeout(function(){e("body").on("touchstart."+o.namespace,function(){o.hide()})},0),o.options.interactive){d&&o.$tooltip.on("touchstart."+o.namespace,function(e){e.stopPropagation()});var m=null;o.$elProxy.add(o.$tooltip).on("mouseleave."+o.namespace+"-autoClose",function(){clearTimeout(m),m=setTimeout(function(){o.hide()},o.options.interactiveTolerance)}).on("mouseenter."+o.namespace+"-autoClose",function(){clearTimeout(m)})}else o.$elProxy.on("mouseleave."+o.namespace+"-autoClose",function(){o.hide()});else"click"==o.options.trigger&&(setTimeout(function(){e("body").on("click."+o.namespace+" touchstart."+o.namespace,function(){o.hide()})},0),o.options.interactive&&o.$tooltip.on("click."+o.namespace+" touchstart."+o.namespace,function(e){e.stopPropagation()}))}o.options.timer>0&&(o.timerHide=setTimeout(function(){o.timerHide=null,o.hide()},o.options.timer+s))}})},_interval_set:function(){var t=this;t.checkInterval=setInterval(function(){if(0===e("body").find(t.$el).length||0===e("body").find(t.$elProxy).length||"hidden"==t.Status||0===e("body").find(t.$tooltip).length)("shown"==t.Status||"appearing"==t.Status)&&t.hide(),t._interval_cancel();else if(t.options.positionTracker){var i=t._repositionInfo(t.$elProxy),o=!1;n(i.dimension,t.elProxyPosition.dimension)&&("fixed"===t.$elProxy.css("position")?n(i.position,t.elProxyPosition.position)&&(o=!0):n(i.offset,t.elProxyPosition.offset)&&(o=!0)),o||t.reposition()}},200)},_interval_cancel:function(){clearInterval(this.checkInterval),this.checkInterval=null},_content_set:function(e){"object"==typeof e&&null!==e&&this.options.contentCloning&&(e=e.clone(!0)),this.Content=e},_content_insert:function(){var e=this,t=this.$tooltip.find(".tooltipster-content");"string"!=typeof e.Content||e.options.contentAsHTML?t.empty().append(e.Content):t.text(e.Content)},_update:function(e){var t=this;t._content_set(e),null!==t.Content?"hidden"!==t.Status&&(t._content_insert(),t.reposition(),t.options.updateAnimation&&(r()?(t.$tooltip.css({width:"","-webkit-transition":"all "+t.options.speed+"ms, width 0ms, height 0ms, left 0ms, top 0ms","-moz-transition":"all "+t.options.speed+"ms, width 0ms, height 0ms, left 0ms, top 0ms","-o-transition":"all "+t.options.speed+"ms, width 0ms, height 0ms, left 0ms, top 0ms","-ms-transition":"all "+t.options.speed+"ms, width 0ms, height 0ms, left 0ms, top 0ms",transition:"all "+t.options.speed+"ms, width 0ms, height 0ms, left 0ms, top 0ms"}).addClass("tooltipster-content-changing"),setTimeout(function(){"hidden"!=t.Status&&(t.$tooltip.removeClass("tooltipster-content-changing"),setTimeout(function(){"hidden"!==t.Status&&t.$tooltip.css({"-webkit-transition":t.options.speed+"ms","-moz-transition":t.options.speed+"ms","-o-transition":t.options.speed+"ms","-ms-transition":t.options.speed+"ms",transition:t.options.speed+"ms"})},t.options.speed))},t.options.speed)):t.$tooltip.fadeTo(t.options.speed,.5,function(){"hidden"!=t.Status&&t.$tooltip.fadeTo(t.options.speed,1)}))):t.hide()},_repositionInfo:function(e){return{dimension:{height:e.outerHeight(!1),width:e.outerWidth(!1)},offset:e.offset(),position:{left:parseInt(e.css("left")),top:parseInt(e.css("top"))}}},hide:function(i){var o=this;i&&o.callbacks.hide.push(i),o.callbacks.show=[],clearTimeout(o.timerShow),o.timerShow=null,clearTimeout(o.timerHide),o.timerHide=null;var n=function(){e.each(o.callbacks.hide,function(e,t){t.call(o.$el)}),o.callbacks.hide=[]};if("shown"==o.Status||"appearing"==o.Status){o.Status="disappearing";var s=function(){o.Status="hidden","object"==typeof o.Content&&null!==o.Content&&o.Content.detach(),o.$tooltip.remove(),o.$tooltip=null,e(t).off("."+o.namespace),e("body").off("."+o.namespace).css("overflow-x",o.bodyOverflowX),e("body").off("."+o.namespace),o.$elProxy.off("."+o.namespace+"-autoClose"),o.options.functionAfter.call(o.$el,o.$el),n()};r()?(o.$tooltip.clearQueue().removeClass("tooltipster-"+o.options.animation+"-show").addClass("tooltipster-dying"),o.options.speed>0&&o.$tooltip.delay(o.options.speed),o.$tooltip.queue(s)):o.$tooltip.stop().fadeOut(o.options.speed,s)}else"hidden"==o.Status&&n();return o},show:function(e){return this._showNow(e),this},update:function(e){return this.content(e)},content:function(e){return"undefined"==typeof e?this.Content:(this._update(e),this)},reposition:function(){function i(){var i=e(t).scrollLeft();0>E-i&&(s=E-i,E=i),E+l-i>r&&(s=E-(r+i-l),E=r+i-l)}function o(i,o){a.offset.top-e(t).scrollTop()-d-F-12<0&&o.indexOf("top")>-1&&(I=i),a.offset.top+a.dimension.height+d+12+F>e(t).scrollTop()+e(t).height()&&o.indexOf("bottom")>-1&&(I=i,z=a.offset.top-d-F-12)}var n=this;if(0!==e("body").find(n.$tooltip).length){n.$tooltip.css("width",""),n.elProxyPosition=n._repositionInfo(n.$elProxy);var s=null,r=e(t).width(),a=n.elProxyPosition,l=n.$tooltip.outerWidth(!1),d=(n.$tooltip.innerWidth()+1,n.$tooltip.outerHeight(!1));if(n.$elProxy.is("area")){var c=n.$elProxy.attr("shape"),u=n.$elProxy.parent().attr("name"),h=e('img[usemap="#'+u+'"]'),m=h.offset().left,p=h.offset().top,f=void 0!==n.$elProxy.attr("coords")?n.$elProxy.attr("coords").split(","):void 0;if("circle"==c){var g=parseInt(f[0]),v=parseInt(f[1]),y=parseInt(f[2]);a.dimension.height=2*y,a.dimension.width=2*y,a.offset.top=p+v-y,a.offset.left=m+g-y}else if("rect"==c){var g=parseInt(f[0]),v=parseInt(f[1]),w=parseInt(f[2]),b=parseInt(f[3]);a.dimension.height=b-v,a.dimension.width=w-g,a.offset.top=p+v,a.offset.left=m+g}else if("poly"==c){for(var x=0,T=0,S=0,C=0,j="even",k=0;k<f.length;k++){var M=parseInt(f[k]);"even"==j?(M>S&&(S=M,0===k&&(x=S)),x>M&&(x=M),j="odd"):(M>C&&(C=M,1==k&&(T=C)),T>M&&(T=M),j="even")}a.dimension.height=C-T,a.dimension.width=S-x,a.offset.top=p+T,a.offset.left=m+x}else a.dimension.height=h.outerHeight(!1),a.dimension.width=h.outerWidth(!1),a.offset.top=p,a.offset.left=m}var E=0,P=0,z=0,F=parseInt(n.options.offsetY),A=parseInt(n.options.offsetX),I=n.options.position;if("top"==I){var L=a.offset.left+l-(a.offset.left+a.dimension.width);E=a.offset.left+A-L/2,z=a.offset.top-d-F-12,i(),o("bottom","top")}if("top-left"==I&&(E=a.offset.left+A,z=a.offset.top-d-F-12,i(),o("bottom-left","top-left")),"top-right"==I&&(E=a.offset.left+a.dimension.width+A-l,z=a.offset.top-d-F-12,i(),o("bottom-right","top-right")),"bottom"==I){var L=a.offset.left+l-(a.offset.left+a.dimension.width);E=a.offset.left-L/2+A,z=a.offset.top+a.dimension.height+F+12,i(),o("top","bottom")}if("bottom-left"==I&&(E=a.offset.left+A,z=a.offset.top+a.dimension.height+F+12,i(),o("top-left","bottom-left")),"bottom-right"==I&&(E=a.offset.left+a.dimension.width+A-l,z=a.offset.top+a.dimension.height+F+12,i(),o("top-right","bottom-right")),"left"==I){E=a.offset.left-A-l-12,P=a.offset.left+A+a.dimension.width+12;var _=a.offset.top+d-(a.offset.top+a.dimension.height);if(z=a.offset.top-_/2-F,0>E&&P+l>r){var B=2*parseFloat(n.$tooltip.css("border-width")),N=l+E-B;n.$tooltip.css("width",N+"px"),d=n.$tooltip.outerHeight(!1),E=a.offset.left-A-N-12-B,_=a.offset.top+d-(a.offset.top+a.dimension.height),z=a.offset.top-_/2-F}else 0>E&&(E=a.offset.left+A+a.dimension.width+12,s="left")}if("right"==I){E=a.offset.left+A+a.dimension.width+12,P=a.offset.left-A-l-12;var _=a.offset.top+d-(a.offset.top+a.dimension.height);if(z=a.offset.top-_/2-F,E+l>r&&0>P){var B=2*parseFloat(n.$tooltip.css("border-width")),N=r-E-B;n.$tooltip.css("width",N+"px"),d=n.$tooltip.outerHeight(!1),_=a.offset.top+d-(a.offset.top+a.dimension.height),z=a.offset.top-_/2-F}else E+l>r&&(E=a.offset.left-A-l-12,s="right")}if(n.options.arrow){var H="tooltipster-arrow-"+I;if(n.options.arrowColor.length<1)var $=n.$tooltip.css("background-color");else var $=n.options.arrowColor;if(s?"left"==s?(H="tooltipster-arrow-right",s=""):"right"==s?(H="tooltipster-arrow-left",s=""):s="left:"+Math.round(s)+"px;":s="","top"==I||"top-left"==I||"top-right"==I)var O=parseFloat(n.$tooltip.css("border-bottom-width")),R=n.$tooltip.css("border-bottom-color");else if("bottom"==I||"bottom-left"==I||"bottom-right"==I)var O=parseFloat(n.$tooltip.css("border-top-width")),R=n.$tooltip.css("border-top-color");else if("left"==I)var O=parseFloat(n.$tooltip.css("border-right-width")),R=n.$tooltip.css("border-right-color");else if("right"==I)var O=parseFloat(n.$tooltip.css("border-left-width")),R=n.$tooltip.css("border-left-color");else var O=parseFloat(n.$tooltip.css("border-bottom-width")),R=n.$tooltip.css("border-bottom-color");O>1&&O++;var D="";if(0!==O){var W="",V="border-color: "+R+";";-1!==H.indexOf("bottom")?W="margin-top: -"+Math.round(O)+"px;":-1!==H.indexOf("top")?W="margin-bottom: -"+Math.round(O)+"px;":-1!==H.indexOf("left")?W="margin-right: -"+Math.round(O)+"px;":-1!==H.indexOf("right")&&(W="margin-left: -"+Math.round(O)+"px;"),D='<span class="tooltipster-arrow-border" style="'+W+" "+V+';"></span>'}n.$tooltip.find(".tooltipster-arrow").remove();var U='<div class="'+H+' tooltipster-arrow" style="'+s+'">'+D+'<span style="border-color:'+$+';"></span></div>';n.$tooltip.append(U)}n.$tooltip.css({top:Math.round(z)+"px",left:Math.round(E)+"px"})}return n},enable:function(){return this.enabled=!0,this},disable:function(){return this.hide(),this.enabled=!1,this},destroy:function(){var t=this;t.hide(),t.$el[0]!==t.$elProxy[0]&&t.$elProxy.remove(),t.$el.removeData(t.namespace).off("."+t.namespace);var i=t.$el.data("tooltipster-ns");if(1===i.length){var o="string"==typeof t.Content?t.Content:e("<div></div>").append(t.Content).html();t.$el.removeClass("tooltipstered").attr("title",o).removeData(t.namespace).removeData("tooltipster-ns").off("."+t.namespace)}else i=e.grep(i,function(e){return e!==t.namespace}),t.$el.data("tooltipster-ns",i);return t},elementIcon:function(){return this.$el[0]!==this.$elProxy[0]?this.$elProxy[0]:void 0},elementTooltip:function(){return this.$tooltip?this.$tooltip[0]:void 0},option:function(e,t){return"undefined"==typeof t?this.options[e]:(this.options[e]=t,this)},status:function(){return this.Status}},e.fn[a]=function(){var t=arguments;if(0===this.length){if("string"==typeof t[0]){var i=!0;switch(t[0]){case"setDefaults":e.extend(l,t[1]);break;default:i=!1}return i?!0:this}return this}if("string"==typeof t[0]){var n="#*$~&";return this.each(function(){var i=e(this).data("tooltipster-ns"),o=i?e(this).data(i[0]):null;if(!o)throw new Error("You called Tooltipster's \""+t[0]+'" method on an uninitialized element');if("function"!=typeof o[t[0]])throw new Error('Unknown method .tooltipster("'+t[0]+'")');var s=o[t[0]](t[1],t[2]);return s!==o?(n=s,!1):void 0}),"#*$~&"!==n?n:this}var s=[],r=t[0]&&"undefined"!=typeof t[0].multiple,a=r&&t[0].multiple||!r&&l.multiple;return this.each(function(){var i=!1,n=e(this).data("tooltipster-ns"),r=null;n?a?i=!0:console.log('Tooltipster: one or more tooltips are already attached to this element: ignoring. Use the "multiple" option to attach more tooltips.'):i=!0,i&&(r=new o(this,t[0]),n||(n=[]),n.push(r.namespace),e(this).data("tooltipster-ns",n),e(this).data(r.namespace,r)),s.push(r)}),a?s:this};var d=!!("ontouchstart"in t),c=!1;e("body").one("mousemove",function(){c=!0})}(jQuery,window,document),!function(e,t){"function"==typeof define&&define.amd?define(t):e.BackgroundCheck=t(e)}(this,function(){"use strict";function e(e){if(void 0===e||void 0===e.targets)throw"Missing attributes";I.debug=o(e.debug,!1),I.debugOverlay=o(e.debugOverlay,!1),I.targets=r(e.targets),I.images=r(e.images||"img",!0),I.changeParent=o(e.changeParent,!1),I.threshold=o(e.threshold,50),I.minComplexity=o(e.minComplexity,30),I.minOverlap=o(e.minOverlap,50),I.windowEvents=o(e.windowEvents,!0),I.maxDuration=o(e.maxDuration,500),I.mask=o(e.mask,{r:0,g:255,b:0}),I.classes=o(e.classes,{dark:"background--dark",light:"background--light",complex:"background--complex"}),void 0===M&&(a(),M&&(E.style.position="fixed",E.style.top="0px",E.style.left="0px",E.style.width="100%",E.style.height="100%",window.addEventListener(A,S.bind(null,function(){c(),T()})),window.addEventListener("scroll",S.bind(null,T)),c(),T()))}function t(){M=null,E=null,P=null,I={},z&&clearTimeout(z)}function i(e){j("debug")&&console.log(e)}function o(e,t){return n(e,typeof t),void 0===e?t:e}function n(e,t){if(void 0!==e&&typeof e!==t)throw"Incorrect attribute type"}function s(e){for(var t,o,n=[],s=0;s<e.length;s++)if(t=e[s],n.push(t),"IMG"!==t.tagName){if(o=window.getComputedStyle(t).backgroundImage,o.split(/,url|, url/).length>1)throw"Multiple backgrounds are not supported";if(!o||"none"===o)throw"Element is not an <img> but does not have a background-image";n[s]={img:new Image,el:n[s]},o=o.slice(4,-1),o=o.replace(/"/g,""),n[s].img.src=o,i("CSS Image - "+o)}return n}function r(e,t){var i=e;if("string"==typeof e?i=document.querySelectorAll(e):e&&1===e.nodeType&&(i=[e]),!i||0===i.length||void 0===i.length)throw"Elements not found";return t&&(i=s(i)),i=Array.prototype.slice.call(i)}function a(){E=document.createElement("canvas"),E&&E.getContext?(P=E.getContext("2d"),M=!0):M=!1,l()}function l(){j("debugOverlay")?(E.style.opacity=.5,E.style.pointerEvents="none",document.body.appendChild(E)):E.parentNode&&E.parentNode.removeChild(E)}function d(e){var o=(new Date).getTime()-e;i("Duration: "+o+"ms"),o>j("maxDuration")&&(console.log("BackgroundCheck - Killed"),g(),t())}function c(){F={left:0,top:0,right:document.body.clientWidth,bottom:window.innerHeight},E.width=document.body.clientWidth,E.height=window.innerHeight}function u(e,t,i){var o,n;return-1!==e.indexOf("px")?o=parseFloat(e):-1!==e.indexOf("%")?(o=parseFloat(e),n=o/100,o=n*t,i&&(o-=i*n)):o=t,o}function h(e){var t=window.getComputedStyle(e.el);e.el.style.backgroundRepeat="no-repeat",e.el.style.backgroundOrigin="padding-box";var i=t.backgroundSize.split(" "),o=i[0],n=void 0===i[1]?"auto":i[1],s=e.el.clientWidth/e.el.clientHeight,r=e.img.naturalWidth/e.img.naturalHeight;"cover"===o?s>=r?(o="100%",n="auto"):(o="auto",i[0]="auto",n="100%"):"contain"===o&&(1/r>1/s?(o="auto",i[0]="auto",n="100%"):(o="100%",n="auto")),o="auto"===o?e.img.naturalWidth:u(o,e.el.clientWidth),n="auto"===n?o/e.img.naturalWidth*e.img.naturalHeight:u(n,e.el.clientHeight),"auto"===i[0]&&"auto"!==i[1]&&(o=n/e.img.naturalHeight*e.img.naturalWidth);var a=t.backgroundPosition;"top"===a?a="50% 0%":"left"===a?a="0% 50%":"right"===a?a="100% 50%":"bottom"===a?a="50% 100%":"center"===a&&(a="50% 50%"),a=a.split(" ");var l,d;return 4===a.length?(l=a[1],d=a[3]):(l=a[0],d=a[1]),d=d||"50%",l=u(l,e.el.clientWidth,o),d=u(d,e.el.clientHeight,n),4===a.length&&("right"===a[0]&&(l=e.el.clientWidth-e.img.naturalWidth-l),"bottom"===a[2]&&(d=e.el.clientHeight-e.img.naturalHeight-d)),l+=e.el.getBoundingClientRect().left,d+=e.el.getBoundingClientRect().top,{left:Math.floor(l),right:Math.floor(l+o),top:Math.floor(d),bottom:Math.floor(d+n),width:Math.floor(o),height:Math.floor(n)}}function m(e){var t,i,o;if(e.nodeType){var n=e.getBoundingClientRect();t={left:n.left,right:n.right,top:n.top,bottom:n.bottom,width:n.width,height:n.height},o=e.parentNode,i=e}else t=h(e),o=e.el,i=e.img;o=o.getBoundingClientRect(),t.imageTop=0,t.imageLeft=0,t.imageWidth=i.naturalWidth,t.imageHeight=i.naturalHeight;var s,r=t.imageHeight/t.height;return t.top<o.top&&(s=o.top-t.top,t.imageTop=r*s,t.imageHeight-=r*s,t.top+=s,t.height-=s),t.left<o.left&&(s=o.left-t.left,t.imageLeft+=r*s,t.imageWidth-=r*s,t.width-=s,t.left+=s),t.bottom>o.bottom&&(s=t.bottom-o.bottom,t.imageHeight-=r*s,t.height-=s),t.right>o.right&&(s=t.right-o.right,t.imageWidth-=r*s,t.width-=s),t.imageTop=Math.floor(t.imageTop),t.imageLeft=Math.floor(t.imageLeft),t.imageHeight=Math.floor(t.imageHeight),t.imageWidth=Math.floor(t.imageWidth),t}function p(e){var t=m(e);e=e.nodeType?e:e.img,t.imageWidth>0&&t.imageHeight>0&&t.width>0&&t.height>0?P.drawImage(e,t.imageLeft,t.imageTop,t.imageWidth,t.imageHeight,t.left,t.top,t.width,t.height):i("Skipping image - "+e.src+" - area too small")}function f(e,t,i){var o=e.className;switch(i){case"add":o+=" "+t;break;case"remove":var n=new RegExp("(?:^|\\s)"+t+"(?!\\S)","g");o=o.replace(n,"")}e.className=o.trim()}function g(e){for(var t,i=e?[e]:j("targets"),o=0;o<i.length;o++)t=i[o],t=j("changeParent")?t.parentNode:t,f(t,j("classes").light,"remove"),f(t,j("classes").dark,"remove"),f(t,j("classes").complex,"remove")}function v(e){var t,o,n,s,r=e.getBoundingClientRect(),a=0,l=0,d=0,c=0,u=j("mask");if(r.width>0&&r.height>0){g(e),e=j("changeParent")?e.parentNode:e,o=P.getImageData(r.left,r.top,r.width,r.height).data;for(var h=0;h<o.length;h+=4)o[h]===u.r&&o[h+1]===u.g&&o[h+2]===u.b?c++:(a++,t=.2126*o[h]+.7152*o[h+1]+.0722*o[h+2],n=t-d,l+=n*n,d+=n/a);c<=o.length/4*(1-j("minOverlap")/100)&&(s=Math.sqrt(l/a)/255,d/=255,i("Target: "+e.className+" lum: "+d+" var: "+s),f(e,d<=j("threshold")/100?j("classes").dark:j("classes").light,"add"),s>j("minComplexity")/100&&f(e,j("classes").complex,"add"))}}function y(e,t){return e=(e.nodeType?e:e.el).getBoundingClientRect(),t=t===F?t:(t.nodeType?t:t.el).getBoundingClientRect(),!(e.right<t.left||e.left>t.right||e.top>t.bottom||e.bottom<t.top)}function w(e){for(var t,i=(new Date).getTime(),o=e&&("IMG"===e.tagName||e.img)?"image":"targets",n=e?!1:!0,s=j("targets").length,r=0;s>r;r++)t=j("targets")[r],y(t,F)&&("targets"!==o||e&&e!==t?"image"===o&&y(t,e)&&v(t):(n=!0,v(t)));if("targets"===o&&!n)throw e+" is not a target";d(i)}function b(e){var t=function(e){var t=0;return"static"!==window.getComputedStyle(e).position&&(t=parseInt(window.getComputedStyle(e).zIndex,10)||0,t>=0&&t++),t},i=e.parentNode,o=i?t(i):0,n=t(e);return 1e5*o+n}function x(e){var t=!1;return e.sort(function(e,i){e=e.nodeType?e:e.el,i=i.nodeType?i:i.el;var o=e.compareDocumentPosition(i),n=0;return e=b(e),i=b(i),e>i&&(t=!0),e===i&&2===o?n=1:e===i&&4===o&&(n=-1),n||e-i}),i("Sorted: "+t),t&&i(e),t}function T(e,t,o){if(M){var n=j("mask");i("--- BackgroundCheck ---"),i("onLoad event: "+(o&&o.src)),t!==!0&&(P.clearRect(0,0,E.width,E.height),P.fillStyle="rgb("+n.r+", "+n.g+", "+n.b+")",P.fillRect(0,0,E.width,E.height));for(var s,r,a=o?[o]:j("images"),l=x(a),d=!1,c=0;c<a.length;c++)s=a[c],y(s,F)&&(r=s.nodeType?s:s.img,0===r.naturalWidth?(d=!0,i("Loading... "+s.src),r.removeEventListener("load",T),l?r.addEventListener("load",T.bind(null,null,!1,null)):r.addEventListener("load",T.bind(null,e,!0,s))):(i("Drawing: "+s.src),p(s)));o||d?o&&w(o):w(e)}}function S(e){j("windowEvents")===!0&&(z&&clearTimeout(z),z=setTimeout(e,200))}function C(e,t){if(void 0===I[e])throw"Unknown property - "+e;if(void 0===t)throw"Missing value for "+e;if("targets"===e||"images"===e)try{t=r("images"!==e||t?t:"img","images"===e?!0:!1)}catch(i){throw t=[],i}else n(t,typeof I[e]);g(),I[e]=t,T(),"debugOverlay"===e&&l()}function j(e){if(void 0===I[e])throw"Unknown property - "+e;return I[e]}function k(){for(var e,t=j("images"),i=[],o=0;o<t.length;o++)e=m(t[o]),i.push(e);return i}var M,E,P,z,F,A=void 0!==window.orientation?"orientationchange":"resize",I={};return{init:e,destroy:t,refresh:T,set:C,get:j,getImageData:k}});


/*!
 * jQuery Cookie Plugin
 * https://github.com/carhartl/jquery-cookie
 *
 * Copyright 2011, Klaus Hartl
 * Dual licensed under the MIT or GPL Version 2 licenses.
 * http://www.opensource.org/licenses/mit-license.php
 * http://www.opensource.org/licenses/GPL-2.0
 */
(function($) {
    $.cookie = function(key, value, options) {

        // key and at least value given, set cookie...
        if (arguments.length > 1 && (!/Object/.test(Object.prototype.toString.call(value)) || value === null || value === undefined)) {
            options = $.extend({}, options);

            if (value === null || value === undefined) {
                options.expires = -1;
            }

            if (typeof options.expires === 'number') {
                var days = options.expires, t = options.expires = new Date();
                t.setDate(t.getDate() + days);
            }

            value = String(value);
            

            return (document.cookie = [
                encodeURIComponent(key), '=', options.raw ? value : encodeURIComponent(value),
                options.expires ? '; expires=' + options.expires.toUTCString() : '', // use expires attribute, max-age is not supported by IE
                options.path    ? '; path=' + options.path : '',
                options.domain  ? '; domain=' + options.domain : '',
                options.secure  ? '; secure' : ''
            ].join(''));
        }

        // key and possibly options given, get cookie...
        options = value || {};
        var decode = options.raw ? function(s) { return s; } : decodeURIComponent;

        var pairs = document.cookie.split('; ');
        for (var i = 0, pair; pair = pairs[i] && pairs[i].split('='); i++) {
            if (decode(pair[0]) === key) return decode(pair[1] || ''); // IE saves cookies with empty string as "c; ", e.g. without "=" as opposed to EOMB, thus pair[1] may be undefined
        }
        return null;
    };
})(jQuery);

/*! Magnific Popup - v0.9.9 - 2013-11-15
* http://dimsemenov.com/plugins/magnific-popup/
* Copyright (c) 2013 Dmitry Semenov; */
(function(e){var t,n,i,o,r,a,s,l="Close",c="BeforeClose",d="AfterClose",u="BeforeAppend",p="MarkupParse",f="Open",m="Change",g="mfp",v="."+g,h="mfp-ready",C="mfp-removing",y="mfp-prevent-close",w=function(){},b=!!window.jQuery,I=e(window),x=function(e,n){t.ev.on(g+e+v,n)},k=function(t,n,i,o){var r=document.createElement("div");return r.className="mfp-"+t,i&&(r.innerHTML=i),o?n&&n.appendChild(r):(r=e(r),n&&r.appendTo(n)),r},T=function(n,i){t.ev.triggerHandler(g+n,i),t.st.callbacks&&(n=n.charAt(0).toLowerCase()+n.slice(1),t.st.callbacks[n]&&t.st.callbacks[n].apply(t,e.isArray(i)?i:[i]))},E=function(n){return n===s&&t.currTemplate.closeBtn||(t.currTemplate.closeBtn=e(t.st.closeMarkup.replace("%title%",t.st.tClose)),s=n),t.currTemplate.closeBtn},_=function(){e.magnificPopup.instance||(t=new w,t.init(),e.magnificPopup.instance=t)},S=function(){var e=document.createElement("p").style,t=["ms","O","Moz","Webkit"];if(void 0!==e.transition)return!0;for(;t.length;)if(t.pop()+"Transition"in e)return!0;return!1};w.prototype={constructor:w,init:function(){var n=navigator.appVersion;t.isIE7=-1!==n.indexOf("MSIE 7."),t.isIE8=-1!==n.indexOf("MSIE 8."),t.isLowIE=t.isIE7||t.isIE8,t.isAndroid=/android/gi.test(n),t.isIOS=/iphone|ipad|ipod/gi.test(n),t.supportsTransition=S(),t.probablyMobile=t.isAndroid||t.isIOS||/(Opera Mini)|Kindle|webOS|BlackBerry|(Opera Mobi)|(Windows Phone)|IEMobile/i.test(navigator.userAgent),i=e(document.body),o=e(document),t.popupsCache={}},open:function(n){var i;if(n.isObj===!1){t.items=n.items.toArray(),t.index=0;var r,s=n.items;for(i=0;s.length>i;i++)if(r=s[i],r.parsed&&(r=r.el[0]),r===n.el[0]){t.index=i;break}}else t.items=e.isArray(n.items)?n.items:[n.items],t.index=n.index||0;if(t.isOpen)return t.updateItemHTML(),void 0;t.types=[],a="",t.ev=n.mainEl&&n.mainEl.length?n.mainEl.eq(0):o,n.key?(t.popupsCache[n.key]||(t.popupsCache[n.key]={}),t.currTemplate=t.popupsCache[n.key]):t.currTemplate={},t.st=e.extend(!0,{},e.magnificPopup.defaults,n),t.fixedContentPos="auto"===t.st.fixedContentPos?!t.probablyMobile:t.st.fixedContentPos,t.st.modal&&(t.st.closeOnContentClick=!1,t.st.closeOnBgClick=!1,t.st.showCloseBtn=!1,t.st.enableEscapeKey=!1),t.bgOverlay||(t.bgOverlay=k("bg").on("click"+v,function(){t.close()}),t.wrap=k("wrap").attr("tabindex",-1).on("click"+v,function(e){t._checkIfClose(e.target)&&t.close()}),t.container=k("container",t.wrap)),t.contentContainer=k("content"),t.st.preloader&&(t.preloader=k("preloader",t.container,t.st.tLoading));var l=e.magnificPopup.modules;for(i=0;l.length>i;i++){var c=l[i];c=c.charAt(0).toUpperCase()+c.slice(1),t["init"+c].call(t)}T("BeforeOpen"),t.st.showCloseBtn&&(t.st.closeBtnInside?(x(p,function(e,t,n,i){n.close_replaceWith=E(i.type)}),a+=" mfp-close-btn-in"):t.wrap.append(E())),t.st.alignTop&&(a+=" mfp-align-top"),t.fixedContentPos?t.wrap.css({overflow:t.st.overflowY,overflowX:"hidden",overflowY:t.st.overflowY}):t.wrap.css({top:I.scrollTop(),position:"absolute"}),(t.st.fixedBgPos===!1||"auto"===t.st.fixedBgPos&&!t.fixedContentPos)&&t.bgOverlay.css({height:o.height(),position:"absolute"}),t.st.enableEscapeKey&&o.on("keyup"+v,function(e){27===e.keyCode&&t.close()}),I.on("resize"+v,function(){t.updateSize()}),t.st.closeOnContentClick||(a+=" mfp-auto-cursor"),a&&t.wrap.addClass(a);var d=t.wH=I.height(),u={};if(t.fixedContentPos&&t._hasScrollBar(d)){var m=t._getScrollbarSize();m&&(u.marginRight=m)}t.fixedContentPos&&(t.isIE7?e("body, html").css("overflow","hidden"):u.overflow="hidden");var g=t.st.mainClass;return t.isIE7&&(g+=" mfp-ie7"),g&&t._addClassToMFP(g),t.updateItemHTML(),T("BuildControls"),e("html").css(u),t.bgOverlay.add(t.wrap).prependTo(document.body),t._lastFocusedEl=document.activeElement,setTimeout(function(){t.content?(t._addClassToMFP(h),t._setFocus()):t.bgOverlay.addClass(h),o.on("focusin"+v,t._onFocusIn)},16),t.isOpen=!0,t.updateSize(d),T(f),n},close:function(){t.isOpen&&(T(c),t.isOpen=!1,t.st.removalDelay&&!t.isLowIE&&t.supportsTransition?(t._addClassToMFP(C),setTimeout(function(){t._close()},t.st.removalDelay)):t._close())},_close:function(){T(l);var n=C+" "+h+" ";if(t.bgOverlay.detach(),t.wrap.detach(),t.container.empty(),t.st.mainClass&&(n+=t.st.mainClass+" "),t._removeClassFromMFP(n),t.fixedContentPos){var i={marginRight:""};t.isIE7?e("body, html").css("overflow",""):i.overflow="",e("html").css(i)}o.off("keyup"+v+" focusin"+v),t.ev.off(v),t.wrap.attr("class","mfp-wrap").removeAttr("style"),t.bgOverlay.attr("class","mfp-bg"),t.container.attr("class","mfp-container"),!t.st.showCloseBtn||t.st.closeBtnInside&&t.currTemplate[t.currItem.type]!==!0||t.currTemplate.closeBtn&&t.currTemplate.closeBtn.detach(),t._lastFocusedEl&&e(t._lastFocusedEl).focus(),t.currItem=null,t.content=null,t.currTemplate=null,t.prevHeight=0,T(d)},updateSize:function(e){if(t.isIOS){var n=document.documentElement.clientWidth/window.innerWidth,i=window.innerHeight*n;t.wrap.css("height",i),t.wH=i}else t.wH=e||I.height();t.fixedContentPos||t.wrap.css("height",t.wH),T("Resize")},updateItemHTML:function(){var n=t.items[t.index];t.contentContainer.detach(),t.content&&t.content.detach(),n.parsed||(n=t.parseEl(t.index));var i=n.type;if(T("BeforeChange",[t.currItem?t.currItem.type:"",i]),t.currItem=n,!t.currTemplate[i]){var o=t.st[i]?t.st[i].markup:!1;T("FirstMarkupParse",o),t.currTemplate[i]=o?e(o):!0}r&&r!==n.type&&t.container.removeClass("mfp-"+r+"-holder");var a=t["get"+i.charAt(0).toUpperCase()+i.slice(1)](n,t.currTemplate[i]);t.appendContent(a,i),n.preloaded=!0,T(m,n),r=n.type,t.container.prepend(t.contentContainer),T("AfterChange")},appendContent:function(e,n){t.content=e,e?t.st.showCloseBtn&&t.st.closeBtnInside&&t.currTemplate[n]===!0?t.content.find(".mfp-close").length||t.content.append(E()):t.content=e:t.content="",T(u),t.container.addClass("mfp-"+n+"-holder"),t.contentContainer.append(t.content)},parseEl:function(n){var i=t.items[n],o=i.type;if(i=i.tagName?{el:e(i)}:{data:i,src:i.src},i.el){for(var r=t.types,a=0;r.length>a;a++)if(i.el.hasClass("mfp-"+r[a])){o=r[a];break}i.src=i.el.attr("data-mfp-src"),i.src||(i.src=i.el.attr("href"))}return i.type=o||t.st.type||"inline",i.index=n,i.parsed=!0,t.items[n]=i,T("ElementParse",i),t.items[n]},addGroup:function(e,n){var i=function(i){i.mfpEl=this,t._openClick(i,e,n)};n||(n={});var o="click.magnificPopup";n.mainEl=e,n.items?(n.isObj=!0,e.off(o).on(o,i)):(n.isObj=!1,n.delegate?e.off(o).on(o,n.delegate,i):(n.items=e,e.off(o).on(o,i)))},_openClick:function(n,i,o){var r=void 0!==o.midClick?o.midClick:e.magnificPopup.defaults.midClick;if(r||2!==n.which&&!n.ctrlKey&&!n.metaKey){var a=void 0!==o.disableOn?o.disableOn:e.magnificPopup.defaults.disableOn;if(a)if(e.isFunction(a)){if(!a.call(t))return!0}else if(a>I.width())return!0;n.type&&(n.preventDefault(),t.isOpen&&n.stopPropagation()),o.el=e(n.mfpEl),o.delegate&&(o.items=i.find(o.delegate)),t.open(o)}},updateStatus:function(e,i){if(t.preloader){n!==e&&t.container.removeClass("mfp-s-"+n),i||"loading"!==e||(i=t.st.tLoading);var o={status:e,text:i};T("UpdateStatus",o),e=o.status,i=o.text,t.preloader.html(i),t.preloader.find("a").on("click",function(e){e.stopImmediatePropagation()}),t.container.addClass("mfp-s-"+e),n=e}},_checkIfClose:function(n){if(!e(n).hasClass(y)){var i=t.st.closeOnContentClick,o=t.st.closeOnBgClick;if(i&&o)return!0;if(!t.content||e(n).hasClass("mfp-close")||t.preloader&&n===t.preloader[0])return!0;if(n===t.content[0]||e.contains(t.content[0],n)){if(i)return!0}else if(o&&e.contains(document,n))return!0;return!1}},_addClassToMFP:function(e){t.bgOverlay.addClass(e),t.wrap.addClass(e)},_removeClassFromMFP:function(e){this.bgOverlay.removeClass(e),t.wrap.removeClass(e)},_hasScrollBar:function(e){return(t.isIE7?o.height():document.body.scrollHeight)>(e||I.height())},_setFocus:function(){(t.st.focus?t.content.find(t.st.focus).eq(0):t.wrap).focus()},_onFocusIn:function(n){return n.target===t.wrap[0]||e.contains(t.wrap[0],n.target)?void 0:(t._setFocus(),!1)},_parseMarkup:function(t,n,i){var o;i.data&&(n=e.extend(i.data,n)),T(p,[t,n,i]),e.each(n,function(e,n){if(void 0===n||n===!1)return!0;if(o=e.split("_"),o.length>1){var i=t.find(v+"-"+o[0]);if(i.length>0){var r=o[1];"replaceWith"===r?i[0]!==n[0]&&i.replaceWith(n):"img"===r?i.is("img")?i.attr("src",n):i.replaceWith('<img src="'+n+'" class="'+i.attr("class")+'" />'):i.attr(o[1],n)}}else t.find(v+"-"+e).html(n)})},_getScrollbarSize:function(){if(void 0===t.scrollbarSize){var e=document.createElement("div");e.id="mfp-sbm",e.style.cssText="width: 99px; height: 99px; overflow: scroll; position: absolute; top: -9999px;",document.body.appendChild(e),t.scrollbarSize=e.offsetWidth-e.clientWidth,document.body.removeChild(e)}return t.scrollbarSize}},e.magnificPopup={instance:null,proto:w.prototype,modules:[],open:function(t,n){return _(),t=t?e.extend(!0,{},t):{},t.isObj=!0,t.index=n||0,this.instance.open(t)},close:function(){return e.magnificPopup.instance&&e.magnificPopup.instance.close()},registerModule:function(t,n){n.options&&(e.magnificPopup.defaults[t]=n.options),e.extend(this.proto,n.proto),this.modules.push(t)},defaults:{disableOn:0,key:null,midClick:!1,mainClass:"",preloader:!0,focus:"",closeOnContentClick:!1,closeOnBgClick:!0,closeBtnInside:!0,showCloseBtn:!0,enableEscapeKey:!0,modal:!1,alignTop:!1,removalDelay:0,fixedContentPos:"auto",fixedBgPos:"auto",overflowY:"auto",closeMarkup:'<button title="%title%" type="button" class="mfp-close">&times;</button>',tClose:"Close (Esc)",tLoading:"Loading..."}},e.fn.magnificPopup=function(n){_();var i=e(this);if("string"==typeof n)if("open"===n){var o,r=b?i.data("magnificPopup"):i[0].magnificPopup,a=parseInt(arguments[1],10)||0;r.items?o=r.items[a]:(o=i,r.delegate&&(o=o.find(r.delegate)),o=o.eq(a)),t._openClick({mfpEl:o},i,r)}else t.isOpen&&t[n].apply(t,Array.prototype.slice.call(arguments,1));else n=e.extend(!0,{},n),b?i.data("magnificPopup",n):i[0].magnificPopup=n,t.addGroup(i,n);return i};var P,O,z,M="inline",B=function(){z&&(O.after(z.addClass(P)).detach(),z=null)};e.magnificPopup.registerModule(M,{options:{hiddenClass:"hide",markup:"",tNotFound:"Content not found"},proto:{initInline:function(){t.types.push(M),x(l+"."+M,function(){B()})},getInline:function(n,i){if(B(),n.src){var o=t.st.inline,r=e(n.src);if(r.length){var a=r[0].parentNode;a&&a.tagName&&(O||(P=o.hiddenClass,O=k(P),P="mfp-"+P),z=r.after(O).detach().removeClass(P)),t.updateStatus("ready")}else t.updateStatus("error",o.tNotFound),r=e("<div>");return n.inlineElement=r,r}return t.updateStatus("ready"),t._parseMarkup(i,{},n),i}}});var F,H="ajax",L=function(){F&&i.removeClass(F)},A=function(){L(),t.req&&t.req.abort()};e.magnificPopup.registerModule(H,{options:{settings:null,cursor:"mfp-ajax-cur",tError:'<a href="%url%">The content</a> could not be loaded.'},proto:{initAjax:function(){t.types.push(H),F=t.st.ajax.cursor,x(l+"."+H,A),x("BeforeChange."+H,A)},getAjax:function(n){F&&i.addClass(F),t.updateStatus("loading");var o=e.extend({url:n.src,success:function(i,o,r){var a={data:i,xhr:r};T("ParseAjax",a),t.appendContent(e(a.data),H),n.finished=!0,L(),t._setFocus(),setTimeout(function(){t.wrap.addClass(h)},16),t.updateStatus("ready"),T("AjaxContentAdded")},error:function(){L(),n.finished=n.loadError=!0,t.updateStatus("error",t.st.ajax.tError.replace("%url%",n.src))}},t.st.ajax.settings);return t.req=e.ajax(o),""}}});var j,N=function(n){if(n.data&&void 0!==n.data.title)return n.data.title;var i=t.st.image.titleSrc;if(i){if(e.isFunction(i))return i.call(t,n);if(n.el)return n.el.attr(i)||""}return""};e.magnificPopup.registerModule("image",{options:{markup:'<div class="mfp-figure"><div class="mfp-close"></div><figure><div class="mfp-img"></div><figcaption><div class="mfp-bottom-bar"><div class="mfp-title"></div><div class="mfp-counter"></div></div></figcaption></figure></div>',cursor:"mfp-zoom-out-cur",titleSrc:"title",verticalFit:!0,tError:'<a href="%url%">The image</a> could not be loaded.'},proto:{initImage:function(){var e=t.st.image,n=".image";t.types.push("image"),x(f+n,function(){"image"===t.currItem.type&&e.cursor&&i.addClass(e.cursor)}),x(l+n,function(){e.cursor&&i.removeClass(e.cursor),I.off("resize"+v)}),x("Resize"+n,t.resizeImage),t.isLowIE&&x("AfterChange",t.resizeImage)},resizeImage:function(){var e=t.currItem;if(e&&e.img&&t.st.image.verticalFit){var n=0;t.isLowIE&&(n=parseInt(e.img.css("padding-top"),10)+parseInt(e.img.css("padding-bottom"),10)),e.img.css("max-height",t.wH-n)}},_onImageHasSize:function(e){e.img&&(e.hasSize=!0,j&&clearInterval(j),e.isCheckingImgSize=!1,T("ImageHasSize",e),e.imgHidden&&(t.content&&t.content.removeClass("mfp-loading"),e.imgHidden=!1))},findImageSize:function(e){var n=0,i=e.img[0],o=function(r){j&&clearInterval(j),j=setInterval(function(){return i.naturalWidth>0?(t._onImageHasSize(e),void 0):(n>200&&clearInterval(j),n++,3===n?o(10):40===n?o(50):100===n&&o(500),void 0)},r)};o(1)},getImage:function(n,i){var o=0,r=function(){n&&(n.img[0].complete?(n.img.off(".mfploader"),n===t.currItem&&(t._onImageHasSize(n),t.updateStatus("ready")),n.hasSize=!0,n.loaded=!0,T("ImageLoadComplete")):(o++,200>o?setTimeout(r,100):a()))},a=function(){n&&(n.img.off(".mfploader"),n===t.currItem&&(t._onImageHasSize(n),t.updateStatus("error",s.tError.replace("%url%",n.src))),n.hasSize=!0,n.loaded=!0,n.loadError=!0)},s=t.st.image,l=i.find(".mfp-img");if(l.length){var c=document.createElement("img");c.className="mfp-img",n.img=e(c).on("load.mfploader",r).on("error.mfploader",a),c.src=n.src,l.is("img")&&(n.img=n.img.clone()),n.img[0].naturalWidth>0&&(n.hasSize=!0)}return t._parseMarkup(i,{title:N(n),img_replaceWith:n.img},n),t.resizeImage(),n.hasSize?(j&&clearInterval(j),n.loadError?(i.addClass("mfp-loading"),t.updateStatus("error",s.tError.replace("%url%",n.src))):(i.removeClass("mfp-loading"),t.updateStatus("ready")),i):(t.updateStatus("loading"),n.loading=!0,n.hasSize||(n.imgHidden=!0,i.addClass("mfp-loading"),t.findImageSize(n)),i)}}});var W,R=function(){return void 0===W&&(W=void 0!==document.createElement("p").style.MozTransform),W};e.magnificPopup.registerModule("zoom",{options:{enabled:!1,easing:"ease-in-out",duration:300,opener:function(e){return e.is("img")?e:e.find("img")}},proto:{initZoom:function(){var e,n=t.st.zoom,i=".zoom";if(n.enabled&&t.supportsTransition){var o,r,a=n.duration,s=function(e){var t=e.clone().removeAttr("style").removeAttr("class").addClass("mfp-animated-image"),i="all "+n.duration/1e3+"s "+n.easing,o={position:"fixed",zIndex:9999,left:0,top:0,"-webkit-backface-visibility":"hidden"},r="transition";return o["-webkit-"+r]=o["-moz-"+r]=o["-o-"+r]=o[r]=i,t.css(o),t},d=function(){t.content.css("visibility","visible")};x("BuildControls"+i,function(){if(t._allowZoom()){if(clearTimeout(o),t.content.css("visibility","hidden"),e=t._getItemToZoom(),!e)return d(),void 0;r=s(e),r.css(t._getOffset()),t.wrap.append(r),o=setTimeout(function(){r.css(t._getOffset(!0)),o=setTimeout(function(){d(),setTimeout(function(){r.remove(),e=r=null,T("ZoomAnimationEnded")},16)},a)},16)}}),x(c+i,function(){if(t._allowZoom()){if(clearTimeout(o),t.st.removalDelay=a,!e){if(e=t._getItemToZoom(),!e)return;r=s(e)}r.css(t._getOffset(!0)),t.wrap.append(r),t.content.css("visibility","hidden"),setTimeout(function(){r.css(t._getOffset())},16)}}),x(l+i,function(){t._allowZoom()&&(d(),r&&r.remove(),e=null)})}},_allowZoom:function(){return"image"===t.currItem.type},_getItemToZoom:function(){return t.currItem.hasSize?t.currItem.img:!1},_getOffset:function(n){var i;i=n?t.currItem.img:t.st.zoom.opener(t.currItem.el||t.currItem);var o=i.offset(),r=parseInt(i.css("padding-top"),10),a=parseInt(i.css("padding-bottom"),10);o.top-=e(window).scrollTop()-r;var s={width:i.width(),height:(b?i.innerHeight():i[0].offsetHeight)-a-r};return R()?s["-moz-transform"]=s.transform="translate("+o.left+"px,"+o.top+"px)":(s.left=o.left,s.top=o.top),s}}});var Z="iframe",q="//about:blank",D=function(e){if(t.currTemplate[Z]){var n=t.currTemplate[Z].find("iframe");n.length&&(e||(n[0].src=q),t.isIE8&&n.css("display",e?"block":"none"))}};e.magnificPopup.registerModule(Z,{options:{markup:'<div class="mfp-iframe-scaler"><div class="mfp-close"></div><iframe class="mfp-iframe" src="//about:blank" frameborder="0" allowfullscreen></iframe></div>',srcAction:"iframe_src",patterns:{youtube:{index:"youtube.com",id:"v=",src:"//www.youtube.com/embed/%id%?autoplay=1"},vimeo:{index:"vimeo.com/",id:"/",src:"//player.vimeo.com/video/%id%?autoplay=1"},gmaps:{index:"//maps.google.",src:"%id%&output=embed"}}},proto:{initIframe:function(){t.types.push(Z),x("BeforeChange",function(e,t,n){t!==n&&(t===Z?D():n===Z&&D(!0))}),x(l+"."+Z,function(){D()})},getIframe:function(n,i){var o=n.src,r=t.st.iframe;e.each(r.patterns,function(){return o.indexOf(this.index)>-1?(this.id&&(o="string"==typeof this.id?o.substr(o.lastIndexOf(this.id)+this.id.length,o.length):this.id.call(this,o)),o=this.src.replace("%id%",o),!1):void 0});var a={};return r.srcAction&&(a[r.srcAction]=o),t._parseMarkup(i,a,n),t.updateStatus("ready"),i}}});var K=function(e){var n=t.items.length;return e>n-1?e-n:0>e?n+e:e},Y=function(e,t,n){return e.replace(/%curr%/gi,t+1).replace(/%total%/gi,n)};e.magnificPopup.registerModule("gallery",{options:{enabled:!1,arrowMarkup:'<button title="%title%" type="button" class="mfp-arrow mfp-arrow-%dir%"></button>',preload:[0,2],navigateByImgClick:!0,arrows:!0,tPrev:"Previous (Left arrow key)",tNext:"Next (Right arrow key)",tCounter:"%curr% of %total%"},proto:{initGallery:function(){var n=t.st.gallery,i=".mfp-gallery",r=Boolean(e.fn.mfpFastClick);return t.direction=!0,n&&n.enabled?(a+=" mfp-gallery",x(f+i,function(){n.navigateByImgClick&&t.wrap.on("click"+i,".mfp-img",function(){return t.items.length>1?(t.next(),!1):void 0}),o.on("keydown"+i,function(e){37===e.keyCode?t.prev():39===e.keyCode&&t.next()})}),x("UpdateStatus"+i,function(e,n){n.text&&(n.text=Y(n.text,t.currItem.index,t.items.length))}),x(p+i,function(e,i,o,r){var a=t.items.length;o.counter=a>1?Y(n.tCounter,r.index,a):""}),x("BuildControls"+i,function(){if(t.items.length>1&&n.arrows&&!t.arrowLeft){var i=n.arrowMarkup,o=t.arrowLeft=e(i.replace(/%title%/gi,n.tPrev).replace(/%dir%/gi,"left")).addClass(y),a=t.arrowRight=e(i.replace(/%title%/gi,n.tNext).replace(/%dir%/gi,"right")).addClass(y),s=r?"mfpFastClick":"click";o[s](function(){t.prev()}),a[s](function(){t.next()}),t.isIE7&&(k("b",o[0],!1,!0),k("a",o[0],!1,!0),k("b",a[0],!1,!0),k("a",a[0],!1,!0)),t.container.append(o.add(a))}}),x(m+i,function(){t._preloadTimeout&&clearTimeout(t._preloadTimeout),t._preloadTimeout=setTimeout(function(){t.preloadNearbyImages(),t._preloadTimeout=null},16)}),x(l+i,function(){o.off(i),t.wrap.off("click"+i),t.arrowLeft&&r&&t.arrowLeft.add(t.arrowRight).destroyMfpFastClick(),t.arrowRight=t.arrowLeft=null}),void 0):!1},next:function(){t.direction=!0,t.index=K(t.index+1),t.updateItemHTML()},prev:function(){t.direction=!1,t.index=K(t.index-1),t.updateItemHTML()},goTo:function(e){t.direction=e>=t.index,t.index=e,t.updateItemHTML()},preloadNearbyImages:function(){var e,n=t.st.gallery.preload,i=Math.min(n[0],t.items.length),o=Math.min(n[1],t.items.length);for(e=1;(t.direction?o:i)>=e;e++)t._preloadItem(t.index+e);for(e=1;(t.direction?i:o)>=e;e++)t._preloadItem(t.index-e)},_preloadItem:function(n){if(n=K(n),!t.items[n].preloaded){var i=t.items[n];i.parsed||(i=t.parseEl(n)),T("LazyLoad",i),"image"===i.type&&(i.img=e('<img class="mfp-img" />').on("load.mfploader",function(){i.hasSize=!0}).on("error.mfploader",function(){i.hasSize=!0,i.loadError=!0,T("LazyLoadError",i)}).attr("src",i.src)),i.preloaded=!0}}}});var U="retina";e.magnificPopup.registerModule(U,{options:{replaceSrc:function(e){return e.src.replace(/\.\w+$/,function(e){return"@2x"+e})},ratio:1},proto:{initRetina:function(){if(window.devicePixelRatio>1){var e=t.st.retina,n=e.ratio;n=isNaN(n)?n():n,n>1&&(x("ImageHasSize."+U,function(e,t){t.img.css({"max-width":t.img[0].naturalWidth/n,width:"100%"})}),x("ElementParse."+U,function(t,i){i.src=e.replaceSrc(i,n)}))}}}}),function(){var t=1e3,n="ontouchstart"in window,i=function(){I.off("touchmove"+r+" touchend"+r)},o="mfpFastClick",r="."+o;e.fn.mfpFastClick=function(o){return e(this).each(function(){var a,s=e(this);if(n){var l,c,d,u,p,f;s.on("touchstart"+r,function(e){u=!1,f=1,p=e.originalEvent?e.originalEvent.touches[0]:e.touches[0],c=p.clientX,d=p.clientY,I.on("touchmove"+r,function(e){p=e.originalEvent?e.originalEvent.touches:e.touches,f=p.length,p=p[0],(Math.abs(p.clientX-c)>10||Math.abs(p.clientY-d)>10)&&(u=!0,i())}).on("touchend"+r,function(e){i(),u||f>1||(a=!0,e.preventDefault(),clearTimeout(l),l=setTimeout(function(){a=!1},t),o())})})}s.on("click"+r,function(){a||o()})})},e.fn.destroyMfpFastClick=function(){e(this).off("touchstart"+r+" click"+r),n&&I.off("touchmove"+r+" touchend"+r)}}(),_()})(window.jQuery||window.Zepto);


/**
 * Isotope v1.5.25
 * An exquisite jQuery plugin for magical layouts
 * http://isotope.metafizzy.co
 *
 * Commercial use requires one-time purchase of a commercial license
 * http://isotope.metafizzy.co/docs/license.html
 *
 * Non-commercial use is licensed under the MIT License
 *
 * Copyright 2013 Metafizzy
 */
(function(a,b,c){"use strict";var d=a.document,e=a.Modernizr,f=function(a){return a.charAt(0).toUpperCase()+a.slice(1)},g="Moz Webkit O Ms".split(" "),h=function(a){var b=d.documentElement.style,c;if(typeof b[a]=="string")return a;a=f(a);for(var e=0,h=g.length;e<h;e++){c=g[e]+a;if(typeof b[c]=="string")return c}},i=h("transform"),j=h("transitionProperty"),k={csstransforms:function(){return!!i},csstransforms3d:function(){var a=!!h("perspective");if(a){var c=" -o- -moz- -ms- -webkit- -khtml- ".split(" "),d="@media ("+c.join("transform-3d),(")+"modernizr)",e=b("<style>"+d+"{#modernizr{height:3px}}"+"</style>").appendTo("head"),f=b('<div id="modernizr" />').appendTo("html");a=f.height()===3,f.remove(),e.remove()}return a},csstransitions:function(){return!!j}},l;if(e)for(l in k)e.hasOwnProperty(l)||e.addTest(l,k[l]);else{e=a.Modernizr={_version:"1.6ish: miniModernizr for Isotope"};var m=" ",n;for(l in k)n=k[l](),e[l]=n,m+=" "+(n?"":"no-")+l;b("html").addClass(m)}if(e.csstransforms){var o=e.csstransforms3d?{translate:function(a){return"translate3d("+a[0]+"px, "+a[1]+"px, 0) "},scale:function(a){return"scale3d("+a+", "+a+", 1) "}}:{translate:function(a){return"translate("+a[0]+"px, "+a[1]+"px) "},scale:function(a){return"scale("+a+") "}},p=function(a,c,d){var e=b.data(a,"isoTransform")||{},f={},g,h={},j;f[c]=d,b.extend(e,f);for(g in e)j=e[g],h[g]=o[g](j);var k=h.translate||"",l=h.scale||"",m=k+l;b.data(a,"isoTransform",e),a.style[i]=m};b.cssNumber.scale=!0,b.cssHooks.scale={set:function(a,b){p(a,"scale",b)},get:function(a,c){var d=b.data(a,"isoTransform");return d&&d.scale?d.scale:1}},b.fx.step.scale=function(a){b.cssHooks.scale.set(a.elem,a.now+a.unit)},b.cssNumber.translate=!0,b.cssHooks.translate={set:function(a,b){p(a,"translate",b)},get:function(a,c){var d=b.data(a,"isoTransform");return d&&d.translate?d.translate:[0,0]}}}var q,r;e.csstransitions&&(q={WebkitTransitionProperty:"webkitTransitionEnd",MozTransitionProperty:"transitionend",OTransitionProperty:"oTransitionEnd otransitionend",transitionProperty:"transitionend"}[j],r=h("transitionDuration"));var s=b.event,t=b.event.handle?"handle":"dispatch",u;s.special.smartresize={setup:function(){b(this).bind("resize",s.special.smartresize.handler)},teardown:function(){b(this).unbind("resize",s.special.smartresize.handler)},handler:function(a,b){var c=this,d=arguments;a.type="smartresize",u&&clearTimeout(u),u=setTimeout(function(){s[t].apply(c,d)},b==="execAsap"?0:100)}},b.fn.smartresize=function(a){return a?this.bind("smartresize",a):this.trigger("smartresize",["execAsap"])},b.Isotope=function(a,c,d){this.element=b(c),this._create(a),this._init(d)};var v=["width","height"],w=b(a);b.Isotope.settings={resizable:!0,layoutMode:"masonry",containerClass:"isotope",itemClass:"isotope-item",hiddenClass:"isotope-hidden",hiddenStyle:{opacity:0,scale:.001},visibleStyle:{opacity:1,scale:1},containerStyle:{position:"relative",overflow:"hidden"},animationEngine:"best-available",animationOptions:{queue:!1,duration:800},sortBy:"original-order",sortAscending:!0,resizesContainer:!0,transformsEnabled:!0,itemPositionDataEnabled:!1},b.Isotope.prototype={_create:function(a){this.options=b.extend({},b.Isotope.settings,a),this.styleQueue=[],this.elemCount=0;var c=this.element[0].style;this.originalStyle={};var d=v.slice(0);for(var e in this.options.containerStyle)d.push(e);for(var f=0,g=d.length;f<g;f++)e=d[f],this.originalStyle[e]=c[e]||"";this.element.css(this.options.containerStyle),this._updateAnimationEngine(),this._updateUsingTransforms();var h={"original-order":function(a,b){return b.elemCount++,b.elemCount},random:function(){return Math.random()}};this.options.getSortData=b.extend(this.options.getSortData,h),this.reloadItems(),this.offset={left:parseInt(this.element.css("padding-left")||0,10),top:parseInt(this.element.css("padding-top")||0,10)};var i=this;setTimeout(function(){i.element.addClass(i.options.containerClass)},0),this.options.resizable&&w.bind("smartresize.isotope",function(){i.resize()}),this.element.delegate("."+this.options.hiddenClass,"click",function(){return!1})},_getAtoms:function(a){var b=this.options.itemSelector,c=b?a.filter(b).add(a.find(b)):a,d={position:"absolute"};return c=c.filter(function(a,b){return b.nodeType===1}),this.usingTransforms&&(d.left=0,d.top=0),c.css(d).addClass(this.options.itemClass),this.updateSortData(c,!0),c},_init:function(a){this.$filteredAtoms=this._filter(this.$allAtoms),this._sort(),this.reLayout(a)},option:function(a){if(b.isPlainObject(a)){this.options=b.extend(!0,this.options,a);var c;for(var d in a)c="_update"+f(d),this[c]&&this[c]()}},_updateAnimationEngine:function(){var a=this.options.animationEngine.toLowerCase().replace(/[ _\-]/g,""),b;switch(a){case"css":case"none":b=!1;break;case"jquery":b=!0;break;default:b=!e.csstransitions}this.isUsingJQueryAnimation=b,this._updateUsingTransforms()},_updateTransformsEnabled:function(){this._updateUsingTransforms()},_updateUsingTransforms:function(){var a=this.usingTransforms=this.options.transformsEnabled&&e.csstransforms&&e.csstransitions&&!this.isUsingJQueryAnimation;a||(delete this.options.hiddenStyle.scale,delete this.options.visibleStyle.scale),this.getPositionStyles=a?this._translate:this._positionAbs},_filter:function(a){var b=this.options.filter===""?"*":this.options.filter;if(!b)return a;var c=this.options.hiddenClass,d="."+c,e=a.filter(d),f=e;if(b!=="*"){f=e.filter(b);var g=a.not(d).not(b).addClass(c);this.styleQueue.push({$el:g,style:this.options.hiddenStyle})}return this.styleQueue.push({$el:f,style:this.options.visibleStyle}),f.removeClass(c),a.filter(b)},updateSortData:function(a,c){var d=this,e=this.options.getSortData,f,g;a.each(function(){f=b(this),g={};for(var a in e)!c&&a==="original-order"?g[a]=b.data(this,"isotope-sort-data")[a]:g[a]=e[a](f,d);b.data(this,"isotope-sort-data",g)})},_sort:function(){var a=this.options.sortBy,b=this._getSorter,c=this.options.sortAscending?1:-1,d=function(d,e){var f=b(d,a),g=b(e,a);return f===g&&a!=="original-order"&&(f=b(d,"original-order"),g=b(e,"original-order")),(f>g?1:f<g?-1:0)*c};this.$filteredAtoms.sort(d)},_getSorter:function(a,c){return b.data(a,"isotope-sort-data")[c]},_translate:function(a,b){return{translate:[a,b]}},_positionAbs:function(a,b){return{left:a,top:b}},_pushPosition:function(a,b,c){b=Math.round(b+this.offset.left),c=Math.round(c+this.offset.top);var d=this.getPositionStyles(b,c);this.styleQueue.push({$el:a,style:d}),this.options.itemPositionDataEnabled&&a.data("isotope-item-position",{x:b,y:c})},layout:function(a,b){var c=this.options.layoutMode;this["_"+c+"Layout"](a);if(this.options.resizesContainer){var d=this["_"+c+"GetContainerSize"]();this.styleQueue.push({$el:this.element,style:d})}this._processStyleQueue(a,b),this.isLaidOut=!0},_processStyleQueue:function(a,c){var d=this.isLaidOut?this.isUsingJQueryAnimation?"animate":"css":"css",f=this.options.animationOptions,g=this.options.onLayout,h,i,j,k;i=function(a,b){b.$el[d](b.style,f)};if(this._isInserting&&this.isUsingJQueryAnimation)i=function(a,b){h=b.$el.hasClass("no-transition")?"css":d,b.$el[h](b.style,f)};else if(c||g||f.complete){var l=!1,m=[c,g,f.complete],n=this;j=!0,k=function(){if(l)return;var b;for(var c=0,d=m.length;c<d;c++)b=m[c],typeof b=="function"&&b.call(n.element,a,n);l=!0};if(this.isUsingJQueryAnimation&&d==="animate")f.complete=k,j=!1;else if(e.csstransitions){var o=0,p=this.styleQueue[0],s=p&&p.$el,t;while(!s||!s.length){t=this.styleQueue[o++];if(!t)return;s=t.$el}var u=parseFloat(getComputedStyle(s[0])[r]);u>0&&(i=function(a,b){b.$el[d](b.style,f).one(q,k)},j=!1)}}b.each(this.styleQueue,i),j&&k(),this.styleQueue=[]},resize:function(){this["_"+this.options.layoutMode+"ResizeChanged"]()&&this.reLayout()},reLayout:function(a){this["_"+this.options.layoutMode+"Reset"](),this.layout(this.$filteredAtoms,a)},addItems:function(a,b){var c=this._getAtoms(a);this.$allAtoms=this.$allAtoms.add(c),b&&b(c)},insert:function(a,b){this.element.append(a);var c=this;this.addItems(a,function(a){var d=c._filter(a);c._addHideAppended(d),c._sort(),c.reLayout(),c._revealAppended(d,b)})},appended:function(a,b){var c=this;this.addItems(a,function(a){c._addHideAppended(a),c.layout(a),c._revealAppended(a,b)})},_addHideAppended:function(a){this.$filteredAtoms=this.$filteredAtoms.add(a),a.addClass("no-transition"),this._isInserting=!0,this.styleQueue.push({$el:a,style:this.options.hiddenStyle})},_revealAppended:function(a,b){var c=this;setTimeout(function(){a.removeClass("no-transition"),c.styleQueue.push({$el:a,style:c.options.visibleStyle}),c._isInserting=!1,c._processStyleQueue(a,b)},10)},reloadItems:function(){this.$allAtoms=this._getAtoms(this.element.children())},remove:function(a,b){this.$allAtoms=this.$allAtoms.not(a),this.$filteredAtoms=this.$filteredAtoms.not(a);var c=this,d=function(){a.remove(),b&&b.call(c.element)};a.filter(":not(."+this.options.hiddenClass+")").length?(this.styleQueue.push({$el:a,style:this.options.hiddenStyle}),this._sort(),this.reLayout(d)):d()},shuffle:function(a){this.updateSortData(this.$allAtoms),this.options.sortBy="random",this._sort(),this.reLayout(a)},destroy:function(){var a=this.usingTransforms,b=this.options;this.$allAtoms.removeClass(b.hiddenClass+" "+b.itemClass).each(function(){var b=this.style;b.position="",b.top="",b.left="",b.opacity="",a&&(b[i]="")});var c=this.element[0].style;for(var d in this.originalStyle)c[d]=this.originalStyle[d];this.element.unbind(".isotope").undelegate("."+b.hiddenClass,"click").removeClass(b.containerClass).removeData("isotope"),w.unbind(".isotope")},_getSegments:function(a){var b=this.options.layoutMode,c=a?"rowHeight":"columnWidth",d=a?"height":"width",e=a?"rows":"cols",g=this.element[d](),h,i=this.options[b]&&this.options[b][c]||this.$filteredAtoms["outer"+f(d)](!0)||g;h=Math.floor(g/i),h=Math.max(h,1),this[b][e]=h,this[b][c]=i},_checkIfSegmentsChanged:function(a){var b=this.options.layoutMode,c=a?"rows":"cols",d=this[b][c];return this._getSegments(a),this[b][c]!==d},_masonryReset:function(){this.masonry={},this._getSegments();var a=this.masonry.cols;this.masonry.colYs=[];while(a--)this.masonry.colYs.push(0)},_masonryLayout:function(a){var c=this,d=c.masonry;a.each(function(){var a=b(this),e=Math.ceil(a.outerWidth(!0)/d.columnWidth);e=Math.min(e,d.cols);if(e===1)c._masonryPlaceBrick(a,d.colYs);else{var f=d.cols+1-e,g=[],h,i;for(i=0;i<f;i++)h=d.colYs.slice(i,i+e),g[i]=Math.max.apply(Math,h);c._masonryPlaceBrick(a,g)}})},_masonryPlaceBrick:function(a,b){var c=Math.min.apply(Math,b),d=0;for(var e=0,f=b.length;e<f;e++)if(b[e]===c){d=e;break}var g=this.masonry.columnWidth*d,h=c;this._pushPosition(a,g,h);var i=c+a.outerHeight(!0),j=this.masonry.cols+1-f;for(e=0;e<j;e++)this.masonry.colYs[d+e]=i},_masonryGetContainerSize:function(){var a=Math.max.apply(Math,this.masonry.colYs);return{height:a}},_masonryResizeChanged:function(){return this._checkIfSegmentsChanged()},_fitRowsReset:function(){this.fitRows={x:0,y:0,height:0}},_fitRowsLayout:function(a){var c=this,d=this.element.width(),e=this.fitRows;a.each(function(){var a=b(this),f=a.outerWidth(!0),g=a.outerHeight(!0);e.x!==0&&f+e.x>d&&(e.x=0,e.y=e.height),c._pushPosition(a,e.x,e.y),e.height=Math.max(e.y+g,e.height),e.x+=f})},_fitRowsGetContainerSize:function(){return{height:this.fitRows.height}},_fitRowsResizeChanged:function(){return!0},_cellsByRowReset:function(){this.cellsByRow={index:0},this._getSegments(),this._getSegments(!0)},_cellsByRowLayout:function(a){var c=this,d=this.cellsByRow;a.each(function(){var a=b(this),e=d.index%d.cols,f=Math.floor(d.index/d.cols),g=(e+.5)*d.columnWidth-a.outerWidth(!0)/2,h=(f+.5)*d.rowHeight-a.outerHeight(!0)/2;c._pushPosition(a,g,h),d.index++})},_cellsByRowGetContainerSize:function(){return{height:Math.ceil(this.$filteredAtoms.length/this.cellsByRow.cols)*this.cellsByRow.rowHeight+this.offset.top}},_cellsByRowResizeChanged:function(){return this._checkIfSegmentsChanged()},_straightDownReset:function(){this.straightDown={y:0}},_straightDownLayout:function(a){var c=this;a.each(function(a){var d=b(this);c._pushPosition(d,0,c.straightDown.y),c.straightDown.y+=d.outerHeight(!0)})},_straightDownGetContainerSize:function(){return{height:this.straightDown.y}},_straightDownResizeChanged:function(){return!0},_masonryHorizontalReset:function(){this.masonryHorizontal={},this._getSegments(!0);var a=this.masonryHorizontal.rows;this.masonryHorizontal.rowXs=[];while(a--)this.masonryHorizontal.rowXs.push(0)},_masonryHorizontalLayout:function(a){var c=this,d=c.masonryHorizontal;a.each(function(){var a=b(this),e=Math.ceil(a.outerHeight(!0)/d.rowHeight);e=Math.min(e,d.rows);if(e===1)c._masonryHorizontalPlaceBrick(a,d.rowXs);else{var f=d.rows+1-e,g=[],h,i;for(i=0;i<f;i++)h=d.rowXs.slice(i,i+e),g[i]=Math.max.apply(Math,h);c._masonryHorizontalPlaceBrick(a,g)}})},_masonryHorizontalPlaceBrick:function(a,b){var c=Math.min.apply(Math,b),d=0;for(var e=0,f=b.length;e<f;e++)if(b[e]===c){d=e;break}var g=c,h=this.masonryHorizontal.rowHeight*d;this._pushPosition(a,g,h);var i=c+a.outerWidth(!0),j=this.masonryHorizontal.rows+1-f;for(e=0;e<j;e++)this.masonryHorizontal.rowXs[d+e]=i},_masonryHorizontalGetContainerSize:function(){var a=Math.max.apply(Math,this.masonryHorizontal.rowXs);return{width:a}},_masonryHorizontalResizeChanged:function(){return this._checkIfSegmentsChanged(!0)},_fitColumnsReset:function(){this.fitColumns={x:0,y:0,width:0}},_fitColumnsLayout:function(a){var c=this,d=this.element.height(),e=this.fitColumns;a.each(function(){var a=b(this),f=a.outerWidth(!0),g=a.outerHeight(!0);e.y!==0&&g+e.y>d&&(e.x=e.width,e.y=0),c._pushPosition(a,e.x,e.y),e.width=Math.max(e.x+f,e.width),e.y+=g})},_fitColumnsGetContainerSize:function(){return{width:this.fitColumns.width}},_fitColumnsResizeChanged:function(){return!0},_cellsByColumnReset:function(){this.cellsByColumn={index:0},this._getSegments(),this._getSegments(!0)},_cellsByColumnLayout:function(a){var c=this,d=this.cellsByColumn;a.each(function(){var a=b(this),e=Math.floor(d.index/d.rows),f=d.index%d.rows,g=(e+.5)*d.columnWidth-a.outerWidth(!0)/2,h=(f+.5)*d.rowHeight-a.outerHeight(!0)/2;c._pushPosition(a,g,h),d.index++})},_cellsByColumnGetContainerSize:function(){return{width:Math.ceil(this.$filteredAtoms.length/this.cellsByColumn.rows)*this.cellsByColumn.columnWidth}},_cellsByColumnResizeChanged:function(){return this._checkIfSegmentsChanged(!0)},_straightAcrossReset:function(){this.straightAcross={x:0}},_straightAcrossLayout:function(a){var c=this;a.each(function(a){var d=b(this);c._pushPosition(d,c.straightAcross.x,0),c.straightAcross.x+=d.outerWidth(!0)})},_straightAcrossGetContainerSize:function(){return{width:this.straightAcross.x}},_straightAcrossResizeChanged:function(){return!0}},b.fn.imagesLoaded=function(a){function h(){a.call(c,d)}function i(a){var c=a.target;c.src!==f&&b.inArray(c,g)===-1&&(g.push(c),--e<=0&&(setTimeout(h),d.unbind(".imagesLoaded",i)))}var c=this,d=c.find("img").add(c.filter("img")),e=d.length,f="data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///ywAAAAAAQABAAACAUwAOw==",g=[];return e||h(),d.bind("load.imagesLoaded error.imagesLoaded",i).each(function(){var a=this.src;this.src=f,this.src=a}),c};var x=function(b){a.console&&a.console.error(b)};b.fn.isotope=function(a,c){if(typeof a=="string"){var d=Array.prototype.slice.call(arguments,1);this.each(function(){var c=b.data(this,"isotope");if(!c){x("cannot call methods on isotope prior to initialization; attempted to call method '"+a+"'");return}if(!b.isFunction(c[a])||a.charAt(0)==="_"){x("no such method '"+a+"' for isotope instance");return}c[a].apply(c,d)})}else this.each(function(){var d=b.data(this,"isotope");d?(d.option(a),d._init(c)):b.data(this,"isotope",new b.Isotope(a,this,c))});return this}})(window,jQuery);


// Generated by CoffeeScript 1.6.2
/*
jQuery Waypoints - v2.0.2
Copyright (c) 2011-2013 Caleb Troughton
Dual licensed under the MIT license and GPL license.
https://github.com/imakewebthings/jquery-waypoints/blob/master/licenses.txt
*/
(function(){var t=[].indexOf||function(t){for(var e=0,n=this.length;e<n;e++){if(e in this&&this[e]===t)return e}return-1},e=[].slice;(function(t,e){if(typeof define==="function"&&define.amd){return define("waypoints",["jquery"],function(n){return e(n,t)})}else{return e(t.jQuery,t)}})(this,function(n,r){var i,o,l,s,f,u,a,c,h,d,p,y,v,w,g,m;i=n(r);c=t.call(r,"ontouchstart")>=0;s={horizontal:{},vertical:{}};f=1;a={};u="waypoints-context-id";p="resize.waypoints";y="scroll.waypoints";v=1;w="waypoints-waypoint-ids";g="waypoint";m="waypoints";o=function(){function t(t){var e=this;this.$element=t;this.element=t[0];this.didResize=false;this.didScroll=false;this.id="context"+f++;this.oldScroll={x:t.scrollLeft(),y:t.scrollTop()};this.waypoints={horizontal:{},vertical:{}};t.data(u,this.id);a[this.id]=this;t.bind(y,function(){var t;if(!(e.didScroll||c)){e.didScroll=true;t=function(){e.doScroll();return e.didScroll=false};return r.setTimeout(t,n[m].settings.scrollThrottle)}});t.bind(p,function(){var t;if(!e.didResize){e.didResize=true;t=function(){n[m]("refresh");return e.didResize=false};return r.setTimeout(t,n[m].settings.resizeThrottle)}})}t.prototype.doScroll=function(){var t,e=this;t={horizontal:{newScroll:this.$element.scrollLeft(),oldScroll:this.oldScroll.x,forward:"right",backward:"left"},vertical:{newScroll:this.$element.scrollTop(),oldScroll:this.oldScroll.y,forward:"down",backward:"up"}};if(c&&(!t.vertical.oldScroll||!t.vertical.newScroll)){n[m]("refresh")}n.each(t,function(t,r){var i,o,l;l=[];o=r.newScroll>r.oldScroll;i=o?r.forward:r.backward;n.each(e.waypoints[t],function(t,e){var n,i;if(r.oldScroll<(n=e.offset)&&n<=r.newScroll){return l.push(e)}else if(r.newScroll<(i=e.offset)&&i<=r.oldScroll){return l.push(e)}});l.sort(function(t,e){return t.offset-e.offset});if(!o){l.reverse()}return n.each(l,function(t,e){if(e.options.continuous||t===l.length-1){return e.trigger([i])}})});return this.oldScroll={x:t.horizontal.newScroll,y:t.vertical.newScroll}};t.prototype.refresh=function(){var t,e,r,i=this;r=n.isWindow(this.element);e=this.$element.offset();this.doScroll();t={horizontal:{contextOffset:r?0:e.left,contextScroll:r?0:this.oldScroll.x,contextDimension:this.$element.width(),oldScroll:this.oldScroll.x,forward:"right",backward:"left",offsetProp:"left"},vertical:{contextOffset:r?0:e.top,contextScroll:r?0:this.oldScroll.y,contextDimension:r?n[m]("viewportHeight"):this.$element.height(),oldScroll:this.oldScroll.y,forward:"down",backward:"up",offsetProp:"top"}};return n.each(t,function(t,e){return n.each(i.waypoints[t],function(t,r){var i,o,l,s,f;i=r.options.offset;l=r.offset;o=n.isWindow(r.element)?0:r.$element.offset()[e.offsetProp];if(n.isFunction(i)){i=i.apply(r.element)}else if(typeof i==="string"){i=parseFloat(i);if(r.options.offset.indexOf("%")>-1){i=Math.ceil(e.contextDimension*i/100)}}r.offset=o-e.contextOffset+e.contextScroll-i;if(r.options.onlyOnScroll&&l!=null||!r.enabled){return}if(l!==null&&l<(s=e.oldScroll)&&s<=r.offset){return r.trigger([e.backward])}else if(l!==null&&l>(f=e.oldScroll)&&f>=r.offset){return r.trigger([e.forward])}else if(l===null&&e.oldScroll>=r.offset){return r.trigger([e.forward])}})})};t.prototype.checkEmpty=function(){if(n.isEmptyObject(this.waypoints.horizontal)&&n.isEmptyObject(this.waypoints.vertical)){this.$element.unbind([p,y].join(" "));return delete a[this.id]}};return t}();l=function(){function t(t,e,r){var i,o;r=n.extend({},n.fn[g].defaults,r);if(r.offset==="bottom-in-view"){r.offset=function(){var t;t=n[m]("viewportHeight");if(!n.isWindow(e.element)){t=e.$element.height()}return t-n(this).outerHeight()}}this.$element=t;this.element=t[0];this.axis=r.horizontal?"horizontal":"vertical";this.callback=r.handler;this.context=e;this.enabled=r.enabled;this.id="waypoints"+v++;this.offset=null;this.options=r;e.waypoints[this.axis][this.id]=this;s[this.axis][this.id]=this;i=(o=t.data(w))!=null?o:[];i.push(this.id);t.data(w,i)}t.prototype.trigger=function(t){if(!this.enabled){return}if(this.callback!=null){this.callback.apply(this.element,t)}if(this.options.triggerOnce){return this.destroy()}};t.prototype.disable=function(){return this.enabled=false};t.prototype.enable=function(){this.context.refresh();return this.enabled=true};t.prototype.destroy=function(){delete s[this.axis][this.id];delete this.context.waypoints[this.axis][this.id];return this.context.checkEmpty()};t.getWaypointsByElement=function(t){var e,r;r=n(t).data(w);if(!r){return[]}e=n.extend({},s.horizontal,s.vertical);return n.map(r,function(t){return e[t]})};return t}();d={init:function(t,e){var r;if(e==null){e={}}if((r=e.handler)==null){e.handler=t}this.each(function(){var t,r,i,s;t=n(this);i=(s=e.context)!=null?s:n.fn[g].defaults.context;if(!n.isWindow(i)){i=t.closest(i)}i=n(i);r=a[i.data(u)];if(!r){r=new o(i)}return new l(t,r,e)});n[m]("refresh");return this},disable:function(){return d._invoke(this,"disable")},enable:function(){return d._invoke(this,"enable")},destroy:function(){return d._invoke(this,"destroy")},prev:function(t,e){return d._traverse.call(this,t,e,function(t,e,n){if(e>0){return t.push(n[e-1])}})},next:function(t,e){return d._traverse.call(this,t,e,function(t,e,n){if(e<n.length-1){return t.push(n[e+1])}})},_traverse:function(t,e,i){var o,l;if(t==null){t="vertical"}if(e==null){e=r}l=h.aggregate(e);o=[];this.each(function(){var e;e=n.inArray(this,l[t]);return i(o,e,l[t])});return this.pushStack(o)},_invoke:function(t,e){t.each(function(){var t;t=l.getWaypointsByElement(this);return n.each(t,function(t,n){n[e]();return true})});return this}};n.fn[g]=function(){var t,r;r=arguments[0],t=2<=arguments.length?e.call(arguments,1):[];if(d[r]){return d[r].apply(this,t)}else if(n.isFunction(r)){return d.init.apply(this,arguments)}else if(n.isPlainObject(r)){return d.init.apply(this,[null,r])}else if(!r){return n.error("jQuery Waypoints needs a callback function or handler option.")}else{return n.error("The "+r+" method does not exist in jQuery Waypoints.")}};n.fn[g].defaults={context:r,continuous:true,enabled:true,horizontal:false,offset:0,triggerOnce:false};h={refresh:function(){return n.each(a,function(t,e){return e.refresh()})},viewportHeight:function(){var t;return(t=r.innerHeight)!=null?t:i.height()},aggregate:function(t){var e,r,i;e=s;if(t){e=(i=a[n(t).data(u)])!=null?i.waypoints:void 0}if(!e){return[]}r={horizontal:[],vertical:[]};n.each(r,function(t,i){n.each(e[t],function(t,e){return i.push(e)});i.sort(function(t,e){return t.offset-e.offset});r[t]=n.map(i,function(t){return t.element});return r[t]=n.unique(r[t])});return r},above:function(t){if(t==null){t=r}return h._filter(t,"vertical",function(t,e){return e.offset<=t.oldScroll.y})},below:function(t){if(t==null){t=r}return h._filter(t,"vertical",function(t,e){return e.offset>t.oldScroll.y})},left:function(t){if(t==null){t=r}return h._filter(t,"horizontal",function(t,e){return e.offset<=t.oldScroll.x})},right:function(t){if(t==null){t=r}return h._filter(t,"horizontal",function(t,e){return e.offset>t.oldScroll.x})},enable:function(){return h._invoke("enable")},disable:function(){return h._invoke("disable")},destroy:function(){return h._invoke("destroy")},extendFn:function(t,e){return d[t]=e},_invoke:function(t){var e;e=n.extend({},s.vertical,s.horizontal);return n.each(e,function(e,n){n[t]();return true})},_filter:function(t,e,r){var i,o;i=a[n(t).data(u)];if(!i){return[]}o=[];n.each(i.waypoints[e],function(t,e){if(r(i,e)){return o.push(e)}});o.sort(function(t,e){return t.offset-e.offset});return n.map(o,function(t){return t.element})}};n[m]=function(){var t,n;n=arguments[0],t=2<=arguments.length?e.call(arguments,1):[];if(h[n]){return h[n].apply(null,t)}else{return h.aggregate.call(null,n)}};n[m].settings={resizeThrottle:100,scrollThrottle:30};return i.load(function(){return n[m]("refresh")})})}).call(this);

/*!
* MediaElement.js
* HTML5 <video> and <audio> shim and player
* http://mediaelementjs.com/
*
* Creates a JavaScript object that mimics HTML5 MediaElement API
* for browsers that don't understand HTML5 or can't play the provided codec
* Can play MP4 (H.264), Ogg, WebM, FLV, WMV, WMA, ACC, and MP3
*
* Copyright 2010-2014, John Dyer (http://j.hn)
* License: MIT
*
*/var mejs=mejs||{};mejs.version="2.14.2";mejs.meIndex=0;
mejs.plugins={silverlight:[{version:[3,0],types:["video/mp4","video/m4v","video/mov","video/wmv","audio/wma","audio/m4a","audio/mp3","audio/wav","audio/mpeg"]}],flash:[{version:[9,0,124],types:["video/mp4","video/m4v","video/mov","video/flv","video/rtmp","video/x-flv","audio/flv","audio/x-flv","audio/mp3","audio/m4a","audio/mpeg","video/youtube","video/x-youtube"]}],youtube:[{version:null,types:["video/youtube","video/x-youtube","audio/youtube","audio/x-youtube"]}],vimeo:[{version:null,types:["video/vimeo",
"video/x-vimeo"]}]};
mejs.Utility={encodeUrl:function(a){return encodeURIComponent(a)},escapeHTML:function(a){return a.toString().split("&").join("&amp;").split("<").join("&lt;").split('"').join("&quot;")},absolutizeUrl:function(a){var b=document.createElement("div");b.innerHTML='<a href="'+this.escapeHTML(a)+'">x</a>';return b.firstChild.href},getScriptPath:function(a){for(var b=0,c,d="",e="",g,f,i=document.getElementsByTagName("script"),k=i.length,h=a.length;b<k;b++){g=i[b].src;c=g.lastIndexOf("/");if(c>-1){f=g.substring(c+
1);g=g.substring(0,c+1)}else{f=g;g=""}for(c=0;c<h;c++){e=a[c];e=f.indexOf(e);if(e>-1){d=g;break}}if(d!=="")break}return d},secondsToTimeCode:function(a,b,c,d){if(typeof c=="undefined")c=false;else if(typeof d=="undefined")d=25;var e=Math.floor(a/3600)%24,g=Math.floor(a/60)%60,f=Math.floor(a%60);a=Math.floor((a%1*d).toFixed(3));return(b||e>0?(e<10?"0"+e:e)+":":"")+(g<10?"0"+g:g)+":"+(f<10?"0"+f:f)+(c?":"+(a<10?"0"+a:a):"")},timeCodeToSeconds:function(a,b,c,d){if(typeof c=="undefined")c=false;else if(typeof d==
"undefined")d=25;a=a.split(":");b=parseInt(a[0],10);var e=parseInt(a[1],10),g=parseInt(a[2],10),f=0,i=0;if(c)f=parseInt(a[3])/d;return i=b*3600+e*60+g+f},convertSMPTEtoSeconds:function(a){if(typeof a!="string")return false;a=a.replace(",",".");var b=0,c=a.indexOf(".")!=-1?a.split(".")[1].length:0,d=1;a=a.split(":").reverse();for(var e=0;e<a.length;e++){d=1;if(e>0)d=Math.pow(60,e);b+=Number(a[e])*d}return Number(b.toFixed(c))},removeSwf:function(a){var b=document.getElementById(a);if(b&&/object|embed/i.test(b.nodeName))if(mejs.MediaFeatures.isIE){b.style.display=
"none";(function(){b.readyState==4?mejs.Utility.removeObjectInIE(a):setTimeout(arguments.callee,10)})()}else b.parentNode.removeChild(b)},removeObjectInIE:function(a){if(a=document.getElementById(a)){for(var b in a)if(typeof a[b]=="function")a[b]=null;a.parentNode.removeChild(a)}}};
mejs.PluginDetector={hasPluginVersion:function(a,b){var c=this.plugins[a];b[1]=b[1]||0;b[2]=b[2]||0;return c[0]>b[0]||c[0]==b[0]&&c[1]>b[1]||c[0]==b[0]&&c[1]==b[1]&&c[2]>=b[2]?true:false},nav:window.navigator,ua:window.navigator.userAgent.toLowerCase(),plugins:[],addPlugin:function(a,b,c,d,e){this.plugins[a]=this.detectPlugin(b,c,d,e)},detectPlugin:function(a,b,c,d){var e=[0,0,0],g;if(typeof this.nav.plugins!="undefined"&&typeof this.nav.plugins[a]=="object"){if((c=this.nav.plugins[a].description)&&
!(typeof this.nav.mimeTypes!="undefined"&&this.nav.mimeTypes[b]&&!this.nav.mimeTypes[b].enabledPlugin)){e=c.replace(a,"").replace(/^\s+/,"").replace(/\sr/gi,".").split(".");for(a=0;a<e.length;a++)e[a]=parseInt(e[a].match(/\d+/),10)}}else if(typeof window.ActiveXObject!="undefined")try{if(g=new ActiveXObject(c))e=d(g)}catch(f){}return e}};
mejs.PluginDetector.addPlugin("flash","Shockwave Flash","application/x-shockwave-flash","ShockwaveFlash.ShockwaveFlash",function(a){var b=[];if(a=a.GetVariable("$version")){a=a.split(" ")[1].split(",");b=[parseInt(a[0],10),parseInt(a[1],10),parseInt(a[2],10)]}return b});
mejs.PluginDetector.addPlugin("silverlight","Silverlight Plug-In","application/x-silverlight-2","AgControl.AgControl",function(a){var b=[0,0,0,0],c=function(d,e,g,f){for(;d.isVersionSupported(e[0]+"."+e[1]+"."+e[2]+"."+e[3]);)e[g]+=f;e[g]-=f};c(a,b,0,1);c(a,b,1,1);c(a,b,2,1E4);c(a,b,2,1E3);c(a,b,2,100);c(a,b,2,10);c(a,b,2,1);c(a,b,3,1);return b});
mejs.MediaFeatures={init:function(){var a=this,b=document,c=mejs.PluginDetector.nav,d=mejs.PluginDetector.ua.toLowerCase(),e,g=["source","track","audio","video"];a.isiPad=d.match(/ipad/i)!==null;a.isiPhone=d.match(/iphone/i)!==null;a.isiOS=a.isiPhone||a.isiPad;a.isAndroid=d.match(/android/i)!==null;a.isBustedAndroid=d.match(/android 2\.[12]/)!==null;a.isBustedNativeHTTPS=location.protocol==="https:"&&(d.match(/android [12]\./)!==null||d.match(/macintosh.* version.* safari/)!==null);a.isIE=c.appName.toLowerCase().indexOf("microsoft")!=
-1||c.appName.toLowerCase().match(/trident/gi)!==null;a.isChrome=d.match(/chrome/gi)!==null;a.isFirefox=d.match(/firefox/gi)!==null;a.isWebkit=d.match(/webkit/gi)!==null;a.isGecko=d.match(/gecko/gi)!==null&&!a.isWebkit&&!a.isIE;a.isOpera=d.match(/opera/gi)!==null;a.hasTouch="ontouchstart"in window;a.svg=!!document.createElementNS&&!!document.createElementNS("http://www.w3.org/2000/svg","svg").createSVGRect;for(c=0;c<g.length;c++)e=document.createElement(g[c]);a.supportsMediaTag=typeof e.canPlayType!==
"undefined"||a.isBustedAndroid;try{e.canPlayType("video/mp4")}catch(f){a.supportsMediaTag=false}a.hasSemiNativeFullScreen=typeof e.webkitEnterFullscreen!=="undefined";a.hasNativeFullscreen=typeof e.requestFullscreen!=="undefined";a.hasWebkitNativeFullScreen=typeof e.webkitRequestFullScreen!=="undefined";a.hasMozNativeFullScreen=typeof e.mozRequestFullScreen!=="undefined";a.hasMsNativeFullScreen=typeof e.msRequestFullscreen!=="undefined";a.hasTrueNativeFullScreen=a.hasWebkitNativeFullScreen||a.hasMozNativeFullScreen||
a.hasMsNativeFullScreen;a.nativeFullScreenEnabled=a.hasTrueNativeFullScreen;if(a.hasMozNativeFullScreen)a.nativeFullScreenEnabled=document.mozFullScreenEnabled;else if(a.hasMsNativeFullScreen)a.nativeFullScreenEnabled=document.msFullscreenEnabled;if(a.isChrome)a.hasSemiNativeFullScreen=false;if(a.hasTrueNativeFullScreen){a.fullScreenEventName="";if(a.hasWebkitNativeFullScreen)a.fullScreenEventName="webkitfullscreenchange";else if(a.hasMozNativeFullScreen)a.fullScreenEventName="mozfullscreenchange";
else if(a.hasMsNativeFullScreen)a.fullScreenEventName="MSFullscreenChange";a.isFullScreen=function(){if(e.mozRequestFullScreen)return b.mozFullScreen;else if(e.webkitRequestFullScreen)return b.webkitIsFullScreen;else if(e.hasMsNativeFullScreen)return b.msFullscreenElement!==null};a.requestFullScreen=function(i){if(a.hasWebkitNativeFullScreen)i.webkitRequestFullScreen();else if(a.hasMozNativeFullScreen)i.mozRequestFullScreen();else a.hasMsNativeFullScreen&&i.msRequestFullscreen()};a.cancelFullScreen=
function(){if(a.hasWebkitNativeFullScreen)document.webkitCancelFullScreen();else if(a.hasMozNativeFullScreen)document.mozCancelFullScreen();else a.hasMsNativeFullScreen&&document.msExitFullscreen()}}if(a.hasSemiNativeFullScreen&&d.match(/mac os x 10_5/i)){a.hasNativeFullScreen=false;a.hasSemiNativeFullScreen=false}}};mejs.MediaFeatures.init();
mejs.HtmlMediaElement={pluginType:"native",isFullScreen:false,setCurrentTime:function(a){this.currentTime=a},setMuted:function(a){this.muted=a},setVolume:function(a){this.volume=a},stop:function(){this.pause()},setSrc:function(a){for(var b=this.getElementsByTagName("source");b.length>0;)this.removeChild(b[0]);if(typeof a=="string")this.src=a;else{var c;for(b=0;b<a.length;b++){c=a[b];if(this.canPlayType(c.type)){this.src=c.src;break}}}},setVideoSize:function(a,b){this.width=a;this.height=b}};
mejs.PluginMediaElement=function(a,b,c){this.id=a;this.pluginType=b;this.src=c;this.events={};this.attributes={}};
mejs.PluginMediaElement.prototype={pluginElement:null,pluginType:"",isFullScreen:false,playbackRate:-1,defaultPlaybackRate:-1,seekable:[],played:[],paused:true,ended:false,seeking:false,duration:0,error:null,tagName:"",muted:false,volume:1,currentTime:0,play:function(){if(this.pluginApi!=null){this.pluginType=="youtube"||this.pluginType=="vimeo"?this.pluginApi.playVideo():this.pluginApi.playMedia();this.paused=false}},load:function(){if(this.pluginApi!=null){this.pluginType=="youtube"||this.pluginType==
"vimeo"||this.pluginApi.loadMedia();this.paused=false}},pause:function(){if(this.pluginApi!=null){this.pluginType=="youtube"||this.pluginType=="vimeo"?this.pluginApi.pauseVideo():this.pluginApi.pauseMedia();this.paused=true}},stop:function(){if(this.pluginApi!=null){this.pluginType=="youtube"||this.pluginType=="vimeo"?this.pluginApi.stopVideo():this.pluginApi.stopMedia();this.paused=true}},canPlayType:function(a){var b,c,d,e=mejs.plugins[this.pluginType];for(b=0;b<e.length;b++){d=e[b];if(mejs.PluginDetector.hasPluginVersion(this.pluginType,
d.version))for(c=0;c<d.types.length;c++)if(a==d.types[c])return"probably"}return""},positionFullscreenButton:function(a,b,c){this.pluginApi!=null&&this.pluginApi.positionFullscreenButton&&this.pluginApi.positionFullscreenButton(Math.floor(a),Math.floor(b),c)},hideFullscreenButton:function(){this.pluginApi!=null&&this.pluginApi.hideFullscreenButton&&this.pluginApi.hideFullscreenButton()},setSrc:function(a){if(typeof a=="string"){this.pluginApi.setSrc(mejs.Utility.absolutizeUrl(a));this.src=mejs.Utility.absolutizeUrl(a)}else{var b,
c;for(b=0;b<a.length;b++){c=a[b];if(this.canPlayType(c.type)){this.pluginApi.setSrc(mejs.Utility.absolutizeUrl(c.src));this.src=mejs.Utility.absolutizeUrl(a);break}}}},setCurrentTime:function(a){if(this.pluginApi!=null){this.pluginType=="youtube"||this.pluginType=="vimeo"?this.pluginApi.seekTo(a):this.pluginApi.setCurrentTime(a);this.currentTime=a}},setVolume:function(a){if(this.pluginApi!=null){this.pluginType=="youtube"||this.pluginType=="vimeo"?this.pluginApi.setVolume(a*100):this.pluginApi.setVolume(a);
this.volume=a}},setMuted:function(a){if(this.pluginApi!=null){if(this.pluginType=="youtube"||this.pluginType=="vimeo"){a?this.pluginApi.mute():this.pluginApi.unMute();this.muted=a;this.dispatchEvent("volumechange")}else this.pluginApi.setMuted(a);this.muted=a}},setVideoSize:function(a,b){if(this.pluginElement.style){this.pluginElement.style.width=a+"px";this.pluginElement.style.height=b+"px"}this.pluginApi!=null&&this.pluginApi.setVideoSize&&this.pluginApi.setVideoSize(a,b)},setFullscreen:function(a){this.pluginApi!=
null&&this.pluginApi.setFullscreen&&this.pluginApi.setFullscreen(a)},enterFullScreen:function(){this.pluginApi!=null&&this.pluginApi.setFullscreen&&this.setFullscreen(true)},exitFullScreen:function(){this.pluginApi!=null&&this.pluginApi.setFullscreen&&this.setFullscreen(false)},addEventListener:function(a,b){this.events[a]=this.events[a]||[];this.events[a].push(b)},removeEventListener:function(a,b){if(!a){this.events={};return true}var c=this.events[a];if(!c)return true;if(!b){this.events[a]=[];return true}for(var d=
0;d<c.length;d++)if(c[d]===b){this.events[a].splice(d,1);return true}return false},dispatchEvent:function(a){var b,c,d=this.events[a];if(d){c=Array.prototype.slice.call(arguments,1);for(b=0;b<d.length;b++)d[b].apply(null,c)}},hasAttribute:function(a){return a in this.attributes},removeAttribute:function(a){delete this.attributes[a]},getAttribute:function(a){if(this.hasAttribute(a))return this.attributes[a];return""},setAttribute:function(a,b){this.attributes[a]=b},remove:function(){mejs.Utility.removeSwf(this.pluginElement.id);
mejs.MediaPluginBridge.unregisterPluginElement(this.pluginElement.id)}};
mejs.MediaPluginBridge={pluginMediaElements:{},htmlMediaElements:{},registerPluginElement:function(a,b,c){this.pluginMediaElements[a]=b;this.htmlMediaElements[a]=c},unregisterPluginElement:function(a){delete this.pluginMediaElements[a];delete this.htmlMediaElements[a]},initPlugin:function(a){var b=this.pluginMediaElements[a],c=this.htmlMediaElements[a];if(b){switch(b.pluginType){case "flash":b.pluginElement=b.pluginApi=document.getElementById(a);break;case "silverlight":b.pluginElement=document.getElementById(b.id);
b.pluginApi=b.pluginElement.Content.MediaElementJS}b.pluginApi!=null&&b.success&&b.success(b,c)}},fireEvent:function(a,b,c){var d,e;if(a=this.pluginMediaElements[a]){b={type:b,target:a};for(d in c){a[d]=c[d];b[d]=c[d]}e=c.bufferedTime||0;b.target.buffered=b.buffered={start:function(){return 0},end:function(){return e},length:1};a.dispatchEvent(b.type,b)}}};
mejs.MediaElementDefaults={mode:"auto",plugins:["flash","silverlight","youtube","vimeo"],enablePluginDebug:false,httpsBasicAuthSite:false,type:"",pluginPath:mejs.Utility.getScriptPath(["mediaelement.js","mediaelement.min.js","mediaelement-and-player.js","mediaelement-and-player.min.js"]),flashName:"flashmediaelement.swf",flashStreamer:"",enablePluginSmoothing:false,enablePseudoStreaming:false,pseudoStreamingStartQueryParam:"start",silverlightName:"silverlightmediaelement.xap",defaultVideoWidth:480,
defaultVideoHeight:270,pluginWidth:-1,pluginHeight:-1,pluginVars:[],timerRate:250,startVolume:0.8,success:function(){},error:function(){}};mejs.MediaElement=function(a,b){return mejs.HtmlMediaElementShim.create(a,b)};
mejs.HtmlMediaElementShim={create:function(a,b){var c=mejs.MediaElementDefaults,d=typeof a=="string"?document.getElementById(a):a,e=d.tagName.toLowerCase(),g=e==="audio"||e==="video",f=g?d.getAttribute("src"):d.getAttribute("href");e=d.getAttribute("poster");var i=d.getAttribute("autoplay"),k=d.getAttribute("preload"),h=d.getAttribute("controls"),j;for(j in b)c[j]=b[j];f=typeof f=="undefined"||f===null||f==""?null:f;e=typeof e=="undefined"||e===null?"":e;k=typeof k=="undefined"||k===null||k==="false"?
"none":k;i=!(typeof i=="undefined"||i===null||i==="false");h=!(typeof h=="undefined"||h===null||h==="false");j=this.determinePlayback(d,c,mejs.MediaFeatures.supportsMediaTag,g,f);j.url=j.url!==null?mejs.Utility.absolutizeUrl(j.url):"";if(j.method=="native"){if(mejs.MediaFeatures.isBustedAndroid){d.src=j.url;d.addEventListener("click",function(){d.play()},false)}return this.updateNative(j,c,i,k)}else if(j.method!=="")return this.createPlugin(j,c,e,i,k,h);else{this.createErrorMessage(j,c,e);return this}},
determinePlayback:function(a,b,c,d,e){var g=[],f,i,k,h={method:"",url:"",htmlMediaElement:a,isVideo:a.tagName.toLowerCase()!="audio"},j;if(typeof b.type!="undefined"&&b.type!=="")if(typeof b.type=="string")g.push({type:b.type,url:e});else for(f=0;f<b.type.length;f++)g.push({type:b.type[f],url:e});else if(e!==null){k=this.formatType(e,a.getAttribute("type"));g.push({type:k,url:e})}else for(f=0;f<a.childNodes.length;f++){i=a.childNodes[f];if(i.nodeType==1&&i.tagName.toLowerCase()=="source"){e=i.getAttribute("src");
k=this.formatType(e,i.getAttribute("type"));i=i.getAttribute("media");if(!i||!window.matchMedia||window.matchMedia&&window.matchMedia(i).matches)g.push({type:k,url:e})}}if(!d&&g.length>0&&g[0].url!==null&&this.getTypeFromFile(g[0].url).indexOf("audio")>-1)h.isVideo=false;if(mejs.MediaFeatures.isBustedAndroid)a.canPlayType=function(m){return m.match(/video\/(mp4|m4v)/gi)!==null?"maybe":""};if(c&&(b.mode==="auto"||b.mode==="auto_plugin"||b.mode==="native")&&!(mejs.MediaFeatures.isBustedNativeHTTPS&&
b.httpsBasicAuthSite===true)){if(!d){f=document.createElement(h.isVideo?"video":"audio");a.parentNode.insertBefore(f,a);a.style.display="none";h.htmlMediaElement=a=f}for(f=0;f<g.length;f++)if(a.canPlayType(g[f].type).replace(/no/,"")!==""||a.canPlayType(g[f].type.replace(/mp3/,"mpeg")).replace(/no/,"")!==""||a.canPlayType(g[f].type.replace(/m4a/,"mp4")).replace(/no/,"")!==""){h.method="native";h.url=g[f].url;break}if(h.method==="native"){if(h.url!==null)a.src=h.url;if(b.mode!=="auto_plugin")return h}}if(b.mode===
"auto"||b.mode==="auto_plugin"||b.mode==="shim")for(f=0;f<g.length;f++){k=g[f].type;for(a=0;a<b.plugins.length;a++){e=b.plugins[a];i=mejs.plugins[e];for(c=0;c<i.length;c++){j=i[c];if(j.version==null||mejs.PluginDetector.hasPluginVersion(e,j.version))for(d=0;d<j.types.length;d++)if(k==j.types[d]){h.method=e;h.url=g[f].url;return h}}}}if(b.mode==="auto_plugin"&&h.method==="native")return h;if(h.method===""&&g.length>0)h.url=g[0].url;return h},formatType:function(a,b){return a&&!b?this.getTypeFromFile(a):
b&&~b.indexOf(";")?b.substr(0,b.indexOf(";")):b},getTypeFromFile:function(a){a=a.split("?")[0];a=a.substring(a.lastIndexOf(".")+1).toLowerCase();return(/(mp4|m4v|ogg|ogv|webm|webmv|flv|wmv|mpeg|mov)/gi.test(a)?"video":"audio")+"/"+this.getTypeFromExtension(a)},getTypeFromExtension:function(a){switch(a){case "mp4":case "m4v":case "m4a":return"mp4";case "webm":case "webma":case "webmv":return"webm";case "ogg":case "oga":case "ogv":return"ogg";default:return a}},createErrorMessage:function(a,b,c){var d=
a.htmlMediaElement,e=document.createElement("div");e.className="me-cannotplay";try{e.style.width=d.width+"px";e.style.height=d.height+"px"}catch(g){}e.innerHTML=b.customError?b.customError:c!==""?'<a href="'+a.url+'"><img src="'+c+'" width="100%" height="100%" /></a>':'<a href="'+a.url+'"><span>'+mejs.i18n.t("Download File")+"</span></a>";d.parentNode.insertBefore(e,d);d.style.display="none";b.error(d)},createPlugin:function(a,b,c,d,e,g){c=a.htmlMediaElement;var f=1,i=1,k="me_"+a.method+"_"+mejs.meIndex++,
h=new mejs.PluginMediaElement(k,a.method,a.url),j=document.createElement("div"),m;h.tagName=c.tagName;for(m=0;m<c.attributes.length;m++){var q=c.attributes[m];q.specified==true&&h.setAttribute(q.name,q.value)}for(m=c.parentNode;m!==null&&m.tagName.toLowerCase()!=="body"&&m.parentNode!=null;){if(m.parentNode.tagName.toLowerCase()==="p"){m.parentNode.parentNode.insertBefore(m,m.parentNode);break}m=m.parentNode}if(a.isVideo){f=b.pluginWidth>0?b.pluginWidth:b.videoWidth>0?b.videoWidth:c.getAttribute("width")!==
null?c.getAttribute("width"):b.defaultVideoWidth;i=b.pluginHeight>0?b.pluginHeight:b.videoHeight>0?b.videoHeight:c.getAttribute("height")!==null?c.getAttribute("height"):b.defaultVideoHeight;f=mejs.Utility.encodeUrl(f);i=mejs.Utility.encodeUrl(i)}else if(b.enablePluginDebug){f=320;i=240}h.success=b.success;mejs.MediaPluginBridge.registerPluginElement(k,h,c);j.className="me-plugin";j.id=k+"_container";a.isVideo?c.parentNode.insertBefore(j,c):document.body.insertBefore(j,document.body.childNodes[0]);
d=["id="+k,"isvideo="+(a.isVideo?"true":"false"),"autoplay="+(d?"true":"false"),"preload="+e,"width="+f,"startvolume="+b.startVolume,"timerrate="+b.timerRate,"flashstreamer="+b.flashStreamer,"height="+i,"pseudostreamstart="+b.pseudoStreamingStartQueryParam];if(a.url!==null)a.method=="flash"?d.push("file="+mejs.Utility.encodeUrl(a.url)):d.push("file="+a.url);b.enablePluginDebug&&d.push("debug=true");b.enablePluginSmoothing&&d.push("smoothing=true");b.enablePseudoStreaming&&d.push("pseudostreaming=true");
g&&d.push("controls=true");if(b.pluginVars)d=d.concat(b.pluginVars);switch(a.method){case "silverlight":j.innerHTML='<object data="data:application/x-silverlight-2," type="application/x-silverlight-2" id="'+k+'" name="'+k+'" width="'+f+'" height="'+i+'" class="mejs-shim"><param name="initParams" value="'+d.join(",")+'" /><param name="windowless" value="true" /><param name="background" value="black" /><param name="minRuntimeVersion" value="3.0.0.0" /><param name="autoUpgrade" value="true" /><param name="source" value="'+
b.pluginPath+b.silverlightName+'" /></object>';break;case "flash":if(mejs.MediaFeatures.isIE){a=document.createElement("div");j.appendChild(a);a.outerHTML='<object classid="clsid:D27CDB6E-AE6D-11cf-96B8-444553540000" codebase="//download.macromedia.com/pub/shockwave/cabs/flash/swflash.cab" id="'+k+'" width="'+f+'" height="'+i+'" class="mejs-shim"><param name="movie" value="'+b.pluginPath+b.flashName+"?x="+new Date+'" /><param name="flashvars" value="'+d.join("&amp;")+'" /><param name="quality" value="high" /><param name="bgcolor" value="#000000" /><param name="wmode" value="transparent" /><param name="allowScriptAccess" value="always" /><param name="allowFullScreen" value="true" /><param name="scale" value="default" /></object>'}else j.innerHTML=
'<embed id="'+k+'" name="'+k+'" play="true" loop="false" quality="high" bgcolor="#000000" wmode="transparent" allowScriptAccess="always" allowFullScreen="true" type="application/x-shockwave-flash" pluginspage="//www.macromedia.com/go/getflashplayer" src="'+b.pluginPath+b.flashName+'" flashvars="'+d.join("&")+'" width="'+f+'" height="'+i+'" scale="default"class="mejs-shim"></embed>';break;case "youtube":if(a.url.lastIndexOf("youtu.be")!=-1){a=a.url.substr(a.url.lastIndexOf("/")+1);if(a.indexOf("?")!=
-1)a=a.substr(0,a.indexOf("?"))}else a=a.url.substr(a.url.lastIndexOf("=")+1);youtubeSettings={container:j,containerId:j.id,pluginMediaElement:h,pluginId:k,videoId:a,height:i,width:f};mejs.PluginDetector.hasPluginVersion("flash",[10,0,0])?mejs.YouTubeApi.createFlash(youtubeSettings):mejs.YouTubeApi.enqueueIframe(youtubeSettings);break;case "vimeo":b=k+"_player";h.vimeoid=a.url.substr(a.url.lastIndexOf("/")+1);j.innerHTML='<iframe src="//player.vimeo.com/video/'+h.vimeoid+"?api=1&portrait=0&byline=0&title=0&player_id="+
b+'" width="'+f+'" height="'+i+'" frameborder="0" class="mejs-shim" id="'+b+'"></iframe>';if(typeof $f=="function"){var l=$f(j.childNodes[0]);l.addEvent("ready",function(){function o(n,p,r,s){n={type:r,target:p};if(r=="timeupdate"){p.currentTime=n.currentTime=s.seconds;p.duration=n.duration=s.duration}p.dispatchEvent(n.type,n)}l.playVideo=function(){l.api("play")};l.pauseVideo=function(){l.api("pause")};l.seekTo=function(n){l.api("seekTo",n)};l.addEvent("play",function(){o(l,h,"play");o(l,h,"playing")});
l.addEvent("pause",function(){o(l,h,"pause")});l.addEvent("finish",function(){o(l,h,"ended")});l.addEvent("playProgress",function(n){o(l,h,"timeupdate",n)});h.pluginApi=l;mejs.MediaPluginBridge.initPlugin(k)})}else console.warn("You need to include froogaloop for vimeo to work")}c.style.display="none";c.removeAttribute("autoplay");return h},updateNative:function(a,b){var c=a.htmlMediaElement,d;for(d in mejs.HtmlMediaElement)c[d]=mejs.HtmlMediaElement[d];b.success(c,c);return c}};
mejs.YouTubeApi={isIframeStarted:false,isIframeLoaded:false,loadIframeApi:function(){if(!this.isIframeStarted){var a=document.createElement("script");a.src="//www.youtube.com/player_api";var b=document.getElementsByTagName("script")[0];b.parentNode.insertBefore(a,b);this.isIframeStarted=true}},iframeQueue:[],enqueueIframe:function(a){if(this.isLoaded)this.createIframe(a);else{this.loadIframeApi();this.iframeQueue.push(a)}},createIframe:function(a){var b=a.pluginMediaElement,c=new YT.Player(a.containerId,
{height:a.height,width:a.width,videoId:a.videoId,playerVars:{controls:0},events:{onReady:function(){a.pluginMediaElement.pluginApi=c;mejs.MediaPluginBridge.initPlugin(a.pluginId);setInterval(function(){mejs.YouTubeApi.createEvent(c,b,"timeupdate")},250)},onStateChange:function(d){mejs.YouTubeApi.handleStateChange(d.data,c,b)}}})},createEvent:function(a,b,c){c={type:c,target:b};if(a&&a.getDuration){b.currentTime=c.currentTime=a.getCurrentTime();b.duration=c.duration=a.getDuration();c.paused=b.paused;
c.ended=b.ended;c.muted=a.isMuted();c.volume=a.getVolume()/100;c.bytesTotal=a.getVideoBytesTotal();c.bufferedBytes=a.getVideoBytesLoaded();var d=c.bufferedBytes/c.bytesTotal*c.duration;c.target.buffered=c.buffered={start:function(){return 0},end:function(){return d},length:1}}b.dispatchEvent(c.type,c)},iFrameReady:function(){for(this.isIframeLoaded=this.isLoaded=true;this.iframeQueue.length>0;)this.createIframe(this.iframeQueue.pop())},flashPlayers:{},createFlash:function(a){this.flashPlayers[a.pluginId]=
a;var b,c="//www.youtube.com/apiplayer?enablejsapi=1&amp;playerapiid="+a.pluginId+"&amp;version=3&amp;autoplay=0&amp;controls=0&amp;modestbranding=1&loop=0";if(mejs.MediaFeatures.isIE){b=document.createElement("div");a.container.appendChild(b);b.outerHTML='<object classid="clsid:D27CDB6E-AE6D-11cf-96B8-444553540000" codebase="//download.macromedia.com/pub/shockwave/cabs/flash/swflash.cab" id="'+a.pluginId+'" width="'+a.width+'" height="'+a.height+'" class="mejs-shim"><param name="movie" value="'+
c+'" /><param name="wmode" value="transparent" /><param name="allowScriptAccess" value="always" /><param name="allowFullScreen" value="true" /></object>'}else a.container.innerHTML='<object type="application/x-shockwave-flash" id="'+a.pluginId+'" data="'+c+'" width="'+a.width+'" height="'+a.height+'" style="visibility: visible; " class="mejs-shim"><param name="allowScriptAccess" value="always"><param name="wmode" value="transparent"></object>'},flashReady:function(a){var b=this.flashPlayers[a],c=
document.getElementById(a),d=b.pluginMediaElement;d.pluginApi=d.pluginElement=c;mejs.MediaPluginBridge.initPlugin(a);c.cueVideoById(b.videoId);a=b.containerId+"_callback";window[a]=function(e){mejs.YouTubeApi.handleStateChange(e,c,d)};c.addEventListener("onStateChange",a);setInterval(function(){mejs.YouTubeApi.createEvent(c,d,"timeupdate")},250)},handleStateChange:function(a,b,c){switch(a){case -1:c.paused=true;c.ended=true;mejs.YouTubeApi.createEvent(b,c,"loadedmetadata");break;case 0:c.paused=false;
c.ended=true;mejs.YouTubeApi.createEvent(b,c,"ended");break;case 1:c.paused=false;c.ended=false;mejs.YouTubeApi.createEvent(b,c,"play");mejs.YouTubeApi.createEvent(b,c,"playing");break;case 2:c.paused=true;c.ended=false;mejs.YouTubeApi.createEvent(b,c,"pause");break;case 3:mejs.YouTubeApi.createEvent(b,c,"progress")}}};function onYouTubePlayerAPIReady(){mejs.YouTubeApi.iFrameReady()}function onYouTubePlayerReady(a){mejs.YouTubeApi.flashReady(a)}window.mejs=mejs;window.MediaElement=mejs.MediaElement;
(function(a,b){var c={locale:{language:"",strings:{}},methods:{}};c.getLanguage=function(){return(c.locale.language||window.navigator.userLanguage||window.navigator.language).substr(0,2).toLowerCase()};if(typeof mejsL10n!="undefined")c.locale.language=mejsL10n.language;c.methods.checkPlain=function(d){var e,g,f={"&":"&amp;",'"':"&quot;","<":"&lt;",">":"&gt;"};d=String(d);for(e in f)if(f.hasOwnProperty(e)){g=RegExp(e,"g");d=d.replace(g,f[e])}return d};c.methods.t=function(d,e){if(c.locale.strings&&
c.locale.strings[e.context]&&c.locale.strings[e.context][d])d=c.locale.strings[e.context][d];return c.methods.checkPlain(d)};c.t=function(d,e){if(typeof d==="string"&&d.length>0){var g=c.getLanguage();e=e||{context:g};return c.methods.t(d,e)}else throw{name:"InvalidArgumentException",message:"First argument is either not a string or empty."};};b.i18n=c})(document,mejs);(function(a){if(typeof mejsL10n!="undefined")a[mejsL10n.language]=mejsL10n.strings})(mejs.i18n.locale.strings);
(function(a){if(typeof a.de==="undefined")a.de={Fullscreen:"Vollbild","Go Fullscreen":"Vollbild an","Turn off Fullscreen":"Vollbild aus",Close:"Schlie\u00dfen"}})(mejs.i18n.locale.strings);(function(a){if(typeof a.zh==="undefined")a.zh={Fullscreen:"\u5168\u87a2\u5e55","Go Fullscreen":"\u5168\u5c4f\u6a21\u5f0f","Turn off Fullscreen":"\u9000\u51fa\u5168\u5c4f\u6a21\u5f0f",Close:"\u95dc\u9589"}})(mejs.i18n.locale.strings);

/*!
 * MediaElementPlayer
 * http://mediaelementjs.com/
 *
 * Creates a controller bar for HTML5 <video> add <audio> tags
 * using jQuery and MediaElement.js (HTML5 Flash/Silverlight wrapper)
 *
 * Copyright 2010-2013, John Dyer (http://j.hn/)
 * License: MIT
 *
 */if(typeof jQuery!="undefined")mejs.$=jQuery;else if(typeof ender!="undefined")mejs.$=ender;
(function(f){mejs.MepDefaults={poster:"",showPosterWhenEnded:false,defaultVideoWidth:480,defaultVideoHeight:270,videoWidth:-1,videoHeight:-1,defaultAudioWidth:400,defaultAudioHeight:30,defaultSeekBackwardInterval:function(a){return a.duration*0.05},defaultSeekForwardInterval:function(a){return a.duration*0.05},audioWidth:-1,audioHeight:-1,startVolume:0.8,loop:false,autoRewind:true,enableAutosize:true,alwaysShowHours:false,showTimecodeFrameCount:false,framesPerSecond:25,autosizeProgress:true,alwaysShowControls:false,
hideVideoControlsOnLoad:false,clickToPlayPause:true,iPadUseNativeControls:false,iPhoneUseNativeControls:false,AndroidUseNativeControls:false,features:["playpause","current","progress","duration","tracks","volume","fullscreen"],isVideo:true,enableKeyboard:true,pauseOtherPlayers:true,keyActions:[{keys:[32,179],action:function(a,b){b.paused||b.ended?a.play():a.pause()}},{keys:[38],action:function(a,b){b.setVolume(Math.min(b.volume+0.1,1))}},{keys:[40],action:function(a,b){b.setVolume(Math.max(b.volume-
0.1,0))}},{keys:[37,227],action:function(a,b){if(!isNaN(b.duration)&&b.duration>0){if(a.isVideo){a.showControls();a.startControlsTimer()}var c=Math.max(b.currentTime-a.options.defaultSeekBackwardInterval(b),0);b.setCurrentTime(c)}}},{keys:[39,228],action:function(a,b){if(!isNaN(b.duration)&&b.duration>0){if(a.isVideo){a.showControls();a.startControlsTimer()}var c=Math.min(b.currentTime+a.options.defaultSeekForwardInterval(b),b.duration);b.setCurrentTime(c)}}},{keys:[70],action:function(a){if(typeof a.enterFullScreen!=
"undefined")a.isFullScreen?a.exitFullScreen():a.enterFullScreen()}}]};mejs.mepIndex=0;mejs.players={};mejs.MediaElementPlayer=function(a,b){if(!(this instanceof mejs.MediaElementPlayer))return new mejs.MediaElementPlayer(a,b);this.$media=this.$node=f(a);this.node=this.media=this.$media[0];if(typeof this.node.player!="undefined")return this.node.player;else this.node.player=this;if(typeof b=="undefined")b=this.$node.data("mejsoptions");this.options=f.extend({},mejs.MepDefaults,b);this.id="mep_"+mejs.mepIndex++;
mejs.players[this.id]=this;this.init();return this};mejs.MediaElementPlayer.prototype={hasFocus:false,controlsAreVisible:true,init:function(){var a=this,b=mejs.MediaFeatures,c=f.extend(true,{},a.options,{success:function(d,g){a.meReady(d,g)},error:function(d){a.handleError(d)}}),e=a.media.tagName.toLowerCase();a.isDynamic=e!=="audio"&&e!=="video";a.isVideo=a.isDynamic?a.options.isVideo:e!=="audio"&&a.options.isVideo;if(b.isiPad&&a.options.iPadUseNativeControls||b.isiPhone&&a.options.iPhoneUseNativeControls){a.$media.attr("controls",
"controls");b.isiPad&&a.media.getAttribute("autoplay")!==null&&a.play()}else if(!(b.isAndroid&&a.options.AndroidUseNativeControls)){a.$media.removeAttr("controls");a.container=f('<div id="'+a.id+'" class="mejs-container '+(mejs.MediaFeatures.svg?"svg":"no-svg")+'"><div class="mejs-inner"><div class="mejs-mediaelement"></div><div class="mejs-layers"></div><div class="mejs-controls"></div><div class="mejs-clear"></div></div></div>').addClass(a.$media[0].className).insertBefore(a.$media);a.container.addClass((b.isAndroid?
"mejs-android ":"")+(b.isiOS?"mejs-ios ":"")+(b.isiPad?"mejs-ipad ":"")+(b.isiPhone?"mejs-iphone ":"")+(a.isVideo?"mejs-video ":"mejs-audio "));if(b.isiOS){b=a.$media.clone();a.container.find(".mejs-mediaelement").append(b);a.$media.remove();a.$node=a.$media=b;a.node=a.media=b[0]}else a.container.find(".mejs-mediaelement").append(a.$media);a.controls=a.container.find(".mejs-controls");a.layers=a.container.find(".mejs-layers");b=a.isVideo?"video":"audio";e=b.substring(0,1).toUpperCase()+b.substring(1);
a.width=a.options[b+"Width"]>0||a.options[b+"Width"].toString().indexOf("%")>-1?a.options[b+"Width"]:a.media.style.width!==""&&a.media.style.width!==null?a.media.style.width:a.media.getAttribute("width")!==null?a.$media.attr("width"):a.options["default"+e+"Width"];a.height=a.options[b+"Height"]>0||a.options[b+"Height"].toString().indexOf("%")>-1?a.options[b+"Height"]:a.media.style.height!==""&&a.media.style.height!==null?a.media.style.height:a.$media[0].getAttribute("height")!==null?a.$media.attr("height"):
a.options["default"+e+"Height"];a.setPlayerSize(a.width,a.height);c.pluginWidth=a.width;c.pluginHeight=a.height}mejs.MediaElement(a.$media[0],c);typeof a.container!="undefined"&&a.controlsAreVisible&&a.container.trigger("controlsshown")},showControls:function(a){var b=this;a=typeof a=="undefined"||a;if(!b.controlsAreVisible){if(a){b.controls.css("visibility","visible").stop(true,true).fadeIn(200,function(){b.controlsAreVisible=true;b.container.trigger("controlsshown")});b.container.find(".mejs-control").css("visibility",
"visible").stop(true,true).fadeIn(200,function(){b.controlsAreVisible=true})}else{b.controls.css("visibility","visible").css("display","block");b.container.find(".mejs-control").css("visibility","visible").css("display","block");b.controlsAreVisible=true;b.container.trigger("controlsshown")}b.setControlsSize()}},hideControls:function(a){var b=this;a=typeof a=="undefined"||a;if(!(!b.controlsAreVisible||b.options.alwaysShowControls))if(a){b.controls.stop(true,true).fadeOut(200,function(){f(this).css("visibility",
"hidden").css("display","block");b.controlsAreVisible=false;b.container.trigger("controlshidden")});b.container.find(".mejs-control").stop(true,true).fadeOut(200,function(){f(this).css("visibility","hidden").css("display","block")})}else{b.controls.css("visibility","hidden").css("display","block");b.container.find(".mejs-control").css("visibility","hidden").css("display","block");b.controlsAreVisible=false;b.container.trigger("controlshidden")}},controlsTimer:null,startControlsTimer:function(a){var b=
this;a=typeof a!="undefined"?a:1500;b.killControlsTimer("start");b.controlsTimer=setTimeout(function(){b.hideControls();b.killControlsTimer("hide")},a)},killControlsTimer:function(){if(this.controlsTimer!==null){clearTimeout(this.controlsTimer);delete this.controlsTimer;this.controlsTimer=null}},controlsEnabled:true,disableControls:function(){this.killControlsTimer();this.hideControls(false);this.controlsEnabled=false},enableControls:function(){this.showControls(false);this.controlsEnabled=true},
meReady:function(a,b){var c=this,e=mejs.MediaFeatures,d=b.getAttribute("autoplay");d=!(typeof d=="undefined"||d===null||d==="false");var g;if(!c.created){c.created=true;c.media=a;c.domNode=b;if(!(e.isAndroid&&c.options.AndroidUseNativeControls)&&!(e.isiPad&&c.options.iPadUseNativeControls)&&!(e.isiPhone&&c.options.iPhoneUseNativeControls)){c.buildposter(c,c.controls,c.layers,c.media);c.buildkeyboard(c,c.controls,c.layers,c.media);c.buildoverlays(c,c.controls,c.layers,c.media);c.findTracks();for(g in c.options.features){e=
c.options.features[g];if(c["build"+e])try{c["build"+e](c,c.controls,c.layers,c.media)}catch(k){}}c.container.trigger("controlsready");c.setPlayerSize(c.width,c.height);c.setControlsSize();if(c.isVideo){if(mejs.MediaFeatures.hasTouch)c.$media.bind("touchstart",function(){if(c.controlsAreVisible)c.hideControls(false);else c.controlsEnabled&&c.showControls(false)});else{c.clickToPlayPauseCallback=function(){if(c.options.clickToPlayPause)c.media.paused?c.play():c.pause()};c.media.addEventListener("click",
c.clickToPlayPauseCallback,false);c.container.bind("mouseenter mouseover",function(){if(c.controlsEnabled)if(!c.options.alwaysShowControls){c.killControlsTimer("enter");c.showControls();c.startControlsTimer(2500)}}).bind("mousemove",function(){if(c.controlsEnabled){c.controlsAreVisible||c.showControls();c.options.alwaysShowControls||c.startControlsTimer(2500)}}).bind("mouseleave",function(){c.controlsEnabled&&!c.media.paused&&!c.options.alwaysShowControls&&c.startControlsTimer(1E3)})}c.options.hideVideoControlsOnLoad&&
c.hideControls(false);d&&!c.options.alwaysShowControls&&c.hideControls();c.options.enableAutosize&&c.media.addEventListener("loadedmetadata",function(j){if(c.options.videoHeight<=0&&c.domNode.getAttribute("height")===null&&!isNaN(j.target.videoHeight)){c.setPlayerSize(j.target.videoWidth,j.target.videoHeight);c.setControlsSize();c.media.setVideoSize(j.target.videoWidth,j.target.videoHeight)}},false)}a.addEventListener("play",function(){for(var j in mejs.players){var m=mejs.players[j];m.id!=c.id&&
c.options.pauseOtherPlayers&&!m.paused&&!m.ended&&m.pause();m.hasFocus=false}c.hasFocus=true},false);c.media.addEventListener("ended",function(){if(c.options.autoRewind)try{c.media.setCurrentTime(0)}catch(j){}c.media.pause();c.setProgressRail&&c.setProgressRail();c.setCurrentRail&&c.setCurrentRail();if(c.options.loop)c.play();else!c.options.alwaysShowControls&&c.controlsEnabled&&c.showControls()},false);c.media.addEventListener("loadedmetadata",function(){c.updateDuration&&c.updateDuration();c.updateCurrent&&
c.updateCurrent();if(!c.isFullScreen){c.setPlayerSize(c.width,c.height);c.setControlsSize()}},false);setTimeout(function(){c.setPlayerSize(c.width,c.height);c.setControlsSize()},50);c.globalBind("resize",function(){c.isFullScreen||mejs.MediaFeatures.hasTrueNativeFullScreen&&document.webkitIsFullScreen||c.setPlayerSize(c.width,c.height);c.setControlsSize()});c.media.pluginType=="youtube"&&c.container.find(".mejs-overlay-play").hide()}d&&a.pluginType=="native"&&c.play();if(c.options.success)typeof c.options.success==
"string"?window[c.options.success](c.media,c.domNode,c):c.options.success(c.media,c.domNode,c)}},handleError:function(a){this.controls.hide();this.options.error&&this.options.error(a)},setPlayerSize:function(a,b){if(typeof a!="undefined")this.width=a;if(typeof b!="undefined")this.height=b;if(this.height.toString().indexOf("%")>0||this.$node.css("max-width")==="100%"||parseInt(this.$node.css("max-width").replace(/px/,""),10)/this.$node.offsetParent().width()===1||this.$node[0].currentStyle&&this.$node[0].currentStyle.maxWidth===
"100%"){var c=this.isVideo?this.media.videoWidth&&this.media.videoWidth>0?this.media.videoWidth:this.options.defaultVideoWidth:this.options.defaultAudioWidth,e=this.isVideo?this.media.videoHeight&&this.media.videoHeight>0?this.media.videoHeight:this.options.defaultVideoHeight:this.options.defaultAudioHeight,d=this.container.parent().closest(":visible").width();c=this.isVideo||!this.options.autosizeProgress?parseInt(d*e/c,10):e;if(isNaN(c))c=this.container.parent().closest(":visible").height();if(this.container.parent()[0].tagName.toLowerCase()===
"body"){d=f(window).width();c=f(window).height()}if(c!=0&&d!=0){this.container.width(d).height(c);this.$media.add(this.container.find(".mejs-shim")).width("100%").height("100%");this.isVideo&&this.media.setVideoSize&&this.media.setVideoSize(d,c);this.layers.children(".mejs-layer").width("100%").height("100%")}}else{this.container.width(this.width).height(this.height);this.layers.children(".mejs-layer").width(this.width).height(this.height)}d=this.layers.find(".mejs-overlay-play");c=d.find(".mejs-overlay-button");
d.height(this.container.height()-this.controls.height());c.css("margin-top","-"+(c.height()/2-this.controls.height()/2).toString()+"px")},setControlsSize:function(){var a=0,b=0,c=this.controls.find(".mejs-time-rail"),e=this.controls.find(".mejs-time-total");this.controls.find(".mejs-time-current");this.controls.find(".mejs-time-loaded");var d=c.siblings(),g=d.last(),k=null;if(!(!this.container.is(":visible")||!c.length||!c.is(":visible"))){if(this.options&&!this.options.autosizeProgress)b=parseInt(c.css("width"));
if(b===0||!b){d.each(function(){var j=f(this);if(j.css("position")!="absolute"&&j.is(":visible"))a+=f(this).outerWidth(true)});b=this.controls.width()-a-(c.outerWidth(true)-c.width())}do{c.width(b);e.width(b-(e.outerWidth(true)-e.width()));if(g.css("position")!="absolute"){k=g.position();b--}}while(k!=null&&k.top>0&&b>0);this.setProgressRail&&this.setProgressRail();this.setCurrentRail&&this.setCurrentRail()}},buildposter:function(a,b,c,e){var d=f('<div class="mejs-poster mejs-layer"></div>').appendTo(c);
b=a.$media.attr("poster");if(a.options.poster!=="")b=a.options.poster;b!==""&&b!=null?this.setPoster(b):d.hide();e.addEventListener("play",function(){d.hide()},false);a.options.showPosterWhenEnded&&a.options.autoRewind&&e.addEventListener("ended",function(){d.show()},false)},setPoster:function(a){var b=this.container.find(".mejs-poster"),c=b.find("img");if(c.length==0)c=f('<img width="100%" height="100%" />').appendTo(b);c.attr("src",a);b.css({"background-image":"url("+a+")"})},buildoverlays:function(a,
b,c,e){var d=this;if(a.isVideo){var g=f('<div class="mejs-overlay mejs-layer"><div class="mejs-overlay-loading"><span></span></div></div>').hide().appendTo(c),k=f('<div class="mejs-overlay mejs-layer"><div class="mejs-overlay-error"></div></div>').hide().appendTo(c),j=f('<div class="mejs-overlay mejs-layer mejs-overlay-play"><div class="mejs-overlay-button"></div></div>').appendTo(c).bind("click touchstart",function(){d.options.clickToPlayPause&&e.paused&&e.play()});e.addEventListener("play",function(){j.hide();
g.hide();b.find(".mejs-time-buffering").hide();k.hide()},false);e.addEventListener("playing",function(){j.hide();g.hide();b.find(".mejs-time-buffering").hide();k.hide()},false);e.addEventListener("seeking",function(){g.show();b.find(".mejs-time-buffering").show()},false);e.addEventListener("seeked",function(){g.hide();b.find(".mejs-time-buffering").hide()},false);e.addEventListener("pause",function(){mejs.MediaFeatures.isiPhone||j.show()},false);e.addEventListener("waiting",function(){g.show();b.find(".mejs-time-buffering").show()},
false);e.addEventListener("loadeddata",function(){g.show();b.find(".mejs-time-buffering").show()},false);e.addEventListener("canplay",function(){g.hide();b.find(".mejs-time-buffering").hide()},false);e.addEventListener("error",function(){g.hide();b.find(".mejs-time-buffering").hide();k.show();k.find("mejs-overlay-error").html("Error loading this resource")},false)}},buildkeyboard:function(a,b,c,e){this.globalBind("keydown",function(d){if(a.hasFocus&&a.options.enableKeyboard)for(var g=0,k=a.options.keyActions.length;g<
k;g++)for(var j=a.options.keyActions[g],m=0,q=j.keys.length;m<q;m++)if(d.keyCode==j.keys[m]){d.preventDefault();j.action(a,e,d.keyCode);return false}return true});this.globalBind("click",function(d){a.hasFocus=f(d.target).closest(".mejs-container").length!=0})},findTracks:function(){var a=this,b=a.$media.find("track");a.tracks=[];b.each(function(c,e){e=f(e);a.tracks.push({srclang:e.attr("srclang")?e.attr("srclang").toLowerCase():"",src:e.attr("src"),kind:e.attr("kind"),label:e.attr("label")||"",entries:[],
isLoaded:false})})},changeSkin:function(a){this.container[0].className="mejs-container "+a;this.setPlayerSize(this.width,this.height);this.setControlsSize()},play:function(){this.load();this.media.play()},pause:function(){try{this.media.pause()}catch(a){}},load:function(){this.isLoaded||this.media.load();this.isLoaded=true},setMuted:function(a){this.media.setMuted(a)},setCurrentTime:function(a){this.media.setCurrentTime(a)},getCurrentTime:function(){return this.media.currentTime},setVolume:function(a){this.media.setVolume(a)},
getVolume:function(){return this.media.volume},setSrc:function(a){this.media.setSrc(a)},remove:function(){var a,b;for(a in this.options.features){b=this.options.features[a];if(this["clean"+b])try{this["clean"+b](this)}catch(c){}}if(this.isDynamic)this.$node.insertBefore(this.container);else{this.$media.prop("controls",true);this.$node.clone().show().insertBefore(this.container);this.$node.remove()}this.media.pluginType!=="native"&&this.media.remove();delete mejs.players[this.id];typeof this.container==
"object"&&this.container.remove();this.globalUnbind();delete this.node.player}};(function(){function a(c,e){var d={d:[],w:[]};f.each((c||"").split(" "),function(g,k){var j=k+"."+e;if(j.indexOf(".")===0){d.d.push(j);d.w.push(j)}else d[b.test(k)?"w":"d"].push(j)});d.d=d.d.join(" ");d.w=d.w.join(" ");return d}var b=/^((after|before)print|(before)?unload|hashchange|message|o(ff|n)line|page(hide|show)|popstate|resize|storage)\b/;mejs.MediaElementPlayer.prototype.globalBind=function(c,e,d){c=a(c,this.id);
c.d&&f(document).bind(c.d,e,d);c.w&&f(window).bind(c.w,e,d)};mejs.MediaElementPlayer.prototype.globalUnbind=function(c,e){c=a(c,this.id);c.d&&f(document).unbind(c.d,e);c.w&&f(window).unbind(c.w,e)}})();if(typeof jQuery!="undefined")jQuery.fn.mediaelementplayer=function(a){a===false?this.each(function(){var b=jQuery(this).data("mediaelementplayer");b&&b.remove();jQuery(this).removeData("mediaelementplayer")}):this.each(function(){jQuery(this).data("mediaelementplayer",new mejs.MediaElementPlayer(this,
a))});return this};f(document).ready(function(){f(".mejs-player").mediaelementplayer()});window.MediaElementPlayer=mejs.MediaElementPlayer})(mejs.$);
(function(f){f.extend(mejs.MepDefaults,{playpauseText:mejs.i18n.t("Play/Pause")});f.extend(MediaElementPlayer.prototype,{buildplaypause:function(a,b,c,e){var d=f('<div class="mejs-button mejs-playpause-button mejs-play" ><button type="button" aria-controls="'+this.id+'" title="'+this.options.playpauseText+'" aria-label="'+this.options.playpauseText+'"></button></div>').appendTo(b).click(function(g){g.preventDefault();e.paused?e.play():e.pause();return false});e.addEventListener("play",function(){d.removeClass("mejs-play").addClass("mejs-pause")},
false);e.addEventListener("playing",function(){d.removeClass("mejs-play").addClass("mejs-pause")},false);e.addEventListener("pause",function(){d.removeClass("mejs-pause").addClass("mejs-play")},false);e.addEventListener("paused",function(){d.removeClass("mejs-pause").addClass("mejs-play")},false)}})})(mejs.$);
(function(f){f.extend(mejs.MepDefaults,{stopText:"Stop"});f.extend(MediaElementPlayer.prototype,{buildstop:function(a,b,c,e){f('<div class="mejs-button mejs-stop-button mejs-stop"><button type="button" aria-controls="'+this.id+'" title="'+this.options.stopText+'" aria-label="'+this.options.stopText+'"></button></div>').appendTo(b).click(function(){e.paused||e.pause();if(e.currentTime>0){e.setCurrentTime(0);e.pause();b.find(".mejs-time-current").width("0px");b.find(".mejs-time-handle").css("left",
"0px");b.find(".mejs-time-float-current").html(mejs.Utility.secondsToTimeCode(0));b.find(".mejs-currenttime").html(mejs.Utility.secondsToTimeCode(0));c.find(".mejs-poster").show()}})}})})(mejs.$);
(function(f){f.extend(MediaElementPlayer.prototype,{buildprogress:function(a,b,c,e){f('<div class="mejs-time-rail"><span class="mejs-time-total"><span class="mejs-time-buffering"></span><span class="mejs-time-loaded"></span><span class="mejs-time-current"></span><span class="mejs-time-handle"></span><span class="mejs-time-float"><span class="mejs-time-float-current">00:00</span><span class="mejs-time-float-corner"></span></span></span></div>').appendTo(b);b.find(".mejs-time-buffering").hide();var d=
this,g=b.find(".mejs-time-total");c=b.find(".mejs-time-loaded");var k=b.find(".mejs-time-current"),j=b.find(".mejs-time-handle"),m=b.find(".mejs-time-float"),q=b.find(".mejs-time-float-current"),p=function(h){h=h.originalEvent.changedTouches?h.originalEvent.changedTouches[0].pageX:h.pageX;var l=g.offset(),r=g.outerWidth(true),n=0,o=n=0;if(e.duration){if(h<l.left)h=l.left;else if(h>r+l.left)h=r+l.left;o=h-l.left;n=o/r;n=n<=0.02?0:n*e.duration;t&&n!==e.currentTime&&e.setCurrentTime(n);if(!mejs.MediaFeatures.hasTouch){m.css("left",
o);q.html(mejs.Utility.secondsToTimeCode(n));m.show()}}},t=false;g.bind("mousedown touchstart",function(h){if(h.which===1||h.which===0){t=true;p(h);d.globalBind("mousemove.dur touchmove.dur",function(l){p(l)});d.globalBind("mouseup.dur touchend.dur",function(){t=false;m.hide();d.globalUnbind(".dur")});return false}}).bind("mouseenter",function(){d.globalBind("mousemove.dur",function(h){p(h)});mejs.MediaFeatures.hasTouch||m.show()}).bind("mouseleave",function(){if(!t){d.globalUnbind(".dur");m.hide()}});
e.addEventListener("progress",function(h){a.setProgressRail(h);a.setCurrentRail(h)},false);e.addEventListener("timeupdate",function(h){a.setProgressRail(h);a.setCurrentRail(h)},false);d.loaded=c;d.total=g;d.current=k;d.handle=j},setProgressRail:function(a){var b=a!=undefined?a.target:this.media,c=null;if(b&&b.buffered&&b.buffered.length>0&&b.buffered.end&&b.duration)c=b.buffered.end(0)/b.duration;else if(b&&b.bytesTotal!=undefined&&b.bytesTotal>0&&b.bufferedBytes!=undefined)c=b.bufferedBytes/b.bytesTotal;
else if(a&&a.lengthComputable&&a.total!=0)c=a.loaded/a.total;if(c!==null){c=Math.min(1,Math.max(0,c));this.loaded&&this.total&&this.loaded.width(this.total.width()*c)}},setCurrentRail:function(){if(this.media.currentTime!=undefined&&this.media.duration)if(this.total&&this.handle){var a=Math.round(this.total.width()*this.media.currentTime/this.media.duration),b=a-Math.round(this.handle.outerWidth(true)/2);this.current.width(a);this.handle.css("left",b)}}})})(mejs.$);
(function(f){f.extend(mejs.MepDefaults,{duration:-1,timeAndDurationSeparator:"<span> | </span>"});f.extend(MediaElementPlayer.prototype,{buildcurrent:function(a,b,c,e){f('<div class="mejs-time"><span class="mejs-currenttime">'+(a.options.alwaysShowHours?"00:":"")+(a.options.showTimecodeFrameCount?"00:00:00":"00:00")+"</span></div>").appendTo(b);this.currenttime=this.controls.find(".mejs-currenttime");e.addEventListener("timeupdate",function(){a.updateCurrent()},false)},buildduration:function(a,b,
c,e){if(b.children().last().find(".mejs-currenttime").length>0)f(this.options.timeAndDurationSeparator+'<span class="mejs-duration">'+(this.options.duration>0?mejs.Utility.secondsToTimeCode(this.options.duration,this.options.alwaysShowHours||this.media.duration>3600,this.options.showTimecodeFrameCount,this.options.framesPerSecond||25):(a.options.alwaysShowHours?"00:":"")+(a.options.showTimecodeFrameCount?"00:00:00":"00:00"))+"</span>").appendTo(b.find(".mejs-time"));else{b.find(".mejs-currenttime").parent().addClass("mejs-currenttime-container");
f('<div class="mejs-time mejs-duration-container"><span class="mejs-duration">'+(this.options.duration>0?mejs.Utility.secondsToTimeCode(this.options.duration,this.options.alwaysShowHours||this.media.duration>3600,this.options.showTimecodeFrameCount,this.options.framesPerSecond||25):(a.options.alwaysShowHours?"00:":"")+(a.options.showTimecodeFrameCount?"00:00:00":"00:00"))+"</span></div>").appendTo(b)}this.durationD=this.controls.find(".mejs-duration");e.addEventListener("timeupdate",function(){a.updateDuration()},
false)},updateCurrent:function(){if(this.currenttime)this.currenttime.html(mejs.Utility.secondsToTimeCode(this.media.currentTime,this.options.alwaysShowHours||this.media.duration>3600,this.options.showTimecodeFrameCount,this.options.framesPerSecond||25))},updateDuration:function(){this.container.toggleClass("mejs-long-video",this.media.duration>3600);if(this.durationD&&(this.options.duration>0||this.media.duration))this.durationD.html(mejs.Utility.secondsToTimeCode(this.options.duration>0?this.options.duration:
this.media.duration,this.options.alwaysShowHours,this.options.showTimecodeFrameCount,this.options.framesPerSecond||25))}})})(mejs.$);
(function(f){f.extend(mejs.MepDefaults,{muteText:mejs.i18n.t("Mute Toggle"),hideVolumeOnTouchDevices:true,audioVolume:"horizontal",videoVolume:"vertical"});f.extend(MediaElementPlayer.prototype,{buildvolume:function(a,b,c,e){if(!((mejs.MediaFeatures.isAndroid||mejs.MediaFeatures.isiOS)&&this.options.hideVolumeOnTouchDevices)){var d=this,g=d.isVideo?d.options.videoVolume:d.options.audioVolume,k=g=="horizontal"?f('<div class="mejs-button mejs-volume-button mejs-mute"><button type="button" aria-controls="'+
d.id+'" title="'+d.options.muteText+'" aria-label="'+d.options.muteText+'"></button></div><div class="mejs-horizontal-volume-slider"><div class="mejs-horizontal-volume-total"></div><div class="mejs-horizontal-volume-current"></div><div class="mejs-horizontal-volume-handle"></div></div>').appendTo(b):f('<div class="mejs-button mejs-volume-button mejs-mute"><button type="button" aria-controls="'+d.id+'" title="'+d.options.muteText+'" aria-label="'+d.options.muteText+'"></button><div class="mejs-volume-slider"><div class="mejs-volume-total"></div><div class="mejs-volume-current"></div><div class="mejs-volume-handle"></div></div></div>').appendTo(b),
j=d.container.find(".mejs-volume-slider, .mejs-horizontal-volume-slider"),m=d.container.find(".mejs-volume-total, .mejs-horizontal-volume-total"),q=d.container.find(".mejs-volume-current, .mejs-horizontal-volume-current"),p=d.container.find(".mejs-volume-handle, .mejs-horizontal-volume-handle"),t=function(n,o){if(!j.is(":visible")&&typeof o=="undefined"){j.show();t(n,true);j.hide()}else{n=Math.max(0,n);n=Math.min(n,1);n==0?k.removeClass("mejs-mute").addClass("mejs-unmute"):k.removeClass("mejs-unmute").addClass("mejs-mute");
if(g=="vertical"){var s=m.height(),u=m.position(),v=s-s*n;p.css("top",Math.round(u.top+v-p.height()/2));q.height(s-v);q.css("top",u.top+v)}else{s=m.width();u=m.position();s=s*n;p.css("left",Math.round(u.left+s-p.width()/2));q.width(Math.round(s))}}},h=function(n){var o=null,s=m.offset();if(g=="vertical"){o=m.height();parseInt(m.css("top").replace(/px/,""),10);o=(o-(n.pageY-s.top))/o;if(s.top==0||s.left==0)return}else{o=m.width();o=(n.pageX-s.left)/o}o=Math.max(0,o);o=Math.min(o,1);t(o);o==0?e.setMuted(true):
e.setMuted(false);e.setVolume(o)},l=false,r=false;k.hover(function(){j.show();r=true},function(){r=false;!l&&g=="vertical"&&j.hide()});j.bind("mouseover",function(){r=true}).bind("mousedown",function(n){h(n);d.globalBind("mousemove.vol",function(o){h(o)});d.globalBind("mouseup.vol",function(){l=false;d.globalUnbind(".vol");!r&&g=="vertical"&&j.hide()});l=true;return false});k.find("button").click(function(){e.setMuted(!e.muted)});e.addEventListener("volumechange",function(){if(!l)if(e.muted){t(0);
k.removeClass("mejs-mute").addClass("mejs-unmute")}else{t(e.volume);k.removeClass("mejs-unmute").addClass("mejs-mute")}},false);if(d.container.is(":visible")){t(a.options.startVolume);a.options.startVolume===0&&e.setMuted(true);e.pluginType==="native"&&e.setVolume(a.options.startVolume)}}}})})(mejs.$);
(function(f){f.extend(mejs.MepDefaults,{usePluginFullScreen:true,newWindowCallback:function(){return""},fullscreenText:mejs.i18n.t("Fullscreen")});f.extend(MediaElementPlayer.prototype,{isFullScreen:false,isNativeFullScreen:false,isInIframe:false,buildfullscreen:function(a,b,c,e){if(a.isVideo){a.isInIframe=window.location!=window.parent.location;if(mejs.MediaFeatures.hasTrueNativeFullScreen){c=function(){if(a.isFullScreen)if(mejs.MediaFeatures.isFullScreen()){a.isNativeFullScreen=true;a.setControlsSize()}else{a.isNativeFullScreen=
false;a.exitFullScreen()}};mejs.MediaFeatures.hasMozNativeFullScreen?a.globalBind(mejs.MediaFeatures.fullScreenEventName,c):a.container.bind(mejs.MediaFeatures.fullScreenEventName,c)}var d=this,g=f('<div class="mejs-button mejs-fullscreen-button"><button type="button" aria-controls="'+d.id+'" title="'+d.options.fullscreenText+'" aria-label="'+d.options.fullscreenText+'"></button></div>').appendTo(b);if(d.media.pluginType==="native"||!d.options.usePluginFullScreen&&!mejs.MediaFeatures.isFirefox)g.click(function(){mejs.MediaFeatures.hasTrueNativeFullScreen&&
mejs.MediaFeatures.isFullScreen()||a.isFullScreen?a.exitFullScreen():a.enterFullScreen()});else{var k=null;if(function(){var h=document.createElement("x"),l=document.documentElement,r=window.getComputedStyle;if(!("pointerEvents"in h.style))return false;h.style.pointerEvents="auto";h.style.pointerEvents="x";l.appendChild(h);r=r&&r(h,"").pointerEvents==="auto";l.removeChild(h);return!!r}()&&!mejs.MediaFeatures.isOpera){var j=false,m=function(){if(j){for(var h in q)q[h].hide();g.css("pointer-events",
"");d.controls.css("pointer-events","");d.media.removeEventListener("click",d.clickToPlayPauseCallback);j=false}},q={};b=["top","left","right","bottom"];var p,t=function(){var h=g.offset().left-d.container.offset().left,l=g.offset().top-d.container.offset().top,r=g.outerWidth(true),n=g.outerHeight(true),o=d.container.width(),s=d.container.height();for(p in q)q[p].css({position:"absolute",top:0,left:0});q.top.width(o).height(l);q.left.width(h).height(n).css({top:l});q.right.width(o-h-r).height(n).css({top:l,
left:h+r});q.bottom.width(o).height(s-n-l).css({top:l+n})};d.globalBind("resize",function(){t()});p=0;for(c=b.length;p<c;p++)q[b[p]]=f('<div class="mejs-fullscreen-hover" />').appendTo(d.container).mouseover(m).hide();g.on("mouseover",function(){if(!d.isFullScreen){var h=g.offset(),l=a.container.offset();e.positionFullscreenButton(h.left-l.left,h.top-l.top,false);g.css("pointer-events","none");d.controls.css("pointer-events","none");d.media.addEventListener("click",d.clickToPlayPauseCallback);for(p in q)q[p].show();
t();j=true}});e.addEventListener("fullscreenchange",function(){d.isFullScreen=!d.isFullScreen;d.isFullScreen?d.media.removeEventListener("click",d.clickToPlayPauseCallback):d.media.addEventListener("click",d.clickToPlayPauseCallback);m()});d.globalBind("mousemove",function(h){if(j){var l=g.offset();if(h.pageY<l.top||h.pageY>l.top+g.outerHeight(true)||h.pageX<l.left||h.pageX>l.left+g.outerWidth(true)){g.css("pointer-events","");d.controls.css("pointer-events","");j=false}}})}else g.on("mouseover",
function(){if(k!==null){clearTimeout(k);delete k}var h=g.offset(),l=a.container.offset();e.positionFullscreenButton(h.left-l.left,h.top-l.top,true)}).on("mouseout",function(){if(k!==null){clearTimeout(k);delete k}k=setTimeout(function(){e.hideFullscreenButton()},1500)})}a.fullscreenBtn=g;d.globalBind("keydown",function(h){if((mejs.MediaFeatures.hasTrueNativeFullScreen&&mejs.MediaFeatures.isFullScreen()||d.isFullScreen)&&h.keyCode==27)a.exitFullScreen()})}},cleanfullscreen:function(a){a.exitFullScreen()},
containerSizeTimeout:null,enterFullScreen:function(){var a=this;if(!(a.media.pluginType!=="native"&&(mejs.MediaFeatures.isFirefox||a.options.usePluginFullScreen))){f(document.documentElement).addClass("mejs-fullscreen");normalHeight=a.container.height();normalWidth=a.container.width();if(a.media.pluginType==="native")if(mejs.MediaFeatures.hasTrueNativeFullScreen){mejs.MediaFeatures.requestFullScreen(a.container[0]);a.isInIframe&&setTimeout(function c(){if(a.isNativeFullScreen){var e=(window.devicePixelRatio||
1)*f(window).width(),d=screen.width;Math.abs(d-e)>d*0.0020?a.exitFullScreen():setTimeout(c,500)}},500)}else if(mejs.MediaFeatures.hasSemiNativeFullScreen){a.media.webkitEnterFullscreen();return}if(a.isInIframe){var b=a.options.newWindowCallback(this);if(b!=="")if(mejs.MediaFeatures.hasTrueNativeFullScreen)setTimeout(function(){if(!a.isNativeFullScreen){a.pause();window.open(b,a.id,"top=0,left=0,width="+screen.availWidth+",height="+screen.availHeight+",resizable=yes,scrollbars=no,status=no,toolbar=no")}},
250);else{a.pause();window.open(b,a.id,"top=0,left=0,width="+screen.availWidth+",height="+screen.availHeight+",resizable=yes,scrollbars=no,status=no,toolbar=no");return}}a.container.addClass("mejs-container-fullscreen").width("100%").height("100%");a.containerSizeTimeout=setTimeout(function(){a.container.css({width:"100%",height:"100%"});a.setControlsSize()},500);if(a.media.pluginType==="native")a.$media.width("100%").height("100%");else{a.container.find(".mejs-shim").width("100%").height("100%");
a.media.setVideoSize(f(window).width(),f(window).height())}a.layers.children("div").width("100%").height("100%");a.fullscreenBtn&&a.fullscreenBtn.removeClass("mejs-fullscreen").addClass("mejs-unfullscreen");a.setControlsSize();a.isFullScreen=true}},exitFullScreen:function(){clearTimeout(this.containerSizeTimeout);if(this.media.pluginType!=="native"&&mejs.MediaFeatures.isFirefox)this.media.setFullscreen(false);else{if(mejs.MediaFeatures.hasTrueNativeFullScreen&&(mejs.MediaFeatures.isFullScreen()||
this.isFullScreen))mejs.MediaFeatures.cancelFullScreen();f(document.documentElement).removeClass("mejs-fullscreen");this.container.removeClass("mejs-container-fullscreen").width(normalWidth).height(normalHeight);if(this.media.pluginType==="native")this.$media.width(normalWidth).height(normalHeight);else{this.container.find(".mejs-shim").width(normalWidth).height(normalHeight);this.media.setVideoSize(normalWidth,normalHeight)}this.layers.children("div").width(normalWidth).height(normalHeight);this.fullscreenBtn.removeClass("mejs-unfullscreen").addClass("mejs-fullscreen");
this.setControlsSize();this.isFullScreen=false}}})})(mejs.$);
(function(f){f.extend(mejs.MepDefaults,{startLanguage:"",tracksText:mejs.i18n.t("Captions/Subtitles"),hideCaptionsButtonWhenEmpty:true,toggleCaptionsButtonWhenOnlyOne:false,slidesSelector:""});f.extend(MediaElementPlayer.prototype,{hasChapters:false,buildtracks:function(a,b,c,e){if(a.tracks.length!=0){var d;if(this.domNode.textTracks)for(d=this.domNode.textTracks.length-1;d>=0;d--)this.domNode.textTracks[d].mode="hidden";a.chapters=f('<div class="mejs-chapters mejs-layer"></div>').prependTo(c).hide();a.captions=
f('<div class="mejs-captions-layer mejs-layer"><div class="mejs-captions-position mejs-captions-position-hover"><span class="mejs-captions-text"></span></div></div>').prependTo(c).hide();a.captionsText=a.captions.find(".mejs-captions-text");a.captionsButton=f('<div class="mejs-button mejs-captions-button"><button type="button" aria-controls="'+this.id+'" title="'+this.options.tracksText+'" aria-label="'+this.options.tracksText+'"></button><div class="mejs-captions-selector"><ul><li><input type="radio" name="'+
a.id+'_captions" id="'+a.id+'_captions_none" value="none" checked="checked" /><label for="'+a.id+'_captions_none">'+mejs.i18n.t("None")+"</label></li></ul></div></div>").appendTo(b);for(d=b=0;d<a.tracks.length;d++)a.tracks[d].kind=="subtitles"&&b++;this.options.toggleCaptionsButtonWhenOnlyOne&&b==1?a.captionsButton.on("click",function(){a.setTrack(a.selectedTrack==null?a.tracks[0].srclang:"none")}):a.captionsButton.hover(function(){f(this).find(".mejs-captions-selector").css("visibility","visible")},
function(){f(this).find(".mejs-captions-selector").css("visibility","hidden")}).on("click","input[type=radio]",function(){lang=this.value;a.setTrack(lang)});a.options.alwaysShowControls?a.container.find(".mejs-captions-position").addClass("mejs-captions-position-hover"):a.container.bind("controlsshown",function(){a.container.find(".mejs-captions-position").addClass("mejs-captions-position-hover")}).bind("controlshidden",function(){e.paused||a.container.find(".mejs-captions-position").removeClass("mejs-captions-position-hover")});
a.trackToLoad=-1;a.selectedTrack=null;a.isLoadingTrack=false;for(d=0;d<a.tracks.length;d++)a.tracks[d].kind=="subtitles"&&a.addTrackButton(a.tracks[d].srclang,a.tracks[d].label);a.loadNextTrack();e.addEventListener("timeupdate",function(){a.displayCaptions()},false);if(a.options.slidesSelector!=""){a.slidesContainer=f(a.options.slidesSelector);e.addEventListener("timeupdate",function(){a.displaySlides()},false)}e.addEventListener("loadedmetadata",function(){a.displayChapters()},false);a.container.hover(function(){if(a.hasChapters){a.chapters.css("visibility",
"visible");a.chapters.fadeIn(200).height(a.chapters.find(".mejs-chapter").outerHeight())}},function(){a.hasChapters&&!e.paused&&a.chapters.fadeOut(200,function(){f(this).css("visibility","hidden");f(this).css("display","block")})});a.node.getAttribute("autoplay")!==null&&a.chapters.css("visibility","hidden")}},setTrack:function(a){var b;if(a=="none"){this.selectedTrack=null;this.captionsButton.removeClass("mejs-captions-enabled")}else for(b=0;b<this.tracks.length;b++)if(this.tracks[b].srclang==a){this.selectedTrack==
null&&this.captionsButton.addClass("mejs-captions-enabled");this.selectedTrack=this.tracks[b];this.captions.attr("lang",this.selectedTrack.srclang);this.displayCaptions();break}},loadNextTrack:function(){this.trackToLoad++;if(this.trackToLoad<this.tracks.length){this.isLoadingTrack=true;this.loadTrack(this.trackToLoad)}else{this.isLoadingTrack=false;this.checkForTracks()}},loadTrack:function(a){var b=this,c=b.tracks[a];f.ajax({url:c.src,dataType:"text",success:function(e){c.entries=typeof e=="string"&&
/<tt\s+xml/ig.exec(e)?mejs.TrackFormatParser.dfxp.parse(e):mejs.TrackFormatParser.webvvt.parse(e);c.isLoaded=true;b.enableTrackButton(c.srclang,c.label);b.loadNextTrack();c.kind=="chapters"&&b.media.addEventListener("play",function(){b.media.duration>0&&b.displayChapters(c)},false);c.kind=="slides"&&b.setupSlides(c)},error:function(){b.loadNextTrack()}})},enableTrackButton:function(a,b){if(b==="")b=mejs.language.codes[a]||a;this.captionsButton.find("input[value="+a+"]").prop("disabled",false).siblings("label").html(b);
this.options.startLanguage==a&&f("#"+this.id+"_captions_"+a).click();this.adjustLanguageBox()},addTrackButton:function(a,b){if(b==="")b=mejs.language.codes[a]||a;this.captionsButton.find("ul").append(f('<li><input type="radio" name="'+this.id+'_captions" id="'+this.id+"_captions_"+a+'" value="'+a+'" disabled="disabled" /><label for="'+this.id+"_captions_"+a+'">'+b+" (loading)</label></li>"));this.adjustLanguageBox();this.container.find(".mejs-captions-translations option[value="+a+"]").remove()},
adjustLanguageBox:function(){this.captionsButton.find(".mejs-captions-selector").height(this.captionsButton.find(".mejs-captions-selector ul").outerHeight(true)+this.captionsButton.find(".mejs-captions-translations").outerHeight(true))},checkForTracks:function(){var a=false;if(this.options.hideCaptionsButtonWhenEmpty){for(i=0;i<this.tracks.length;i++)if(this.tracks[i].kind=="subtitles"){a=true;break}if(!a){this.captionsButton.hide();this.setControlsSize()}}},displayCaptions:function(){if(typeof this.tracks!=
"undefined"){var a,b=this.selectedTrack;if(b!=null&&b.isLoaded)for(a=0;a<b.entries.times.length;a++)if(this.media.currentTime>=b.entries.times[a].start&&this.media.currentTime<=b.entries.times[a].stop){this.captionsText.html(b.entries.text[a]);this.captions.show().height(0);return}this.captions.hide()}},setupSlides:function(a){this.slides=a;this.slides.entries.imgs=[this.slides.entries.text.length];this.showSlide(0)},showSlide:function(a){if(!(typeof this.tracks=="undefined"||typeof this.slidesContainer==
"undefined")){var b=this,c=b.slides.entries.text[a],e=b.slides.entries.imgs[a];if(typeof e=="undefined"||typeof e.fadeIn=="undefined")b.slides.entries.imgs[a]=e=f('<img src="'+c+'">').on("load",function(){e.appendTo(b.slidesContainer).hide().fadeIn().siblings(":visible").fadeOut()});else!e.is(":visible")&&!e.is(":animated")&&e.fadeIn().siblings(":visible").fadeOut()}},displaySlides:function(){if(typeof this.slides!="undefined"){var a=this.slides,b;for(b=0;b<a.entries.times.length;b++)if(this.media.currentTime>=
a.entries.times[b].start&&this.media.currentTime<=a.entries.times[b].stop){this.showSlide(b);break}}},displayChapters:function(){var a;for(a=0;a<this.tracks.length;a++)if(this.tracks[a].kind=="chapters"&&this.tracks[a].isLoaded){this.drawChapters(this.tracks[a]);this.hasChapters=true;break}},drawChapters:function(a){var b=this,c,e,d=e=0;b.chapters.empty();for(c=0;c<a.entries.times.length;c++){e=a.entries.times[c].stop-a.entries.times[c].start;e=Math.floor(e/b.media.duration*100);if(e+d>100||c==a.entries.times.length-
1&&e+d<100)e=100-d;b.chapters.append(f('<div class="mejs-chapter" rel="'+a.entries.times[c].start+'" style="left: '+d.toString()+"%;width: "+e.toString()+'%;"><div class="mejs-chapter-block'+(c==a.entries.times.length-1?" mejs-chapter-block-last":"")+'"><span class="ch-title">'+a.entries.text[c]+'</span><span class="ch-time">'+mejs.Utility.secondsToTimeCode(a.entries.times[c].start)+"&ndash;"+mejs.Utility.secondsToTimeCode(a.entries.times[c].stop)+"</span></div></div>"));d+=e}b.chapters.find("div.mejs-chapter").click(function(){b.media.setCurrentTime(parseFloat(f(this).attr("rel")));
b.media.paused&&b.media.play()});b.chapters.show()}});mejs.language={codes:{af:"Afrikaans",sq:"Albanian",ar:"Arabic",be:"Belarusian",bg:"Bulgarian",ca:"Catalan",zh:"Chinese","zh-cn":"Chinese Simplified","zh-tw":"Chinese Traditional",hr:"Croatian",cs:"Czech",da:"Danish",nl:"Dutch",en:"English",et:"Estonian",tl:"Filipino",fi:"Finnish",fr:"French",gl:"Galician",de:"German",el:"Greek",ht:"Haitian Creole",iw:"Hebrew",hi:"Hindi",hu:"Hungarian",is:"Icelandic",id:"Indonesian",ga:"Irish",it:"Italian",ja:"Japanese",
ko:"Korean",lv:"Latvian",lt:"Lithuanian",mk:"Macedonian",ms:"Malay",mt:"Maltese",no:"Norwegian",fa:"Persian",pl:"Polish",pt:"Portuguese",ro:"Romanian",ru:"Russian",sr:"Serbian",sk:"Slovak",sl:"Slovenian",es:"Spanish",sw:"Swahili",sv:"Swedish",tl:"Tagalog",th:"Thai",tr:"Turkish",uk:"Ukrainian",vi:"Vietnamese",cy:"Welsh",yi:"Yiddish"}};mejs.TrackFormatParser={webvvt:{pattern_identifier:/^([a-zA-z]+-)?[0-9]+$/,pattern_timecode:/^([0-9]{2}:[0-9]{2}:[0-9]{2}([,.][0-9]{1,3})?) --\> ([0-9]{2}:[0-9]{2}:[0-9]{2}([,.][0-9]{3})?)(.*)$/,
parse:function(a){var b=0;a=mejs.TrackFormatParser.split2(a,/\r?\n/);for(var c={text:[],times:[]},e,d;b<a.length;b++)if(this.pattern_identifier.exec(a[b])){b++;if((e=this.pattern_timecode.exec(a[b]))&&b<a.length){b++;d=a[b];for(b++;a[b]!==""&&b<a.length;){d=d+"\n"+a[b];b++}d=f.trim(d).replace(/(\b(https?|ftp|file):\/\/[-A-Z0-9+&@#\/%?=~_|!:,.;]*[-A-Z0-9+&@#\/%=~_|])/ig,"<a href='$1' target='_blank'>$1</a>");c.text.push(d);c.times.push({start:mejs.Utility.convertSMPTEtoSeconds(e[1])==0?0.2:mejs.Utility.convertSMPTEtoSeconds(e[1]),
stop:mejs.Utility.convertSMPTEtoSeconds(e[3]),settings:e[5]})}}return c}},dfxp:{parse:function(a){a=f(a).filter("tt");var b=0;b=a.children("div").eq(0);var c=b.find("p");b=a.find("#"+b.attr("style"));var e,d;a={text:[],times:[]};if(b.length){d=b.removeAttr("id").get(0).attributes;if(d.length){e={};for(b=0;b<d.length;b++)e[d[b].name.split(":")[1]]=d[b].value}}for(b=0;b<c.length;b++){var g;d={start:null,stop:null,style:null};if(c.eq(b).attr("begin"))d.start=mejs.Utility.convertSMPTEtoSeconds(c.eq(b).attr("begin"));
if(!d.start&&c.eq(b-1).attr("end"))d.start=mejs.Utility.convertSMPTEtoSeconds(c.eq(b-1).attr("end"));if(c.eq(b).attr("end"))d.stop=mejs.Utility.convertSMPTEtoSeconds(c.eq(b).attr("end"));if(!d.stop&&c.eq(b+1).attr("begin"))d.stop=mejs.Utility.convertSMPTEtoSeconds(c.eq(b+1).attr("begin"));if(e){g="";for(var k in e)g+=k+":"+e[k]+";"}if(g)d.style=g;if(d.start==0)d.start=0.2;a.times.push(d);d=f.trim(c.eq(b).html()).replace(/(\b(https?|ftp|file):\/\/[-A-Z0-9+&@#\/%?=~_|!:,.;]*[-A-Z0-9+&@#\/%=~_|])/ig,
"<a href='$1' target='_blank'>$1</a>");a.text.push(d);if(a.times.start==0)a.times.start=2}return a}},split2:function(a,b){return a.split(b)}};if("x\n\ny".split(/\n/gi).length!=3)mejs.TrackFormatParser.split2=function(a,b){var c=[],e="",d;for(d=0;d<a.length;d++){e+=a.substring(d,d+1);if(b.test(e)){c.push(e.replace(b,""));e=""}}c.push(e);return c}})(mejs.$);
(function(f){f.extend(mejs.MepDefaults,{contextMenuItems:[{render:function(a){if(typeof a.enterFullScreen=="undefined")return null;return a.isFullScreen?mejs.i18n.t("Turn off Fullscreen"):mejs.i18n.t("Go Fullscreen")},click:function(a){a.isFullScreen?a.exitFullScreen():a.enterFullScreen()}},{render:function(a){return a.media.muted?mejs.i18n.t("Unmute"):mejs.i18n.t("Mute")},click:function(a){a.media.muted?a.setMuted(false):a.setMuted(true)}},{isSeparator:true},{render:function(){return mejs.i18n.t("Download Video")},
click:function(a){window.location.href=a.media.currentSrc}}]});f.extend(MediaElementPlayer.prototype,{buildcontextmenu:function(a){a.contextMenu=f('<div class="mejs-contextmenu"></div>').appendTo(f("body")).hide();a.container.bind("contextmenu",function(b){if(a.isContextMenuEnabled){b.preventDefault();a.renderContextMenu(b.clientX-1,b.clientY-1);return false}});a.container.bind("click",function(){a.contextMenu.hide()});a.contextMenu.bind("mouseleave",function(){a.startContextMenuTimer()})},cleancontextmenu:function(a){a.contextMenu.remove()},
isContextMenuEnabled:true,enableContextMenu:function(){this.isContextMenuEnabled=true},disableContextMenu:function(){this.isContextMenuEnabled=false},contextMenuTimeout:null,startContextMenuTimer:function(){var a=this;a.killContextMenuTimer();a.contextMenuTimer=setTimeout(function(){a.hideContextMenu();a.killContextMenuTimer()},750)},killContextMenuTimer:function(){var a=this.contextMenuTimer;if(a!=null){clearTimeout(a);delete a}},hideContextMenu:function(){this.contextMenu.hide()},renderContextMenu:function(a,
b){for(var c=this,e="",d=c.options.contextMenuItems,g=0,k=d.length;g<k;g++)if(d[g].isSeparator)e+='<div class="mejs-contextmenu-separator"></div>';else{var j=d[g].render(c);if(j!=null)e+='<div class="mejs-contextmenu-item" data-itemindex="'+g+'" id="element-'+Math.random()*1E6+'">'+j+"</div>"}c.contextMenu.empty().append(f(e)).css({top:b,left:a}).show();c.contextMenu.find(".mejs-contextmenu-item").each(function(){var m=f(this),q=parseInt(m.data("itemindex"),10),p=c.options.contextMenuItems[q];typeof p.show!=
"undefined"&&p.show(m,c);m.click(function(){typeof p.click!="undefined"&&p.click(c);c.contextMenu.hide()})});setTimeout(function(){c.killControlsTimer("rev3")},100)}})})(mejs.$);
(function(f){f.extend(mejs.MepDefaults,{postrollCloseText:mejs.i18n.t("Close")});f.extend(MediaElementPlayer.prototype,{buildpostroll:function(a,b,c){var e=this.container.find('link[rel="postroll"]').attr("href");if(typeof e!=="undefined"){a.postroll=f('<div class="mejs-postroll-layer mejs-layer"><a class="mejs-postroll-close" onclick="$(this).parent().hide();return false;">'+this.options.postrollCloseText+'</a><div class="mejs-postroll-layer-content"></div></div>').prependTo(c).hide();this.media.addEventListener("ended",
function(){f.ajax({dataType:"html",url:e,success:function(d){c.find(".mejs-postroll-layer-content").html(d)}});a.postroll.show()},false)}}})})(mejs.$);

/**
 * @license MIT
 * @fileOverview Favico animations
 * @author Miroslav Magda, http://blog.ejci.net
 * @version 0.3.0
 */
!function(){var t=function(t){"use strict";function e(t){if(t.paused||t.ended||g)return!1;try{s.clearRect(0,0,h,a),s.drawImage(t,0,0,h,a)}catch(o){}setTimeout(e,L.duration,t),E.setIcon(c)}function o(t){var e=/^#?([a-f\d])([a-f\d])([a-f\d])$/i;t=t.replace(e,function(t,e,o,n){return e+e+o+o+n+n});var o=/^#?([a-f\d]{2})([a-f\d]{2})([a-f\d]{2})$/i.exec(t);return o?{r:parseInt(o[1],16),g:parseInt(o[2],16),b:parseInt(o[3],16)}:!1}function n(t,e){var o,n={};for(o in t)n[o]=t[o];for(o in e)n[o]=e[o];return n}t=t?t:{};var r,i,a,h,c,s,l,f,u,d,y,g,w,x={bgColor:"#d00",textColor:"#fff",fontFamily:"sans-serif",fontStyle:"bold",type:"circle",position:"down",animation:"slide",elementId:!1},m=[];y=function(){},f=g=!1;var p=function(){if(r=n(x,t),r.bgColor=o(r.bgColor),r.textColor=o(r.textColor),r.position=r.position.toLowerCase(),r.animation=L.types[""+r.animation]?r.animation:x.animation,"up"===r.position)for(var e=0;e<L.types[""+r.animation].length;e++){var f=L.types[""+r.animation][e];f.y=f.y<.6?f.y-.4:f.y-2*f.y+(1-f.w),L.types[""+r.animation][e]=f}r.type=b[""+r.type]?r.type:x.type;try{i=E.getIcon(),c=document.createElement("canvas"),l=document.createElement("img"),l.setAttribute("src",i.getAttribute("href")),l.onload=function(){a=l.height>0?l.height:32,h=l.width>0?l.width:32,c.height=a,c.width=h,s=c.getContext("2d"),v.ready()},w={},w.ff=/firefox/i.test(navigator.userAgent.toLowerCase()),w.chrome=/chrome/i.test(navigator.userAgent.toLowerCase()),w.opera=/opera/i.test(navigator.userAgent.toLowerCase()),w.ie=/msie/i.test(navigator.userAgent.toLowerCase())||/trident/i.test(navigator.userAgent.toLowerCase()),w.supported=w.chrome||w.ff||w.opera}catch(u){throw"Error initializing favico..."}},v={};v.ready=function(){f=!0,v.reset(),y()},v.reset=function(){m=[],u=!1,s.clearRect(0,0,h,a),s.drawImage(l,0,0,h,a),E.setIcon(c)},v.start=function(){if(f&&!d){var t=function(){u=m[0],d=!1,m.length>0&&(m.shift(),v.start())};m.length>0&&(d=!0,u?L.run(u.options,function(){L.run(m[0].options,function(){t()},!1)},!0):L.run(m[0].options,function(){t()},!1))}};var b={},C=function(t){return t.n=Math.abs(t.n),t.x=h*t.x,t.y=a*t.y,t.w=h*t.w,t.h=a*t.h,t};b.circle=function(t){t=C(t);var e=t.n>9&&t.n<100;e&&(t.x=t.x-.4*t.w,t.w=1.4*t.w),s.clearRect(0,0,h,a),s.drawImage(l,0,0,h,a),s.beginPath(),s.font=r.fontStyle+" "+Math.floor(t.h)+"px "+r.fontFamily,s.textAlign="center",e?(s.moveTo(t.x+t.w/2,t.y),s.lineTo(t.x+t.w-t.h/2,t.y),s.quadraticCurveTo(t.x+t.w,t.y,t.x+t.w,t.y+t.h/2),s.lineTo(t.x+t.w,t.y+t.h-t.h/2),s.quadraticCurveTo(t.x+t.w,t.y+t.h,t.x+t.w-t.h/2,t.y+t.h),s.lineTo(t.x+t.h/2,t.y+t.h),s.quadraticCurveTo(t.x,t.y+t.h,t.x,t.y+t.h-t.h/2),s.lineTo(t.x,t.y+t.h/2),s.quadraticCurveTo(t.x,t.y,t.x+t.h/2,t.y)):s.arc(t.x+t.w/2,t.y+t.h/2,t.h/2,0,2*Math.PI),s.fillStyle="rgba("+r.bgColor.r+","+r.bgColor.g+","+r.bgColor.b+","+t.o+")",s.fill(),s.closePath(),s.beginPath(),s.stroke(),s.fillStyle="rgba("+r.textColor.r+","+r.textColor.g+","+r.textColor.b+","+t.o+")",t.n>99?s.fillText("?",Math.floor(t.x+t.w/2),Math.floor(t.y+t.h-.15*t.h)):s.fillText(t.n,Math.floor(t.x+t.w/2),Math.floor(t.y+t.h-.15*t.h)),s.closePath()},b.rectangle=function(t){t=C(t);var e=t.n>9&&t.n<100;e&&(t.x=Math.floor(t.x-.4*t.w),t.w=Math.floor(1.4*t.w)),s.clearRect(0,0,h,a),s.drawImage(l,0,0,h,a),s.beginPath(),s.font="bold "+Math.floor(t.h)+"px sans-serif",s.textAlign="center",s.fillStyle="rgba("+r.bgColor.r+","+r.bgColor.g+","+r.bgColor.b+","+t.o+")",s.fillRect(t.x,t.y,t.w,t.h),s.fillStyle="rgba("+r.textColor.r+","+r.textColor.g+","+r.textColor.b+","+t.o+")",t.n>99?s.fillText("?",Math.floor(t.x+t.w/2),Math.floor(t.y+t.h-.15*t.h)):s.fillText(t.n,Math.floor(t.x+t.w/2),Math.floor(t.y+t.h-.15*t.h)),s.closePath()};var I=function(t,e){y=function(){try{if(t>0){if(L.types[""+e]&&(r.animation=e),m.push({type:"badge",options:{n:t}}),m.length>100)throw"Too many badges requests in queue...";v.start()}else v.reset()}catch(o){throw"Error setting badge..."}},f&&y()},A=function(t){y=function(){try{var e=t.width,o=t.height,n=document.createElement("img"),r=o/a>e/h?e/h:o/a;n.setAttribute("src",t.getAttribute("src")),n.height=o/r,n.width=e/r,s.clearRect(0,0,h,a),s.drawImage(n,0,0,h,a),E.setIcon(c)}catch(i){throw"Error setting image..."}},f&&y()},M=function(t){y=function(){try{if("stop"===t)return g=!0,v.reset(),g=!1,void 0;t.addEventListener("play",function(){e(this)},!1)}catch(o){throw"Error setting video..."}},f&&y()},T=function(t){if(window.URL&&window.URL.createObjectURL||(window.URL=window.URL||{},window.URL.createObjectURL=function(t){return t}),w.supported){var o=!1;navigator.getUserMedia=navigator.getUserMedia||navigator.oGetUserMedia||navigator.msGetUserMedia||navigator.mozGetUserMedia||navigator.webkitGetUserMedia,y=function(){try{if("stop"===t)return g=!0,v.reset(),g=!1,void 0;o=document.createElement("video"),o.width=h,o.height=a,navigator.getUserMedia({video:!0,audio:!1},function(t){o.src=URL.createObjectURL(t),o.play(),e(o)},function(){})}catch(n){throw"Error setting webcam..."}},f&&y()}},E={};E.getIcon=function(){var t=!1,e=function(){for(var t=document.getElementsByTagName("head")[0].getElementsByTagName("link"),e=t.length,o=e-1;o>=0;o--)if(/icon/i.test(t[o].getAttribute("rel")))return t[o];return!1};return r.elementId?(t=document.getElementById(r.elementId),t.setAttribute("href",t.getAttribute("src"))):(t=e(),t===!1&&(t=document.createElement("link"),t.setAttribute("rel","icon"),document.getElementsByTagName("head")[0].appendChild(t))),t.setAttribute("type","image/png"),t},E.setIcon=function(t){var e=t.toDataURL("image/png");if(r.elementId)document.getElementById(r.elementId).setAttribute("src",e);else if(w.ff||w.opera){var o=i;i=document.createElement("link"),w.opera&&i.setAttribute("rel","icon"),i.setAttribute("rel","icon"),i.setAttribute("type","image/png"),document.getElementsByTagName("head")[0].appendChild(i),i.setAttribute("href",e),o.parentNode&&o.parentNode.removeChild(o)}else i.setAttribute("href",e)};var L={};return L.duration=40,L.types={},L.types.fade=[{x:.4,y:.4,w:.6,h:.6,o:0},{x:.4,y:.4,w:.6,h:.6,o:.1},{x:.4,y:.4,w:.6,h:.6,o:.2},{x:.4,y:.4,w:.6,h:.6,o:.3},{x:.4,y:.4,w:.6,h:.6,o:.4},{x:.4,y:.4,w:.6,h:.6,o:.5},{x:.4,y:.4,w:.6,h:.6,o:.6},{x:.4,y:.4,w:.6,h:.6,o:.7},{x:.4,y:.4,w:.6,h:.6,o:.8},{x:.4,y:.4,w:.6,h:.6,o:.9},{x:.4,y:.4,w:.6,h:.6,o:1}],L.types.none=[{x:.4,y:.4,w:.6,h:.6,o:1}],L.types.pop=[{x:1,y:1,w:0,h:0,o:1},{x:.9,y:.9,w:.1,h:.1,o:1},{x:.8,y:.8,w:.2,h:.2,o:1},{x:.7,y:.7,w:.3,h:.3,o:1},{x:.6,y:.6,w:.4,h:.4,o:1},{x:.5,y:.5,w:.5,h:.5,o:1},{x:.4,y:.4,w:.6,h:.6,o:1}],L.types.popFade=[{x:.75,y:.75,w:0,h:0,o:0},{x:.65,y:.65,w:.1,h:.1,o:.2},{x:.6,y:.6,w:.2,h:.2,o:.4},{x:.55,y:.55,w:.3,h:.3,o:.6},{x:.5,y:.5,w:.4,h:.4,o:.8},{x:.45,y:.45,w:.5,h:.5,o:.9},{x:.4,y:.4,w:.6,h:.6,o:1}],L.types.slide=[{x:.4,y:1,w:.6,h:.6,o:1},{x:.4,y:.9,w:.6,h:.6,o:1},{x:.4,y:.9,w:.6,h:.6,o:1},{x:.4,y:.8,w:.6,h:.6,o:1},{x:.4,y:.7,w:.6,h:.6,o:1},{x:.4,y:.6,w:.6,h:.6,o:1},{x:.4,y:.5,w:.6,h:.6,o:1},{x:.4,y:.4,w:.6,h:.6,o:1}],L.run=function(t,e,o,i){var a=L.types[r.animation];return i=o===!0?"undefined"!=typeof i?i:a.length-1:"undefined"!=typeof i?i:0,e=e?e:function(){},i<a.length&&i>=0?(b[r.type](n(t,a[i])),setTimeout(function(){o?i-=1:i+=1,L.run(t,e,o,i)},L.duration),E.setIcon(c),void 0):(e(),void 0)},p(),{badge:I,video:M,image:A,webcam:T,reset:v.reset}};"undefined"!=typeof define&&define.amd?define([],function(){return t}):"undefined"!=typeof module&&module.exports?module.exports=t:this.Favico=t}();

/**
 * jquery.emodal.js v1.0.0
 * http://8theme.com
 *
 * Licensed under the MIT license.
 * http://www.opensource.org/licenses/mit-license.php
 * 
 * Copyright 2013, Serg
 * http://8theme.com
 */
;( function( $, window, undefined ) {

	'use strict';

	// global
	var Modernizr = window.Modernizr;

	var settings = {};


	var methods = {
		_init : function( options ) {

			methods.$el = $(this);

			// options
			methods.options = $.extend(true, {
				'custom': false,
				'modalIdAttribute': 'modal-id',
				'hiddeBtnID': 'hideemodal'
			}, options);

			methods._config();

			// show modal
			methods.$el.click(function(event) {
				//methods.showModal();
			});

			return this;

		},
		_config : function() {

			//modal window
			var id = methods.$el.data(methods.options.modalIdAttribute);
			settings.modal = $('#' + id);

			return this;

		},
		showModal : function() {
			// base HTML
			methods.baseHtml();
            methods.startLoading();
			settings.overlay.addClass('shown');
			settings.html.addClass('shown');
			return this;
		},
		hideModal: function() {
			settings.overlay.removeClass('shown');
			settings.html.removeClass('shown');
			setTimeout(function(){
				methods.destroy();
			}, 300)
			return this;
		},
		setHideEvent: function (){
			// hide modal
			settings.overlay.click(function(event) {
				methods.hideModal();
			});

			settings.closeBtnHtml.click(function(event) {
				methods.hideModal();
			});

			// other hide btn
			var hideBtn = $('#' + methods.options.hiddeBtnID);
			hideBtn.click(function(event) {
				methods.hideModal();
			});
		},
		setHTML: function(html){
			settings.html.html(html);
			return this;
		},
		setTitle: function(title){
			settings.modalTitle.text(title);
			return this;
		},
		addText: function(text){
			settings.modalText.append(text);
			return this;
		},
		addError: function(text){
			settings.modalText.append('<p class="error-msg">' + text + '</p>');
			settings.modalTitle.text('ERROR');
			return this;
		},
		addImage: function(src){
			settings.html.addClass('with-image');
			settings.modalImage = jQuery('<img src="' + src + '" />').appendTo(settings.html);
			return this;
		},
		addBtn: function(attr){
			attr = $.extend(true, {
				'href': '',
				'cssClass': '',
				'onclick': '',
				'id': '',
				'title': '',
				'hideOnClick': false
			}, attr);

			settings.modalBtn = jQuery('<a href="' + attr.href + '" id="' + attr.id + '" class="' + attr.cssClass + '" onclick="' + attr.onclick + '"><span>' + attr.title + '</span></a>').appendTo(settings.modalText);
		
			if(attr.hideOnClick) {
				settings.modalBtn.click(function(){
					methods.hideModal();
				});
			}

			return this;
		},
		startLoading: function(){
			settings.html.addClass('eloading');
			return this;
		},
		endLoading: function(){
			settings.html.removeClass('eloading');
			return this;
		},
		baseHtml: function (){
			// Base HTML structure
			settings.overlay = jQuery('<div class="emodal-overlay"></div>');
			settings.html = jQuery('<div class="emodal" id="base-modal"><div class="emodal-border"></div></div>');
			settings.modalText = jQuery('<div class="emodal-text"></div>').prependTo(settings.html);
			settings.modalTitle = jQuery('<h5 class="emodal-title"></h5>').prependTo(settings.modalText);
			settings.closeBtnHtml = jQuery('<div class="close-modal"><i class="icon-remove"></i></div>').prependTo(settings.html);

			if(Modernizr.csstransforms) {
				settings.overlay.addClass('with-transforms');
				settings.html.addClass('with-transforms');
			}

			if(Modernizr.csstransitions) {
				settings.overlay.addClass('with-transitions');
				settings.html.addClass('with-transitions');
			}

			// add base html to body
			$('body').prepend(settings.overlay);
			$('body').prepend(settings.html);
			methods.setHideEvent();
			return this;

		},
		destroy: function(){
			settings.overlay.remove();
			settings.html.remove();
			return this;
		}
	}

	/* public functions */
	$.fn.eModal = function(method) {

		if(methods[method]) {
			return methods[method].apply(this, Array.prototype.slice.call(arguments, 1));
		} else if (typeof method === 'object' || !method) {
			return methods._init.apply(this, arguments);
		} else {
			$.error('invalid method call!');
		}

    };


	var logError = function( message ) {
		if ( window.console ) {
			window.console.error( message );
		}
	};


} )( jQuery, window );



/*! Copyright (c) 2011 Brandon Aaron (http://brandonaaron.net)
 * Licensed under the MIT License (LICENSE.txt).
 *
 * Thanks to: http://adomas.org/javascript-mouse-wheel/ for some pointers.
 * Thanks to: Mathias Bank(http://www.mathias-bank.de) for a scope bug fix.
 * Thanks to: Seamus Leahy for adding deltaX and deltaY
 *
 * Version: 3.0.6
 * 
 * Requires: 1.2.2+
 */

(function($) {

var types = ['DOMMouseScroll', 'mousewheel'];

if ($.event.fixHooks) {
    for ( var i=types.length; i; ) {
        $.event.fixHooks[ types[--i] ] = $.event.mouseHooks;
    }
}

$.event.special.mousewheel = {
    setup: function() {
        if ( this.addEventListener ) {
            for ( var i=types.length; i; ) {
                this.addEventListener( types[--i], handler, false );
            }
        } else {
            this.onmousewheel = handler;
        }
    },
    
    teardown: function() {
        if ( this.removeEventListener ) {
            for ( var i=types.length; i; ) {
                this.removeEventListener( types[--i], handler, false );
            }
        } else {
            this.onmousewheel = null;
        }
    }
};

$.fn.extend({
    mousewheel: function(fn) {
        return fn ? this.bind("mousewheel", fn) : this.trigger("mousewheel");
    },
    
    unmousewheel: function(fn) {
        return this.unbind("mousewheel", fn);
    }
});


function handler(event) {
    var orgEvent = event || window.event, args = [].slice.call( arguments, 1 ), delta = 0, returnValue = true, deltaX = 0, deltaY = 0;
    event = $.event.fix(orgEvent);
    event.type = "mousewheel";
    
    // Old school scrollwheel delta
    if ( orgEvent.wheelDelta ) { delta = orgEvent.wheelDelta/120; }
    if ( orgEvent.detail     ) { delta = -orgEvent.detail/3; }
    
    // New school multidimensional scroll (touchpads) deltas
    deltaY = delta;
    
    // Gecko
    if ( orgEvent.axis !== undefined && orgEvent.axis === orgEvent.HORIZONTAL_AXIS ) {
        deltaY = 0;
        deltaX = -1*delta;
    }
    
    // Webkit
    if ( orgEvent.wheelDeltaY !== undefined ) { deltaY = orgEvent.wheelDeltaY/120; }
    if ( orgEvent.wheelDeltaX !== undefined ) { deltaX = -1*orgEvent.wheelDeltaX/120; }
    
    // Add event and delta to the front of the arguments
    args.unshift(event, delta, deltaX, deltaY);
    
    return ($.event.dispatch || $.event.handle).apply(this, args);
}

})(jQuery);


/* Tooltipster v3.2.4 */;(function(e,t,n){function s(t,n){this.bodyOverflowX;this.callbacks={hide:[],show:[]};this.checkInterval=null;this.Content;this.$el=e(t);this.$elProxy;this.elProxyPosition;this.enabled=true;this.options=e.extend({},i,n);this.mouseIsOverProxy=false;this.namespace="tooltipster-"+Math.round(Math.random()*1e5);this.Status="hidden";this.timerHide=null;this.timerShow=null;this.$tooltip;this.options.iconTheme=this.options.iconTheme.replace(".","");this.options.theme=this.options.theme.replace(".","");this._init()}function o(t,n){var r=true;e.each(t,function(e,i){if(typeof n[e]==="undefined"||t[e]!==n[e]){r=false;return false}});return r}function f(){return!a&&u}function l(){var e=n.body||n.documentElement,t=e.style,r="transition";if(typeof t[r]=="string"){return true}v=["Moz","Webkit","Khtml","O","ms"],r=r.charAt(0).toUpperCase()+r.substr(1);for(var i=0;i<v.length;i++){if(typeof t[v[i]+r]=="string"){return true}}return false}var r="tooltipster",i={animation:"fade",arrow:true,arrowColor:"",autoClose:true,content:null,contentAsHTML:false,contentCloning:true,delay:200,minWidth:0,maxWidth:null,functionInit:function(e,t){},functionBefore:function(e,t){t()},functionReady:function(e,t){},functionAfter:function(e){},icon:"(?)",iconCloning:true,iconDesktop:false,iconTouch:false,iconTheme:"tooltipster-icon",interactive:false,interactiveTolerance:350,multiple:false,offsetX:0,offsetY:0,onlyOne:false,position:"top",positionTracker:false,speed:350,timer:0,theme:"tooltipster-default",touchDevices:true,trigger:"hover",updateAnimation:true};s.prototype={_init:function(){var t=this;if(n.querySelector){if(t.options.content!==null){t._content_set(t.options.content)}else{var r=t.$el.attr("title");if(typeof r==="undefined")r=null;t._content_set(r)}var i=t.options.functionInit.call(t.$el,t.$el,t.Content);if(typeof i!=="undefined")t._content_set(i);t.$el.removeAttr("title").addClass("tooltipstered");if(!u&&t.options.iconDesktop||u&&t.options.iconTouch){if(typeof t.options.icon==="string"){t.$elProxy=e('<span class="'+t.options.iconTheme+'"></span>');t.$elProxy.text(t.options.icon)}else{if(t.options.iconCloning)t.$elProxy=t.options.icon.clone(true);else t.$elProxy=t.options.icon}t.$elProxy.insertAfter(t.$el)}else{t.$elProxy=t.$el}if(t.options.trigger=="hover"){t.$elProxy.on("mouseenter."+t.namespace,function(){if(!f()||t.options.touchDevices){t.mouseIsOverProxy=true;t._show()}}).on("mouseleave."+t.namespace,function(){if(!f()||t.options.touchDevices){t.mouseIsOverProxy=false}});if(u&&t.options.touchDevices){t.$elProxy.on("touchstart."+t.namespace,function(){t._showNow()})}}else if(t.options.trigger=="click"){t.$elProxy.on("click."+t.namespace,function(){if(!f()||t.options.touchDevices){t._show()}})}}},_show:function(){var e=this;if(e.Status!="shown"&&e.Status!="appearing"){if(e.options.delay){e.timerShow=setTimeout(function(){if(e.options.trigger=="click"||e.options.trigger=="hover"&&e.mouseIsOverProxy){e._showNow()}},e.options.delay)}else e._showNow()}},_showNow:function(n){var r=this;r.options.functionBefore.call(r.$el,r.$el,function(){if(r.enabled&&r.Content!==null){if(n)r.callbacks.show.push(n);r.callbacks.hide=[];clearTimeout(r.timerShow);r.timerShow=null;clearTimeout(r.timerHide);r.timerHide=null;if(r.options.onlyOne){e(".tooltipstered").not(r.$el).each(function(t,n){var r=e(n),i=r.data("tooltipster-ns");e.each(i,function(e,t){var n=r.data(t),i=n.status(),s=n.option("autoClose");if(i!=="hidden"&&i!=="disappearing"&&s){n.hide()}})})}var i=function(){r.Status="shown";e.each(r.callbacks.show,function(e,t){t.call(r.$el)});r.callbacks.show=[]};if(r.Status!=="hidden"){var s=0;if(r.Status==="disappearing"){r.Status="appearing";if(l()){r.$tooltip.clearQueue().removeClass("tooltipster-dying").addClass("tooltipster-"+r.options.animation+"-show");if(r.options.speed>0)r.$tooltip.delay(r.options.speed);r.$tooltip.queue(i)}else{r.$tooltip.stop().fadeIn(i)}}else if(r.Status==="shown"){i()}}else{r.Status="appearing";var s=r.options.speed;r.bodyOverflowX=e("body").css("overflow-x");e("body").css("overflow-x","hidden");var o="tooltipster-"+r.options.animation,a="-webkit-transition-duration: "+r.options.speed+"ms; -webkit-animation-duration: "+r.options.speed+"ms; -moz-transition-duration: "+r.options.speed+"ms; -moz-animation-duration: "+r.options.speed+"ms; -o-transition-duration: "+r.options.speed+"ms; -o-animation-duration: "+r.options.speed+"ms; -ms-transition-duration: "+r.options.speed+"ms; -ms-animation-duration: "+r.options.speed+"ms; transition-duration: "+r.options.speed+"ms; animation-duration: "+r.options.speed+"ms;",f=r.options.minWidth?"min-width:"+Math.round(r.options.minWidth)+"px;":"",c=r.options.maxWidth?"max-width:"+Math.round(r.options.maxWidth)+"px;":"",h=r.options.interactive?"pointer-events: auto;":"";r.$tooltip=e('<div class="tooltipster-base '+r.options.theme+'" style="'+f+" "+c+" "+h+" "+a+'"><div class="tooltipster-content"></div></div>');if(l())r.$tooltip.addClass(o);r._content_insert();r.$tooltip.appendTo("body");r.reposition();r.options.functionReady.call(r.$el,r.$el,r.$tooltip);if(l()){r.$tooltip.addClass(o+"-show");if(r.options.speed>0)r.$tooltip.delay(r.options.speed);r.$tooltip.queue(i)}else{r.$tooltip.css("display","none").fadeIn(r.options.speed,i)}r._interval_set();e(t).on("scroll."+r.namespace+" resize."+r.namespace,function(){r.reposition()});if(r.options.autoClose){e("body").off("."+r.namespace);if(r.options.trigger=="hover"){if(u){setTimeout(function(){e("body").on("touchstart."+r.namespace,function(){r.hide()})},0)}if(r.options.interactive){if(u){r.$tooltip.on("touchstart."+r.namespace,function(e){e.stopPropagation()})}var p=null;r.$elProxy.add(r.$tooltip).on("mouseleave."+r.namespace+"-autoClose",function(){clearTimeout(p);p=setTimeout(function(){r.hide()},r.options.interactiveTolerance)}).on("mouseenter."+r.namespace+"-autoClose",function(){clearTimeout(p)})}else{r.$elProxy.on("mouseleave."+r.namespace+"-autoClose",function(){r.hide()})}}else if(r.options.trigger=="click"){setTimeout(function(){e("body").on("click."+r.namespace+" touchstart."+r.namespace,function(){r.hide()})},0);if(r.options.interactive){r.$tooltip.on("click."+r.namespace+" touchstart."+r.namespace,function(e){e.stopPropagation()})}}}}if(r.options.timer>0){r.timerHide=setTimeout(function(){r.timerHide=null;r.hide()},r.options.timer+s)}}})},_interval_set:function(){var t=this;t.checkInterval=setInterval(function(){if(e("body").find(t.$el).length===0||e("body").find(t.$elProxy).length===0||t.Status=="hidden"||e("body").find(t.$tooltip).length===0){if(t.Status=="shown"||t.Status=="appearing")t.hide();t._interval_cancel()}else{if(t.options.positionTracker){var n=t._repositionInfo(t.$elProxy),r=false;if(o(n.dimension,t.elProxyPosition.dimension)){if(t.$elProxy.css("position")==="fixed"){if(o(n.position,t.elProxyPosition.position))r=true}else{if(o(n.offset,t.elProxyPosition.offset))r=true}}if(!r){t.reposition()}}}},200)},_interval_cancel:function(){clearInterval(this.checkInterval);this.checkInterval=null},_content_set:function(e){if(typeof e==="object"&&e!==null&&this.options.contentCloning){e=e.clone(true)}this.Content=e},_content_insert:function(){var e=this,t=this.$tooltip.find(".tooltipster-content");if(typeof e.Content==="string"&&!e.options.contentAsHTML){t.text(e.Content)}else{t.empty().append(e.Content)}},_update:function(e){var t=this;t._content_set(e);if(t.Content!==null){if(t.Status!=="hidden"){t._content_insert();t.reposition();if(t.options.updateAnimation){if(l()){t.$tooltip.css({width:"","-webkit-transition":"all "+t.options.speed+"ms, width 0ms, height 0ms, left 0ms, top 0ms","-moz-transition":"all "+t.options.speed+"ms, width 0ms, height 0ms, left 0ms, top 0ms","-o-transition":"all "+t.options.speed+"ms, width 0ms, height 0ms, left 0ms, top 0ms","-ms-transition":"all "+t.options.speed+"ms, width 0ms, height 0ms, left 0ms, top 0ms",transition:"all "+t.options.speed+"ms, width 0ms, height 0ms, left 0ms, top 0ms"}).addClass("tooltipster-content-changing");setTimeout(function(){if(t.Status!="hidden"){t.$tooltip.removeClass("tooltipster-content-changing");setTimeout(function(){if(t.Status!=="hidden"){t.$tooltip.css({"-webkit-transition":t.options.speed+"ms","-moz-transition":t.options.speed+"ms","-o-transition":t.options.speed+"ms","-ms-transition":t.options.speed+"ms",transition:t.options.speed+"ms"})}},t.options.speed)}},t.options.speed)}else{t.$tooltip.fadeTo(t.options.speed,.5,function(){if(t.Status!="hidden"){t.$tooltip.fadeTo(t.options.speed,1)}})}}}}else{t.hide()}},_repositionInfo:function(e){return{dimension:{height:e.outerHeight(false),width:e.outerWidth(false)},offset:e.offset(),position:{left:parseInt(e.css("left")),top:parseInt(e.css("top"))}}},hide:function(n){var r=this;if(n)r.callbacks.hide.push(n);r.callbacks.show=[];clearTimeout(r.timerShow);r.timerShow=null;clearTimeout(r.timerHide);r.timerHide=null;var i=function(){e.each(r.callbacks.hide,function(e,t){t.call(r.$el)});r.callbacks.hide=[]};if(r.Status=="shown"||r.Status=="appearing"){r.Status="disappearing";var s=function(){r.Status="hidden";if(typeof r.Content=="object"&&r.Content!==null){r.Content.detach()}r.$tooltip.remove();r.$tooltip=null;e(t).off("."+r.namespace);e("body").off("."+r.namespace).css("overflow-x",r.bodyOverflowX);e("body").off("."+r.namespace);r.$elProxy.off("."+r.namespace+"-autoClose");r.options.functionAfter.call(r.$el,r.$el);i()};if(l()){r.$tooltip.clearQueue().removeClass("tooltipster-"+r.options.animation+"-show").addClass("tooltipster-dying");if(r.options.speed>0)r.$tooltip.delay(r.options.speed);r.$tooltip.queue(s)}else{r.$tooltip.stop().fadeOut(r.options.speed,s)}}else if(r.Status=="hidden"){i()}return r},show:function(e){this._showNow(e);return this},update:function(e){return this.content(e)},content:function(e){if(typeof e==="undefined"){return this.Content}else{this._update(e);return this}},reposition:function(){var n=this;if(e("body").find(n.$tooltip).length!==0){n.$tooltip.css("width","");n.elProxyPosition=n._repositionInfo(n.$elProxy);var r=null,i=e(t).width(),s=n.elProxyPosition,o=n.$tooltip.outerWidth(false),u=n.$tooltip.innerWidth()+1,a=n.$tooltip.outerHeight(false);if(n.$elProxy.is("area")){var f=n.$elProxy.attr("shape"),l=n.$elProxy.parent().attr("name"),c=e('img[usemap="#'+l+'"]'),h=c.offset().left,p=c.offset().top,d=n.$elProxy.attr("coords")!==undefined?n.$elProxy.attr("coords").split(","):undefined;if(f=="circle"){var v=parseInt(d[0]),m=parseInt(d[1]),g=parseInt(d[2]);s.dimension.height=g*2;s.dimension.width=g*2;s.offset.top=p+m-g;s.offset.left=h+v-g}else if(f=="rect"){var v=parseInt(d[0]),m=parseInt(d[1]),y=parseInt(d[2]),b=parseInt(d[3]);s.dimension.height=b-m;s.dimension.width=y-v;s.offset.top=p+m;s.offset.left=h+v}else if(f=="poly"){var w=[],E=[],S=0,x=0,T=0,N=0,C="even";for(var k=0;k<d.length;k++){var L=parseInt(d[k]);if(C=="even"){if(L>T){T=L;if(k===0){S=T}}if(L<S){S=L}C="odd"}else{if(L>N){N=L;if(k==1){x=N}}if(L<x){x=L}C="even"}}s.dimension.height=N-x;s.dimension.width=T-S;s.offset.top=p+x;s.offset.left=h+S}else{s.dimension.height=c.outerHeight(false);s.dimension.width=c.outerWidth(false);s.offset.top=p;s.offset.left=h}}var A=0,O=0,M=0,_=parseInt(n.options.offsetY),D=parseInt(n.options.offsetX),P=n.options.position;function H(){var n=e(t).scrollLeft();if(A-n<0){r=A-n;A=n}if(A+o-n>i){r=A-(i+n-o);A=i+n-o}}function B(n,r){if(s.offset.top-e(t).scrollTop()-a-_-12<0&&r.indexOf("top")>-1){P=n}if(s.offset.top+s.dimension.height+a+12+_>e(t).scrollTop()+e(t).height()&&r.indexOf("bottom")>-1){P=n;M=s.offset.top-a-_-12}}if(P=="top"){var j=s.offset.left+o-(s.offset.left+s.dimension.width);A=s.offset.left+D-j/2;M=s.offset.top-a-_-12;H();B("bottom","top")}if(P=="top-left"){A=s.offset.left+D;M=s.offset.top-a-_-12;H();B("bottom-left","top-left")}if(P=="top-right"){A=s.offset.left+s.dimension.width+D-o;M=s.offset.top-a-_-12;H();B("bottom-right","top-right")}if(P=="bottom"){var j=s.offset.left+o-(s.offset.left+s.dimension.width);A=s.offset.left-j/2+D;M=s.offset.top+s.dimension.height+_+12;H();B("top","bottom")}if(P=="bottom-left"){A=s.offset.left+D;M=s.offset.top+s.dimension.height+_+12;H();B("top-left","bottom-left")}if(P=="bottom-right"){A=s.offset.left+s.dimension.width+D-o;M=s.offset.top+s.dimension.height+_+12;H();B("top-right","bottom-right")}if(P=="left"){A=s.offset.left-D-o-12;O=s.offset.left+D+s.dimension.width+12;var F=s.offset.top+a-(s.offset.top+s.dimension.height);M=s.offset.top-F/2-_;if(A<0&&O+o>i){var I=parseFloat(n.$tooltip.css("border-width"))*2,q=o+A-I;n.$tooltip.css("width",q+"px");a=n.$tooltip.outerHeight(false);A=s.offset.left-D-q-12-I;F=s.offset.top+a-(s.offset.top+s.dimension.height);M=s.offset.top-F/2-_}else if(A<0){A=s.offset.left+D+s.dimension.width+12;r="left"}}if(P=="right"){A=s.offset.left+D+s.dimension.width+12;O=s.offset.left-D-o-12;var F=s.offset.top+a-(s.offset.top+s.dimension.height);M=s.offset.top-F/2-_;if(A+o>i&&O<0){var I=parseFloat(n.$tooltip.css("border-width"))*2,q=i-A-I;n.$tooltip.css("width",q+"px");a=n.$tooltip.outerHeight(false);F=s.offset.top+a-(s.offset.top+s.dimension.height);M=s.offset.top-F/2-_}else if(A+o>i){A=s.offset.left-D-o-12;r="right"}}if(n.options.arrow){var R="tooltipster-arrow-"+P;if(n.options.arrowColor.length<1){var U=n.$tooltip.css("background-color")}else{var U=n.options.arrowColor}if(!r){r=""}else if(r=="left"){R="tooltipster-arrow-right";r=""}else if(r=="right"){R="tooltipster-arrow-left";r=""}else{r="left:"+Math.round(r)+"px;"}if(P=="top"||P=="top-left"||P=="top-right"){var z=parseFloat(n.$tooltip.css("border-bottom-width")),W=n.$tooltip.css("border-bottom-color")}else if(P=="bottom"||P=="bottom-left"||P=="bottom-right"){var z=parseFloat(n.$tooltip.css("border-top-width")),W=n.$tooltip.css("border-top-color")}else if(P=="left"){var z=parseFloat(n.$tooltip.css("border-right-width")),W=n.$tooltip.css("border-right-color")}else if(P=="right"){var z=parseFloat(n.$tooltip.css("border-left-width")),W=n.$tooltip.css("border-left-color")}else{var z=parseFloat(n.$tooltip.css("border-bottom-width")),W=n.$tooltip.css("border-bottom-color")}if(z>1){z++}var X="";if(z!==0){var V="",J="border-color: "+W+";";if(R.indexOf("bottom")!==-1){V="margin-top: -"+Math.round(z)+"px;"}else if(R.indexOf("top")!==-1){V="margin-bottom: -"+Math.round(z)+"px;"}else if(R.indexOf("left")!==-1){V="margin-right: -"+Math.round(z)+"px;"}else if(R.indexOf("right")!==-1){V="margin-left: -"+Math.round(z)+"px;"}X='<span class="tooltipster-arrow-border" style="'+V+" "+J+';"></span>'}n.$tooltip.find(".tooltipster-arrow").remove();var K='<div class="'+R+' tooltipster-arrow" style="'+r+'">'+X+'<span style="border-color:'+U+';"></span></div>';n.$tooltip.append(K)}n.$tooltip.css({top:Math.round(M)+"px",left:Math.round(A)+"px"})}return n},enable:function(){this.enabled=true;return this},disable:function(){this.hide();this.enabled=false;return this},destroy:function(){var t=this;t.hide();if(t.$el[0]!==t.$elProxy[0])t.$elProxy.remove();t.$el.removeData(t.namespace).off("."+t.namespace);var n=t.$el.data("tooltipster-ns");if(n.length===1){var r=typeof t.Content==="string"?t.Content:e("<div></div>").append(t.Content).html();t.$el.removeClass("tooltipstered").attr("title",r).removeData(t.namespace).removeData("tooltipster-ns").off("."+t.namespace)}else{n=e.grep(n,function(e,n){return e!==t.namespace});t.$el.data("tooltipster-ns",n)}return t},elementIcon:function(){return this.$el[0]!==this.$elProxy[0]?this.$elProxy[0]:undefined},elementTooltip:function(){return this.$tooltip?this.$tooltip[0]:undefined},option:function(e,t){if(typeof t=="undefined")return this.options[e];else{this.options[e]=t;return this}},status:function(){return this.Status}};e.fn[r]=function(){var t=arguments;if(this.length===0){if(typeof t[0]==="string"){var n=true;switch(t[0]){case"setDefaults":e.extend(i,t[1]);break;default:n=false;break}if(n)return true;else return this}else{return this}}else{if(typeof t[0]==="string"){var r="#*$~&";this.each(function(){var n=e(this).data("tooltipster-ns"),i=n?e(this).data(n[0]):null;if(i){if(typeof i[t[0]]==="function"){var s=i[t[0]](t[1],t[2])}else{throw new Error('Unknown method .tooltipster("'+t[0]+'")')}if(s!==i){r=s;return false}}else{throw new Error("You called Tooltipster's \""+t[0]+'" method on an uninitialized element')}});return r!=="#*$~&"?r:this}else{var o=[],u=t[0]&&typeof t[0].multiple!=="undefined",a=u&&t[0].multiple||!u&&i.multiple;this.each(function(){var n=false,r=e(this).data("tooltipster-ns"),i=null;if(!r){n=true}else{if(a)n=true;else console.log('Tooltipster: one or more tooltips are already attached to this element: ignoring. Use the "multiple" option to attach more tooltips.')}if(n){i=new s(this,t[0]);if(!r)r=[];r.push(i.namespace);e(this).data("tooltipster-ns",r);e(this).data(i.namespace,i)}o.push(i)});if(a)return o;else return this}}};var u=!!("ontouchstart"in t);var a=false;e("body").one("mousemove",function(){a=true})})(jQuery,window,document)

/*Parallax on mouse move*/
!function(t,i,e,s){"use strict";function o(i,e){this.element=i,this.$context=t(i).data("api",this),this.$layers=this.$context.find(".layer");var s={calibrateX:this.$context.data("calibrate-x")||null,calibrateY:this.$context.data("calibrate-y")||null,invertX:this.$context.data("invert-x")||null,invertY:this.$context.data("invert-y")||null,limitX:parseFloat(this.$context.data("limit-x"))||null,limitY:parseFloat(this.$context.data("limit-y"))||null,scalarX:parseFloat(this.$context.data("scalar-x"))||null,scalarY:parseFloat(this.$context.data("scalar-y"))||null,frictionX:parseFloat(this.$context.data("friction-x"))||null,frictionY:parseFloat(this.$context.data("friction-y"))||null,originX:parseFloat(this.$context.data("origin-x"))||null,originY:parseFloat(this.$context.data("origin-y"))||null};for(var o in s)null===s[o]&&delete s[o];t.extend(this,r,e,s),this.calibrationTimer=null,this.calibrationFlag=!0,this.enabled=!1,this.depths=[],this.raf=null,this.bounds=null,this.ex=0,this.ey=0,this.ew=0,this.eh=0,this.ecx=0,this.ecy=0,this.erx=0,this.ery=0,this.cx=0,this.cy=0,this.ix=0,this.iy=0,this.mx=0,this.my=0,this.vx=0,this.vy=0,this.onMouseMove=this.onMouseMove.bind(this),this.onDeviceOrientation=this.onDeviceOrientation.bind(this),this.onOrientationTimer=this.onOrientationTimer.bind(this),this.onCalibrationTimer=this.onCalibrationTimer.bind(this),this.onAnimationFrame=this.onAnimationFrame.bind(this),this.onWindowResize=this.onWindowResize.bind(this),this.initialise()}var n="parallax",a=30,r={relativeInput:!1,clipRelativeInput:!1,calibrationThreshold:100,calibrationDelay:500,supportDelay:500,calibrateX:!1,calibrateY:!0,invertX:!0,invertY:!0,limitX:!1,limitY:!1,scalarX:10,scalarY:10,frictionX:.1,frictionY:.1,originX:.5,originY:.5};o.prototype.transformSupport=function(t){for(var o=e.createElement("div"),n=!1,a=null,r=!1,h=null,l=null,p=0,c=this.vendors.length;c>p;p++)if(null!==this.vendors[p]?(h=this.vendors[p][0]+"transform",l=this.vendors[p][1]+"Transform"):(h="transform",l="transform"),o.style[l]!==s){n=!0;break}switch(t){case"2D":r=n;break;case"3D":if(n){var m=e.body||e.createElement("body"),u=e.documentElement,y=u.style.overflow;e.body||(u.style.overflow="hidden",u.appendChild(m),m.style.overflow="hidden",m.style.background=""),m.appendChild(o),o.style[l]="translate3d(1px,1px,1px)",a=i.getComputedStyle(o).getPropertyValue(h),r=a!==s&&a.length>0&&"none"!==a,u.style.overflow=y,m.removeChild(o)}}return r},o.prototype.ww=null,o.prototype.wh=null,o.prototype.wcx=null,o.prototype.wcy=null,o.prototype.wrx=null,o.prototype.wry=null,o.prototype.portrait=null,o.prototype.desktop=!navigator.userAgent.match(/(iPhone|iPod|iPad|Android|BlackBerry|BB10|mobi|tablet|opera mini|nexus 7)/i),o.prototype.vendors=[null,["-webkit-","webkit"],["-moz-","Moz"],["-o-","O"],["-ms-","ms"]],o.prototype.motionSupport=!!i.DeviceMotionEvent,o.prototype.orientationSupport=!!i.DeviceOrientationEvent,o.prototype.orientationStatus=0,o.prototype.transform2DSupport=o.prototype.transformSupport("2D"),o.prototype.transform3DSupport=o.prototype.transformSupport("3D"),o.prototype.propertyCache={},o.prototype.initialise=function(){"static"===this.$context.css("position")&&this.$context.css({position:"relative"}),this.accelerate(this.$context),this.updateLayers(),this.updateDimensions(),this.enable(),this.queueCalibration(this.calibrationDelay)},o.prototype.updateLayers=function(){this.$layers=this.$context.find(".layer"),this.depths=[],this.$layers.css({position:"absolute",display:"block",left:0,top:0}),this.$layers.first().css({position:"relative"}),this.accelerate(this.$layers),this.$layers.each(t.proxy(function(i,e){this.depths.push(t(e).data("depth")||0)},this))},o.prototype.updateDimensions=function(){this.ww=i.innerWidth,this.wh=i.innerHeight,this.wcx=this.ww*this.originX,this.wcy=this.wh*this.originY,this.wrx=Math.max(this.wcx,this.ww-this.wcx),this.wry=Math.max(this.wcy,this.wh-this.wcy)},o.prototype.updateBounds=function(){this.bounds=this.element.getBoundingClientRect(),this.ex=this.bounds.left,this.ey=this.bounds.top,this.ew=this.bounds.width,this.eh=this.bounds.height,this.ecx=this.ew*this.originX,this.ecy=this.eh*this.originY,this.erx=Math.max(this.ecx,this.ew-this.ecx),this.ery=Math.max(this.ecy,this.eh-this.ecy)},o.prototype.queueCalibration=function(t){clearTimeout(this.calibrationTimer),this.calibrationTimer=setTimeout(this.onCalibrationTimer,t)},o.prototype.enable=function(){this.enabled||(this.enabled=!0,this.orientationSupport?(this.portrait=null,i.addEventListener("deviceorientation",this.onDeviceOrientation),setTimeout(this.onOrientationTimer,this.supportDelay)):(this.cx=0,this.cy=0,this.portrait=!1,i.addEventListener("mousemove",this.onMouseMove)),i.addEventListener("resize",this.onWindowResize),this.raf=requestAnimationFrame(this.onAnimationFrame))},o.prototype.disable=function(){this.enabled&&(this.enabled=!1,this.orientationSupport?i.removeEventListener("deviceorientation",this.onDeviceOrientation):i.removeEventListener("mousemove",this.onMouseMove),i.removeEventListener("resize",this.onWindowResize),cancelAnimationFrame(this.raf))},o.prototype.calibrate=function(t,i){this.calibrateX=t===s?this.calibrateX:t,this.calibrateY=i===s?this.calibrateY:i},o.prototype.invert=function(t,i){this.invertX=t===s?this.invertX:t,this.invertY=i===s?this.invertY:i},o.prototype.friction=function(t,i){this.frictionX=t===s?this.frictionX:t,this.frictionY=i===s?this.frictionY:i},o.prototype.scalar=function(t,i){this.scalarX=t===s?this.scalarX:t,this.scalarY=i===s?this.scalarY:i},o.prototype.limit=function(t,i){this.limitX=t===s?this.limitX:t,this.limitY=i===s?this.limitY:i},o.prototype.origin=function(t,i){this.originX=t===s?this.originX:t,this.originY=i===s?this.originY:i},o.prototype.clamp=function(t,i,e){return t=Math.max(t,i),t=Math.min(t,e)},o.prototype.css=function(i,e,o){var n=this.propertyCache[e];if(!n)for(var a=0,r=this.vendors.length;r>a;a++)if(n=null!==this.vendors[a]?t.camelCase(this.vendors[a][1]+"-"+e):e,i.style[n]!==s){this.propertyCache[e]=n;break}i.style[n]=o},o.prototype.accelerate=function(t){for(var i=0,e=t.length;e>i;i++){var s=t[i];this.css(s,"transform","translate3d(0,0,0)"),this.css(s,"transform-style","preserve-3d"),this.css(s,"backface-visibility","hidden")}},o.prototype.setPosition=function(t,i,e){i+="px",e+="px",this.transform3DSupport?this.css(t,"transform","translate3d("+i+","+e+",0)"):this.transform2DSupport?this.css(t,"transform","translate("+i+","+e+")"):(t.style.left=i,t.style.top=e)},o.prototype.onOrientationTimer=function(){this.orientationSupport&&0===this.orientationStatus&&(this.disable(),this.orientationSupport=!1,this.enable())},o.prototype.onCalibrationTimer=function(){this.calibrationFlag=!0},o.prototype.onWindowResize=function(){this.updateDimensions()},o.prototype.onAnimationFrame=function(){this.updateBounds();var t=this.ix-this.cx,i=this.iy-this.cy;(Math.abs(t)>this.calibrationThreshold||Math.abs(i)>this.calibrationThreshold)&&this.queueCalibration(0),this.portrait?(this.mx=this.calibrateX?i:this.iy,this.my=this.calibrateY?t:this.ix):(this.mx=this.calibrateX?t:this.ix,this.my=this.calibrateY?i:this.iy),this.mx*=this.ew*(this.scalarX/100),this.my*=this.eh*(this.scalarY/100),isNaN(parseFloat(this.limitX))||(this.mx=this.clamp(this.mx,-this.limitX,this.limitX)),isNaN(parseFloat(this.limitY))||(this.my=this.clamp(this.my,-this.limitY,this.limitY)),this.vx+=(this.mx-this.vx)*this.frictionX,this.vy+=(this.my-this.vy)*this.frictionY;for(var e=0,s=this.$layers.length;s>e;e++){var o=this.depths[e],n=this.$layers[e],a=this.vx*o*(this.invertX?-1:1),r=this.vy*o*(this.invertY?-1:1);this.setPosition(n,a,r)}this.raf=requestAnimationFrame(this.onAnimationFrame)},o.prototype.onDeviceOrientation=function(t){if(!this.desktop&&null!==t.beta&&null!==t.gamma){this.orientationStatus=1;var e=(t.beta||0)/a,s=(t.gamma||0)/a,o=i.innerHeight>i.innerWidth;this.portrait!==o&&(this.portrait=o,this.calibrationFlag=!0),this.calibrationFlag&&(this.calibrationFlag=!1,this.cx=e,this.cy=s),this.ix=e,this.iy=s}},o.prototype.onMouseMove=function(t){var i=t.clientX,e=t.clientY;!this.orientationSupport&&this.relativeInput?(this.clipRelativeInput&&(i=Math.max(i,this.ex),i=Math.min(i,this.ex+this.ew),e=Math.max(e,this.ey),e=Math.min(e,this.ey+this.eh)),this.ix=(i-this.ex-this.ecx)/this.erx,this.iy=(e-this.ey-this.ecy)/this.ery):(this.ix=(i-this.wcx)/this.wrx,this.iy=(e-this.wcy)/this.wry)};var h={enable:o.prototype.enable,disable:o.prototype.disable,updateLayers:o.prototype.updateLayers,calibrate:o.prototype.calibrate,friction:o.prototype.friction,invert:o.prototype.invert,scalar:o.prototype.scalar,limit:o.prototype.limit,origin:o.prototype.origin};t.fn[n]=function(i){var e=arguments;return this.each(function(){var s=t(this),a=s.data(n);a||(a=new o(this,i),s.data(n,a)),h[i]&&a[i].apply(a,Array.prototype.slice.call(e,1))})}}(window.jQuery||window.Zepto,window,document),function(){for(var t=0,i=["ms","moz","webkit","o"],e=0;e<i.length&&!window.requestAnimationFrame;++e)window.requestAnimationFrame=window[i[e]+"RequestAnimationFrame"],window.cancelAnimationFrame=window[i[e]+"CancelAnimationFrame"]||window[i[e]+"CancelRequestAnimationFrame"];window.requestAnimationFrame||(window.requestAnimationFrame=function(i){var e=(new Date).getTime(),s=Math.max(0,16-(e-t)),o=window.setTimeout(function(){i(e+s)},s);return t=e+s,o}),window.cancelAnimationFrame||(window.cancelAnimationFrame=function(t){clearTimeout(t)})}();

/*
 * jPlayer Plugin for jQuery JavaScript Library
 * http://www.jplayer.org
 *
 * Copyright (c) 2009 - 2014 Happyworm Ltd
 * Licensed under the MIT license.
 * http://opensource.org/licenses/MIT
 *
 * Author: Mark J Panaghiston
 * Version: 2.7.0
 * Date: 1st September 2014
 */

(function(b,f){"function"===typeof define&&define.amd?define(["jquery"],f):b.jQuery?f(b.jQuery):f(b.Zepto)})(this,function(b,f){b.fn.jPlayer=function(a){var c="string"===typeof a,d=Array.prototype.slice.call(arguments,1),e=this;a=!c&&d.length?b.extend.apply(null,[!0,a].concat(d)):a;if(c&&"_"===a.charAt(0))return e;c?this.each(function(){var c=b(this).data("jPlayer"),h=c&&b.isFunction(c[a])?c[a].apply(c,d):c;if(h!==c&&h!==f)return e=h,!1}):this.each(function(){var c=b(this).data("jPlayer");c?c.option(a||
{}):b(this).data("jPlayer",new b.jPlayer(a,this))});return e};b.jPlayer=function(a,c){if(arguments.length){this.element=b(c);this.options=b.extend(!0,{},this.options,a);var d=this;this.element.bind("remove.jPlayer",function(){d.destroy()});this._init()}};"function"!==typeof b.fn.stop&&(b.fn.stop=function(){});b.jPlayer.emulateMethods="load play pause";b.jPlayer.emulateStatus="src readyState networkState currentTime duration paused ended playbackRate";b.jPlayer.emulateOptions="muted volume";b.jPlayer.reservedEvent=
"ready flashreset resize repeat error warning";b.jPlayer.event={};b.each("ready setmedia flashreset resize repeat click error warning loadstart progress suspend abort emptied stalled play pause loadedmetadata loadeddata waiting playing canplay canplaythrough seeking seeked timeupdate ended ratechange durationchange volumechange".split(" "),function(){b.jPlayer.event[this]="jPlayer_"+this});b.jPlayer.htmlEvent="loadstart abort emptied stalled loadedmetadata loadeddata canplay canplaythrough".split(" ");
b.jPlayer.pause=function(){b.each(b.jPlayer.prototype.instances,function(a,c){c.data("jPlayer").status.srcSet&&c.jPlayer("pause")})};b.jPlayer.timeFormat={showHour:!1,showMin:!0,showSec:!0,padHour:!1,padMin:!0,padSec:!0,sepHour:":",sepMin:":",sepSec:""};var l=function(){this.init()};l.prototype={init:function(){this.options={timeFormat:b.jPlayer.timeFormat}},time:function(a){var c=new Date(1E3*(a&&"number"===typeof a?a:0)),b=c.getUTCHours();a=this.options.timeFormat.showHour?c.getUTCMinutes():c.getUTCMinutes()+
60*b;c=this.options.timeFormat.showMin?c.getUTCSeconds():c.getUTCSeconds()+60*a;b=this.options.timeFormat.padHour&&10>b?"0"+b:b;a=this.options.timeFormat.padMin&&10>a?"0"+a:a;c=this.options.timeFormat.padSec&&10>c?"0"+c:c;b=""+(this.options.timeFormat.showHour?b+this.options.timeFormat.sepHour:"");b+=this.options.timeFormat.showMin?a+this.options.timeFormat.sepMin:"";return b+=this.options.timeFormat.showSec?c+this.options.timeFormat.sepSec:""}};var n=new l;b.jPlayer.convertTime=function(a){return n.time(a)};
b.jPlayer.uaBrowser=function(a){a=a.toLowerCase();var c=/(opera)(?:.*version)?[ \/]([\w.]+)/,b=/(msie) ([\w.]+)/,e=/(mozilla)(?:.*? rv:([\w.]+))?/;a=/(webkit)[ \/]([\w.]+)/.exec(a)||c.exec(a)||b.exec(a)||0>a.indexOf("compatible")&&e.exec(a)||[];return{browser:a[1]||"",version:a[2]||"0"}};b.jPlayer.uaPlatform=function(a){var c=a.toLowerCase(),b=/(android)/,e=/(mobile)/;a=/(ipad|iphone|ipod|android|blackberry|playbook|windows ce|webos)/.exec(c)||[];c=/(ipad|playbook)/.exec(c)||!e.exec(c)&&b.exec(c)||
[];a[1]&&(a[1]=a[1].replace(/\s/g,"_"));return{platform:a[1]||"",tablet:c[1]||""}};b.jPlayer.browser={};b.jPlayer.platform={};var k=b.jPlayer.uaBrowser(navigator.userAgent);k.browser&&(b.jPlayer.browser[k.browser]=!0,b.jPlayer.browser.version=k.version);k=b.jPlayer.uaPlatform(navigator.userAgent);k.platform&&(b.jPlayer.platform[k.platform]=!0,b.jPlayer.platform.mobile=!k.tablet,b.jPlayer.platform.tablet=!!k.tablet);b.jPlayer.getDocMode=function(){var a;b.jPlayer.browser.msie&&(document.documentMode?
a=document.documentMode:(a=5,document.compatMode&&"CSS1Compat"===document.compatMode&&(a=7)));return a};b.jPlayer.browser.documentMode=b.jPlayer.getDocMode();b.jPlayer.nativeFeatures={init:function(){var a=document,c=a.createElement("video"),b={w3c:"fullscreenEnabled fullscreenElement requestFullscreen exitFullscreen fullscreenchange fullscreenerror".split(" "),moz:"mozFullScreenEnabled mozFullScreenElement mozRequestFullScreen mozCancelFullScreen mozfullscreenchange mozfullscreenerror".split(" "),
webkit:" webkitCurrentFullScreenElement webkitRequestFullScreen webkitCancelFullScreen webkitfullscreenchange ".split(" "),webkitVideo:"webkitSupportsFullscreen webkitDisplayingFullscreen webkitEnterFullscreen webkitExitFullscreen  ".split(" ")},e=["w3c","moz","webkit","webkitVideo"],g,h;this.fullscreen=c={support:{w3c:!!a[b.w3c[0]],moz:!!a[b.moz[0]],webkit:"function"===typeof a[b.webkit[3]],webkitVideo:"function"===typeof c[b.webkitVideo[2]]},used:{}};g=0;for(h=e.length;g<h;g++){var f=e[g];if(c.support[f]){c.spec=
f;c.used[f]=!0;break}}if(c.spec){var m=b[c.spec];c.api={fullscreenEnabled:!0,fullscreenElement:function(c){c=c?c:a;return c[m[1]]},requestFullscreen:function(a){return a[m[2]]()},exitFullscreen:function(c){c=c?c:a;return c[m[3]]()}};c.event={fullscreenchange:m[4],fullscreenerror:m[5]}}else c.api={fullscreenEnabled:!1,fullscreenElement:function(){return null},requestFullscreen:function(){},exitFullscreen:function(){}},c.event={}}};b.jPlayer.nativeFeatures.init();b.jPlayer.focus=null;b.jPlayer.keyIgnoreElementNames=
"A INPUT TEXTAREA SELECT BUTTON";var p=function(a){var c=b.jPlayer.focus,d=document.activeElement,e;c&&("undefined"!==typeof d?null!==d&&"BODY"!==d.nodeName.toUpperCase()&&(e=!0):b.each(b.jPlayer.keyIgnoreElementNames.split(/\s+/g),function(c,b){if(a.target.nodeName.toUpperCase()===b.toUpperCase())return e=!0,!1}),e||b.each(c.options.keyBindings,function(d,e){if(e&&a.which===e.key&&b.isFunction(e.fn))return a.preventDefault(),e.fn(c),!1}))};b.jPlayer.keys=function(a){b(document.documentElement).unbind("keydown.jPlayer");
a&&b(document.documentElement).bind("keydown.jPlayer",p)};b.jPlayer.keys(!0);b.jPlayer.prototype={count:0,version:{script:"2.7.0",needFlash:"2.7.0",flash:"unknown"},options:{swfPath:"js",solution:"html, flash",supplied:"mp3",preload:"metadata",volume:.8,muted:!1,remainingDuration:!1,toggleDuration:!1,captureDuration:!0,playbackRate:1,defaultPlaybackRate:1,minPlaybackRate:.5,maxPlaybackRate:4,wmode:"opaque",backgroundColor:"#000000",cssSelectorAncestor:"#jp_container_1",cssSelector:{videoPlay:".jp-video-play",
play:".jp-play",pause:".jp-pause",stop:".jp-stop",seekBar:".jp-seek-bar",playBar:".jp-play-bar",mute:".jp-mute",unmute:".jp-unmute",volumeBar:".jp-volume-bar",volumeBarValue:".jp-volume-bar-value",volumeMax:".jp-volume-max",playbackRateBar:".jp-playback-rate-bar",playbackRateBarValue:".jp-playback-rate-bar-value",currentTime:".jp-current-time",duration:".jp-duration",title:".jp-title",fullScreen:".jp-full-screen",restoreScreen:".jp-restore-screen",repeat:".jp-repeat",repeatOff:".jp-repeat-off",gui:".jp-gui",
noSolution:".jp-no-solution"},stateClass:{playing:"jp-state-playing",seeking:"jp-state-seeking",muted:"jp-state-muted",looped:"jp-state-looped",fullScreen:"jp-state-full-screen"},useStateClassSkin:!1,autoBlur:!0,smoothPlayBar:!1,fullScreen:!1,fullWindow:!1,autohide:{restored:!1,full:!0,fadeIn:200,fadeOut:600,hold:1E3},loop:!1,repeat:function(a){a.jPlayer.options.loop?b(this).unbind(".jPlayerRepeat").bind(b.jPlayer.event.ended+".jPlayer.jPlayerRepeat",function(){b(this).jPlayer("play")}):b(this).unbind(".jPlayerRepeat")},
nativeVideoControls:{},noFullWindow:{msie:/msie [0-6]\./,ipad:/ipad.*?os [0-4]\./,iphone:/iphone/,ipod:/ipod/,android_pad:/android [0-3]\.(?!.*?mobile)/,android_phone:/android.*?mobile/,blackberry:/blackberry/,windows_ce:/windows ce/,iemobile:/iemobile/,webos:/webos/},noVolume:{ipad:/ipad/,iphone:/iphone/,ipod:/ipod/,android_pad:/android(?!.*?mobile)/,android_phone:/android.*?mobile/,blackberry:/blackberry/,windows_ce:/windows ce/,iemobile:/iemobile/,webos:/webos/,playbook:/playbook/},timeFormat:{},
keyEnabled:!1,audioFullScreen:!1,keyBindings:{play:{key:32,fn:function(a){a.status.paused?a.play():a.pause()}},fullScreen:{key:13,fn:function(a){(a.status.video||a.options.audioFullScreen)&&a._setOption("fullScreen",!a.options.fullScreen)}},muted:{key:8,fn:function(a){a._muted(!a.options.muted)}},volumeUp:{key:38,fn:function(a){a.volume(a.options.volume+.1)}},volumeDown:{key:40,fn:function(a){a.volume(a.options.volume-.1)}}},verticalVolume:!1,verticalPlaybackRate:!1,globalVolume:!1,idPrefix:"jp",
noConflict:"jQuery",emulateHtml:!1,consoleAlerts:!0,errorAlerts:!1,warningAlerts:!1},optionsAudio:{size:{width:"0px",height:"0px",cssClass:""},sizeFull:{width:"0px",height:"0px",cssClass:""}},optionsVideo:{size:{width:"480px",height:"270px",cssClass:"jp-video-270p"},sizeFull:{width:"100%",height:"100%",cssClass:"jp-video-full"}},instances:{},status:{src:"",media:{},paused:!0,format:{},formatType:"",waitForPlay:!0,waitForLoad:!0,srcSet:!1,video:!1,seekPercent:0,currentPercentRelative:0,currentPercentAbsolute:0,
currentTime:0,duration:0,remaining:0,videoWidth:0,videoHeight:0,readyState:0,networkState:0,playbackRate:1,ended:0},internal:{ready:!1},solution:{html:!0,flash:!0},format:{mp3:{codec:"audio/mpeg",flashCanPlay:!0,media:"audio"},m4a:{codec:'audio/mp4; codecs="mp4a.40.2"',flashCanPlay:!0,media:"audio"},m3u8a:{codec:'application/vnd.apple.mpegurl; codecs="mp4a.40.2"',flashCanPlay:!1,media:"audio"},m3ua:{codec:"audio/mpegurl",flashCanPlay:!1,media:"audio"},oga:{codec:'audio/ogg; codecs="vorbis, opus"',
flashCanPlay:!1,media:"audio"},flac:{codec:"audio/x-flac",flashCanPlay:!1,media:"audio"},wav:{codec:'audio/wav; codecs="1"',flashCanPlay:!1,media:"audio"},webma:{codec:'audio/webm; codecs="vorbis"',flashCanPlay:!1,media:"audio"},fla:{codec:"audio/x-flv",flashCanPlay:!0,media:"audio"},rtmpa:{codec:'audio/rtmp; codecs="rtmp"',flashCanPlay:!0,media:"audio"},m4v:{codec:'video/mp4; codecs="avc1.42E01E, mp4a.40.2"',flashCanPlay:!0,media:"video"},m3u8v:{codec:'application/vnd.apple.mpegurl; codecs="avc1.42E01E, mp4a.40.2"',
flashCanPlay:!1,media:"video"},m3uv:{codec:"audio/mpegurl",flashCanPlay:!1,media:"video"},ogv:{codec:'video/ogg; codecs="theora, vorbis"',flashCanPlay:!1,media:"video"},webmv:{codec:'video/webm; codecs="vorbis, vp8"',flashCanPlay:!1,media:"video"},flv:{codec:"video/x-flv",flashCanPlay:!0,media:"video"},rtmpv:{codec:'video/rtmp; codecs="rtmp"',flashCanPlay:!0,media:"video"}},_init:function(){var a=this;this.element.empty();this.status=b.extend({},this.status);this.internal=b.extend({},this.internal);
this.options.timeFormat=b.extend({},b.jPlayer.timeFormat,this.options.timeFormat);this.internal.cmdsIgnored=b.jPlayer.platform.ipad||b.jPlayer.platform.iphone||b.jPlayer.platform.ipod;this.internal.domNode=this.element.get(0);this.options.keyEnabled&&!b.jPlayer.focus&&(b.jPlayer.focus=this);this.androidFix={setMedia:!1,play:!1,pause:!1,time:NaN};b.jPlayer.platform.android&&(this.options.preload="auto"!==this.options.preload?"metadata":"auto");this.formats=[];this.solutions=[];this.require={};this.htmlElement=
{};this.html={};this.html.audio={};this.html.video={};this.flash={};this.css={};this.css.cs={};this.css.jq={};this.ancestorJq=[];this.options.volume=this._limitValue(this.options.volume,0,1);b.each(this.options.supplied.toLowerCase().split(","),function(c,d){var e=d.replace(/^\s+|\s+$/g,"");if(a.format[e]){var f=!1;b.each(a.formats,function(a,c){if(e===c)return f=!0,!1});f||a.formats.push(e)}});b.each(this.options.solution.toLowerCase().split(","),function(c,d){var e=d.replace(/^\s+|\s+$/g,"");if(a.solution[e]){var f=
!1;b.each(a.solutions,function(a,c){if(e===c)return f=!0,!1});f||a.solutions.push(e)}});this.internal.instance="jp_"+this.count;this.instances[this.internal.instance]=this.element;this.element.attr("id")||this.element.attr("id",this.options.idPrefix+"_jplayer_"+this.count);this.internal.self=b.extend({},{id:this.element.attr("id"),jq:this.element});this.internal.audio=b.extend({},{id:this.options.idPrefix+"_audio_"+this.count,jq:f});this.internal.video=b.extend({},{id:this.options.idPrefix+"_video_"+
this.count,jq:f});this.internal.flash=b.extend({},{id:this.options.idPrefix+"_flash_"+this.count,jq:f,swf:this.options.swfPath+(".swf"!==this.options.swfPath.toLowerCase().slice(-4)?(this.options.swfPath&&"/"!==this.options.swfPath.slice(-1)?"/":"")+"Jplayer.swf":"")});this.internal.poster=b.extend({},{id:this.options.idPrefix+"_poster_"+this.count,jq:f});b.each(b.jPlayer.event,function(c,b){a.options[c]!==f&&(a.element.bind(b+".jPlayer",a.options[c]),a.options[c]=f)});this.require.audio=!1;this.require.video=
!1;b.each(this.formats,function(c,b){a.require[a.format[b].media]=!0});this.options=this.require.video?b.extend(!0,{},this.optionsVideo,this.options):b.extend(!0,{},this.optionsAudio,this.options);this._setSize();this.status.nativeVideoControls=this._uaBlocklist(this.options.nativeVideoControls);this.status.noFullWindow=this._uaBlocklist(this.options.noFullWindow);this.status.noVolume=this._uaBlocklist(this.options.noVolume);b.jPlayer.nativeFeatures.fullscreen.api.fullscreenEnabled&&this._fullscreenAddEventListeners();
this._restrictNativeVideoControls();this.htmlElement.poster=document.createElement("img");this.htmlElement.poster.id=this.internal.poster.id;this.htmlElement.poster.onload=function(){a.status.video&&!a.status.waitForPlay||a.internal.poster.jq.show()};this.element.append(this.htmlElement.poster);this.internal.poster.jq=b("#"+this.internal.poster.id);this.internal.poster.jq.css({width:this.status.width,height:this.status.height});this.internal.poster.jq.hide();this.internal.poster.jq.bind("click.jPlayer",
function(){a._trigger(b.jPlayer.event.click)});this.html.audio.available=!1;this.require.audio&&(this.htmlElement.audio=document.createElement("audio"),this.htmlElement.audio.id=this.internal.audio.id,this.html.audio.available=!!this.htmlElement.audio.canPlayType&&this._testCanPlayType(this.htmlElement.audio));this.html.video.available=!1;this.require.video&&(this.htmlElement.video=document.createElement("video"),this.htmlElement.video.id=this.internal.video.id,this.html.video.available=!!this.htmlElement.video.canPlayType&&
this._testCanPlayType(this.htmlElement.video));this.flash.available=this._checkForFlash(10.1);this.html.canPlay={};this.flash.canPlay={};b.each(this.formats,function(c,b){a.html.canPlay[b]=a.html[a.format[b].media].available&&""!==a.htmlElement[a.format[b].media].canPlayType(a.format[b].codec);a.flash.canPlay[b]=a.format[b].flashCanPlay&&a.flash.available});this.html.desired=!1;this.flash.desired=!1;b.each(this.solutions,function(c,d){if(0===c)a[d].desired=!0;else{var e=!1,f=!1;b.each(a.formats,function(c,
b){a[a.solutions[0]].canPlay[b]&&("video"===a.format[b].media?f=!0:e=!0)});a[d].desired=a.require.audio&&!e||a.require.video&&!f}});this.html.support={};this.flash.support={};b.each(this.formats,function(c,b){a.html.support[b]=a.html.canPlay[b]&&a.html.desired;a.flash.support[b]=a.flash.canPlay[b]&&a.flash.desired});this.html.used=!1;this.flash.used=!1;b.each(this.solutions,function(c,d){b.each(a.formats,function(c,b){if(a[d].support[b])return a[d].used=!0,!1})});this._resetActive();this._resetGate();
this._cssSelectorAncestor(this.options.cssSelectorAncestor);this.html.used||this.flash.used?this.css.jq.noSolution.length&&this.css.jq.noSolution.hide():(this._error({type:b.jPlayer.error.NO_SOLUTION,context:"{solution:'"+this.options.solution+"', supplied:'"+this.options.supplied+"'}",message:b.jPlayer.errorMsg.NO_SOLUTION,hint:b.jPlayer.errorHint.NO_SOLUTION}),this.css.jq.noSolution.length&&this.css.jq.noSolution.show());if(this.flash.used){var c,d="jQuery="+encodeURI(this.options.noConflict)+"&id="+
encodeURI(this.internal.self.id)+"&vol="+this.options.volume+"&muted="+this.options.muted;if(b.jPlayer.browser.msie&&(9>Number(b.jPlayer.browser.version)||9>b.jPlayer.browser.documentMode)){d=['<param name="movie" value="'+this.internal.flash.swf+'" />','<param name="FlashVars" value="'+d+'" />','<param name="allowScriptAccess" value="always" />','<param name="bgcolor" value="'+this.options.backgroundColor+'" />','<param name="wmode" value="'+this.options.wmode+'" />'];c=document.createElement('<object id="'+
this.internal.flash.id+'" classid="clsid:d27cdb6e-ae6d-11cf-96b8-444553540000" width="0" height="0" tabindex="-1"></object>');for(var e=0;e<d.length;e++)c.appendChild(document.createElement(d[e]))}else e=function(a,c,b){var d=document.createElement("param");d.setAttribute("name",c);d.setAttribute("value",b);a.appendChild(d)},c=document.createElement("object"),c.setAttribute("id",this.internal.flash.id),c.setAttribute("name",this.internal.flash.id),c.setAttribute("data",this.internal.flash.swf),c.setAttribute("type",
"application/x-shockwave-flash"),c.setAttribute("width","1"),c.setAttribute("height","1"),c.setAttribute("tabindex","-1"),e(c,"flashvars",d),e(c,"allowscriptaccess","always"),e(c,"bgcolor",this.options.backgroundColor),e(c,"wmode",this.options.wmode);this.element.append(c);this.internal.flash.jq=b(c)}this.status.playbackRateEnabled=this.html.used&&!this.flash.used?this._testPlaybackRate("audio"):!1;this._updatePlaybackRate();this.html.used&&(this.html.audio.available&&(this._addHtmlEventListeners(this.htmlElement.audio,
this.html.audio),this.element.append(this.htmlElement.audio),this.internal.audio.jq=b("#"+this.internal.audio.id)),this.html.video.available&&(this._addHtmlEventListeners(this.htmlElement.video,this.html.video),this.element.append(this.htmlElement.video),this.internal.video.jq=b("#"+this.internal.video.id),this.status.nativeVideoControls?this.internal.video.jq.css({width:this.status.width,height:this.status.height}):this.internal.video.jq.css({width:"0px",height:"0px"}),this.internal.video.jq.bind("click.jPlayer",
function(){a._trigger(b.jPlayer.event.click)})));this.options.emulateHtml&&this._emulateHtmlBridge();this.html.used&&!this.flash.used&&setTimeout(function(){a.internal.ready=!0;a.version.flash="n/a";a._trigger(b.jPlayer.event.repeat);a._trigger(b.jPlayer.event.ready)},100);this._updateNativeVideoControls();this.css.jq.videoPlay.length&&this.css.jq.videoPlay.hide();b.jPlayer.prototype.count++},destroy:function(){this.clearMedia();this._removeUiClass();this.css.jq.currentTime.length&&this.css.jq.currentTime.text("");
this.css.jq.duration.length&&this.css.jq.duration.text("");b.each(this.css.jq,function(a,c){c.length&&c.unbind(".jPlayer")});this.internal.poster.jq.unbind(".jPlayer");this.internal.video.jq&&this.internal.video.jq.unbind(".jPlayer");this._fullscreenRemoveEventListeners();this===b.jPlayer.focus&&(b.jPlayer.focus=null);this.options.emulateHtml&&this._destroyHtmlBridge();this.element.removeData("jPlayer");this.element.unbind(".jPlayer");this.element.empty();delete this.instances[this.internal.instance]},
enable:function(){},disable:function(){},_testCanPlayType:function(a){try{return a.canPlayType(this.format.mp3.codec),!0}catch(c){return!1}},_testPlaybackRate:function(a){a=document.createElement("string"===typeof a?a:"audio");try{return"playbackRate"in a?(a.playbackRate=.5,.5===a.playbackRate):!1}catch(c){return!1}},_uaBlocklist:function(a){var c=navigator.userAgent.toLowerCase(),d=!1;b.each(a,function(a,b){if(b&&b.test(c))return d=!0,!1});return d},_restrictNativeVideoControls:function(){this.require.audio&&
this.status.nativeVideoControls&&(this.status.nativeVideoControls=!1,this.status.noFullWindow=!0)},_updateNativeVideoControls:function(){this.html.video.available&&this.html.used&&(this.htmlElement.video.controls=this.status.nativeVideoControls,this._updateAutohide(),this.status.nativeVideoControls&&this.require.video?(this.internal.poster.jq.hide(),this.internal.video.jq.css({width:this.status.width,height:this.status.height})):this.status.waitForPlay&&this.status.video&&(this.internal.poster.jq.show(),
this.internal.video.jq.css({width:"0px",height:"0px"})))},_addHtmlEventListeners:function(a,c){var d=this;a.preload=this.options.preload;a.muted=this.options.muted;a.volume=this.options.volume;this.status.playbackRateEnabled&&(a.defaultPlaybackRate=this.options.defaultPlaybackRate,a.playbackRate=this.options.playbackRate);a.addEventListener("progress",function(){c.gate&&(d.internal.cmdsIgnored&&0<this.readyState&&(d.internal.cmdsIgnored=!1),d.androidFix.setMedia=!1,d.androidFix.play&&(d.androidFix.play=
!1,d.play(d.androidFix.time)),d.androidFix.pause&&(d.androidFix.pause=!1,d.pause(d.androidFix.time)),d._getHtmlStatus(a),d._updateInterface(),d._trigger(b.jPlayer.event.progress))},!1);a.addEventListener("timeupdate",function(){c.gate&&(d._getHtmlStatus(a),d._updateInterface(),d._trigger(b.jPlayer.event.timeupdate))},!1);a.addEventListener("durationchange",function(){c.gate&&(d._getHtmlStatus(a),d._updateInterface(),d._trigger(b.jPlayer.event.durationchange))},!1);a.addEventListener("play",function(){c.gate&&
(d._updateButtons(!0),d._html_checkWaitForPlay(),d._trigger(b.jPlayer.event.play))},!1);a.addEventListener("playing",function(){c.gate&&(d._updateButtons(!0),d._seeked(),d._trigger(b.jPlayer.event.playing))},!1);a.addEventListener("pause",function(){c.gate&&(d._updateButtons(!1),d._trigger(b.jPlayer.event.pause))},!1);a.addEventListener("waiting",function(){c.gate&&(d._seeking(),d._trigger(b.jPlayer.event.waiting))},!1);a.addEventListener("seeking",function(){c.gate&&(d._seeking(),d._trigger(b.jPlayer.event.seeking))},
!1);a.addEventListener("seeked",function(){c.gate&&(d._seeked(),d._trigger(b.jPlayer.event.seeked))},!1);a.addEventListener("volumechange",function(){c.gate&&(d.options.volume=a.volume,d.options.muted=a.muted,d._updateMute(),d._updateVolume(),d._trigger(b.jPlayer.event.volumechange))},!1);a.addEventListener("ratechange",function(){c.gate&&(d.options.defaultPlaybackRate=a.defaultPlaybackRate,d.options.playbackRate=a.playbackRate,d._updatePlaybackRate(),d._trigger(b.jPlayer.event.ratechange))},!1);
a.addEventListener("suspend",function(){c.gate&&(d._seeked(),d._trigger(b.jPlayer.event.suspend))},!1);a.addEventListener("ended",function(){c.gate&&(b.jPlayer.browser.webkit||(d.htmlElement.media.currentTime=0),d.htmlElement.media.pause(),d._updateButtons(!1),d._getHtmlStatus(a,!0),d._updateInterface(),d._trigger(b.jPlayer.event.ended))},!1);a.addEventListener("error",function(){c.gate&&(d._updateButtons(!1),d._seeked(),d.status.srcSet&&(clearTimeout(d.internal.htmlDlyCmdId),d.status.waitForLoad=
!0,d.status.waitForPlay=!0,d.status.video&&!d.status.nativeVideoControls&&d.internal.video.jq.css({width:"0px",height:"0px"}),d._validString(d.status.media.poster)&&!d.status.nativeVideoControls&&d.internal.poster.jq.show(),d.css.jq.videoPlay.length&&d.css.jq.videoPlay.show(),d._error({type:b.jPlayer.error.URL,context:d.status.src,message:b.jPlayer.errorMsg.URL,hint:b.jPlayer.errorHint.URL})))},!1);b.each(b.jPlayer.htmlEvent,function(e,g){a.addEventListener(this,function(){c.gate&&d._trigger(b.jPlayer.event[g])},
!1)})},_getHtmlStatus:function(a,c){var b=0,e=0,g=0,f=0;isFinite(a.duration)&&(this.status.duration=a.duration);b=a.currentTime;e=0<this.status.duration?100*b/this.status.duration:0;"object"===typeof a.seekable&&0<a.seekable.length?(g=0<this.status.duration?100*a.seekable.end(a.seekable.length-1)/this.status.duration:100,f=0<this.status.duration?100*a.currentTime/a.seekable.end(a.seekable.length-1):0):(g=100,f=e);c&&(e=f=b=0);this.status.seekPercent=g;this.status.currentPercentRelative=f;this.status.currentPercentAbsolute=
e;this.status.currentTime=b;this.status.remaining=this.status.duration-this.status.currentTime;this.status.videoWidth=a.videoWidth;this.status.videoHeight=a.videoHeight;this.status.readyState=a.readyState;this.status.networkState=a.networkState;this.status.playbackRate=a.playbackRate;this.status.ended=a.ended},_resetStatus:function(){this.status=b.extend({},this.status,b.jPlayer.prototype.status)},_trigger:function(a,c,d){a=b.Event(a);a.jPlayer={};a.jPlayer.version=b.extend({},this.version);a.jPlayer.options=
b.extend(!0,{},this.options);a.jPlayer.status=b.extend(!0,{},this.status);a.jPlayer.html=b.extend(!0,{},this.html);a.jPlayer.flash=b.extend(!0,{},this.flash);c&&(a.jPlayer.error=b.extend({},c));d&&(a.jPlayer.warning=b.extend({},d));this.element.trigger(a)},jPlayerFlashEvent:function(a,c){if(a===b.jPlayer.event.ready)if(!this.internal.ready)this.internal.ready=!0,this.internal.flash.jq.css({width:"0px",height:"0px"}),this.version.flash=c.version,this.version.needFlash!==this.version.flash&&this._error({type:b.jPlayer.error.VERSION,
context:this.version.flash,message:b.jPlayer.errorMsg.VERSION+this.version.flash,hint:b.jPlayer.errorHint.VERSION}),this._trigger(b.jPlayer.event.repeat),this._trigger(a);else if(this.flash.gate){if(this.status.srcSet){var d=this.status.currentTime,e=this.status.paused;this.setMedia(this.status.media);this.volumeWorker(this.options.volume);0<d&&(e?this.pause(d):this.play(d))}this._trigger(b.jPlayer.event.flashreset)}if(this.flash.gate)switch(a){case b.jPlayer.event.progress:this._getFlashStatus(c);
this._updateInterface();this._trigger(a);break;case b.jPlayer.event.timeupdate:this._getFlashStatus(c);this._updateInterface();this._trigger(a);break;case b.jPlayer.event.play:this._seeked();this._updateButtons(!0);this._trigger(a);break;case b.jPlayer.event.pause:this._updateButtons(!1);this._trigger(a);break;case b.jPlayer.event.ended:this._updateButtons(!1);this._trigger(a);break;case b.jPlayer.event.click:this._trigger(a);break;case b.jPlayer.event.error:this.status.waitForLoad=!0;this.status.waitForPlay=
!0;this.status.video&&this.internal.flash.jq.css({width:"0px",height:"0px"});this._validString(this.status.media.poster)&&this.internal.poster.jq.show();this.css.jq.videoPlay.length&&this.status.video&&this.css.jq.videoPlay.show();this.status.video?this._flash_setVideo(this.status.media):this._flash_setAudio(this.status.media);this._updateButtons(!1);this._error({type:b.jPlayer.error.URL,context:c.src,message:b.jPlayer.errorMsg.URL,hint:b.jPlayer.errorHint.URL});break;case b.jPlayer.event.seeking:this._seeking();
this._trigger(a);break;case b.jPlayer.event.seeked:this._seeked();this._trigger(a);break;case b.jPlayer.event.ready:break;default:this._trigger(a)}return!1},_getFlashStatus:function(a){this.status.seekPercent=a.seekPercent;this.status.currentPercentRelative=a.currentPercentRelative;this.status.currentPercentAbsolute=a.currentPercentAbsolute;this.status.currentTime=a.currentTime;this.status.duration=a.duration;this.status.remaining=a.duration-a.currentTime;this.status.videoWidth=a.videoWidth;this.status.videoHeight=
a.videoHeight;this.status.readyState=4;this.status.networkState=0;this.status.playbackRate=1;this.status.ended=!1},_updateButtons:function(a){a===f?a=!this.status.paused:this.status.paused=!a;a?this.addStateClass("playing"):this.removeStateClass("playing");!this.status.noFullWindow&&this.options.fullWindow?this.addStateClass("fullScreen"):this.removeStateClass("fullScreen");this.options.loop?this.addStateClass("looped"):this.removeStateClass("looped");this.css.jq.play.length&&this.css.jq.pause.length&&
(a?(this.css.jq.play.hide(),this.css.jq.pause.show()):(this.css.jq.play.show(),this.css.jq.pause.hide()));this.css.jq.restoreScreen.length&&this.css.jq.fullScreen.length&&(this.status.noFullWindow?(this.css.jq.fullScreen.hide(),this.css.jq.restoreScreen.hide()):this.options.fullWindow?(this.css.jq.fullScreen.hide(),this.css.jq.restoreScreen.show()):(this.css.jq.fullScreen.show(),this.css.jq.restoreScreen.hide()));this.css.jq.repeat.length&&this.css.jq.repeatOff.length&&(this.options.loop?(this.css.jq.repeat.hide(),
this.css.jq.repeatOff.show()):(this.css.jq.repeat.show(),this.css.jq.repeatOff.hide()))},_updateInterface:function(){this.css.jq.seekBar.length&&this.css.jq.seekBar.width(this.status.seekPercent+"%");this.css.jq.playBar.length&&(this.options.smoothPlayBar?this.css.jq.playBar.stop().animate({width:this.status.currentPercentAbsolute+"%"},250,"linear"):this.css.jq.playBar.width(this.status.currentPercentRelative+"%"));var a="";this.css.jq.currentTime.length&&(a=this._convertTime(this.status.currentTime),
a!==this.css.jq.currentTime.text()&&this.css.jq.currentTime.text(this._convertTime(this.status.currentTime)));var a="",a=this.status.duration,c=this.status.remaining;this.css.jq.duration.length&&("string"===typeof this.status.media.duration?a=this.status.media.duration:("number"===typeof this.status.media.duration&&(a=this.status.media.duration,c=a-this.status.currentTime),a=this.options.remainingDuration?(0<c?"-":"")+this._convertTime(c):this._convertTime(a)),a!==this.css.jq.duration.text()&&this.css.jq.duration.text(a))},
_convertTime:l.prototype.time,_seeking:function(){this.css.jq.seekBar.length&&this.css.jq.seekBar.addClass("jp-seeking-bg");this.addStateClass("seeking")},_seeked:function(){this.css.jq.seekBar.length&&this.css.jq.seekBar.removeClass("jp-seeking-bg");this.removeStateClass("seeking")},_resetGate:function(){this.html.audio.gate=!1;this.html.video.gate=!1;this.flash.gate=!1},_resetActive:function(){this.html.active=!1;this.flash.active=!1},_escapeHtml:function(a){return a.split("&").join("&amp;").split("<").join("&lt;").split(">").join("&gt;").split('"').join("&quot;")},
_qualifyURL:function(a){var c=document.createElement("div");c.innerHTML='<a href="'+this._escapeHtml(a)+'">x</a>';return c.firstChild.href},_absoluteMediaUrls:function(a){var c=this;b.each(a,function(b,e){e&&c.format[b]&&(a[b]=c._qualifyURL(e))});return a},addStateClass:function(a){this.ancestorJq.length&&this.ancestorJq.addClass(this.options.stateClass[a])},removeStateClass:function(a){this.ancestorJq.length&&this.ancestorJq.removeClass(this.options.stateClass[a])},setMedia:function(a){var c=this,
d=!1,e=this.status.media.poster!==a.poster;this._resetMedia();this._resetGate();this._resetActive();this.androidFix.setMedia=!1;this.androidFix.play=!1;this.androidFix.pause=!1;a=this._absoluteMediaUrls(a);b.each(this.formats,function(e,f){var k="video"===c.format[f].media;b.each(c.solutions,function(e,g){if(c[g].support[f]&&c._validString(a[f])){var l="html"===g;k?(l?(c.html.video.gate=!0,c._html_setVideo(a),c.html.active=!0):(c.flash.gate=!0,c._flash_setVideo(a),c.flash.active=!0),c.css.jq.videoPlay.length&&
c.css.jq.videoPlay.show(),c.status.video=!0):(l?(c.html.audio.gate=!0,c._html_setAudio(a),c.html.active=!0,b.jPlayer.platform.android&&(c.androidFix.setMedia=!0)):(c.flash.gate=!0,c._flash_setAudio(a),c.flash.active=!0),c.css.jq.videoPlay.length&&c.css.jq.videoPlay.hide(),c.status.video=!1);d=!0;return!1}});if(d)return!1});d?(this.status.nativeVideoControls&&this.html.video.gate||!this._validString(a.poster)||(e?this.htmlElement.poster.src=a.poster:this.internal.poster.jq.show()),this.css.jq.title.length&&
"string"===typeof a.title&&(this.css.jq.title.html(a.title),this.htmlElement.audio&&this.htmlElement.audio.setAttribute("title",a.title),this.htmlElement.video&&this.htmlElement.video.setAttribute("title",a.title)),this.status.srcSet=!0,this.status.media=b.extend({},a),this._updateButtons(!1),this._updateInterface(),this._trigger(b.jPlayer.event.setmedia)):this._error({type:b.jPlayer.error.NO_SUPPORT,context:"{supplied:'"+this.options.supplied+"'}",message:b.jPlayer.errorMsg.NO_SUPPORT,hint:b.jPlayer.errorHint.NO_SUPPORT})},
_resetMedia:function(){this._resetStatus();this._updateButtons(!1);this._updateInterface();this._seeked();this.internal.poster.jq.hide();clearTimeout(this.internal.htmlDlyCmdId);this.html.active?this._html_resetMedia():this.flash.active&&this._flash_resetMedia()},clearMedia:function(){this._resetMedia();this.html.active?this._html_clearMedia():this.flash.active&&this._flash_clearMedia();this._resetGate();this._resetActive()},load:function(){this.status.srcSet?this.html.active?this._html_load():this.flash.active&&
this._flash_load():this._urlNotSetError("load")},focus:function(){this.options.keyEnabled&&(b.jPlayer.focus=this)},play:function(a){"object"===typeof a&&this.options.useStateClassSkin&&!this.status.paused?this.pause(a):(a="number"===typeof a?a:NaN,this.status.srcSet?(this.focus(),this.html.active?this._html_play(a):this.flash.active&&this._flash_play(a)):this._urlNotSetError("play"))},videoPlay:function(){this.play()},pause:function(a){a="number"===typeof a?a:NaN;this.status.srcSet?this.html.active?
this._html_pause(a):this.flash.active&&this._flash_pause(a):this._urlNotSetError("pause")},tellOthers:function(a,c){var d=this,e="function"===typeof c,g=Array.prototype.slice.call(arguments);"string"===typeof a&&(e&&g.splice(1,1),b.each(this.instances,function(){d.element!==this&&(e&&!c.call(this.data("jPlayer"),d)||this.jPlayer.apply(this,g))}))},pauseOthers:function(a){this.tellOthers("pause",function(){return this.status.srcSet},a)},stop:function(){this.status.srcSet?this.html.active?this._html_pause(0):
this.flash.active&&this._flash_pause(0):this._urlNotSetError("stop")},playHead:function(a){a=this._limitValue(a,0,100);this.status.srcSet?this.html.active?this._html_playHead(a):this.flash.active&&this._flash_playHead(a):this._urlNotSetError("playHead")},_muted:function(a){this.mutedWorker(a);this.options.globalVolume&&this.tellOthers("mutedWorker",function(){return this.options.globalVolume},a)},mutedWorker:function(a){this.options.muted=a;this.html.used&&this._html_setProperty("muted",a);this.flash.used&&
this._flash_mute(a);this.html.video.gate||this.html.audio.gate||(this._updateMute(a),this._updateVolume(this.options.volume),this._trigger(b.jPlayer.event.volumechange))},mute:function(a){"object"===typeof a&&this.options.useStateClassSkin&&this.options.muted?this._muted(!1):(a=a===f?!0:!!a,this._muted(a))},unmute:function(a){a=a===f?!0:!!a;this._muted(!a)},_updateMute:function(a){a===f&&(a=this.options.muted);a?this.addStateClass("muted"):this.removeStateClass("muted");this.css.jq.mute.length&&this.css.jq.unmute.length&&
(this.status.noVolume?(this.css.jq.mute.hide(),this.css.jq.unmute.hide()):a?(this.css.jq.mute.hide(),this.css.jq.unmute.show()):(this.css.jq.mute.show(),this.css.jq.unmute.hide()))},volume:function(a){this.volumeWorker(a);this.options.globalVolume&&this.tellOthers("volumeWorker",function(){return this.options.globalVolume},a)},volumeWorker:function(a){a=this._limitValue(a,0,1);this.options.volume=a;this.html.used&&this._html_setProperty("volume",a);this.flash.used&&this._flash_volume(a);this.html.video.gate||
this.html.audio.gate||(this._updateVolume(a),this._trigger(b.jPlayer.event.volumechange))},volumeBar:function(a){if(this.css.jq.volumeBar.length){var c=b(a.currentTarget),d=c.offset(),e=a.pageX-d.left,g=c.width();a=c.height()-a.pageY+d.top;c=c.height();this.options.verticalVolume?this.volume(a/c):this.volume(e/g)}this.options.muted&&this._muted(!1)},_updateVolume:function(a){a===f&&(a=this.options.volume);a=this.options.muted?0:a;this.status.noVolume?(this.css.jq.volumeBar.length&&this.css.jq.volumeBar.hide(),
this.css.jq.volumeBarValue.length&&this.css.jq.volumeBarValue.hide(),this.css.jq.volumeMax.length&&this.css.jq.volumeMax.hide()):(this.css.jq.volumeBar.length&&this.css.jq.volumeBar.show(),this.css.jq.volumeBarValue.length&&(this.css.jq.volumeBarValue.show(),this.css.jq.volumeBarValue[this.options.verticalVolume?"height":"width"](100*a+"%")),this.css.jq.volumeMax.length&&this.css.jq.volumeMax.show())},volumeMax:function(){this.volume(1);this.options.muted&&this._muted(!1)},_cssSelectorAncestor:function(a){var c=
this;this.options.cssSelectorAncestor=a;this._removeUiClass();this.ancestorJq=a?b(a):[];a&&1!==this.ancestorJq.length&&this._warning({type:b.jPlayer.warning.CSS_SELECTOR_COUNT,context:a,message:b.jPlayer.warningMsg.CSS_SELECTOR_COUNT+this.ancestorJq.length+" found for cssSelectorAncestor.",hint:b.jPlayer.warningHint.CSS_SELECTOR_COUNT});this._addUiClass();b.each(this.options.cssSelector,function(a,b){c._cssSelector(a,b)});this._updateInterface();this._updateButtons();this._updateAutohide();this._updateVolume();
this._updateMute()},_cssSelector:function(a,c){var d=this;"string"===typeof c?b.jPlayer.prototype.options.cssSelector[a]?(this.css.jq[a]&&this.css.jq[a].length&&this.css.jq[a].unbind(".jPlayer"),this.options.cssSelector[a]=c,this.css.cs[a]=this.options.cssSelectorAncestor+" "+c,this.css.jq[a]=c?b(this.css.cs[a]):[],this.css.jq[a].length&&this[a]&&this.css.jq[a].bind("click.jPlayer",function(c){c.preventDefault();d[a](c);d.options.autoBlur&&b(this).blur()}),c&&1!==this.css.jq[a].length&&this._warning({type:b.jPlayer.warning.CSS_SELECTOR_COUNT,
context:this.css.cs[a],message:b.jPlayer.warningMsg.CSS_SELECTOR_COUNT+this.css.jq[a].length+" found for "+a+" method.",hint:b.jPlayer.warningHint.CSS_SELECTOR_COUNT})):this._warning({type:b.jPlayer.warning.CSS_SELECTOR_METHOD,context:a,message:b.jPlayer.warningMsg.CSS_SELECTOR_METHOD,hint:b.jPlayer.warningHint.CSS_SELECTOR_METHOD}):this._warning({type:b.jPlayer.warning.CSS_SELECTOR_STRING,context:c,message:b.jPlayer.warningMsg.CSS_SELECTOR_STRING,hint:b.jPlayer.warningHint.CSS_SELECTOR_STRING})},
duration:function(a){this.options.toggleDuration&&(this.options.captureDuration&&a.stopPropagation(),this._setOption("remainingDuration",!this.options.remainingDuration))},seekBar:function(a){if(this.css.jq.seekBar.length){var c=b(a.currentTarget),d=c.offset();a=a.pageX-d.left;c=c.width();this.playHead(100*a/c)}},playbackRate:function(a){this._setOption("playbackRate",a)},playbackRateBar:function(a){if(this.css.jq.playbackRateBar.length){var c=b(a.currentTarget),d=c.offset(),e=a.pageX-d.left,g=c.width();
a=c.height()-a.pageY+d.top;c=c.height();this.playbackRate((this.options.verticalPlaybackRate?a/c:e/g)*(this.options.maxPlaybackRate-this.options.minPlaybackRate)+this.options.minPlaybackRate)}},_updatePlaybackRate:function(){var a=(this.options.playbackRate-this.options.minPlaybackRate)/(this.options.maxPlaybackRate-this.options.minPlaybackRate);this.status.playbackRateEnabled?(this.css.jq.playbackRateBar.length&&this.css.jq.playbackRateBar.show(),this.css.jq.playbackRateBarValue.length&&(this.css.jq.playbackRateBarValue.show(),
this.css.jq.playbackRateBarValue[this.options.verticalPlaybackRate?"height":"width"](100*a+"%"))):(this.css.jq.playbackRateBar.length&&this.css.jq.playbackRateBar.hide(),this.css.jq.playbackRateBarValue.length&&this.css.jq.playbackRateBarValue.hide())},repeat:function(a){"object"===typeof a&&this.options.useStateClassSkin&&this.options.loop?this._loop(!1):this._loop(!0)},repeatOff:function(){this._loop(!1)},_loop:function(a){this.options.loop!==a&&(this.options.loop=a,this._updateButtons(),this._trigger(b.jPlayer.event.repeat))},
option:function(a,c){var d=a;if(0===arguments.length)return b.extend(!0,{},this.options);if("string"===typeof a){var e=a.split(".");if(c===f){for(var d=b.extend(!0,{},this.options),g=0;g<e.length;g++)if(d[e[g]]!==f)d=d[e[g]];else return this._warning({type:b.jPlayer.warning.OPTION_KEY,context:a,message:b.jPlayer.warningMsg.OPTION_KEY,hint:b.jPlayer.warningHint.OPTION_KEY}),f;return d}for(var g=d={},h=0;h<e.length;h++)h<e.length-1?(g[e[h]]={},g=g[e[h]]):g[e[h]]=c}this._setOptions(d);return this},_setOptions:function(a){var c=
this;b.each(a,function(a,b){c._setOption(a,b)});return this},_setOption:function(a,c){var d=this;switch(a){case "volume":this.volume(c);break;case "muted":this._muted(c);break;case "globalVolume":this.options[a]=c;break;case "cssSelectorAncestor":this._cssSelectorAncestor(c);break;case "cssSelector":b.each(c,function(a,c){d._cssSelector(a,c)});break;case "playbackRate":this.options[a]=c=this._limitValue(c,this.options.minPlaybackRate,this.options.maxPlaybackRate);this.html.used&&this._html_setProperty("playbackRate",
c);this._updatePlaybackRate();break;case "defaultPlaybackRate":this.options[a]=c=this._limitValue(c,this.options.minPlaybackRate,this.options.maxPlaybackRate);this.html.used&&this._html_setProperty("defaultPlaybackRate",c);this._updatePlaybackRate();break;case "minPlaybackRate":this.options[a]=c=this._limitValue(c,.1,this.options.maxPlaybackRate-.1);this._updatePlaybackRate();break;case "maxPlaybackRate":this.options[a]=c=this._limitValue(c,this.options.minPlaybackRate+.1,16);this._updatePlaybackRate();
break;case "fullScreen":if(this.options[a]!==c){var e=b.jPlayer.nativeFeatures.fullscreen.used.webkitVideo;if(!e||e&&!this.status.waitForPlay)e||(this.options[a]=c),c?this._requestFullscreen():this._exitFullscreen(),e||this._setOption("fullWindow",c)}break;case "fullWindow":this.options[a]!==c&&(this._removeUiClass(),this.options[a]=c,this._refreshSize());break;case "size":this.options.fullWindow||this.options[a].cssClass===c.cssClass||this._removeUiClass();this.options[a]=b.extend({},this.options[a],
c);this._refreshSize();break;case "sizeFull":this.options.fullWindow&&this.options[a].cssClass!==c.cssClass&&this._removeUiClass();this.options[a]=b.extend({},this.options[a],c);this._refreshSize();break;case "autohide":this.options[a]=b.extend({},this.options[a],c);this._updateAutohide();break;case "loop":this._loop(c);break;case "remainingDuration":this.options[a]=c;this._updateInterface();break;case "toggleDuration":this.options[a]=c;break;case "nativeVideoControls":this.options[a]=b.extend({},
this.options[a],c);this.status.nativeVideoControls=this._uaBlocklist(this.options.nativeVideoControls);this._restrictNativeVideoControls();this._updateNativeVideoControls();break;case "noFullWindow":this.options[a]=b.extend({},this.options[a],c);this.status.nativeVideoControls=this._uaBlocklist(this.options.nativeVideoControls);this.status.noFullWindow=this._uaBlocklist(this.options.noFullWindow);this._restrictNativeVideoControls();this._updateButtons();break;case "noVolume":this.options[a]=b.extend({},
this.options[a],c);this.status.noVolume=this._uaBlocklist(this.options.noVolume);this._updateVolume();this._updateMute();break;case "emulateHtml":this.options[a]!==c&&((this.options[a]=c)?this._emulateHtmlBridge():this._destroyHtmlBridge());break;case "timeFormat":this.options[a]=b.extend({},this.options[a],c);break;case "keyEnabled":this.options[a]=c;c||this!==b.jPlayer.focus||(b.jPlayer.focus=null);break;case "keyBindings":this.options[a]=b.extend(!0,{},this.options[a],c);break;case "audioFullScreen":this.options[a]=
c;break;case "autoBlur":this.options[a]=c}return this},_refreshSize:function(){this._setSize();this._addUiClass();this._updateSize();this._updateButtons();this._updateAutohide();this._trigger(b.jPlayer.event.resize)},_setSize:function(){this.options.fullWindow?(this.status.width=this.options.sizeFull.width,this.status.height=this.options.sizeFull.height,this.status.cssClass=this.options.sizeFull.cssClass):(this.status.width=this.options.size.width,this.status.height=this.options.size.height,this.status.cssClass=
this.options.size.cssClass);this.element.css({width:this.status.width,height:this.status.height})},_addUiClass:function(){this.ancestorJq.length&&this.ancestorJq.addClass(this.status.cssClass)},_removeUiClass:function(){this.ancestorJq.length&&this.ancestorJq.removeClass(this.status.cssClass)},_updateSize:function(){this.internal.poster.jq.css({width:this.status.width,height:this.status.height});!this.status.waitForPlay&&this.html.active&&this.status.video||this.html.video.available&&this.html.used&&
this.status.nativeVideoControls?this.internal.video.jq.css({width:this.status.width,height:this.status.height}):!this.status.waitForPlay&&this.flash.active&&this.status.video&&this.internal.flash.jq.css({width:this.status.width,height:this.status.height})},_updateAutohide:function(){var a=this,c=function(){a.css.jq.gui.fadeIn(a.options.autohide.fadeIn,function(){clearTimeout(a.internal.autohideId);a.internal.autohideId=setTimeout(function(){a.css.jq.gui.fadeOut(a.options.autohide.fadeOut)},a.options.autohide.hold)})};
this.css.jq.gui.length&&(this.css.jq.gui.stop(!0,!0),clearTimeout(this.internal.autohideId),this.element.unbind(".jPlayerAutohide"),this.css.jq.gui.unbind(".jPlayerAutohide"),this.status.nativeVideoControls?this.css.jq.gui.hide():this.options.fullWindow&&this.options.autohide.full||!this.options.fullWindow&&this.options.autohide.restored?(this.element.bind("mousemove.jPlayer.jPlayerAutohide",c),this.css.jq.gui.bind("mousemove.jPlayer.jPlayerAutohide",c),this.css.jq.gui.hide()):this.css.jq.gui.show())},
fullScreen:function(a){"object"===typeof a&&this.options.useStateClassSkin&&this.options.fullScreen?this._setOption("fullScreen",!1):this._setOption("fullScreen",!0)},restoreScreen:function(){this._setOption("fullScreen",!1)},_fullscreenAddEventListeners:function(){var a=this,c=b.jPlayer.nativeFeatures.fullscreen;c.api.fullscreenEnabled&&c.event.fullscreenchange&&("function"!==typeof this.internal.fullscreenchangeHandler&&(this.internal.fullscreenchangeHandler=function(){a._fullscreenchange()}),document.addEventListener(c.event.fullscreenchange,
this.internal.fullscreenchangeHandler,!1))},_fullscreenRemoveEventListeners:function(){var a=b.jPlayer.nativeFeatures.fullscreen;this.internal.fullscreenchangeHandler&&document.removeEventListener(a.event.fullscreenchange,this.internal.fullscreenchangeHandler,!1)},_fullscreenchange:function(){this.options.fullScreen&&!b.jPlayer.nativeFeatures.fullscreen.api.fullscreenElement()&&this._setOption("fullScreen",!1)},_requestFullscreen:function(){var a=this.ancestorJq.length?this.ancestorJq[0]:this.element[0],
c=b.jPlayer.nativeFeatures.fullscreen;c.used.webkitVideo&&(a=this.htmlElement.video);c.api.fullscreenEnabled&&c.api.requestFullscreen(a)},_exitFullscreen:function(){var a=b.jPlayer.nativeFeatures.fullscreen,c;a.used.webkitVideo&&(c=this.htmlElement.video);a.api.fullscreenEnabled&&a.api.exitFullscreen(c)},_html_initMedia:function(a){var c=b(this.htmlElement.media).empty();b.each(a.track||[],function(a,b){var g=document.createElement("track");g.setAttribute("kind",b.kind?b.kind:"");g.setAttribute("src",
b.src?b.src:"");g.setAttribute("srclang",b.srclang?b.srclang:"");g.setAttribute("label",b.label?b.label:"");b.def&&g.setAttribute("default",b.def);c.append(g)});this.htmlElement.media.src=this.status.src;"none"!==this.options.preload&&this._html_load();this._trigger(b.jPlayer.event.timeupdate)},_html_setFormat:function(a){var c=this;b.each(this.formats,function(b,e){if(c.html.support[e]&&a[e])return c.status.src=a[e],c.status.format[e]=!0,c.status.formatType=e,!1})},_html_setAudio:function(a){this._html_setFormat(a);
this.htmlElement.media=this.htmlElement.audio;this._html_initMedia(a)},_html_setVideo:function(a){this._html_setFormat(a);this.status.nativeVideoControls&&(this.htmlElement.video.poster=this._validString(a.poster)?a.poster:"");this.htmlElement.media=this.htmlElement.video;this._html_initMedia(a)},_html_resetMedia:function(){this.htmlElement.media&&(this.htmlElement.media.id!==this.internal.video.id||this.status.nativeVideoControls||this.internal.video.jq.css({width:"0px",height:"0px"}),this.htmlElement.media.pause())},
_html_clearMedia:function(){this.htmlElement.media&&(this.htmlElement.media.src="about:blank",this.htmlElement.media.load())},_html_load:function(){this.status.waitForLoad&&(this.status.waitForLoad=!1,this.htmlElement.media.load());clearTimeout(this.internal.htmlDlyCmdId)},_html_play:function(a){var b=this,d=this.htmlElement.media;this.androidFix.pause=!1;this._html_load();if(this.androidFix.setMedia)this.androidFix.play=!0,this.androidFix.time=a;else if(isNaN(a))d.play();else{this.internal.cmdsIgnored&&
d.play();try{if(!d.seekable||"object"===typeof d.seekable&&0<d.seekable.length)d.currentTime=a,d.play();else throw 1;}catch(e){this.internal.htmlDlyCmdId=setTimeout(function(){b.play(a)},250);return}}this._html_checkWaitForPlay()},_html_pause:function(a){var b=this,d=this.htmlElement.media;this.androidFix.play=!1;0<a?this._html_load():clearTimeout(this.internal.htmlDlyCmdId);d.pause();if(this.androidFix.setMedia)this.androidFix.pause=!0,this.androidFix.time=a;else if(!isNaN(a))try{if(!d.seekable||
"object"===typeof d.seekable&&0<d.seekable.length)d.currentTime=a;else throw 1;}catch(e){this.internal.htmlDlyCmdId=setTimeout(function(){b.pause(a)},250);return}0<a&&this._html_checkWaitForPlay()},_html_playHead:function(a){var b=this,d=this.htmlElement.media;this._html_load();try{if("object"===typeof d.seekable&&0<d.seekable.length)d.currentTime=a*d.seekable.end(d.seekable.length-1)/100;else if(0<d.duration&&!isNaN(d.duration))d.currentTime=a*d.duration/100;else throw"e";}catch(e){this.internal.htmlDlyCmdId=
setTimeout(function(){b.playHead(a)},250);return}this.status.waitForLoad||this._html_checkWaitForPlay()},_html_checkWaitForPlay:function(){this.status.waitForPlay&&(this.status.waitForPlay=!1,this.css.jq.videoPlay.length&&this.css.jq.videoPlay.hide(),this.status.video&&(this.internal.poster.jq.hide(),this.internal.video.jq.css({width:this.status.width,height:this.status.height})))},_html_setProperty:function(a,b){this.html.audio.available&&(this.htmlElement.audio[a]=b);this.html.video.available&&
(this.htmlElement.video[a]=b)},_flash_setAudio:function(a){var c=this;try{b.each(this.formats,function(b,d){if(c.flash.support[d]&&a[d]){switch(d){case "m4a":case "fla":c._getMovie().fl_setAudio_m4a(a[d]);break;case "mp3":c._getMovie().fl_setAudio_mp3(a[d]);break;case "rtmpa":c._getMovie().fl_setAudio_rtmp(a[d])}c.status.src=a[d];c.status.format[d]=!0;c.status.formatType=d;return!1}}),"auto"===this.options.preload&&(this._flash_load(),this.status.waitForLoad=!1)}catch(d){this._flashError(d)}},_flash_setVideo:function(a){var c=
this;try{b.each(this.formats,function(b,d){if(c.flash.support[d]&&a[d]){switch(d){case "m4v":case "flv":c._getMovie().fl_setVideo_m4v(a[d]);break;case "rtmpv":c._getMovie().fl_setVideo_rtmp(a[d])}c.status.src=a[d];c.status.format[d]=!0;c.status.formatType=d;return!1}}),"auto"===this.options.preload&&(this._flash_load(),this.status.waitForLoad=!1)}catch(d){this._flashError(d)}},_flash_resetMedia:function(){this.internal.flash.jq.css({width:"0px",height:"0px"});this._flash_pause(NaN)},_flash_clearMedia:function(){try{this._getMovie().fl_clearMedia()}catch(a){this._flashError(a)}},
_flash_load:function(){try{this._getMovie().fl_load()}catch(a){this._flashError(a)}this.status.waitForLoad=!1},_flash_play:function(a){try{this._getMovie().fl_play(a)}catch(b){this._flashError(b)}this.status.waitForLoad=!1;this._flash_checkWaitForPlay()},_flash_pause:function(a){try{this._getMovie().fl_pause(a)}catch(b){this._flashError(b)}0<a&&(this.status.waitForLoad=!1,this._flash_checkWaitForPlay())},_flash_playHead:function(a){try{this._getMovie().fl_play_head(a)}catch(b){this._flashError(b)}this.status.waitForLoad||
this._flash_checkWaitForPlay()},_flash_checkWaitForPlay:function(){this.status.waitForPlay&&(this.status.waitForPlay=!1,this.css.jq.videoPlay.length&&this.css.jq.videoPlay.hide(),this.status.video&&(this.internal.poster.jq.hide(),this.internal.flash.jq.css({width:this.status.width,height:this.status.height})))},_flash_volume:function(a){try{this._getMovie().fl_volume(a)}catch(b){this._flashError(b)}},_flash_mute:function(a){try{this._getMovie().fl_mute(a)}catch(b){this._flashError(b)}},_getMovie:function(){return document[this.internal.flash.id]},
_getFlashPluginVersion:function(){var a=0,b;if(window.ActiveXObject)try{if(b=new ActiveXObject("ShockwaveFlash.ShockwaveFlash")){var d=b.GetVariable("$version");d&&(d=d.split(" ")[1].split(","),a=parseInt(d[0],10)+"."+parseInt(d[1],10))}}catch(e){}else navigator.plugins&&0<navigator.mimeTypes.length&&(b=navigator.plugins["Shockwave Flash"])&&(a=navigator.plugins["Shockwave Flash"].description.replace(/.*\s(\d+\.\d+).*/,"$1"));return 1*a},_checkForFlash:function(a){var b=!1;this._getFlashPluginVersion()>=
a&&(b=!0);return b},_validString:function(a){return a&&"string"===typeof a},_limitValue:function(a,b,d){return a<b?b:a>d?d:a},_urlNotSetError:function(a){this._error({type:b.jPlayer.error.URL_NOT_SET,context:a,message:b.jPlayer.errorMsg.URL_NOT_SET,hint:b.jPlayer.errorHint.URL_NOT_SET})},_flashError:function(a){var c;c=this.internal.ready?"FLASH_DISABLED":"FLASH";this._error({type:b.jPlayer.error[c],context:this.internal.flash.swf,message:b.jPlayer.errorMsg[c]+a.message,hint:b.jPlayer.errorHint[c]});
this.internal.flash.jq.css({width:"1px",height:"1px"})},_error:function(a){this._trigger(b.jPlayer.event.error,a);this.options.errorAlerts&&this._alert("Error!"+(a.message?"\n"+a.message:"")+(a.hint?"\n"+a.hint:"")+"\nContext: "+a.context)},_warning:function(a){this._trigger(b.jPlayer.event.warning,f,a);this.options.warningAlerts&&this._alert("Warning!"+(a.message?"\n"+a.message:"")+(a.hint?"\n"+a.hint:"")+"\nContext: "+a.context)},_alert:function(a){a="jPlayer "+this.version.script+" : id='"+this.internal.self.id+
"' : "+a;this.options.consoleAlerts?window.console&&window.console.log&&window.console.log(a):alert(a)},_emulateHtmlBridge:function(){var a=this;b.each(b.jPlayer.emulateMethods.split(/\s+/g),function(b,d){a.internal.domNode[d]=function(b){a[d](b)}});b.each(b.jPlayer.event,function(c,d){var e=!0;b.each(b.jPlayer.reservedEvent.split(/\s+/g),function(a,b){if(b===c)return e=!1});e&&a.element.bind(d+".jPlayer.jPlayerHtml",function(){a._emulateHtmlUpdate();var b=document.createEvent("Event");b.initEvent(c,
!1,!0);a.internal.domNode.dispatchEvent(b)})})},_emulateHtmlUpdate:function(){var a=this;b.each(b.jPlayer.emulateStatus.split(/\s+/g),function(b,d){a.internal.domNode[d]=a.status[d]});b.each(b.jPlayer.emulateOptions.split(/\s+/g),function(b,d){a.internal.domNode[d]=a.options[d]})},_destroyHtmlBridge:function(){var a=this;this.element.unbind(".jPlayerHtml");b.each((b.jPlayer.emulateMethods+" "+b.jPlayer.emulateStatus+" "+b.jPlayer.emulateOptions).split(/\s+/g),function(b,d){delete a.internal.domNode[d]})}};
b.jPlayer.error={FLASH:"e_flash",FLASH_DISABLED:"e_flash_disabled",NO_SOLUTION:"e_no_solution",NO_SUPPORT:"e_no_support",URL:"e_url",URL_NOT_SET:"e_url_not_set",VERSION:"e_version"};b.jPlayer.errorMsg={FLASH:"jPlayer's Flash fallback is not configured correctly, or a command was issued before the jPlayer Ready event. Details: ",FLASH_DISABLED:"jPlayer's Flash fallback has been disabled by the browser due to the CSS rules you have used. Details: ",NO_SOLUTION:"No solution can be found by jPlayer in this browser. Neither HTML nor Flash can be used.",
NO_SUPPORT:"It is not possible to play any media format provided in setMedia() on this browser using your current options.",URL:"Media URL could not be loaded.",URL_NOT_SET:"Attempt to issue media playback commands, while no media url is set.",VERSION:"jPlayer "+b.jPlayer.prototype.version.script+" needs Jplayer.swf version "+b.jPlayer.prototype.version.needFlash+" but found "};b.jPlayer.errorHint={FLASH:"Check your swfPath option and that Jplayer.swf is there.",FLASH_DISABLED:"Check that you have not display:none; the jPlayer entity or any ancestor.",
NO_SOLUTION:"Review the jPlayer options: support and supplied.",NO_SUPPORT:"Video or audio formats defined in the supplied option are missing.",URL:"Check media URL is valid.",URL_NOT_SET:"Use setMedia() to set the media URL.",VERSION:"Update jPlayer files."};b.jPlayer.warning={CSS_SELECTOR_COUNT:"e_css_selector_count",CSS_SELECTOR_METHOD:"e_css_selector_method",CSS_SELECTOR_STRING:"e_css_selector_string",OPTION_KEY:"e_option_key"};b.jPlayer.warningMsg={CSS_SELECTOR_COUNT:"The number of css selectors found did not equal one: ",
CSS_SELECTOR_METHOD:"The methodName given in jPlayer('cssSelector') is not a valid jPlayer method.",CSS_SELECTOR_STRING:"The methodCssSelector given in jPlayer('cssSelector') is not a String or is empty.",OPTION_KEY:"The option requested in jPlayer('option') is undefined."};b.jPlayer.warningHint={CSS_SELECTOR_COUNT:"Check your css selector and the ancestor.",CSS_SELECTOR_METHOD:"Check your method name.",CSS_SELECTOR_STRING:"Check your css selector is a string.",OPTION_KEY:"Check your option name."}});


/*! nanoScrollerJS - v0.8.7 - (c) 2015 James Florentino; Licensed MIT */

!function(a){return"function"==typeof define&&define.amd?define(["jquery"],function(b){return a(b,window,document)}):"object"==typeof exports?module.exports=a(require("jquery"),window,document):a(jQuery,window,document)}(function(a,b,c){"use strict";var d,e,f,g,h,i,j,k,l,m,n,o,p,q,r,s,t,u,v,w,x,y,z,A,B,C,D,E,F,G,H;z={paneClass:"nano-pane",sliderClass:"nano-slider",contentClass:"nano-content",iOSNativeScrolling:!1,preventPageScrolling:!1,disableResize:!1,alwaysVisible:!1,flashDelay:1500,sliderMinHeight:20,sliderMaxHeight:null,documentContext:null,windowContext:null},u="scrollbar",t="scroll",l="mousedown",m="mouseenter",n="mousemove",p="mousewheel",o="mouseup",s="resize",h="drag",i="enter",w="up",r="panedown",f="DOMMouseScroll",g="down",x="wheel",j="keydown",k="keyup",v="touchmove",d="Microsoft Internet Explorer"===b.navigator.appName&&/msie 7./i.test(b.navigator.appVersion)&&b.ActiveXObject,e=null,D=b.requestAnimationFrame,y=b.cancelAnimationFrame,F=c.createElement("div").style,H=function(){var a,b,c,d,e,f;for(d=["t","webkitT","MozT","msT","OT"],a=e=0,f=d.length;f>e;a=++e)if(c=d[a],b=d[a]+"ransform",b in F)return d[a].substr(0,d[a].length-1);return!1}(),G=function(a){return H===!1?!1:""===H?a:H+a.charAt(0).toUpperCase()+a.substr(1)},E=G("transform"),B=E!==!1,A=function(){var a,b,d;return a=c.createElement("div"),b=a.style,b.position="absolute",b.width="100px",b.height="100px",b.overflow=t,b.top="-9999px",c.body.appendChild(a),d=a.offsetWidth-a.clientWidth,c.body.removeChild(a),d},C=function(){var a,c,d;return c=b.navigator.userAgent,(a=/(?=.+Mac OS X)(?=.+Firefox)/.test(c))?(d=/Firefox\/\d{2}\./.exec(c),d&&(d=d[0].replace(/\D+/g,"")),a&&+d>23):!1},q=function(){function j(d,f){this.el=d,this.options=f,e||(e=A()),this.$el=a(this.el),this.doc=a(this.options.documentContext||c),this.win=a(this.options.windowContext||b),this.body=this.doc.find("body"),this.$content=this.$el.children("."+this.options.contentClass),this.$content.attr("tabindex",this.options.tabIndex||0),this.content=this.$content[0],this.previousPosition=0,this.options.iOSNativeScrolling&&null!=this.el.style.WebkitOverflowScrolling?this.nativeScrolling():this.generate(),this.createEvents(),this.addEvents(),this.reset()}return j.prototype.preventScrolling=function(a,b){if(this.isActive)if(a.type===f)(b===g&&a.originalEvent.detail>0||b===w&&a.originalEvent.detail<0)&&a.preventDefault();else if(a.type===p){if(!a.originalEvent||!a.originalEvent.wheelDelta)return;(b===g&&a.originalEvent.wheelDelta<0||b===w&&a.originalEvent.wheelDelta>0)&&a.preventDefault()}},j.prototype.nativeScrolling=function(){this.$content.css({WebkitOverflowScrolling:"touch"}),this.iOSNativeScrolling=!0,this.isActive=!0},j.prototype.updateScrollValues=function(){var a,b;a=this.content,this.maxScrollTop=a.scrollHeight-a.clientHeight,this.prevScrollTop=this.contentScrollTop||0,this.contentScrollTop=a.scrollTop,b=this.contentScrollTop>this.previousPosition?"down":this.contentScrollTop<this.previousPosition?"up":"same",this.previousPosition=this.contentScrollTop,"same"!==b&&this.$el.trigger("update",{position:this.contentScrollTop,maximum:this.maxScrollTop,direction:b}),this.iOSNativeScrolling||(this.maxSliderTop=this.paneHeight-this.sliderHeight,this.sliderTop=0===this.maxScrollTop?0:this.contentScrollTop*this.maxSliderTop/this.maxScrollTop)},j.prototype.setOnScrollStyles=function(){var a;B?(a={},a[E]="translate(0, "+this.sliderTop+"px)"):a={top:this.sliderTop},D?(y&&this.scrollRAF&&y(this.scrollRAF),this.scrollRAF=D(function(b){return function(){return b.scrollRAF=null,b.slider.css(a)}}(this))):this.slider.css(a)},j.prototype.createEvents=function(){this.events={down:function(a){return function(b){return a.isBeingDragged=!0,a.offsetY=b.pageY-a.slider.offset().top,a.slider.is(b.target)||(a.offsetY=0),a.pane.addClass("active"),a.doc.bind(n,a.events[h]).bind(o,a.events[w]),a.body.bind(m,a.events[i]),!1}}(this),drag:function(a){return function(b){return a.sliderY=b.pageY-a.$el.offset().top-a.paneTop-(a.offsetY||.5*a.sliderHeight),a.scroll(),a.contentScrollTop>=a.maxScrollTop&&a.prevScrollTop!==a.maxScrollTop?a.$el.trigger("scrollend"):0===a.contentScrollTop&&0!==a.prevScrollTop&&a.$el.trigger("scrolltop"),!1}}(this),up:function(a){return function(b){return a.isBeingDragged=!1,a.pane.removeClass("active"),a.doc.unbind(n,a.events[h]).unbind(o,a.events[w]),a.body.unbind(m,a.events[i]),!1}}(this),resize:function(a){return function(b){a.reset()}}(this),panedown:function(a){return function(b){return a.sliderY=(b.offsetY||b.originalEvent.layerY)-.5*a.sliderHeight,a.scroll(),a.events.down(b),!1}}(this),scroll:function(a){return function(b){a.updateScrollValues(),a.isBeingDragged||(a.iOSNativeScrolling||(a.sliderY=a.sliderTop,a.setOnScrollStyles()),null!=b&&(a.contentScrollTop>=a.maxScrollTop?(a.options.preventPageScrolling&&a.preventScrolling(b,g),a.prevScrollTop!==a.maxScrollTop&&a.$el.trigger("scrollend")):0===a.contentScrollTop&&(a.options.preventPageScrolling&&a.preventScrolling(b,w),0!==a.prevScrollTop&&a.$el.trigger("scrolltop"))))}}(this),wheel:function(a){return function(b){var c;if(null!=b)return c=b.delta||b.wheelDelta||b.originalEvent&&b.originalEvent.wheelDelta||-b.detail||b.originalEvent&&-b.originalEvent.detail,c&&(a.sliderY+=-c/3),a.scroll(),!1}}(this),enter:function(a){return function(b){var c;if(a.isBeingDragged)return 1!==(b.buttons||b.which)?(c=a.events)[w].apply(c,arguments):void 0}}(this)}},j.prototype.addEvents=function(){var a;this.removeEvents(),a=this.events,this.options.disableResize||this.win.bind(s,a[s]),this.iOSNativeScrolling||(this.slider.bind(l,a[g]),this.pane.bind(l,a[r]).bind(""+p+" "+f,a[x])),this.$content.bind(""+t+" "+p+" "+f+" "+v,a[t])},j.prototype.removeEvents=function(){var a;a=this.events,this.win.unbind(s,a[s]),this.iOSNativeScrolling||(this.slider.unbind(),this.pane.unbind()),this.$content.unbind(""+t+" "+p+" "+f+" "+v,a[t])},j.prototype.generate=function(){var a,c,d,f,g,h,i;return f=this.options,h=f.paneClass,i=f.sliderClass,a=f.contentClass,(g=this.$el.children("."+h)).length||g.children("."+i).length||this.$el.append('<div class="'+h+'"><div class="'+i+'" /></div>'),this.pane=this.$el.children("."+h),this.slider=this.pane.find("."+i),0===e&&C()?(d=b.getComputedStyle(this.content,null).getPropertyValue("padding-right").replace(/[^0-9.]+/g,""),c={right:-14,paddingRight:+d+14}):e&&(c={right:-e},this.$el.addClass("has-scrollbar")),null!=c&&this.$content.css(c),this},j.prototype.restore=function(){this.stopped=!1,this.iOSNativeScrolling||this.pane.show(),this.addEvents()},j.prototype.reset=function(){var a,b,c,f,g,h,i,j,k,l,m,n;return this.iOSNativeScrolling?void(this.contentHeight=this.content.scrollHeight):(this.$el.find("."+this.options.paneClass).length||this.generate().stop(),this.stopped&&this.restore(),a=this.content,f=a.style,g=f.overflowY,d&&this.$content.css({height:this.$content.height()}),b=a.scrollHeight+e,l=parseInt(this.$el.css("max-height"),10),l>0&&(this.$el.height(""),this.$el.height(a.scrollHeight>l?l:a.scrollHeight)),i=this.pane.outerHeight(!1),k=parseInt(this.pane.css("top"),10),h=parseInt(this.pane.css("bottom"),10),j=i+k+h,n=Math.round(j/b*i),n<this.options.sliderMinHeight?n=this.options.sliderMinHeight:null!=this.options.sliderMaxHeight&&n>this.options.sliderMaxHeight&&(n=this.options.sliderMaxHeight),g===t&&f.overflowX!==t&&(n+=e),this.maxSliderTop=j-n,this.contentHeight=b,this.paneHeight=i,this.paneOuterHeight=j,this.sliderHeight=n,this.paneTop=k,this.slider.height(n),this.events.scroll(),this.pane.show(),this.isActive=!0,a.scrollHeight===a.clientHeight||this.pane.outerHeight(!0)>=a.scrollHeight&&g!==t?(this.pane.hide(),this.isActive=!1):this.el.clientHeight===a.scrollHeight&&g===t?this.slider.hide():this.slider.show(),this.pane.css({opacity:this.options.alwaysVisible?1:"",visibility:this.options.alwaysVisible?"visible":""}),c=this.$content.css("position"),("static"===c||"relative"===c)&&(m=parseInt(this.$content.css("right"),10),m&&this.$content.css({right:"",marginRight:m})),this)},j.prototype.scroll=function(){return this.isActive?(this.sliderY=Math.max(0,this.sliderY),this.sliderY=Math.min(this.maxSliderTop,this.sliderY),this.$content.scrollTop(this.maxScrollTop*this.sliderY/this.maxSliderTop),this.iOSNativeScrolling||(this.updateScrollValues(),this.setOnScrollStyles()),this):void 0},j.prototype.scrollBottom=function(a){return this.isActive?(this.$content.scrollTop(this.contentHeight-this.$content.height()-a).trigger(p),this.stop().restore(),this):void 0},j.prototype.scrollTop=function(a){return this.isActive?(this.$content.scrollTop(+a).trigger(p),this.stop().restore(),this):void 0},j.prototype.scrollTo=function(a){return this.isActive?(this.scrollTop(this.$el.find(a).get(0).offsetTop),this):void 0},j.prototype.stop=function(){return y&&this.scrollRAF&&(y(this.scrollRAF),this.scrollRAF=null),this.stopped=!0,this.removeEvents(),this.iOSNativeScrolling||this.pane.hide(),this},j.prototype.destroy=function(){return this.stopped||this.stop(),!this.iOSNativeScrolling&&this.pane.length&&this.pane.remove(),d&&this.$content.height(""),this.$content.removeAttr("tabindex"),this.$el.hasClass("has-scrollbar")&&(this.$el.removeClass("has-scrollbar"),this.$content.css({right:""})),this},j.prototype.flash=function(){return!this.iOSNativeScrolling&&this.isActive?(this.reset(),this.pane.addClass("flashed"),setTimeout(function(a){return function(){a.pane.removeClass("flashed")}}(this),this.options.flashDelay),this):void 0},j}(),a.fn.nanoScroller=function(b){return this.each(function(){var c,d;if((d=this.nanoscroller)||(c=a.extend({},z,b),this.nanoscroller=d=new q(this,c)),b&&"object"==typeof b){if(a.extend(d.options,b),null!=b.scrollBottom)return d.scrollBottom(b.scrollBottom);if(null!=b.scrollTop)return d.scrollTop(b.scrollTop);if(b.scrollTo)return d.scrollTo(b.scrollTo);if("bottom"===b.scroll)return d.scrollBottom(0);if("top"===b.scroll)return d.scrollTop(0);if(b.scroll&&b.scroll instanceof a)return d.scrollTo(b.scroll);if(b.stop)return d.stop();if(b.destroy)return d.destroy();if(b.flash)return d.flash()}return d.reset()})},a.fn.nanoScroller.Constructor=q});
//# sourceMappingURL=jquery.nanoscroller.min.js.map

/*
 Sticky-kit v1.1.2 | WTFPL | Leaf Corcoran 2015 | http://leafo.net
*/
(function(){var b,f;b=this.jQuery||window.jQuery;f=b(window);b.fn.stick_in_parent=function(d){var A,w,J,n,B,K,p,q,k,E,t;null==d&&(d={});t=d.sticky_class;B=d.inner_scrolling;E=d.recalc_every;k=d.parent;q=d.offset_top;p=d.spacer;w=d.bottoming;null==q&&(q=0);null==k&&(k=void 0);null==B&&(B=!0);null==t&&(t="is_stuck");A=b(document);null==w&&(w=!0);J=function(a,d,n,C,F,u,r,G){var v,H,m,D,I,c,g,x,y,z,h,l;if(!a.data("sticky_kit")){a.data("sticky_kit",!0);I=A.height();g=a.parent();null!=k&&(g=g.closest(k));
if(!g.length)throw"failed to find stick parent";v=m=!1;(h=null!=p?p&&a.closest(p):b("<div />"))&&h.css("position",a.css("position"));x=function(){var c,f,e;if(!G&&(I=A.height(),c=parseInt(g.css("border-top-width"),10),f=parseInt(g.css("padding-top"),10),d=parseInt(g.css("padding-bottom"),10),n=g.offset().top+c+f,C=g.height(),m&&(v=m=!1,null==p&&(a.insertAfter(h),h.detach()),a.css({position:"",top:"",width:"",bottom:""}).removeClass(t),e=!0),F=a.offset().top-(parseInt(a.css("margin-top"),10)||0)-q,
u=a.outerHeight(!0),r=a.css("float"),h&&h.css({width:a.outerWidth(!0),height:u,display:a.css("display"),"vertical-align":a.css("vertical-align"),"float":r}),e))return l()};x();if(u!==C)return D=void 0,c=q,z=E,l=function(){var b,l,e,k;if(!G&&(e=!1,null!=z&&(--z,0>=z&&(z=E,x(),e=!0)),e||A.height()===I||x(),e=f.scrollTop(),null!=D&&(l=e-D),D=e,m?(w&&(k=e+u+c>C+n,v&&!k&&(v=!1,a.css({position:"fixed",bottom:"",top:c}).trigger("sticky_kit:unbottom"))),e<F&&(m=!1,c=q,null==p&&("left"!==r&&"right"!==r||a.insertAfter(h),
h.detach()),b={position:"",width:"",top:""},a.css(b).removeClass(t).trigger("sticky_kit:unstick")),B&&(b=f.height(),u+q>b&&!v&&(c-=l,c=Math.max(b-u,c),c=Math.min(q,c),m&&a.css({top:c+"px"})))):e>F&&(m=!0,b={position:"fixed",top:c},b.width="border-box"===a.css("box-sizing")?a.outerWidth()+"px":a.width()+"px",a.css(b).addClass(t),null==p&&(a.after(h),"left"!==r&&"right"!==r||h.append(a)),a.trigger("sticky_kit:stick")),m&&w&&(null==k&&(k=e+u+c>C+n),!v&&k)))return v=!0,"static"===g.css("position")&&g.css({position:"relative"}),
a.css({position:"absolute",bottom:d,top:"auto"}).trigger("sticky_kit:bottom")},y=function(){x();return l()},H=function(){G=!0;f.off("touchmove",l);f.off("scroll",l);f.off("resize",y);b(document.body).off("sticky_kit:recalc",y);a.off("sticky_kit:detach",H);a.removeData("sticky_kit");a.css({position:"",bottom:"",top:"",width:""});g.position("position","");if(m)return null==p&&("left"!==r&&"right"!==r||a.insertAfter(h),h.remove()),a.removeClass(t)},f.on("touchmove",l),f.on("scroll",l),f.on("resize",
y),b(document.body).on("sticky_kit:recalc",y),a.on("sticky_kit:detach",H),setTimeout(l,0)}};n=0;for(K=this.length;n<K;n++)d=this[n],J(b(d));return this}}).call(this);


!function(e,t,o,n){"use strict";function s(o,n){d[o]&&(H.before(o,f),y=1,H.sectionName&&(t.location.hash=d[o]),n?(e(H.target).stop().scrollTop(l[o]),H.after(o,f)):(e(H.target).stop().animate({scrollTop:l[o]},H.scrollSpeed,H.easing),e(H.target).promise().done(function(){w=!1,H.after(o,f)})))}function i(e,t){for(var o=d.length;o>=0;o--)"string"==typeof e?d[o]===e&&(m=o,s(o,t)):o===e&&(m=o,s(o,t))}var c,u,a,h,r,l=[],d=[],f=[],p=[],m=0,y=1,v=(t.location.hash,!1),g=e(t).scrollTop(),b=!1,w=!1,M=!1,H={section:"section",sectionName:"section-name",easing:"easeOutExpo",scrollSpeed:1100,offset:0,scrollbars:!0,axis:"y",target:"html,body",before:function(){},after:function(){},afterResize:function(){}};e.scrollify=function(n){function i(t){e(H.target).stop().animate({scrollTop:t},H.scrollSpeed,H.easing)}function T(){e(H.section).each(function(o){e(this).css("height","auto").outerHeight()<e(t).height()?(e(this).css({height:e(t).height()}),p[o]=!1):p[o]=!0})}function E(o){e(H.section).each(function(o){l[o]=o>0?e(this).offset().top+H.offset:e(this).offset().top,d[o]=H.sectionName&&e(this).data(H.sectionName)?"#"+e(this).data(H.sectionName).replace(/ /g,"-"):"#"+(o+1),f[o]=e(this),t.location.hash===d[o]&&(m=o,v=!0)}),!0===o&&s(m,!1)}function S(){return g=e(t).scrollTop(),g>parseInt(l[m])?!1:!0}function D(){return g=e(t).scrollTop(),g<parseInt(l[m])+(f[m].height()-e(t).height())?!1:!0}e.easing.easeOutExpo=function(e,t,o,n,s){return t==s?o+n:n*(-Math.pow(2,-10*t/s)+1)+o},a={handleMousedown:function(){b=!1,M=!1},handleMouseup:function(){b=!0,M&&a.calculateNearest()},handleScroll:function(){c&&clearTimeout(c),c=setTimeout(function(){return M=!0,b===!1?!1:(b=!1,void a.calculateNearest())},200)},calculateNearest:function(){g=e(t).scrollTop();for(var o,n=1,i=l.length,c=0,u=Math.abs(l[0]-g);i>n;n++)o=Math.abs(l[n]-g),u>o&&(u=o,c=n);(D()||S())&&(m=c,s(c,!1))},wheelHandler:function(e,t){return p[m]||e.preventDefault(),t=t||-e.originalEvent.detail/3||e.originalEvent.wheelDelta/120,w?!1:void(0>t?m<l.length-1&&D()&&(e.preventDefault(),m++,w=!0,s(m,!1)):t>0&&m>0&&S()&&(e.preventDefault(),m--,w=!0,s(m,!1)))},keyHandler:function(e){38==e.keyCode?m>0&&S()&&(m--,s(m,!1)):40==e.keyCode&&m<l.length-1&&D()&&(m++,s(m,!1))},init:function(){H.scrollbars?(e(t).bind("mousedown",a.handleMousedown),e(t).bind("mouseup",a.handleMouseup),e(t).bind("scroll",a.handleScroll)):e("body").css({overflow:"hidden"}),e(o).bind("DOMMouseScroll mousewheel",a.wheelHandler),e(o).bind("keydown",a.keyHandler)}},h={touches:{touchstart:{y:-1},touchmove:{y:-1},touchend:!1,direction:"undetermined"},options:{distance:30,timeGap:800,timeStamp:(new Date).getTime()},touchHandler:function(e){var t;if("undefined"!=typeof e&&"undefined"!=typeof e.touches)switch(t=e.touches[0],e.type){case"touchstart":h.touches.touchstart.y=t.pageY,h.touches.touchmove.y=-1,h.options.timeStamp=(new Date).getTime(),h.touches.touchend=!1;case"touchmove":h.touches.touchmove.y=t.pageY,h.touches.touchstart.y!==h.touches.touchmove.y&&(e.preventDefault(),h.options.timeStamp+h.options.timeGap<(new Date).getTime()&&0==h.touches.touchend&&(h.touches.touchend=!0,h.touches.touchstart.y>-1&&Math.abs(h.touches.touchmove.y-h.touches.touchstart.y)>h.options.distance&&(h.touches.touchstart.y<h.touches.touchmove.y?h.up():h.down())));break;case"touchend":h.touches[e.type]===!1&&(h.touches[e.type]=!0,h.touches.touchstart.y>-1&&h.touches.touchmove.y>-1&&(Math.abs(h.touches.touchmove.y-h.touches.touchstart.y)>h.options.distance&&(h.touches.touchstart.y<h.touches.touchmove.y?h.up():h.down()),h.touches.touchstart.y=-1))}},down:function(){m<=l.length-1&&(D()&&m<l.length-1?(m++,s(m,!1)):Math.floor(f[m].height()/e(t).height())>y?(i(parseInt(l[m])+e(t).height()*y),y+=1):i(parseInt(l[m])+(f[m].height()-e(t).height())))},up:function(){m>=0&&(S()&&m>0?(m--,s(m,!1)):y>2?(y-=1,i(parseInt(l[m])+e(t).height()*y)):(y=1,i(parseInt(l[m]))))},init:function(){o.addEventListener&&(o.addEventListener("touchstart",h.touchHandler,!1),o.addEventListener("touchmove",h.touchHandler,!1),o.addEventListener("touchend",h.touchHandler,!1))}},r={handleResize:function(){clearTimeout(u),u=setTimeout(function(){T(),E(!0),H.afterResize()},50)}},H=e.extend(H,n),T(),E(!1),v===!1&&H.sectionName?t.location.hash=d[0]:s(m,!1),a.init(),h.init(),e(t).bind("resize",r.handleResize)},e.scrollify.move=function(e){return e===n?!1:void i(e,!1)},e.scrollify.instantMove=function(e){return e===n?!1:void i(e,!0)},e.scrollify.next=function(){m<d.length&&(m+=1,s(m,!1))},e.scrollify.previous=function(){m>0&&(m-=1,s(m,!1))},e.scrollify.instantNext=function(){m<d.length&&(m+=1,s(m,!0))},e.scrollify.instantPrevious=function(){m>0&&(m-=1,s(m,!0))},e.scrollify.destroy=function(){e(H.section).each(function(){e(this).css("height","auto")}),e(t).unbind("resize",r.handleResize),H.scrollbars&&(e(t).unbind("mousedown",a.handleMousedown),e(t).unbind("mouseup",a.handleMouseup),e(t).unbind("scroll",a.handleScroll)),e(o).unbind("DOMMouseScroll mousewheel",a.wheelHandler),e(o).unbind("keydown",a.keyHandler),o.addEventListener&&(o.removeEventListener("touchstart",h.touchHandler,!1),o.removeEventListener("touchmove",h.touchHandler,!1),o.removeEventListener("touchend",h.touchHandler,!1)),l=d=f=p=null},e.scrollify.update=function(){r.handleResize()},e.scrollify.current=function(){return f[m]}}(jQuery,this,document);
/**
 * jQuery prettySocial: Use custom social share buttons
 * Author: Sonny T. <hi@sonnyt.com>, sonnyt.com
 */(function(a){a.fn.prettySocial=function(){var b={pinterest:{url:"http://pinterest.com/pin/create/button/?url={{url}}&media={{media}}&description={{description}}",popup:{width:685,height:500}},facebook:{url:"https://www.facebook.com/sharer/sharer.php?s=100&p[title]={{title}}&p[summary]={{description}}&p[url]={{url}}&p[images][0]={{media}}",popup:{width:626,height:436}},twitter:{url:"https://twitter.com/share?url={{url}}&text={{description}}",popup:{width:685,height:500}},googleplus:{url:"https://plus.google.com/share?url={{url}}",popup:{width:600,height:600}},linkedin:{url:"https://www.linkedin.com/shareArticle?mini=true&url={{url}}&title={{title}}&summary={{description}}+&source={{via}}",popup:{width:600,height:600}}},d=function(f,e){var h=(window.innerWidth/2)-(f.popup.width/2),g=(window.innerHeight/2)-(f.popup.height/2);return window.open(e,"","toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width="+f.popup.width+", height="+f.popup.height+", top="+g+", left="+h)},c=function(f,g){var e=f.url.replace(/{{url}}/g,encodeURIComponent(g.url)).replace(/{{title}}/g,encodeURIComponent(g.title)).replace(/{{description}}/g,encodeURIComponent(g.description)).replace(/{{media}}/g,encodeURIComponent(g.media)).replace(/{{via}}/g,encodeURIComponent(g.via));return e};return this.each(function(){var i=a(this);var g=i.data("type"),f=b[g]||null;if(!f){a.error("Social site is not set.")}var h={url:i.data("url")||"",title:i.data("title")||"",description:i.data("description")||"",media:i.data("media")||"",via:i.data("via")||""};var e=c(f,h);if(navigator.userAgent.match(/Android|IEMobile|BlackBerry|iPhone|iPad|iPod|Opera Mini/i)){i.bind("touchstart",function(j){if(j.originalEvent.touches.length>1){return}i.data("touchWithoutScroll",true)}).bind("touchmove",function(){i.data("touchWithoutScroll",false);return}).bind("touchend",function(k){k.preventDefault();var j=i.data("touchWithoutScroll");if(k.originalEvent.touches.length>1||!j){return}d(f,e)})}else{i.bind("click",function(j){j.preventDefault();d(f,e)})}})}})(jQuery); 